; calibs.pro
; Created:     Fri Jul  8 17:30:55 2005 by Moster@sun47
; Last change: Fri Aug  5 14:59:55 2005
;
; PURPOSE:
; provide set of calibrators around a given position
;
; CALLING SEQUENCE:
; calibs
; enter rectascension (hours minutes), eg.: 6 45
; enter declination (deg minutes), eg.: -16 0
; enter distance (deg), eg.: 10
;
; if you like an unformated output (eg. for print), call: calibs, /unformat
;
; the standard output is a txt file in the Output subdirectory
; if you like to specify a different path, call: calibs, /path
; you will be asked to specify the path, enter e.g.: /disk-b/moster/calibs/
; do not forget the slashes at the beginning and in the end!
;
; alternatively you can specify a certain HD-Number, and thus get the information of that star
; call: calibs, /star
; you will be asked to specify the HD-Number, enter e.g.: HD402
;
;
; OUTPUT:
; struct containing name, pos, diam, position, distance, spectral type, magnitude, flux, simbad remark, hipparcos and hr notes


pro calibs, UNFORMAT = unformat, PATH = path, STAR = star

  caldb = [ $
{ name: "HD402"          , baynum: ""              , hrnum: "HR18"          , flamnum: ""                 , saonum: "SAO147103"   , ppmnum: "PPM208398"   , varname: "V* CF Cet"   , hipnum: "HIP696"      , starname: ""                , alphah:  0.0 , alpham:  8.0 , alphas:  33.5 , plusmin:  -1 , deltag:  17.0 , deltam: 34.0 , deltas: 41.4  , orig: "iras"	   , spectype: "M0/M1IIICNp" , parallax:     2.42  , parerr:	 0.79  , promot: " PROMOT      0  -0.02" , vmag:   6.13  , hmag:   2.06  , irastwelvemu:     6.77  , qual:   3  , ftwelve:    0.00  , ones:  0.0  , diam:   2.16  , errdiam:  0.07  , simrem: "Variable Star	   " , hvartype: "U"	  , multflag: ""  , compid: ""      , theta:	 0 , rho:   0.00 , compmagdiff: 0.00 , notes: "P" , hdnotes: "" , hdmoent: ""  , hdmcoment: "" },$
{ name: "HD496"          , baynum: "eps Phe"       , hrnum: "HR25"          , flamnum: ""                 , saonum: "SAO214983"   , ppmnum: "PPM304618"   , varname: ""            , hipnum: "HIP765"      , starname: ""                , alphah:  0.0 , alpham:  9.0 , alphas: 24.64 , plusmin:  -1 , deltag:  45.0 , deltam: 44.0 , deltas: 50.7  , orig: "msx"	   , spectype: "K0III"       , parallax:    23.28  , parerr:	 0.98  , promot: " PROMOT   0.13  -0.18" , vmag:   3.88  , hmag:   1.66  , irastwelvemu:     0.00  , qual:   0  , ftwelve:    7.08  , ones:  3.4  , diam:   2.17  , errdiam:  0.06  , simrem: "High proper-motion Star     " , hvartype: ""	 , multflag: "X"  , compid: ""      , theta:	 0 , rho:   0.00 , compmagdiff: 0.00 , notes: ""  , hdnotes: "" , hdmoent: ""  , hdmcoment: "" },$ 
{ name: "HD598"          , baynum: ""              , hrnum: ""              , flamnum: ""                 , saonum: "SAO73785"    , ppmnum: "PPM89472"    , varname: "V* NO Peg"   , hipnum: "HIP852"      , starname: ""                , alphah:  0.0 , alpham: 10.0 , alphas: 26.76 , plusmin:  +1 , deltag:  28.0 , deltam: 39.0 , deltas: 10.4  , orig: "iras"	   , spectype: "M..."	     , parallax:     3.65  , parerr:	 0.87  , promot: " PROMOT      0      0" , vmag:   7.19  , hmag:   1.96  , irastwelvemu:     7.65  , qual:   3  , ftwelve:    0.00  , ones:  0.0  , diam:   2.56  , errdiam:  0.11  , simrem: "Variable of BY Dra type     " , hvartype: "U"	  , multflag: ""  , compid: ""      , theta:	 0 , rho:   0.00 , compmagdiff: 0.00 , notes: "P" , hdnotes: "" , hdmoent: ""  , hdmcoment: "" },$ 
{ name: "HD1014"         , baynum: ""              , hrnum: "HR46"          , flamnum: ""                 , saonum: "SAO128655"   , ppmnum: "PPM182013"   , varname: "V* AD Cet"   , hipnum: "HIP1158"     , starname: ""                , alphah:  0.0 , alpham: 14.0 , alphas: 27.63 , plusmin:  -1 , deltag:   7.0 , deltam: 46.0 , deltas: 49.9  , orig: "iras"	   , spectype: "M3III"       , parallax:     5.21  , parerr:	 0.79  , promot: " PROMOT   0.05   0.01" , vmag:   5.17  , hmag:    0.7  , irastwelvemu:    21.96  , qual:   3  , ftwelve:    0.00  , ones:  0.0  , diam:   4.49  , errdiam:  0.07  , simrem: "Variable Star	   " , hvartype: "U"	  , multflag: ""  , compid: ""      , theta:	 0 , rho:   0.00 , compmagdiff: 0.00 , notes: "P" , hdnotes: "" , hdmoent: ""  , hdmcoment: "" },$
{ name: "HD1038"         , baynum: ""              , hrnum: "HR48"          , flamnum: "FL 7 Cet"         , saonum: "SAO147169"   , ppmnum: "PPM208536"   , varname: "V* AE Cet"   , hipnum: "HIP1170"     , starname: ""                , alphah:  0.0 , alpham: 14.0 , alphas: 38.42 , plusmin:  -1 , deltag:  18.0 , deltam: 55.0 , deltas: 58.3  , orig: "iras"	   , spectype: "M1III"       , parallax:     6.62  , parerr:	 0.82  , promot: " PROMOT  -0.03  -0.06" , vmag:   4.44  , hmag:   0.37  , irastwelvemu:    29.61  , qual:   3  , ftwelve:    0.00  , ones:  0.0  , diam:   4.65  , errdiam:  0.07  , simrem: "Variable Star	   " , hvartype: "U"	  , multflag: ""  , compid: ""      , theta:	 0 , rho:   0.00 , compmagdiff: 0.00 , notes: "P" , hdnotes: "" , hdmoent: ""  , hdmcoment: "" },$
{ name: "HD1522"         , baynum: "iot Cet"       , hrnum: "HR74"          , flamnum: "FL 8 Cet"         , saonum: "SAO128694"   , ppmnum: "PPM182115"   , varname: ""            , hipnum: "HIP1562"     , starname: ""                , alphah:  0.0 , alpham: 19.0 , alphas: 25.67 , plusmin:  -1 , deltag:   8.0 , deltam: 49.0 , deltas: 26.1  , orig: "iras"	   , spectype: "K1.5III"     , parallax:    11.26  , parerr:	 0.73  , promot: " PROMOT  -0.02  -0.03" , vmag:   3.56  , hmag:   1.03  , irastwelvemu:    13.14  , qual:   3  , ftwelve:    0.00  , ones:  0.0  , diam:   3.21  , errdiam:  0.07  , simrem: "Variable Star	   " , hvartype: "M"	  , multflag: ""  , compid: ""      , theta:	 0 , rho:   0.00 , compmagdiff: 0.00 , notes: ""  , hdnotes: "" , hdmoent: ""  , hdmcoment: "" },$
{ name: "HD1632"         , baynum: ""              , hrnum: "HR79"          , flamnum: ""                 , saonum: "SAO 53825"   , ppmnum: "PPM65218"    , varname: ""            , hipnum: "HIP1657"     , starname: ""                , alphah:  0.0 , alpham: 20.0 , alphas: 45.52 , plusmin:  +1 , deltag:  32.0 , deltam: 54.0 , deltas: 40.3  , orig: "iras"	   , spectype: "K5III"       , parallax:     5.05  , parerr:	 0.87  , promot: " PROMOT  -0.03  -0.01" , vmag:   5.82  , hmag:   1.98  , irastwelvemu:     6.35  , qual:   3  , ftwelve:    0.00  , ones:  0.0  , diam:   2.36  , errdiam:  0.16  , simrem: "Star	    " , hvartype: "U"	   , multflag: ""  , compid: ""      , theta:	  0 , rho:   0.00 , compmagdiff: 0.00 , notes: ""  , hdnotes: "" , hdmoent: "Y" , hdmcoment: "" },$
{ name: "HD2024"         , baynum: ""              , hrnum: ""              , flamnum: ""                 , saonum: "SAO128744"   , ppmnum: "PPM182219"   , varname: "V* CE Psc"   , hipnum: "HIP1941"     , starname: ""                , alphah:  0.0 , alpham: 24.0 , alphas:  32.9 , plusmin:  -1 , deltag:   4.0 , deltam: 38.0 , deltas: 52.0  , orig: "iras"	   , spectype: "M..."	     , parallax:     1.48  , parerr:	 0.99  , promot: " PROMOT  -0.01  -0.01" , vmag:   7.63  , hmag:   2.28  , irastwelvemu:     5.85  , qual:   3  , ftwelve:    0.00  , ones:  0.0  , diam:   2.21  , errdiam:  0.07  , simrem: "Variable of BY Dra type     " , hvartype: "U"	  , multflag: ""  , compid: ""      , theta:	 0 , rho:   0.00 , compmagdiff: 0.00 , notes: "P" , hdnotes: "" , hdmoent: ""  , hdmcoment: "" },$ 
{ name: "HD2151"         , baynum: "bet Hyi"       , hrnum: "HR98 "         , flamnum: ""                 , saonum: "SAO255670"   , ppmnum: "PPM366918"   , varname: ""            , hipnum: "HIP2021"     , starname: ""                , alphah:  0.0 , alpham: 25.0 , alphas: 45.07 , plusmin:  -1 , deltag:  77.0 , deltam: 15.0 , deltas: 15.3  , orig: "iras"	   , spectype: "G2IV"	     , parallax:   133.78  , parerr:	 0.51  , promot: " PROMOT   2.22   0.33" , vmag:    2.8  , hmag:   1.38  , irastwelvemu:     8.46  , qual:   3  , ftwelve:    0.00  , ones:  0.0  , diam:   2.14  , errdiam:  0.01  , simrem: "Variable Star	   " , hvartype: ""	 , multflag: ""  , compid: ""	   , theta:	0 , rho:   0.00 , compmagdiff: 0.00 , notes: ""  , hdnotes: "" , hdmoent: ""  , hdmcoment: "" },$ 
{ name: "HD3627"         , baynum: "del And"       , hrnum: "HR165"         , flamnum: "FL 31 And"        , saonum: "SAO 54058"   , ppmnum: "PPM65514"    , varname: ""            , hipnum: "HIP3092"     , starname: ""                , alphah:  0.0 , alpham: 39.0 , alphas: 19.68 , plusmin:  +1 , deltag:  30.0 , deltam: 51.0 , deltas: 39.7  , orig: "iras"	   , spectype: "K3III"       , parallax:    32.19  , parerr:	 0.68  , promot: " PROMOT   0.09  -0.08" , vmag:   3.28  , hmag:   0.56  , irastwelvemu:    21.77  , qual:   3  , ftwelve:    0.00  , ones:  0.0  , diam:   4.00  , errdiam:  0.04  , simrem: "Spectroscopic binary	  " , hvartype: "C"	 , multflag: ""  , compid: ""	   , theta:	0 , rho:   0.00 , compmagdiff: 0.00 , notes: ""  , hdnotes: "" , hdmoent: ""  , hdmcoment: "" },$ 
{ name: "HD4128"         , baynum: "bet Cet"       , hrnum: "HR188"         , flamnum: "FL 16 Cet"        , saonum: "SAO147420"   , ppmnum: "PPM209214"   , varname: ""            , hipnum: "HIP3419"     , starname: ""                , alphah:  0.0 , alpham: 43.0 , alphas: 35.37 , plusmin:  -1 , deltag:  17.0 , deltam: 59.0 , deltas: 11.8  , orig: "iras"	   , spectype: "K0III"       , parallax:    34.04  , parerr:	 0.82  , promot: " PROMOT   0.23   0.04" , vmag:   2.04  , hmag:  -0.14  , irastwelvemu:    41.33  , qual:   3  , ftwelve:    0.00  , ones:  0.0  , diam:   5.04  , errdiam:  0.07  , simrem: "Variable Star	   " , hvartype: "U"	  , multflag: ""  , compid: ""      , theta:	 0 , rho:   0.00 , compmagdiff: 0.00 , notes: ""  , hdnotes: "" , hdmoent: ""  , hdmcoment: "" },$
{ name: "HD4502"         , baynum: "zet And"       , hrnum: "HR215"         , flamnum: "FL 34 And"        , saonum: "SAO 74267"   , ppmnum: "PPM90149"    , varname: "V* zet And"  , hipnum: "HIP3693"     , starname: ""                , alphah:  0.0 , alpham: 47.0 , alphas: 20.33 , plusmin:  +1 , deltag:  24.0 , deltam: 16.0 , deltas:  1.8  , orig: "iras"	   , spectype: "K1IIe"       , parallax:    17.98  , parerr:	 0.83  , promot: " PROMOT   -0.1  -0.08" , vmag:    4.1  , hmag:   1.59  , irastwelvemu:      8.9  , qual:   3  , ftwelve:    0.00  , ones:  0.0  , diam:   2.31  , errdiam:  0.01  , simrem: "Eclipsing binary of beta Lyr type " , hvartype: "P"	, multflag: ""  , compid: ""	  , theta:     0 , rho:   0.00 , compmagdiff: 0.00 , notes: "P" , hdnotes: "" , hdmoent: ""  , hdmcoment: "" },$ 
{ name: "HD5112"         , baynum: ""              , hrnum: "HR248"         , flamnum: "FL 20 Cet"        , saonum: "SAO129009"   , ppmnum: "PPM174810"   , varname: ""            , hipnum: "HIP4147"     , starname: ""                , alphah:  0.0 , alpham: 53.0 , alphas:  0.49 , plusmin:  -1 , deltag:   1.0 , deltam:  8.0 , deltas: 39.3  , orig: "iras"	   , spectype: "M0III"       , parallax:     6.28  , parerr:	 0.85  , promot: " PROMOT   0.01  -0.01" , vmag:   4.78  , hmag:    1.2  , irastwelvemu:    12.16  , qual:   3  , ftwelve:    0.00  , ones:  0.0  , diam:   3.16  , errdiam:  0.07  , simrem: "Star	    " , hvartype: "M"	   , multflag: ""  , compid: ""      , theta:	  0 , rho:   0.00 , compmagdiff: 0.00 , notes: ""  , hdnotes: "" , hdmoent: ""  , hdmcoment: "" },$ 
{ name: "HD5437"         , baynum: "phi03 Cet"     , hrnum: "HR267"         , flamnum: "FL 22 Cet"        , saonum: "SAO147519"   , ppmnum: "PPM209500"   , varname: ""            , hipnum: "HIP4371"     , starname: ""                , alphah:  0.0 , alpham: 56.0 , alphas:  1.49 , plusmin:  -1 , deltag:  11.0 , deltam: 15.0 , deltas: 59.5  , orig: "iras"	   , spectype: "K4III"       , parallax:     6.24  , parerr:	  0.8  , promot: " PROMOT  -0.03  -0.01" , vmag:   5.36  , hmag:    1.9  , irastwelvemu:     6.56  , qual:   3  , ftwelve:    0.00  , ones:  0.0  , diam:   2.38  , errdiam:  0.07  , simrem: "Star	    " , hvartype: "M"	   , multflag: ""  , compid: ""      , theta:	  0 , rho:   0.00 , compmagdiff: 0.00 , notes: ""  , hdnotes: "" , hdmoent: ""  , hdmcoment: "" },$ 
{ name: "HD6311"         , baynum: ""              , hrnum: "HR304"         , flamnum: ""                 , saonum: "SAO248308"   , ppmnum: "PPM352172"   , varname: "V* CC Tuc"   , hipnum: "HIP4879"     , starname: ""                , alphah:  1.0 , alpham:  2.0 , alphas: 42.91 , plusmin:  -1 , deltag:  65.0 , deltam: 27.0 , deltas: 22.0  , orig: "iras"	   , spectype: "M2III"       , parallax:     4.06  , parerr:	  0.6  , promot: " PROMOT   0.01      0" , vmag:   6.31  , hmag:   1.77  , irastwelvemu:     8.46  , qual:   3  , ftwelve:    0.00  , ones:  0.0  , diam:   2.78  , errdiam:  0.09  , simrem: "Variable Star	   " , hvartype: "U"	  , multflag: ""  , compid: ""      , theta:	 0 , rho:   0.00 , compmagdiff: 0.00 , notes: ""  , hdnotes: "" , hdmoent: ""  , hdmcoment: "" },$ 
{ name: "HD6595"         , baynum: "bet Phe"       , hrnum: "HR322"         , flamnum: ""                 , saonum: "SAO215365"   , ppmnum: "PPM305559"   , varname: ""            , hipnum: "HIP5165"     , starname: ""                , alphah:  1.0 , alpham:  6.0 , alphas:  5.05 , plusmin:  -1 , deltag:  46.0 , deltam: 43.0 , deltas:  6.3  , orig: "iras"	   , spectype: "G8IIIvar"    , parallax:    16.46  , parerr:	22.22  , promot: " PROMOT  -0.04      0" , vmag:   3.32  , hmag:   1.35  , irastwelvemu:     9.65  , qual:   3  , ftwelve:    0.00  , ones:  0.0  , diam:   2.41  , errdiam:  0.06  , simrem: "Variable Star	   " , hvartype: "D"	  , multflag: "X"  , compid: ""      , theta:	  0 , rho:   0.00 , compmagdiff: 0.00 , notes: "G" , hdnotes: "" , hdmoent: ""  , hdmcoment: "" },$ 
{ name: "HD6805"         , baynum: "eta Cet"       , hrnum: "HR334"         , flamnum: "FL 31 Cet"        , saonum: "SAO147632"   , ppmnum: "PPM209790"   , varname: ""            , hipnum: "HIP5364"     , starname: ""                , alphah:  1.0 , alpham:  8.0 , alphas: 35.39 , plusmin:  -1 , deltag:  10.0 , deltam: 10.0 , deltas: 56.2  , orig: "iras"	   , spectype: "K1.5III"     , parallax:    27.73  , parerr:	 0.71  , promot: " PROMOT   0.22  -0.14" , vmag:   3.45  , hmag:   0.99  , irastwelvemu:     14.7  , qual:   3  , ftwelve:    0.00  , ones:  0.0  , diam:    3.2  , errdiam:  0.07  , simrem: "High proper-motion Star     " , hvartype: "C"	  , multflag: ""  , compid: ""      , theta:	 0 , rho:   0.00 , compmagdiff: 0.00 , notes: ""  , hdnotes: "" , hdmoent: ""  , hdmcoment: "" },$ 
{ name: "HD8498"         , baynum: ""              , hrnum: "HR400"         , flamnum: ""                 , saonum: "SAO193090"   , ppmnum: "PPM276984"   , varname: ""            , hipnum: "HIP6502"     , starname: ""                , alphah:  1.0 , alpham: 23.0 , alphas: 30.96 , plusmin:  -1 , deltag:  30.0 , deltam: 56.0 , deltas: 44.2  , orig: "iras"	   , spectype: "K5III"       , parallax:     3.67  , parerr:	 0.71  , promot: " PROMOT  -0.01  -0.04" , vmag:   5.84  , hmag:   1.93  , irastwelvemu:      6.6  , qual:   3  , ftwelve:    0.00  , ones:  0.0  , diam:   2.39  , errdiam:  0.07  , simrem: "Variable Star	   " , hvartype: "U"	  , multflag: ""  , compid: ""      , theta:	 0 , rho:   0.00 , compmagdiff: 0.00 , notes: ""  , hdnotes: "" , hdmoent: ""  , hdmcoment: "" },$ 
{ name: "HD9053"         , baynum: "gam Phe"       , hrnum: "HR429"         , flamnum: ""                 , saonum: "SAO215516"   , ppmnum: "PPM305902"   , varname: "V* gam Phe"  , hipnum: "HIP6867"     , starname: ""                , alphah:  1.0 , alpham: 28.0 , alphas: 21.93 , plusmin:  -1 , deltag:  43.0 , deltam: 19.0 , deltas:  5.6  , orig: "iras"	   , spectype: "M0IIIa..."   , parallax:    13.94  , parerr:	 0.64  , promot: " PROMOT  -0.02   -0.2" , vmag:   3.41  , hmag:  -0.23  , irastwelvemu:    48.75  , qual:   3  , ftwelve:    0.00  , ones:  0.0  , diam:   5.91  , errdiam:  0.07  , simrem: "Spectroscopic binary	  " , hvartype: "P"	 , multflag: "O"  , compid: ""      , theta:	 0 , rho:   0.00 , compmagdiff: 0.00 , notes: ""  , hdnotes: "" , hdmoent: ""  , hdmcoment: "Y" },$
{ name: "HD9138"         , baynum: "mu. Psc"       , hrnum: "HR434"         , flamnum: "FL 98 Psc"        , saonum: "SAO109926"   , ppmnum: "PPM144670"   , varname: ""            , hipnum: "HIP7007"     , starname: ""                , alphah:  1.0 , alpham: 30.0 , alphas: 11.12 , plusmin:  +1 , deltag:   6.0 , deltam:  8.0 , deltas: 37.8  , orig: "iras"	   , spectype: "K4III"       , parallax:     9.05  , parerr:	 0.73  , promot: " PROMOT   0.29  -0.04" , vmag:   4.84  , hmag:   1.69  , irastwelvemu:     7.63  , qual:   3  , ftwelve:    0.00  , ones:  0.0  , diam:   2.43  , errdiam:  0.06  , simrem: "High proper-motion Star     " , hvartype: "M"	  , multflag: ""  , compid: ""      , theta:	 0 , rho:   0.00 , compmagdiff: 0.00 , notes: ""  , hdnotes: "" , hdmoent: ""  , hdmcoment: "" },$ 
{ name: "HD9362"         , baynum: "del Phe"       , hrnum: "HR440"         , flamnum: ""                 , saonum: "SAO215536"   , ppmnum: "PPM305952"   , varname: ""            , hipnum: "HIP7083"     , starname: ""                , alphah:  1.0 , alpham: 31.0 , alphas:  15.1 , plusmin:  -1 , deltag:  49.0 , deltam:  4.0 , deltas: 21.7  , orig: "iras"	   , spectype: "G9III"       , parallax:    22.15  , parerr:	 0.61  , promot: " PROMOT   0.14   0.16" , vmag:   3.95  , hmag:   1.72  , irastwelvemu:     6.64  , qual:   3  , ftwelve:    0.00  , ones:  0.0  , diam:    2.1  , errdiam:  0.05  , simrem: "High proper-motion Star     " , hvartype: ""	 , multflag: ""  , compid: ""	   , theta:	0 , rho:   0.00 , compmagdiff: 0.00 , notes: ""  , hdnotes: "" , hdmoent: ""  , hdmcoment: "" },$
{ name: "HD10052"        , baynum: ""              , hrnum: "HR468"         , flamnum: ""                 , saonum: "SAO232477"   , ppmnum: "PPM331188"   , varname: ""            , hipnum: "HIP7506"     , starname: ""                , alphah:  1.0 , alpham: 36.0 , alphas:  44.8 , plusmin:  -1 , deltag:  58.0 , deltam: 16.0 , deltas: 15.5  , orig: "msx"	   , spectype: "M3III"       , parallax:     4.05  , parerr:	 0.57  , promot: " PROMOT   0.02   0.01" , vmag:   6.22  , hmag:   1.65  , irastwelvemu:     0.00  , qual:   0  , ftwelve:    9.41  , ones:  3.2  , diam:   2.91  , errdiam:  0.16  , simrem: "Variable Star	   " , hvartype: "U"	  , multflag: ""  , compid: ""      , theta:	 0 , rho:   0.00 , compmagdiff: 0.00 , notes: ""  , hdnotes: "" , hdmoent: ""  , hdmcoment: "" },$ 
{ name: "HD10144"        , baynum: "alf Eri"       , hrnum: "HR472"         , flamnum: ""                 , saonum: "SAO232481"   , ppmnum: "PPM331199"   , varname: ""            , hipnum: "HIP7588"     , starname: "ACHERNAR"        , alphah:  1.0 , alpham: 37.0 , alphas: 42.85 , plusmin:  -1 , deltag:  57.0 , deltam: 14.0 , deltas: 12.3  , orig: "iras"	   , spectype: "B3Vpe"       , parallax:    22.68  , parerr:	 0.57  , promot: " PROMOT    0.1  -0.03" , vmag:    0.5  , hmag:   0.83  , irastwelvemu:    11.41  , qual:   3  , ftwelve:    0.00  , ones:  0.0  , diam:   1.62  , errdiam:  0.08  , simrem: "Emission-line Star      " , hvartype: "U"      , multflag: "G"  , compid: ""	 , theta:     0 , rho:   0.00 , compmagdiff: 0.00 , notes: "P" , hdnotes: "" , hdmoent: ""  , hdmcoment: "" },$ 
{ name: "HD10380"        , baynum: "nu. Psc"       , hrnum: "HR489"         , flamnum: "FL 106 Psc"       , saonum: "SAO110065"   , ppmnum: "PPM144883"   , varname: ""            , hipnum: "HIP7884"     , starname: ""                , alphah:  1.0 , alpham: 41.0 , alphas: 25.89 , plusmin:  +1 , deltag:   5.0 , deltam: 29.0 , deltas: 15.4  , orig: "iras"	   , spectype: "K3IIIb"      , parallax:     8.86  , parerr:	 0.77  , promot: " PROMOT  -0.02   0.01" , vmag:   4.45  , hmag:   1.38  , irastwelvemu:     9.89  , qual:   3  , ftwelve:    0.00  , ones:  0.0  , diam:   2.85  , errdiam:  0.06  , simrem: "Star	    " , hvartype: ""	  , multflag: ""  , compid: ""      , theta:	 0 , rho:   0.00 , compmagdiff: 0.00 , notes: ""  , hdnotes: "" , hdmoent: ""  , hdmcoment: "" },$ 
{ name: "HD10550"        , baynum: ""              , hrnum: "HR500"         , flamnum: ""                 , saonum: "SAO129465"   , ppmnum: "PPM183757"   , varname: ""            , hipnum: "HIP7999"     , starname: ""                , alphah:  1.0 , alpham: 42.0 , alphas: 43.51 , plusmin:  -1 , deltag:   3.0 , deltam: 41.0 , deltas: 24.7  , orig: "iras"	   , spectype: "K3III"       , parallax:     2.71  , parerr:	  0.9  , promot: " PROMOT  -0.01  -0.03" , vmag:  5.00   , hmag:   2.15  , irastwelvemu:      5.2  , qual:   3  , ftwelve:    0.00  , ones:  0.0  , diam:   2.04  , errdiam:  0.07  , simrem: "Variable Star	   " , hvartype: ""	 , multflag: ""  , compid: ""	   , theta:	0 , rho:   0.00 , compmagdiff: 0.00 , notes: ""  , hdnotes: "" , hdmoent: ""  , hdmcoment: "" },$ 
{ name: "HD10700"        , baynum: "tau Cet"       , hrnum: "HR509"         , flamnum: "FL 52 Cet"        , saonum: "SAO147986"   , ppmnum: "PPM210580"   , varname: ""            , hipnum: "HIP8102"     , starname: ""                , alphah:  1.0 , alpham: 44.0 , alphas:  4.08 , plusmin:  -1 , deltag:  15.0 , deltam: 56.0 , deltas: 14.9  , orig: "iras"	   , spectype: "G8V"	     , parallax:   274.18  , parerr:	  0.8  , promot: " PROMOT  -1.72   0.86" , vmag:    3.5  , hmag:   1.75  , irastwelvemu:     6.59  , qual:   3  , ftwelve:    0.00  , ones:  0.0  , diam:   1.94  , errdiam:  0.02  , simrem: "High proper-motion Star     " , hvartype: ""	 , multflag: ""  , compid: ""	   , theta:	0 , rho:   0.00 , compmagdiff: 0.00 , notes: ""  , hdnotes: "" , hdmoent: ""  , hdmcoment: "" },$ 
{ name: "HD10824"        , baynum: ""              , hrnum: "HR513"         , flamnum: ""                 , saonum: "SAO129490"   , ppmnum: "PPM183822"   , varname: ""            , hipnum: "HIP8230"     , starname: ""                , alphah:  1.0 , alpham: 45.0 , alphas: 59.26 , plusmin:  -1 , deltag:   5.0 , deltam: 43.0 , deltas: 59.9  , orig: "iras"	   , spectype: "K4III"       , parallax:      6.4  , parerr:	 0.78  , promot: " PROMOT  -0.02  -0.03" , vmag:   5.34  , hmag:   1.93  , irastwelvemu:     6.02  , qual:   3  , ftwelve:    0.00  , ones:  0.0  , diam:   2.35  , errdiam:  0.07  , simrem: "Star	    " , hvartype: "M"	   , multflag: ""  , compid: ""      , theta:	  0 , rho:   0.00 , compmagdiff: 0.00 , notes: ""  , hdnotes: "" , hdmoent: ""  , hdmcoment: "" },$ 
{ name: "HD11353"        , baynum: "zet Cet"       , hrnum: "HR539"         , flamnum: "FL 55 Cet"        , saonum: "SAO148059"   , ppmnum: "PPM210734"   , varname: ""            , hipnum: "HIP8645"     , starname: ""                , alphah:  1.0 , alpham: 51.0 , alphas: 27.63 , plusmin:  -1 , deltag:  10.0 , deltam: 20.0 , deltas:  6.1  , orig: "iras"	   , spectype: "K0III"       , parallax:    12.59  , parerr:	 0.85  , promot: " PROMOT   0.04  -0.04" , vmag:   3.74  , hmag:   1.31  , irastwelvemu:     10.1  , qual:   3  , ftwelve:    0.00  , ones:  0.0  , diam:    2.7  , errdiam:  0.07  , simrem: "Spectroscopic binary	  " , hvartype: "C"	 , multflag: "G"  , compid: ""      , theta:	 0 , rho:   0.00 , compmagdiff: 0.00 , notes: ""  , hdnotes: "" , hdmoent: ""  , hdmcoment: "" },$ 
{ name: "HD11937"        , baynum: "chi Eri"       , hrnum: "HR566"         , flamnum: ""                 , saonum: "SAO232573"   , ppmnum: "PPM331456"   , varname: ""            , hipnum: "HIP9007"     , starname: ""                , alphah:  1.0 , alpham: 55.0 , alphas: 57.47 , plusmin:  -1 , deltag:  51.0 , deltam: 36.0 , deltas: 32.0  , orig: "iras"	   , spectype: "G8IIIbCNvar" , parallax:    57.19  , parerr:	 0.62  , promot: " PROMOT   0.68   0.28" , vmag:    3.7  , hmag:   1.76  , irastwelvemu:     6.97  , qual:   3  , ftwelve:    0.00  , ones:  0.0  , diam:   2.01  , errdiam:  0.02  , simrem: "Variable Star	   " , hvartype: "U"	  , multflag: "G"  , compid: ""      , theta:	  0 , rho:   0.00 , compmagdiff: 0.00 , notes: ""  , hdnotes: "" , hdmoent: ""  , hdmcoment: "" },$
{ name: "HD11961"        , baynum: ""              , hrnum: ""              , flamnum: ""                 , saonum: "SAO 55147"   , ppmnum: "PPM66820"    , varname: "V* AA Tri"   , hipnum: "HIP9171"     , starname: ""                , alphah:  1.0 , alpham: 58.0 , alphas:  3.77 , plusmin:  +1 , deltag:  31.0 , deltam:  8.0 , deltas:  3.8  , orig: "iras"	   , spectype: "M3"	     , parallax:      5.8  , parerr:	 0.93  , promot: " PROMOT  -0.05  -0.04" , vmag:   7.02  , hmag:   0.42  , irastwelvemu:    31.81  , qual:   3  , ftwelve:    0.00  , ones:  0.0  , diam:   5.41  , errdiam:  0.11  , simrem: "Variable of BY Dra type     " , hvartype: "U"	  , multflag: ""  , compid: ""      , theta:	 0 , rho:   0.00 , compmagdiff: 0.00 , notes: "P" , hdnotes: "" , hdmoent: ""  , hdmcoment: "" },$
{ name: "HD12076"        , baynum: ""              , hrnum: ""              , flamnum: ""                 , saonum: "SAO129596"   , ppmnum: "PPM184081"   , varname: ""            , hipnum: ""            , starname: ""                , alphah:  1.0 , alpham: 58.0 , alphas: 27.68 , plusmin:  -1 , deltag:   7.0 , deltam:  4.0 , deltas: 42.1  , orig: "iras"	   , spectype: "M0"	     , parallax:     0.00  , parerr:	 0.00  , promot: " PROMOT   0.01   0.02" , vmag:   6.89  , hmag:   2.28  , irastwelvemu:     5.43  , qual:   3  , ftwelve:    0.00  , ones:  0.0  , diam:   2.18  , errdiam:  0.07  , simrem: "Star	    " , hvartype: ""	  , multflag: ""  , compid: ""      , theta:	 0 , rho:   0.00 , compmagdiff: 0.00 , notes: ""  , hdnotes: "" , hdmoent: ""  , hdmcoment: "" },$ 
{ name: "HD12524"        , baynum: "chi Phe"       , hrnum: "HR602"         , flamnum: ""                 , saonum: "SAO215739"   , ppmnum: "PPM306389"   , varname: ""            , hipnum: "HIP9459 "    , starname: ""                , alphah:  2.0 , alpham:  1.0 , alphas: 42.38 , plusmin:  -1 , deltag:  44.0 , deltam: 42.0 , deltas: 48.6  , orig: "iras"	   , spectype: "K5III"       , parallax:     8.76  , parerr:	 0.64  , promot: " PROMOT  -0.03  -0.04" , vmag:   5.16  , hmag:   1.67  , irastwelvemu:     8.71  , qual:   3  , ftwelve:    0.00  , ones:  0.0  , diam:   2.53  , errdiam:  0.07  , simrem: "Star	    " , hvartype: ""	  , multflag: ""  , compid: ""      , theta:	 0 , rho:   0.00 , compmagdiff: 0.00 , notes: ""  , hdnotes: "" , hdmoent: ""  , hdmcoment: "" },$ 
{ name: "HD13325"        , baynum: ""              , hrnum: "HR631"         , flamnum: "FL 15 Ari"        , saonum: "SAO 92822"   , ppmnum: "PPM118003"   , varname: "V* AV Ari"   , hipnum: "HIP10155"    , starname: ""                , alphah:  2.0 , alpham: 10.0 , alphas:  37.6 , plusmin:  +1 , deltag:  19.0 , deltam: 30.0 , deltas:  1.2  , orig: "iras"	   , spectype: "M3III"       , parallax:      4.9  , parerr:	 0.86  , promot: " PROMOT   0.09  -0.02" , vmag:   5.72  , hmag:   1.13  , irastwelvemu:    15.31  , qual:   3  , ftwelve:    0.00  , ones:  0.0  , diam:   3.69  , errdiam:  0.26  , simrem: "Variable Star	   " , hvartype: "P"	  , multflag: ""  , compid: ""      , theta:	 0 , rho:   0.00 , compmagdiff: 0.00 , notes: "P" , hdnotes: "" , hdmoent: ""  , hdmcoment: "" },$ 
{ name: "HD13596"        , baynum: ""              , hrnum: "HR648"         , flamnum: "FL 19 Ari"        , saonum: "SAO 92841"   , ppmnum: "PPM118039"   , varname: ""            , hipnum: "HIP10328"    , starname: ""                , alphah:  2.0 , alpham: 13.0 , alphas:  3.31 , plusmin:  +1 , deltag:  15.0 , deltam: 16.0 , deltas: 47.5  , orig: "iras"	   , spectype: "M0III"       , parallax:     6.03  , parerr:	 0.75  , promot: " PROMOT    0.1  -0.02" , vmag:   5.73  , hmag:   2.01  , irastwelvemu:     6.25  , qual:   3  , ftwelve:    0.00  , ones:  0.0  , diam:   2.17  , errdiam:  0.16  , simrem: "Variable Star	   " , hvartype: "M"	  , multflag: ""  , compid: ""      , theta:	 0 , rho:   0.00 , compmagdiff: 0.00 , notes: ""  , hdnotes: "" , hdmoent: ""  , hdmcoment: "" },$ 
{ name: "HD14512"        , baynum: ""              , hrnum: ""              , flamnum: ""                 , saonum: "SAO 75300"   , ppmnum: "PPM91589"    , varname: "V* AE Ari"   , hipnum: "HIP10964"    , starname: ""                , alphah:  2.0 , alpham: 21.0 , alphas: 14.49 , plusmin:  +1 , deltag:  23.0 , deltam: 25.0 , deltas: 35.8  , orig: "iras"	   , spectype: "M5"	     , parallax:     1.84  , parerr:	 0.95  , promot: " PROMOT   0.01  -0.01" , vmag:   7.56  , hmag:   1.91  , irastwelvemu:      7.9  , qual:   3  , ftwelve:    0.00  , ones:  0.0  , diam:   2.69  , errdiam:  0.28  , simrem: "Variable of BY Dra type     " , hvartype: "U"	  , multflag: ""  , compid: ""      , theta:	 0 , rho:   0.00 , compmagdiff: 0.00 , notes: ""  , hdnotes: "" , hdmoent: ""  , hdmcoment: "" },$ 
{ name: "HD16815"        , baynum: "iot Eri"       , hrnum: "HR794"         , flamnum: ""                 , saonum: "SAO215999"   , ppmnum: "PPM278212"   , varname: ""            , hipnum: "HIP12486"    , starname: ""                , alphah:  2.0 , alpham: 40.0 , alphas: 40.03 , plusmin:  -1 , deltag:  39.0 , deltam: 51.0 , deltas: 19.4  , orig: "iras"	   , spectype: "K0III"       , parallax:    22.42  , parerr:	 0.57  , promot: " PROMOT   0.13  -0.03" , vmag:   4.12  , hmag:   1.78  , irastwelvemu:     6.59  , qual:   3  , ftwelve:    0.00  , ones:  0.0  , diam:   2.21  , errdiam:  0.04  , simrem: "Star	    " , hvartype: ""	  , multflag: ""  , compid: ""      , theta:	 0 , rho:   0.00 , compmagdiff: 0.00 , notes: ""  , hdnotes: "" , hdmoent: ""  , hdmcoment: "" },$ 
{ name: "HD17709"        , baynum: ""              , hrnum: "HR843"         , flamnum: "FL 17 Per"        , saonum: "SAO 55946"   , ppmnum: "PPM67840"    , varname: ""            , hipnum: "HIP13328"    , starname: ""                , alphah:  2.0 , alpham: 51.0 , alphas: 30.84 , plusmin:  +1 , deltag:  35.0 , deltam:  3.0 , deltas: 35.1  , orig: "iras"	   , spectype: "K5III"       , parallax:     7.97  , parerr:	  1.1  , promot: " PROMOT   0.02  -0.06" , vmag:   4.56  , hmag:   0.89  , irastwelvemu:    15.93  , qual:   3  , ftwelve:    0.00  , ones:  0.0  , diam:   3.81  , errdiam:  0.09  , simrem: "Variable Star	   " , hvartype: "U"	  , multflag: ""  , compid: ""      , theta:	 0 , rho:   0.00 , compmagdiff: 0.00 , notes: ""  , hdnotes: "" , hdmoent: "Y" , hdmcoment: "" },$ 
{ name: "HD18322"        , baynum: "eta Eri"       , hrnum: "HR874"         , flamnum: "FL 3 Eri"         , saonum: "SAO130197"   , ppmnum: "PPM185202"   , varname: ""            , hipnum: "HIP13701"    , starname: ""                , alphah:  2.0 , alpham: 56.0 , alphas: 25.65 , plusmin:  -1 , deltag:   8.0 , deltam: 53.0 , deltas: 53.3  , orig: "iras"	   , spectype: "K1III"       , parallax:    24.49  , parerr:	 0.72  , promot: " PROMOT   0.07  -0.22" , vmag:   3.89  , hmag:   1.47  , irastwelvemu:     9.14  , qual:   3  , ftwelve:    0.00  , ones:  0.0  , diam:    2.4  , errdiam:  0.04  , simrem: "Variable Star	   " , hvartype: ""	 , multflag: ""  , compid: ""	   , theta:	0 , rho:   0.00 , compmagdiff: 0.00 , notes: ""  , hdnotes: "" , hdmoent: ""  , hdmcoment: "" },$ 
{ name: "HD18700"        , baynum: ""              , hrnum: "HR902"         , flamnum: ""                 , saonum: "SAO 93232"   , ppmnum: "PPM118745"   , varname: ""            , hipnum: "HIP14036"    , starname: ""                , alphah:  3.0 , alpham:  0.0 , alphas: 44.14 , plusmin:  +1 , deltag:  10.0 , deltam: 52.0 , deltas: 13.4  , orig: "iras"	   , spectype: "K6"	     , parallax:     7.39  , parerr:	 0.82  , promot: " PROMOT   0.08  -0.03" , vmag:   5.96  , hmag:   2.12  , irastwelvemu:     5.86  , qual:   3  , ftwelve:    0.00  , ones:  0.0  , diam:   2.18  , errdiam:  0.05  , simrem: "Star	    " , hvartype: "M"	   , multflag: ""  , compid: ""      , theta:	  0 , rho:   0.00 , compmagdiff: 0.00 , notes: ""  , hdnotes: "" , hdmoent: ""  , hdmcoment: "" },$ 
{ name: "HD18884"        , baynum: "alf Cet"       , hrnum: "HR911"         , flamnum: "FL 92 Cet"        , saonum: "SAO110920"   , ppmnum: "PPM146172"   , varname: "V* alf Cet"  , hipnum: "HIP14135"    , starname: "MENKAR"          , alphah:  3.0 , alpham:  2.0 , alphas: 16.77 , plusmin:  +1 , deltag:   4.0 , deltam:  5.0 , deltas: 23.0  , orig: "iras"	   , spectype: "M1.5IIIa"    , parallax:    14.82  , parerr:	 0.83  , promot: " PROMOT  -0.01  -0.07" , vmag:   2.56  , hmag:   -1.5  , irastwelvemu:   163.63  , qual:   3  , ftwelve:    0.00  , ones:  0.0  , diam:  11.02  , errdiam:  0.04  , simrem: "Variable Star	   " , hvartype: "U"	  , multflag: ""  , compid: ""      , theta:	 0 , rho:   0.00 , compmagdiff: 0.00 , notes: "P" , hdnotes: "" , hdmoent: ""  , hdmcoment: "" },$ 
{ name: "HD20720"        , baynum: "tau04 Eri"     , hrnum: "HR1003"        , flamnum: "FL 16 Eri"        , saonum: "SAO168460"   , ppmnum: "PPM246096"   , varname: "V* tau04 Er" , hipnum: "HIP15474"    , starname: ""                , alphah:  3.0 , alpham: 19.0 , alphas: 31.00 , plusmin:  -1 , deltag:  21.0 , deltam: 45.0 , deltas: 28.3  , orig: "iras"	   , spectype: "M3/M4III"    , parallax:    12.63  , parerr:	 0.89  , promot: " PROMOT   0.05   0.04" , vmag:   3.66  , hmag:  -0.97  , irastwelvemu:   112.76  , qual:   3  , ftwelve:    0.00  , ones:  0.0  , diam:  10.03  , errdiam:   0.1  , simrem: "Variable Star	   " , hvartype: "U"	  , multflag: "V"  , compid: ""      , theta:	  0 , rho:   0.00 , compmagdiff: 0.00 , notes: "P" , hdnotes: "" , hdmoent: ""  , hdmcoment: "" },$ 
{ name: "HD20644"        , baynum: ""              , hrnum: "HR999"         , flamnum: ""                 , saonum: "SAO 75871"   , ppmnum: "PPM92402"    , varname: ""            , hipnum: "HIP15549"    , starname: ""                , alphah:  3.0 , alpham: 20.0 , alphas: 20.36 , plusmin:  +1 , deltag:  29.0 , deltam:  2.0 , deltas: 54.5  , orig: "iras"	   , spectype: "K4III"       , parallax:     5.09  , parerr:	  0.9  , promot: " PROMOT      0  -0.01" , vmag:   4.47  , hmag:   0.99  , irastwelvemu:    14.69  , qual:   3  , ftwelve:    0.00  , ones:  0.0  , diam:   3.62  , errdiam:  0.15  , simrem: "Star	    " , hvartype: "M"	   , multflag: ""  , compid: ""      , theta:	  0 , rho:   0.00 , compmagdiff: 0.00 , notes: ""  , hdnotes: "" , hdmoent: ""  , hdmcoment: "" },$ 
{ name: "HD21120"        , baynum: "omi Tau"       , hrnum: "HR1030"        , flamnum: "FL 1 Tau"         , saonum: "SAO111172"   , ppmnum: "PPM146534"   , varname: ""            , hipnum: "HIP15900"    , starname: ""                , alphah:  3.0 , alpham: 24.0 , alphas: 48.79 , plusmin:  +1 , deltag:   9.0 , deltam:  1.0 , deltas: 43.9  , orig: "iras"	   , spectype: "G6III"       , parallax:    15.42  , parerr:	 1.28  , promot: " PROMOT  -0.07  -0.08" , vmag:   3.62  , hmag:   1.63  , irastwelvemu:     7.32  , qual:   3  , ftwelve:    0.00  , ones:  0.0  , diam:   2.16  , errdiam:  0.01  , simrem: "Spectroscopic binary	  " , hvartype: "C"	 , multflag: "G"  , compid: ""      , theta:	 0 , rho:   0.00 , compmagdiff: 0.00 , notes: ""  , hdnotes: "" , hdmoent: ""  , hdmcoment: "" },$ 
{ name: "HD21754"        , baynum: "f Tau"         , hrnum: "HR1066"        , flamnum: "FL 5 Tau"         , saonum: "SAO 93469"   , ppmnum: "PPM119139"   , varname: ""            , hipnum: "HIP16369"    , starname: ""                , alphah:  3.0 , alpham: 30.0 , alphas: 52.38 , plusmin:  +1 , deltag:  12.0 , deltam: 56.0 , deltas: 12.0  , orig: "iras"	   , spectype: "K0Iab"       , parallax:     9.05  , parerr:	 1.13  , promot: " PROMOT   0.02      0" , vmag:   4.14  , hmag:   1.79  , irastwelvemu:     6.51  , qual:   3  , ftwelve:    0.00  , ones:  0.0  , diam:   2.18  , errdiam:  0.03  , simrem: "Spectroscopic binary	  " , hvartype: "C"	 , multflag: "O"  , compid: ""      , theta:	 0 , rho:   0.00 , compmagdiff: 0.00 , notes: ""  , hdnotes: "" , hdmoent: "Y" , hdmcoment: "Y" },$
{ name: "HD23319"        , baynum: "h Eri"         , hrnum: "HR1143"        , flamnum: ""                 , saonum: "SAO194475"   , ppmnum: "PPM279348"   , varname: ""            , hipnum: "HIP17351"    , starname: ""                , alphah:  3.0 , alpham: 42.0 , alphas: 50.06 , plusmin:  -1 , deltag:  37.0 , deltam: 18.0 , deltas: 48.7  , orig: "iras"	   , spectype: "K2.5III"     , parallax:    18.34  , parerr:	 0.56  , promot: " PROMOT  -0.09  -0.07" , vmag:    4.6  , hmag:   2.11  , irastwelvemu:     5.32  , qual:   3  , ftwelve:    0.00  , ones:  0.0  , diam:    1.9  , errdiam:  0.08  , simrem: "Eclipsing binary      " , hvartype: ""	   , multflag: ""  , compid: ""      , theta:	  0 , rho:   0.00 , compmagdiff: 0.00 , notes: ""  , hdnotes: "" , hdmoent: ""  , hdmcoment: "" },$ 
{ name: "HD23249"        , baynum: "del Eri"       , hrnum: "HR1136"        , flamnum: "FL 23 Eri"        , saonum: "SAO130686"   , ppmnum: "PPM186110"   , varname: "V* del Eri"  , hipnum: "HIP17378"    , starname: ""                , alphah:  3.0 , alpham: 43.0 , alphas:  14.9 , plusmin:  -1 , deltag:   9.0 , deltam: 45.0 , deltas: 48.2  , orig: "iras"	   , spectype: "K0IV"	     , parallax:   110.58  , parerr:	 0.88  , promot: " PROMOT   -0.1   0.75" , vmag:   3.51  , hmag:   1.49  , irastwelvemu:     8.08  , qual:   3  , ftwelve:    0.00  , ones:  0.0  , diam:   2.33  , errdiam:  0.01  , simrem: "Variable of RS CVn type     " , hvartype: "C"	  , multflag: ""  , compid: ""      , theta:	 0 , rho:   0.00 , compmagdiff: 0.00 , notes: ""  , hdnotes: "" , hdmoent: ""  , hdmcoment: "" },$ 
{ name: "HD23817"        , baynum: "bet Ret"       , hrnum: "HR1175"        , flamnum: ""                 , saonum: "SAO248877"   , ppmnum: "PPM353699"   , varname: ""            , hipnum: "HIP17440"    , starname: ""                , alphah:  3.0 , alpham: 44.0 , alphas: 11.98 , plusmin:  -1 , deltag:  64.0 , deltam: 48.0 , deltas: 24.9  , orig: "iras"	   , spectype: "K2III"       , parallax:    32.71  , parerr:	 0.46  , promot: " PROMOT   0.31   0.08" , vmag:   3.85  , hmag:   1.36  , irastwelvemu:     9.64  , qual:   3  , ftwelve:    0.00  , ones:  0.0  , diam:   2.58  , errdiam:  0.04  , simrem: "Spectroscopic binary	  " , hvartype: ""	, multflag: "O"  , compid: ""	   , theta:	0 , rho:   0.00 , compmagdiff: 0.00 , notes: ""  , hdnotes: "" , hdmoent: ""  , hdmcoment: "Y" },$
{ name: "HD25470"        , baynum: ""              , hrnum: "HR1250"        , flamnum: ""                 , saonum: "SAO233354"   , ppmnum: "PPM333123"   , varname: "V* XY Dor"   , hipnum: "HIP18691"    , starname: ""                , alphah:  4.0 , alpham:  0.0 , alphas: 15.53 , plusmin:  -1 , deltag:  51.0 , deltam: 33.0 , deltas: 53.9  , orig: "iras"	   , spectype: "M1III"       , parallax:     2.74  , parerr:	 0.53  , promot: " PROMOT   0.02   0.02" , vmag:   6.52  , hmag:   2.21  , irastwelvemu:     5.28  , qual:   3  , ftwelve:    0.00  , ones:  0.0  , diam:   2.24  , errdiam:  0.14  , simrem: "Variable Star	   " , hvartype: "U"	  , multflag: ""  , compid: ""      , theta:	 0 , rho:   0.00 , compmagdiff: 0.00 , notes: "P" , hdnotes: "" , hdmoent: ""  , hdmcoment: "" },$ 
{ name: "HD25605"        , baynum: ""              , hrnum: ""              , flamnum: ""                 , saonum: "SAO 93747"   , ppmnum: "PPM119590"   , varname: ""            , hipnum: "HIP19003"    , starname: ""                , alphah:  4.0 , alpham:  4.0 , alphas: 18.76 , plusmin:  +1 , deltag:  12.0 , deltam: 30.0 , deltas: 26.8  , orig: "iras"	   , spectype: "M0"	     , parallax:      3.6  , parerr:	 0.97  , promot: " PROMOT   0.05  -0.02" , vmag:   7.47  , hmag:    2.2  , irastwelvemu:      6.2  , qual:   3  , ftwelve:    0.00  , ones:  0.0  , diam:    2.4  , errdiam:  0.62  , simrem: "Variable Star	   " , hvartype: "U"	  , multflag: ""  , compid: ""      , theta:	 0 , rho:   0.00 , compmagdiff: 0.00 , notes: ""  , hdnotes: "" , hdmoent: ""  , hdmcoment: "" },$ 
{ name: "HD25604"        , baynum: "A01 Tau"       , hrnum: "HR1256"        , flamnum: "FL 37 Tau"        , saonum: "SAO 76430"   , ppmnum: "PPM93219"    , varname: ""            , hipnum: "HIP19038"    , starname: ""                , alphah:  4.0 , alpham:  4.0 , alphas: 41.72 , plusmin:  +1 , deltag:  22.0 , deltam:  4.0 , deltas: 54.9  , orig: "iras"	   , spectype: "K0III"       , parallax:    18.04  , parerr:	 0.84  , promot: " PROMOT   0.09  -0.06" , vmag:   4.35  , hmag:   2.07  , irastwelvemu:     5.06  , qual:   3  , ftwelve:    0.00  , ones:  0.0  , diam:   1.88  , errdiam:  0.05  , simrem: "Eclipsing binary      " , hvartype: "C"      , multflag: ""  , compid: ""      , theta:     0 , rho:   0.00 , compmagdiff: 0.00 , notes: ""  , hdnotes: "" , hdmoent: ""  , hdmcoment: "" },$ 
{ name: "HD26967"        , baynum: "alf Hor"       , hrnum: "HR1326"        , flamnum: ""                 , saonum: "SAO216710"   , ppmnum: "PPM308436"   , varname: ""            , hipnum: "HIP19747"    , starname: ""                , alphah:  4.0 , alpham: 13.0 , alphas:  0.11 , plusmin:  -1 , deltag:  42.0 , deltam: 17.0 , deltas: 39.7  , orig: "iras"	   , spectype: "K1III"       , parallax:    27.85  , parerr:	 0.51  , promot: " PROMOT   0.04  -0.21" , vmag:   3.86  , hmag:   1.42  , irastwelvemu:     5.97  , qual:   3  , ftwelve:    0.00  , ones:  0.0  , diam:   2.48  , errdiam:  0.06  , simrem: "High proper-motion Star     " , hvartype: "C"	  , multflag: ""  , compid: ""      , theta:	 0 , rho:   0.00 , compmagdiff: 0.00 , notes: ""  , hdnotes: "" , hdmoent: ""  , hdmcoment: "" },$ 
{ name: "HD27256"        , baynum: "alf Ret"       , hrnum: "HR1336"        , flamnum: ""                 , saonum: "SAO248969"   , ppmnum: "PPM353975"   , varname: ""            , hipnum: "HIP19780"    , starname: ""                , alphah:  4.0 , alpham: 14.0 , alphas: 25.48 , plusmin:  -1 , deltag:  62.0 , deltam: 28.0 , deltas: 25.9  , orig: "iras"	   , spectype: "G8II-III"    , parallax:    19.98  , parerr:	 0.45  , promot: " PROMOT   0.05   0.05" , vmag:   3.34  , hmag:    1.4  , irastwelvemu:     8.91  , qual:   3  , ftwelve:    0.00  , ones:  0.0  , diam:   2.44  , errdiam:  0.06  , simrem: "Eclipsing binary      " , hvartype: "M"      , multflag: ""  , compid: ""      , theta:     0 , rho:   0.00 , compmagdiff: 0.00 , notes: ""  , hdnotes: "" , hdmoent: ""  , hdmcoment: "" },$ 
{ name: "HD27697"        , baynum: "del Tau"       , hrnum: "HR1373"        , flamnum: "FL 61 Tau"        , saonum: "SAO 93897"   , ppmnum: "PPM119835"   , varname: ""            , hipnum: "HIP20455"    , starname: ""                , alphah:  4.0 , alpham: 22.0 , alphas: 56.09 , plusmin:  +1 , deltag:  17.0 , deltam: 32.0 , deltas: 33.0  , orig: "iras"	   , spectype: "K0III"       , parallax:    21.29  , parerr:	 0.93  , promot: " PROMOT   0.11  -0.03" , vmag:   3.76  , hmag:   1.68  , irastwelvemu:     6.99  , qual:   3  , ftwelve:    0.00  , ones:  0.0  , diam:   2.13  , errdiam:  0.04  , simrem: "Spectroscopic binary	  " , hvartype: "C"	 , multflag: ""  , compid: ""	   , theta:	0 , rho:   0.00 , compmagdiff: 0.00 , notes: ""  , hdnotes: "" , hdmoent: ""  , hdmcoment: "" },$ 
{ name: "HD28307"        , baynum: "the01 Tau"     , hrnum: "HR1411"        , flamnum: "FL 77 Tau"        , saonum: "SAO 93955"   , ppmnum: "PPM119933"   , varname: ""            , hipnum: "HIP20885"    , starname: ""                , alphah:  4.0 , alpham: 28.0 , alphas:  34.5 , plusmin:  +1 , deltag:  15.0 , deltam: 57.0 , deltas: 43.9  , orig: "iras"	   , spectype: "K0IIIb"      , parallax:    20.66  , parerr:	 0.85  , promot: " PROMOT    0.1  -0.03" , vmag:   3.85  , hmag:    1.8  , irastwelvemu:     6.79  , qual:   3  , ftwelve:    0.00  , ones:  0.0  , diam:   1.98  , errdiam:  0.06  , simrem: "Eclipsing binary      " , hvartype: ""	   , multflag: ""  , compid: ""      , theta:	  0 , rho:   0.00 , compmagdiff: 0.00 , notes: ""  , hdnotes: "" , hdmoent: ""  , hdmcoment: "" },$ 
{ name: "HD28749"        , baynum: "Eri"           , hrnum: "HR1437"        , flamnum: "FL 45 Eri"        , saonum: "SAO131270"   , ppmnum: "PPM175558"   , varname: ""            , hipnum: "HIP21139"    , starname: ""                , alphah:  4.0 , alpham: 31.0 , alphas: 52.67 , plusmin:  +1 , deltag:   0.0 , deltam:  2.0 , deltas: 38.4  , orig: "iras"	   , spectype: "K3Iab"       , parallax:     3.93  , parerr:	 0.96  , promot: " PROMOT      0  -0.01" , vmag:   4.91  , hmag:    2.1  , irastwelvemu:      5.1  , qual:   3  , ftwelve:    0.00  , ones:  0.0  , diam:   1.96  , errdiam:   0.2  , simrem: "Star	    " , hvartype: ""	  , multflag: ""  , compid: ""      , theta:	 0 , rho:   0.00 , compmagdiff: 0.00 , notes: ""  , hdnotes: "" , hdmoent: ""  , hdmcoment: "" },$ 
{ name: "HD29065"        , baynum: ""              , hrnum: "HR1452"        , flamnum: ""                 , saonum: "SAO131316"   , ppmnum: "PPM187084"   , varname: ""            , hipnum: "HIP21297"    , starname: ""                , alphah:  4.0 , alpham: 34.0 , alphas: 11.77 , plusmin:  -1 , deltag:   8.0 , deltam: 58.0 , deltas: 12.9  , orig: "iras"	   , spectype: "K4III"       , parallax:     4.96  , parerr:	 0.78  , promot: " PROMOT  -0.04  -0.11" , vmag:   5.25  , hmag:   1.94  , irastwelvemu:     6.45  , qual:   3  , ftwelve:    0.00  , ones:  0.0  , diam:   2.29  , errdiam:  0.17  , simrem: "Star	    " , hvartype: "M"	   , multflag: ""  , compid: ""      , theta:	  0 , rho:   0.00 , compmagdiff: 0.00 , notes: ""  , hdnotes: "" , hdmoent: ""  , hdmcoment: "" },$ 
{ name: "HD29051"        , baynum: ""              , hrnum: ""              , flamnum: ""                 , saonum: "SAO 94019"   , ppmnum: "PPM120045"   , varname: ""            , hipnum: "HIP21365"    , starname: ""                , alphah:  4.0 , alpham: 35.0 , alphas:  2.37 , plusmin:  +1 , deltag:  17.0 , deltam: 12.0 , deltas:  4.4  , orig: "iras"	   , spectype: "K5"	     , parallax:     3.33  , parerr:	 0.86  , promot: " PROMOT      0  -0.02" , vmag:   6.82  , hmag:   2.03  , irastwelvemu:     6.79  , qual:   3  , ftwelve:    0.00  , ones:  0.0  , diam:   2.48  , errdiam:  0.37  , simrem: "Star	    " , hvartype: ""	  , multflag: ""  , compid: ""      , theta:	 0 , rho:   0.00 , compmagdiff: 0.00 , notes: ""  , hdnotes: "" , hdmoent: ""  , hdmcoment: "" },$ 
{ name: "HD29139"        , baynum: "alf Tau"       , hrnum: "HR1457"        , flamnum: "FL 87 Tau"        , saonum: "SAO 94027"   , ppmnum: "PPM120061"   , varname: "V* alf Tau"  , hipnum: "HIP21421"    , starname: "ALDEBARAN"       , alphah:  4.0 , alpham: 35.0 , alphas: 55.24 , plusmin:  +1 , deltag:  16.0 , deltam: 30.0 , deltas: 33.5  , orig: "iras"	   , spectype: "K5III"       , parallax:    50.09  , parerr:	 0.95  , promot: " PROMOT   0.07  -0.19" , vmag:   0.85  , hmag:   0.00  , irastwelvemu:   482.55  , qual:   3  , ftwelve:    0.00  , ones:  0.0  , diam:   19.9  , errdiam:  0.02  , simrem: "Variable Star	   " , hvartype: "M"	  , multflag: ""  , compid: ""      , theta:	 0 , rho:   0.00 , compmagdiff: 0.00 , notes: ""  , hdnotes: "" , hdmoent: ""  , hdmcoment: "" },$ 
{ name: "HD29503"        , baynum: "l Eri"         , hrnum: "HR1481"        , flamnum: "FL 53 Eri"        , saonum: "SAO149781"   , ppmnum: "PPM214604"   , varname: ""            , hipnum: "HIP21594"    , starname: ""                , alphah:  4.0 , alpham: 38.0 , alphas: 10.82 , plusmin:  -1 , deltag:  14.0 , deltam: 18.0 , deltas: 14.5  , orig: "iras"	   , spectype: "K1III"       , parallax:    29.84  , parerr:	 0.62  , promot: " PROMOT  -0.07  -0.16" , vmag:   3.85  , hmag:   1.43  , irastwelvemu:      9.7  , qual:   3  , ftwelve:    0.00  , ones:  0.0  , diam:   2.47  , errdiam:  0.07  , simrem: "Double or multiple star     " , hvartype: "D"	  , multflag: "C"  , compid: "AB"      , theta:  343  , rho:  0.81    , compmagdiff:  2.9   , notes: ""  , hdnotes: "" , hdmoent: "Y" , hdmcoment: "" },$ 
{ name: "HD30593"        , baynum: ""              , hrnum: ""              , flamnum: ""                 , saonum: "SAO195295"   , ppmnum: "PPM280672"   , varname: "V* T Cae"    , hipnum: "HIP22247"    , starname: ""                , alphah:  4.0 , alpham: 47.0 , alphas: 18.92 , plusmin:  -1 , deltag:  36.0 , deltam: 12.0 , deltas: 33.6  , orig: "iras"	   , spectype: "CII..."      , parallax:     1.03  , parerr:	 0.76  , promot: " PROMOT   0.05   0.01" , vmag:   7.62  , hmag:   2.71  , irastwelvemu:     9.28  , qual:   3  , ftwelve:    0.00  , ones:  0.0  , diam:   1.89  , errdiam:  0.14  , simrem: "Carbon Star	 " , hvartype: "U"	, multflag: ""  , compid: ""	  , theta:     0 , rho:   0.00 , compmagdiff: 0.00 , notes: "P" , hdnotes: "" , hdmoent: ""  , hdmcoment: "" },$ 
{ name: "HD30354"        , baynum: ""              , hrnum: ""              , flamnum: ""                 , saonum: "SAO 76758"   , ppmnum: "PPM93774"    , varname: ""            , hipnum: "HIP22291"    , starname: ""                , alphah:  4.0 , alpham: 47.0 , alphas: 47.93 , plusmin:  +1 , deltag:  22.0 , deltam:  8.0 , deltas: 21.9  , orig: "iras"	   , spectype: "M2III"       , parallax:     0.00  , parerr:	 0.00  , promot: " PROMOT  -0.02  -0.03" , vmag:   8.47  , hmag:    2.4  , irastwelvemu:     5.41  , qual:   3  , ftwelve:    0.00  , ones:  0.0  , diam:   2.15  , errdiam:  0.07  , simrem: "Star	    " , hvartype: "C"	   , multflag: ""  , compid: ""      , theta:	  0 , rho:   0.00 , compmagdiff: 0.00 , notes: ""  , hdnotes: "" , hdmoent: ""  , hdmcoment: "" },$ 
{ name: "HD31009"        , baynum: ""              , hrnum: ""              , flamnum: ""                 , saonum: "SAO233694"   , ppmnum: "PPM333808"   , varname: "V* XZ Dor"   , hipnum: "HIP22381"    , starname: ""                , alphah:  4.0 , alpham: 49.0 , alphas:  4.75 , plusmin:  -1 , deltag:  56.0 , deltam: 39.0 , deltas: 59.7  , orig: "iras"	   , spectype: "M2III"       , parallax:     2.47  , parerr:	 0.52  , promot: " PROMOT  -0.02   0.02" , vmag:   6.63  , hmag:    2.2  , irastwelvemu:     5.51  , qual:   3  , ftwelve:    0.00  , ones:  0.0  , diam:   2.24  , errdiam:  0.13  , simrem: "Variable Star	   " , hvartype: "U"	  , multflag: ""  , compid: ""      , theta:	 0 , rho:   0.00 , compmagdiff: 0.00 , notes: ""  , hdnotes: "" , hdmoent: ""  , hdmcoment: "" },$ 
{ name: "HD31421"        , baynum: "omi02 Ori"     , hrnum: "HR1580"        , flamnum: "FL 9 Ori"         , saonum: "SAO 94218"   , ppmnum: "PPM120410"   , varname: ""            , hipnum: "HIP22957"    , starname: ""                , alphah:  4.0 , alpham: 56.0 , alphas: 22.27 , plusmin:  +1 , deltag:  13.0 , deltam: 30.0 , deltas: 52.1  , orig: "iras"	   , spectype: "K2IIIb"      , parallax:    19.26  , parerr:	 1.05  , promot: " PROMOT  -0.08  -0.05" , vmag:   4.09  , hmag:   1.45  , irastwelvemu:     9.35  , qual:   3  , ftwelve:    0.00  , ones:  0.0  , diam:   2.49  , errdiam:  0.06  , simrem: "Eclipsing binary      " , hvartype: "C"      , multflag: ""  , compid: ""      , theta:     0 , rho:   0.00 , compmagdiff: 0.00 , notes: ""  , hdnotes: "" , hdmoent: ""  , hdmcoment: "" },$ 
{ name: "HD31398"        , baynum: "iot Aur"       , hrnum: "HR1577"        , flamnum: "FL 3 Aur"         , saonum: "SAO 57522"   , ppmnum: "PPM69775"    , varname: ""            , hipnum: "HIP23015"    , starname: ""                , alphah:  4.0 , alpham: 56.0 , alphas: 59.62 , plusmin:  +1 , deltag:  33.0 , deltam:  9.0 , deltas: 57.9  , orig: "iras"	   , spectype: "K3II"	     , parallax:     6.37  , parerr:	 0.96  , promot: " PROMOT      0  -0.02" , vmag:   2.69  , hmag:   0.00  , irastwelvemu:    60.68  , qual:   3  , ftwelve:    0.00  , ones:  0.0  , diam:   7.15  , errdiam:  0.67  , simrem: "Variable Star	   " , hvartype: ""	 , multflag: ""  , compid: ""	   , theta:	0 , rho:   0.00 , compmagdiff: 0.00 , notes: ""  , hdnotes: "" , hdmoent: ""  , hdmcoment: "" },$ 
{ name: "HD31767"        , baynum: "pi.06 Ori"     , hrnum: "HR1601"        , flamnum: "FL 10 Ori"        , saonum: "SAO112281"   , ppmnum: "PPM148255"   , varname: ""            , hipnum: "HIP23123"    , starname: ""                , alphah:  4.0 , alpham: 58.0 , alphas:  32.9 , plusmin:  +1 , deltag:   1.0 , deltam: 42.0 , deltas: 50.5  , orig: "iras"	   , spectype: "K2II"	     , parallax:     3.42  , parerr:	 0.86  , promot: " PROMOT  -0.01      0" , vmag:   4.47  , hmag:   1.52  , irastwelvemu:     8.97  , qual:   3  , ftwelve:    0.00  , ones:  0.0  , diam:   2.65  , errdiam:  0.36  , simrem: "Variable Star	   " , hvartype: "C"	  , multflag: ""  , compid: ""      , theta:	 0 , rho:   0.00 , compmagdiff: 0.00 , notes: ""  , hdnotes: "" , hdmoent: ""  , hdmcoment: "" },$ 
{ name: "HD32831"        , baynum: "gam Cae"       , hrnum: "HR1652"        , flamnum: ""                 , saonum: "SAO195532"   , ppmnum: "PPM281010"   , varname: ""            , hipnum: "HIP23595"    , starname: ""                , alphah:  5.0 , alpham:  4.0 , alphas:  24.4 , plusmin:  -1 , deltag:  35.0 , deltam: 28.0 , deltas: 58.7  , orig: "iras"	   , spectype: "K3III"       , parallax:    17.63  , parerr:	 0.54  , promot: " PROMOT   0.12  -0.05" , vmag:   4.58  , hmag:   1.88  , irastwelvemu:     6.24  , qual:   3  , ftwelve:    0.00  , ones:  0.0  , diam:   2.14  , errdiam:  0.07  , simrem: "Double or multiple star     " , hvartype: "D"	  , multflag: "C"  , compid: "AB"      , theta:  306  , rho:  3.15    , compmagdiff:  3.75  , notes: ""  , hdnotes: "" , hdmoent: "Y" , hdmcoment: "" },$ 
{ name: "HD33042"        , baynum: "eta02 Pic"     , hrnum: "HR1663"        , flamnum: ""                 , saonum: "SAO217164"   , ppmnum: "PPM309337"   , varname: ""            , hipnum: "HIP23649"    , starname: ""                , alphah:  5.0 , alpham:  4.0 , alphas: 58.01 , plusmin:  -1 , deltag:  49.0 , deltam: 34.0 , deltas: 40.2  , orig: "iras"	   , spectype: "K5III"       , parallax:     6.88  , parerr:	  0.5  , promot: " PROMOT   0.06      0" , vmag:   5.06  , hmag:   1.62  , irastwelvemu:     8.64  , qual:   3  , ftwelve:    0.00  , ones:  0.0  , diam:   2.65  , errdiam:  0.13  , simrem: "Variable Star	   " , hvartype: ""	 , multflag: ""  , compid: ""	   , theta:	0 , rho:   0.00 , compmagdiff: 0.00 , notes: ""  , hdnotes: "" , hdmoent: ""  , hdmcoment: "" },$ 
{ name: "HD32683"        , baynum: ""              , hrnum: ""              , flamnum: ""                 , saonum: "SAO 57637"   , ppmnum: "PPM69919"    , varname: ""            , hipnum: ""            , starname: ""                , alphah:  5.0 , alpham:  6.0 , alphas: 27.52 , plusmin:  +1 , deltag:  34.0 , deltam: 51.0 , deltas: 18.1  , orig: "iras"	   , spectype: "M5"	     , parallax:     0.00  , parerr:	 0.00  , promot: " PROMOT   0.01  -0.03" , vmag:    7.9  , hmag:   0.00  , irastwelvemu:     8.81  , qual:   3  , ftwelve:    8.43  , ones:  3.6  , diam:   2.78  , errdiam:  0.07  , simrem: "Star	    " , hvartype: ""	  , multflag: ""  , compid: ""      , theta:	 0 , rho:   0.00 , compmagdiff: 0.00 , notes: ""  , hdnotes: "" , hdmoent: ""  , hdmcoment: "" },$ 
{ name: "HD33684"        , baynum: ""              , hrnum: "HR1695"        , flamnum: ""                 , saonum: "SAO249198"   , ppmnum: "PPM354554"   , varname: "V* WZ Dor"   , hipnum: "HIP23840"    , starname: ""                , alphah:  5.0 , alpham:  7.0 , alphas: 34.03 , plusmin:  -1 , deltag:  63.0 , deltam: 23.0 , deltas: 58.8  , orig: "iras"	   , spectype: "M3III"       , parallax:      5.2  , parerr:	 0.46  , promot: " PROMOT   0.02  -0.04" , vmag:   5.23  , hmag:   0.52  , irastwelvemu:    27.16  , qual:   3  , ftwelve:    0.00  , ones:  0.0  , diam:   5.09  , errdiam:  0.13  , simrem: "Variable Star	   " , hvartype: "U"	  , multflag: ""  , compid: ""      , theta:	 0 , rho:   0.00 , compmagdiff: 0.00 , notes: "P" , hdnotes: "" , hdmoent: ""  , hdmcoment: "" },$ 
{ name: "HD33856"        , baynum: "rho Ori"       , hrnum: "HR1698"        , flamnum: "FL 17 Ori"        , saonum: "SAO112528"   , ppmnum: "PPM148614"   , varname: ""            , hipnum: "HIP24331"    , starname: ""                , alphah:  5.0 , alpham: 13.0 , alphas: 17.48 , plusmin:  +1 , deltag:   2.0 , deltam: 51.0 , deltas: 40.6  , orig: "iras"	   , spectype: "K0.5III"     , parallax:     9.49  , parerr:	 0.82  , promot: " PROMOT      0   0.01" , vmag:   4.45  , hmag:   1.95  , irastwelvemu:     6.21  , qual:   3  , ftwelve:    0.00  , ones:  0.0  , diam:   2.05  , errdiam:  0.12  , simrem: "Spectroscopic binary	  " , hvartype: "D"	 , multflag: "C"  , compid: "AB"      , theta:   63  , rho:  6.91    , compmagdiff:  3.83  , notes: ""  , hdnotes: "" , hdmoent: "Y" , hdmcoment: "" },$ 
{ name: "HD34334"        , baynum: ""              , hrnum: "HR1726"        , flamnum: "FL 16 Aur"        , saonum: "SAO 57853"   , ppmnum: "PPM70153"    , varname: ""            , hipnum: "HIP24727"    , starname: ""                , alphah:  5.0 , alpham: 18.0 , alphas: 10.57 , plusmin:  +1 , deltag:  33.0 , deltam: 22.0 , deltas: 17.8  , orig: "iras"	   , spectype: "K2.5IIIb"    , parallax:    13.92  , parerr:	 1.39  , promot: " PROMOT   0.03  -0.17" , vmag:   4.55  , hmag:   1.58  , irastwelvemu:     8.47  , qual:   3  , ftwelve:    0.00  , ones:  0.0  , diam:   2.42  , errdiam:  0.09  , simrem: "Spectroscopic binary	  " , hvartype: ""	, multflag: "O"  , compid: ""	   , theta:	0 , rho:   0.00 , compmagdiff: 0.00 , notes: ""  , hdnotes: "" , hdmoent: ""  , hdmcoment: "Y" },$
{ name: "HD35369"        , baynum: "e Ori"         , hrnum: "HR1784"        , flamnum: "FL 29 Ori"        , saonum: "SAO132067"   , ppmnum: "PPM188020"   , varname: ""            , hipnum: "HIP25247"    , starname: ""                , alphah:  5.0 , alpham: 23.0 , alphas: 56.83 , plusmin:  -1 , deltag:   7.0 , deltam: 48.0 , deltas: 29.0  , orig: "iras"	   , spectype: "G8III"       , parallax:    18.71  , parerr:	 0.74  , promot: " PROMOT  -0.02  -0.04" , vmag:   4.14  , hmag:  2.00   , irastwelvemu:     5.32  , qual:   3  , ftwelve:    0.00  , ones:  0.0  , diam:   1.89  , errdiam:  0.04  , simrem: "Star	    " , hvartype: "C"	   , multflag: ""  , compid: ""      , theta:	  0 , rho:   0.00 , compmagdiff: 0.00 , notes: ""  , hdnotes: "" , hdmoent: ""  , hdmcoment: "" },$ 
{ name: "HD35536"        , baynum: ""              , hrnum: "HR1799"        , flamnum: ""                 , saonum: "SAO150420"   , ppmnum: "PPM215733"   , varname: ""            , hipnum: "HIP25329"    , starname: ""                , alphah:  5.0 , alpham: 25.0 , alphas:  1.74 , plusmin:  -1 , deltag:  10.0 , deltam: 19.0 , deltas: 44.0  , orig: "iras"	   , spectype: "K5III"       , parallax:     5.13  , parerr:	 0.81  , promot: " PROMOT  -0.02  -0.02" , vmag:   5.61  , hmag:   2.15  , irastwelvemu:     5.32  , qual:   3  , ftwelve:    0.00  , ones:  0.0  , diam:   2.05  , errdiam:  0.12  , simrem: "Star	    " , hvartype: "C"	   , multflag: ""  , compid: ""      , theta:	  0 , rho:   0.00 , compmagdiff: 0.00 , notes: ""  , hdnotes: "" , hdmoent: ""  , hdmcoment: "" },$ 
{ name: "HD35620"        , baynum: "phi Aur"       , hrnum: "HR1805"        , flamnum: "FL 24 Aur"        , saonum: "SAO 58051"   , ppmnum: "PPM70384"    , varname: ""            , hipnum: "HIP25541"    , starname: ""                , alphah:  5.0 , alpham: 27.0 , alphas: 38.89 , plusmin:  +1 , deltag:  34.0 , deltam: 28.0 , deltas: 33.2  , orig: "iras"	   , spectype: "K3IIICN+"    , parallax:     8.14  , parerr:	  0.8  , promot: " PROMOT      0  -0.04" , vmag:   5.07  , hmag:   0.00  , irastwelvemu:     5.27  , qual:   3  , ftwelve:    5.31  , ones:  3.9  , diam:   2.04  , errdiam:  0.15  , simrem: "Eclipsing binary      " , hvartype: "C"      , multflag: ""  , compid: ""      , theta:     0 , rho:   0.00 , compmagdiff: 0.00 , notes: ""  , hdnotes: "" , hdmoent: ""  , hdmcoment: "" },$ 
{ name: "HD36079"        , baynum: "bet Lep"       , hrnum: "HR1829"        , flamnum: "FL 9 Lep"         , saonum: "SAO170457"   , ppmnum: "PPM248938"   , varname: ""            , hipnum: "HIP25606"    , starname: "NIHAL"           , alphah:  5.0 , alpham: 28.0 , alphas: 14.72 , plusmin:  -1 , deltag:  20.0 , deltam: 45.0 , deltas: 34.0  , orig: "iras"	   , spectype: "G5II"	     , parallax:    20.49  , parerr:	 0.85  , promot: " PROMOT      0  -0.09" , vmag:   2.84  , hmag:   0.97  , irastwelvemu:    14.01  , qual:   3  , ftwelve:    0.00  , ones:  0.0  , diam:    2.9  , errdiam:  0.04  , simrem: "Double or multiple star     " , hvartype: ""	 , multflag: ""  , compid: ""	   , theta:	0 , rho:   0.00 , compmagdiff: 0.00 , notes: ""  , hdnotes: "" , hdmoent: ""  , hdmcoment: "" },$ 
{ name: "HD36597"        , baynum: "eps Col"       , hrnum: "HR1862"        , flamnum: ""                 , saonum: "SAO195924"   , ppmnum: "PPM281547"   , varname: ""            , hipnum: "HIP25859"    , starname: ""                , alphah:  5.0 , alpham: 31.0 , alphas: 12.76 , plusmin:  -1 , deltag:  35.0 , deltam: 28.0 , deltas: 13.9  , orig: "iras"	   , spectype: "K1IIIa"      , parallax:    11.77  , parerr:	 0.51  , promot: " PROMOT   0.02  -0.04" , vmag:   3.88  , hmag:    1.4  , irastwelvemu:     9.73  , qual:   3  , ftwelve:    0.00  , ones:  0.0  , diam:    2.6  , errdiam:  0.09  , simrem: "Star	    " , hvartype: ""	  , multflag: "G"  , compid: ""      , theta:	  0 , rho:   0.00 , compmagdiff: 0.00 , notes: ""  , hdnotes: "" , hdmoent: ""  , hdmcoment: "" },$ 
{ name: "HD36673"        , baynum: "alf Lep"       , hrnum: "HR1865"        , flamnum: "FL 11 Lep"        , saonum: "SAO150547"   , ppmnum: "PPM215925"   , varname: ""            , hipnum: "HIP25985"    , starname: "ARNEB"           , alphah:  5.0 , alpham: 32.0 , alphas: 43.82 , plusmin:  -1 , deltag:  17.0 , deltam: 49.0 , deltas: 20.2  , orig: "iras"	   , spectype: "F0Ib"	     , parallax:     2.54  , parerr:	 0.72  , promot: " PROMOT  -0.01      0" , vmag:    2.6  , hmag:   1.89  , irastwelvemu:     5.62  , qual:   3  , ftwelve:    0.00  , ones:  0.0  , diam:   1.54  , errdiam:   0.1  , simrem: "Variable Star	   " , hvartype: "M"	  , multflag: ""  , compid: ""      , theta:	 0 , rho:   0.00 , compmagdiff: 0.00 , notes: ""  , hdnotes: "" , hdmoent: ""  , hdmcoment: "" },$ 
{ name: "HD37350"        , baynum: "bet Dor"       , hrnum: "HR1922"        , flamnum: ""                 , saonum: "SAO249311"   , ppmnum: "PPM354837"   , varname: "V* bet Dor"  , hipnum: "HIP26069"    , starname: ""                , alphah:  5.0 , alpham: 33.0 , alphas: 37.52 , plusmin:  -1 , deltag:  62.0 , deltam: 29.0 , deltas: 23.4  , orig: "iras"	   , spectype: "F6Ia..."     , parallax:     3.14  , parerr:	 0.59  , promot: " PROMOT  -0.01      0" , vmag:   3.77  , hmag:   2.01  , irastwelvemu:     5.18  , qual:   3  , ftwelve:    0.00  , ones:  0.0  , diam:   1.78  , errdiam:  0.13  , simrem: "Classical Cepheid (delta Cep type)" , hvartype: "P"	, multflag: "V"  , compid: ""	   , theta:	0 , rho:   0.00 , compmagdiff: 0.00 , notes: ""  , hdnotes: "" , hdmoent: ""  , hdmcoment: "" },$ 
{ name: "HD37160"        , baynum: "phi02 Ori"     , hrnum: "HR1907"        , flamnum: "FL 40 Ori"        , saonum: "SAO112958"   , ppmnum: "PPM149219"   , varname: ""            , hipnum: "HIP26366"    , starname: ""                , alphah:  5.0 , alpham: 36.0 , alphas: 54.39 , plusmin:  +1 , deltag:   9.0 , deltam: 17.0 , deltas: 26.4  , orig: "iras"	   , spectype: "K0IIIb"      , parallax:     28.1  , parerr:	 0.91  , promot: " PROMOT   0.09   -0.3" , vmag:   4.09  , hmag:   1.77  , irastwelvemu:     6.47  , qual:   3  , ftwelve:    0.00  , ones:  0.0  , diam:   2.02  , errdiam:  0.02  , simrem: "High proper-motion Star     " , hvartype: "C"	  , multflag: "G"  , compid: ""      , theta:	  0 , rho:   0.00 , compmagdiff: 0.00 , notes: ""  , hdnotes: "" , hdmoent: ""  , hdmcoment: "" },$ 
{ name: "HD39425"        , baynum: "bet Col"       , hrnum: "HR2040"        , flamnum: ""                 , saonum: "SAO196240"   , ppmnum: "PPM281952"   , varname: ""            , hipnum: "HIP27628"    , starname: ""                , alphah:  5.0 , alpham: 50.0 , alphas: 57.59 , plusmin:  -1 , deltag:  35.0 , deltam: 46.0 , deltas:  5.9  , orig: "iras"	   , spectype: "K2III"       , parallax:    37.94  , parerr:	 0.57  , promot: " PROMOT   0.05    0.4" , vmag:   3.12  , hmag:   0.67  , irastwelvemu:    19.35  , qual:   3  , ftwelve:    0.00  , ones:  0.0  , diam:   3.68  , errdiam:  0.02  , simrem: "High proper-motion Star     " , hvartype: ""	 , multflag: ""  , compid: ""	   , theta:	0 , rho:   0.00 , compmagdiff: 0.00 , notes: ""  , hdnotes: "" , hdmoent: ""  , hdmcoment: "" },$ 
{ name: "HD39045"        , baynum: ""              , hrnum: "HR2018"        , flamnum: ""                 , saonum: "SAO 58504"   , ppmnum: "PPM70923"    , varname: "V*V440 Aur"  , hipnum: "HIP27661"    , starname: ""                , alphah:  5.0 , alpham: 51.0 , alphas: 25.75 , plusmin:  +1 , deltag:  32.0 , deltam:  7.0 , deltas: 28.9  , orig: "msx"	   , spectype: "M3III"       , parallax:     5.62  , parerr:	  1.0  , promot: " PROMOT      0   0.01" , vmag:   6.31  , hmag:   1.47  , irastwelvemu:     0.00  , qual:   0  , ftwelve:   10.36  , ones:  3.3  , diam:   3.24  , errdiam:  0.21  , simrem: "Variable Star	   " , hvartype: "U"	  , multflag: ""  , compid: ""      , theta:	 0 , rho:   0.00 , compmagdiff: 0.00 , notes: ""  , hdnotes: "" , hdmoent: ""  , hdmcoment: "" },$ 
{ name: "HD39400"        , baynum: ""              , hrnum: "HR2037"        , flamnum: "FL 56 Ori"        , saonum: "SAO113220"   , ppmnum: "PPM149576"   , varname: ""            , hipnum: "HIP27750"    , starname: ""                , alphah:  5.0 , alpham: 52.0 , alphas: 26.44 , plusmin:  +1 , deltag:   1.0 , deltam: 51.0 , deltas: 18.5  , orig: "iras"	   , spectype: "K1.5IIb"     , parallax:     2.93  , parerr:	 0.93  , promot: " PROMOT  -0.01  -0.01" , vmag:   4.76  , hmag:   1.83  , irastwelvemu:     7.38  , qual:   3  , ftwelve:    0.00  , ones:  0.0  , diam:   2.22  , errdiam:  0.22  , simrem: "Variable Star	   " , hvartype: "C"	  , multflag: ""  , compid: ""      , theta:	 0 , rho:   0.00 , compmagdiff: 0.00 , notes: ""  , hdnotes: "" , hdmoent: ""  , hdmcoment: "" },$ 
{ name: "HD40808"        , baynum: "eta Col"       , hrnum: "HR2120"        , flamnum: ""                 , saonum: "SAO217650"   , ppmnum: "PPM310277"   , varname: ""            , hipnum: "HIP28328"    , starname: ""                , alphah:  5.0 , alpham: 59.0 , alphas:  8.81 , plusmin:  -1 , deltag:  42.0 , deltam: 48.0 , deltas: 54.5  , orig: "iras"	   , spectype: "K0III"       , parallax:     6.14  , parerr:	 0.52  , promot: " PROMOT   0.02  -0.02" , vmag:   3.95  , hmag:   1.57  , irastwelvemu:     8.28  , qual:   3  , ftwelve:    0.00  , ones:  0.0  , diam:   2.44  , errdiam:  0.09  , simrem: "Star	    " , hvartype: ""	  , multflag: ""  , compid: ""      , theta:	 0 , rho:   0.00 , compmagdiff: 0.00 , notes: ""  , hdnotes: "" , hdmoent: ""  , hdmcoment: "" },$ 
{ name: "HD40657"        , baynum: ""              , hrnum: "HR2113"        , flamnum: ""                 , saonum: "SAO132732"   , ppmnum: "PPM188676"   , varname: ""            , hipnum: "HIP28413"    , starname: ""                , alphah:  6.0 , alpham:  0.0 , alphas:  3.35 , plusmin:  -1 , deltag:   3.0 , deltam:  4.0 , deltas: 27.3  , orig: "iras"	   , spectype: "K1.5III"     , parallax:     7.77  , parerr:	 0.82  , promot: " PROMOT      0  -0.07" , vmag:   4.54  , hmag:   1.67  , irastwelvemu:     7.59  , qual:   3  , ftwelve:    0.00  , ones:  0.0  , diam:    2.3  , errdiam:  0.08  , simrem: "Variable Star	   " , hvartype: "C"	  , multflag: ""  , compid: ""      , theta:	 0 , rho:   0.00 , compmagdiff: 0.00 , notes: ""  , hdnotes: "" , hdmoent: ""  , hdmcoment: "" },$ 
{ name: "HD42042"        , baynum: ""              , hrnum: "HR2168"        , flamnum: "FL 19 Lep"        , saonum: "SAO151142"   , ppmnum: "PPM216753"   , varname: ""            , hipnum: "HIP29048"    , starname: ""                , alphah:  6.0 , alpham:  7.0 , alphas: 41.64 , plusmin:  -1 , deltag:  19.0 , deltam:  9.0 , deltas: 57.1  , orig: "iras"	   , spectype: "M1III"       , parallax:     4.59  , parerr:	 0.66  , promot: " PROMOT   0.01   0.05" , vmag:    5.3  , hmag:   1.19  , irastwelvemu:    13.51  , qual:   3  , ftwelve:    0.00  , ones:  0.0  , diam:   3.33  , errdiam:   0.1  , simrem: "Variable Star	   " , hvartype: "U"	  , multflag: ""  , compid: ""      , theta:	 0 , rho:   0.00 , compmagdiff: 0.00 , notes: "P" , hdnotes: "" , hdmoent: ""  , hdmcoment: "" },$ 
{ name: "HD42474"        , baynum: ""              , hrnum: ""              , flamnum: ""                 , saonum: "SAO 78094"   , ppmnum: "PPM95591"    , varname: "V* WY Gem"   , hipnum: "HIP29425"    , starname: ""                , alphah:  6.0 , alpham: 11.0 , alphas: 56.25 , plusmin:  +1 , deltag:  23.0 , deltam: 12.0 , deltas: 25.4  , orig: "msx"	   , spectype: "MIabpeva"    , parallax:    -0.17  , parerr:	 1.13  , promot: " PROMOT      0      0" , vmag:   7.26  , hmag:   2.11  , irastwelvemu:     0.00  , qual:   0  , ftwelve:    7.92  , ones:  3.8  , diam:   2.09  , errdiam:  0.07  , simrem: "Pulsating variable Star     " , hvartype: "U"	  , multflag: ""  , compid: ""      , theta:	 0 , rho:   0.00 , compmagdiff: 0.00 , notes: ""  , hdnotes: "" , hdmoent: ""  , hdmcoment: "" },$ 
{ name: "HD42995"        , baynum: "eta Gem"       , hrnum: "HR2216"        , flamnum: "FL 7 Gem"         , saonum: "SAO 78135"   , ppmnum: "PPM95649"    , varname: "V* eta Gem"  , hipnum: "HIP29655"    , starname: ""                , alphah:  6.0 , alpham: 14.0 , alphas: 52.66 , plusmin:  +1 , deltag:  22.0 , deltam: 30.0 , deltas: 24.5  , orig: "msx"	   , spectype: "M3III"       , parallax:     9.34  , parerr:	 1.99  , promot: " PROMOT  -0.07  -0.01" , vmag:   3.32  , hmag:   0.00  , irastwelvemu:     0.00  , qual:   0  , ftwelve:  137.78  , ones:  3.0  , diam:  10.85  , errdiam:  0.13  , simrem: "Variable of BY Dra type     " , hvartype: "P"	  , multflag: "C"  , compid: "AB"      , theta:  261  , rho:  1.71    , compmagdiff:  2.69  , notes: "W" , hdnotes: "An alternative VIM solution for this system gives position angle 357 deg for the constant star relative to the variable." , hdmoent: "Y" , hdmcoment: "" },$ 
{ name: "HD43039"        , baynum: "kap Aur"       , hrnum: "HR2219"        , flamnum: "FL 44 Aur"        , saonum: "SAO 78143"   , ppmnum: "PPM95662"    , varname: ""            , hipnum: "HIP29696"    , starname: ""                , alphah:  6.0 , alpham: 15.0 , alphas: 22.69 , plusmin:  +1 , deltag:  29.0 , deltam: 29.0 , deltas: 53.1  , orig: "iras"	   , spectype: "G8.5IIIb"    , parallax:    19.31  , parerr:	 0.83  , promot: " PROMOT  -0.07  -0.27" , vmag:   4.35  , hmag:  2.00   , irastwelvemu:     5.78  , qual:   3  , ftwelve:    0.00  , ones:  0.0  , diam:   1.91  , errdiam:  0.04  , simrem: "Variable Star	   " , hvartype: "C"	  , multflag: ""  , compid: ""      , theta:	 0 , rho:   0.00 , compmagdiff: 0.00 , notes: ""  , hdnotes: "" , hdmoent: ""  , hdmcoment: "" },$ 
{ name: "HD44033"        , baynum: ""              , hrnum: "HR2269"        , flamnum: ""                 , saonum: "SAO 95543"   , ppmnum: "PPM122298"   , varname: ""            , hipnum: "HIP30099"    , starname: ""                , alphah:  6.0 , alpham: 20.0 , alphas:  4.22 , plusmin:  +1 , deltag:  14.0 , deltam: 39.0 , deltas:  4.1  , orig: "iras"	   , spectype: "K3Iab"       , parallax:     5.95  , parerr:	 0.88  , promot: " PROMOT      0  -0.02" , vmag:   5.69  , hmag:   1.91  , irastwelvemu:     6.53  , qual:   3  , ftwelve:    6.27  , ones:  3.8  , diam:    2.4  , errdiam:  0.12  , simrem: "Pulsating variable Star     " , hvartype: "U"	  , multflag: ""  , compid: ""      , theta:	 0 , rho:   0.00 , compmagdiff: 0.00 , notes: ""  , hdnotes: "" , hdmoent: ""  , hdmcoment: "" },$ 
{ name: "HD45002"        , baynum: ""              , hrnum: ""              , flamnum: ""                 , saonum: "SAO234465"   , ppmnum: "PPM335121"   , varname: "V* AC Pic"   , hipnum: "HIP30237"    , starname: ""                , alphah:  6.0 , alpham: 21.0 , alphas: 40.74 , plusmin:  -1 , deltag:  56.0 , deltam: 21.0 , deltas: 44.3  , orig: "iras"	   , spectype: "M3III"       , parallax:     2.65  , parerr:	 0.51  , promot: " PROMOT  -0.01  -0.02" , vmag:   6.83  , hmag:   2.29  , irastwelvemu:     5.42  , qual:   3  , ftwelve:    0.00  , ones:  0.0  , diam:   2.17  , errdiam:  0.23  , simrem: "Variable of BY Dra type     " , hvartype: "U"	  , multflag: ""  , compid: ""      , theta:	 0 , rho:   0.00 , compmagdiff: 0.00 , notes: "P" , hdnotes: "" , hdmoent: ""  , hdmcoment: "" },$ 
{ name: "HD45669"        , baynum: "pi.01 Dor"     , hrnum: "HR2352"        , flamnum: ""                 , saonum: "SAO249532"   , ppmnum: "PPM355337"   , varname: ""            , hipnum: "HIP30321"    , starname: ""                , alphah:  6.0 , alpham: 22.0 , alphas: 38.27 , plusmin:  -1 , deltag:  69.0 , deltam: 59.0 , deltas:  2.6  , orig: "iras"	   , spectype: "K5III"       , parallax:     5.48  , parerr:	  0.5  , promot: " PROMOT   0.02   0.03" , vmag:   5.57  , hmag:   2.17  , irastwelvemu:     5.06  , qual:   3  , ftwelve:    0.00  , ones:  0.0  , diam:   2.11  , errdiam:  0.15  , simrem: "Star	    " , hvartype: ""	  , multflag: ""  , compid: ""      , theta:	 0 , rho:   0.00 , compmagdiff: 0.00 , notes: ""  , hdnotes: "" , hdmoent: ""  , hdmcoment: "" },$ 
{ name: "HD44478"        , baynum: "mu. Gem"       , hrnum: "HR2286"        , flamnum: "FL 13 Gem"        , saonum: "SAO 78297"   , ppmnum: "PPM95868"    , varname: "V* mu. Gem"  , hipnum: "HIP30343"    , starname: ""                , alphah:  6.0 , alpham: 22.0 , alphas: 57.63 , plusmin:  +1 , deltag:  22.0 , deltam: 30.0 , deltas: 48.9  , orig: "iras"	   , spectype: "M3III"       , parallax:    14.07  , parerr:	 0.93  , promot: " PROMOT   0.06  -0.11" , vmag:   2.91  , hmag:   0.00  , irastwelvemu:   213.28  , qual:   3  , ftwelve:  209.76  , ones:  3.0  , diam:  13.79  , errdiam:  0.09  , simrem: "Variable Star	   " , hvartype: "U"	  , multflag: ""  , compid: ""      , theta:	 0 , rho:   0.00 , compmagdiff: 0.00 , notes: ""  , hdnotes: "" , hdmoent: ""  , hdmcoment: "" },$ 
{ name: "HD45348"        , baynum: "alf Car"       , hrnum: "HR2326"        , flamnum: ""                 , saonum: "SAO234480"   , ppmnum: "PPM335149"   , varname: ""            , hipnum: "HIP30438"    , starname: "CANOPUS"         , alphah:  6.0 , alpham: 23.0 , alphas: 57.11 , plusmin:  -1 , deltag:  52.0 , deltam: 41.0 , deltas: 44.4  , orig: "iras"	   , spectype: "F0II"	     , parallax:    10.43  , parerr:	 0.53  , promot: " PROMOT   0.03   0.02" , vmag:  -0.72  , hmag:   0.00  , irastwelvemu:   106.88  , qual:   3  , ftwelve:    0.00  , ones:  0.0  , diam:   6.64  , errdiam:  0.11  , simrem: "Star	    " , hvartype: "U"	   , multflag: ""  , compid: ""      , theta:	  0 , rho:   0.00 , compmagdiff: 0.00 , notes: ""  , hdnotes: "" , hdmoent: ""  , hdmcoment: "" },$ 
{ name: "HD45724"        , baynum: ""              , hrnum: "HR2355"        , flamnum: ""                 , saonum: "SAO113940"   , ppmnum: "PPM150600"   , varname: ""            , hipnum: "HIP30906"    , starname: ""                , alphah:  6.0 , alpham: 29.0 , alphas: 14.81 , plusmin:  +1 , deltag:   2.0 , deltam: 38.0 , deltas: 46.3  , orig: "iras"	   , spectype: "M1"	     , parallax:     3.83  , parerr:	 0.86  , promot: " PROMOT      0  -0.04" , vmag:    6.2  , hmag:   2.17  , irastwelvemu:     5.75  , qual:   3  , ftwelve:    5.24  , ones:  4.3  , diam:   2.04  , errdiam:  0.21  , simrem: "Eclipsing binary      " , hvartype: "U"      , multflag: ""  , compid: ""      , theta:     0 , rho:   0.00 , compmagdiff: 0.00 , notes: ""  , hdnotes: "" , hdmoent: ""  , hdmcoment: "" },$ 
{ name: "HD46612"        , baynum: ""              , hrnum: ""              , flamnum: ""                 , saonum: "SAO114079"   , ppmnum: "PPM150786"   , varname: "V*V729 Mon"  , hipnum: "HIP31363"    , starname: ""                , alphah:  6.0 , alpham: 34.0 , alphas: 35.63 , plusmin:  +1 , deltag:   4.0 , deltam: 58.0 , deltas:  4.5  , orig: "msx"	   , spectype: "M0III"       , parallax:     4.27  , parerr:	  0.9  , promot: " PROMOT   0.02  -0.04" , vmag:   6.88  , hmag:   1.66  , irastwelvemu:     0.00  , qual:   0  , ftwelve:    9.87  , ones:  3.4  , diam:   2.81  , errdiam:  0.19  , simrem: "Variable of BY Dra type     " , hvartype: "U"	  , multflag: ""  , compid: ""      , theta:	 0 , rho:   0.00 , compmagdiff: 0.00 , notes: "P" , hdnotes: "" , hdmoent: ""  , hdmcoment: "" },$ 
{ name: "HD47205"        , baynum: "nu.02 CMa"     , hrnum: "HR2429"        , flamnum: "FL 7 CMa"         , saonum: "SAO151702"   , ppmnum: "PPM217422"   , varname: ""            , hipnum: "HIP31592"    , starname: ""                , alphah:  6.0 , alpham: 36.0 , alphas: 41.04 , plusmin:  -1 , deltag:  19.0 , deltam: 15.0 , deltas: 21.2  , orig: "iras"	   , spectype: "K1III+..."   , parallax:    50.41  , parerr:	  0.7  , promot: " PROMOT   0.06  -0.08" , vmag:   3.96  , hmag:   1.71  , irastwelvemu:     6.74  , qual:   3  , ftwelve:    0.00  , ones:  0.0  , diam:   2.25  , errdiam:  0.01  , simrem: "Variable Star	   " , hvartype: "C"	  , multflag: ""  , compid: ""      , theta:	 0 , rho:   0.00 , compmagdiff: 0.00 , notes: ""  , hdnotes: "" , hdmoent: ""  , hdmcoment: "" },$ 
{ name: "HD47452"        , baynum: ""              , hrnum: ""              , flamnum: ""                 , saonum: "SAO114196"   , ppmnum: "PPM150948"   , varname: ""            , hipnum: ""            , starname: ""                , alphah:  6.0 , alpham: 38.0 , alphas: 50.92 , plusmin:  +1 , deltag:   5.0 , deltam: 11.0 , deltas: 27.7  , orig: "iras"	   , spectype: "M..."	     , parallax:     0.00  , parerr:	 0.00  , promot: " PROMOT      0      0" , vmag:   7.67  , hmag:   0.00  , irastwelvemu:      6.8  , qual:   3  , ftwelve:    6.22  , ones:  3.6  , diam:   0.00  , errdiam:  0.00  , simrem: "Star	    " , hvartype: ""	  , multflag: ""  , compid: ""      , theta:	 0 , rho:   0.00 , compmagdiff: 0.00 , notes: ""  , hdnotes: "" , hdmoent: ""  , hdmcoment: "" },$ 
{ name: "HD47886"        , baynum: ""              , hrnum: "HR2458"        , flamnum: ""                 , saonum: "SAO 95997"   , ppmnum: "PPM122874"   , varname: ""            , hipnum: "HIP32012"    , starname: ""                , alphah:  6.0 , alpham: 41.0 , alphas: 17.22 , plusmin:  +1 , deltag:  11.0 , deltam:  0.0 , deltas: 11.5  , orig: "msx"	   , spectype: "M1III"       , parallax:     1.28  , parerr:	 0.93  , promot: " PROMOT      0   0.01" , vmag:   6.21  , hmag:   1.99  , irastwelvemu:     0.00  , qual:   0  , ftwelve:    6.49  , ones:  4.2  , diam:   2.31  , errdiam:   1.6  , simrem: "Variable Star	   " , hvartype: "U"	  , multflag: ""  , compid: ""      , theta:	 0 , rho:   0.00 , compmagdiff: 0.00 , notes: "P" , hdnotes: "" , hdmoent: ""  , hdmcoment: "" },$ 
{ name: "HD48217"        , baynum: ""              , hrnum: "HR2469"        , flamnum: ""                 , saonum: "SAO133585"   , ppmnum: "PPM189456"   , varname: ""            , hipnum: "HIP32064"    , starname: ""                , alphah:  6.0 , alpham: 41.0 , alphas: 56.39 , plusmin:  -1 , deltag:   9.0 , deltam: 10.0 , deltas:  3.1  , orig: "iras"	   , spectype: "M0III"       , parallax:     8.63  , parerr:	 0.77  , promot: " PROMOT   0.04  -0.04" , vmag:   5.22  , hmag:   1.72  , irastwelvemu:     7.82  , qual:   3  , ftwelve:    0.00  , ones:  0.0  , diam:   2.45  , errdiam:  0.07  , simrem: "Star	    " , hvartype: "C"	   , multflag: ""  , compid: ""      , theta:	  0 , rho:   0.00 , compmagdiff: 0.00 , notes: ""  , hdnotes: "" , hdmoent: ""  , hdmcoment: "" },$ 
{ name: "HD48329"        , baynum: "eps Gem"       , hrnum: "HR2473"        , flamnum: "FL 27 Gem"        , saonum: "SAO 78682"   , ppmnum: "PPM96453"    , varname: ""            , hipnum: "HIP32246"    , starname: ""                , alphah:  6.0 , alpham: 43.0 , alphas: 55.93 , plusmin:  +1 , deltag:  25.0 , deltam:  7.0 , deltas: 52.0  , orig: "iras"	   , spectype: "G8Ib"	     , parallax:     3.61  , parerr:	 0.91  , promot: " PROMOT  -0.01      0" , vmag:   3.02  , hmag:   0.00  , irastwelvemu:    27.92  , qual:   3  , ftwelve:    0.00  , ones:  0.0  , diam:   0.24  , errdiam:  0.16  , simrem: "Variable Star	   " , hvartype: "M"	  , multflag: ""  , compid: ""      , theta:	 0 , rho:   0.00 , compmagdiff: 0.00 , notes: ""  , hdnotes: "" , hdmoent: ""  , hdmcoment: "" },$ 
{ name: "HD48433"        , baynum: ""              , hrnum: "HR2478"        , flamnum: "FL 30 Gem"        , saonum: "SAO 96051"   , ppmnum: "PPM122951"   , varname: ""            , hipnum: "HIP32249"    , starname: ""                , alphah:  6.0 , alpham: 43.0 , alphas: 59.29 , plusmin:  +1 , deltag:  13.0 , deltam: 13.0 , deltas: 40.9  , orig: "iras"	   , spectype: "K1III"       , parallax:    11.82  , parerr:	 0.83  , promot: " PROMOT      0  -0.05" , vmag:    4.5  , hmag:   1.91  , irastwelvemu:     5.89  , qual:   3  , ftwelve:    5.12  , ones:  5.9  , diam:   2.02  , errdiam:  0.07  , simrem: "Eclipsing binary      " , hvartype: ""	   , multflag: ""  , compid: ""      , theta:	  0 , rho:   0.00 , compmagdiff: 0.00 , notes: ""  , hdnotes: "" , hdmoent: ""  , hdmcoment: "" },$ 
{ name: "HD48915"        , baynum: "alf CMa"       , hrnum: "HR2491"        , flamnum: "FL 9 CMa"         , saonum: "SAO151881"   , ppmnum: "PPM217626"   , varname: ""            , hipnum: "HIP32349"    , starname: "SIRIUS"          , alphah:  6.0 , alpham: 45.0 , alphas:  8.92 , plusmin:  -1 , deltag:  16.0 , deltam: 42.0 , deltas: 58.0  , orig: "iras"	   , spectype: "A1V"	     , parallax:   379.22  , parerr:	 1.58  , promot: " PROMOT  -0.54  -1.21" , vmag:  -1.47  , hmag:  -1.39  , irastwelvemu:    99.74  , qual:   3  , ftwelve:    0.00  , ones:  0.0  , diam:   5.85  , errdiam:  0.00  , simrem: "Spectroscopic binary	  " , hvartype: "U"	 , multflag: "O"  , compid: ""      , theta:	 0 , rho:   0.00 , compmagdiff: 0.00 , notes: "X" , hdnotes: "Sirius. Due to the extreme brightness of the object, the formal standard errors of great-circle abscissae were severely underestimated. The astrometric standard errors were instead derived from the statistics of the post-fit residuals, resulting in a unit weight error of exactly 1. For this reason, no goodness-of-fit statistic is given in Field H30. Note that the long period of the astrometric orbit (50 years) prevented adjustment of the orbital parameters, which were thus all adopted from the literature (see Part O of the Double and Multiple Systems Annex). The given astrometric standard errors consequently do not include the uncertainties of the adopted orbit used to reduce the observations to the centre of mass of the system." , hdmoent: ""  , hdmcoment: "Y" },$
{ name: "HD49161"        , baynum: ""              , hrnum: "HR2503"        , flamnum: "FL 17 Mon"        , saonum: "SAO114410"   , ppmnum: "PPM151239"   , varname: ""            , hipnum: "HIP32533"    , starname: ""                , alphah:  6.0 , alpham: 47.0 , alphas: 19.83 , plusmin:  +1 , deltag:   8.0 , deltam:  2.0 , deltas: 14.1  , orig: "msx"	   , spectype: "K4III"       , parallax:     6.73  , parerr:	 0.75  , promot: " PROMOT  -0.03  -0.01" , vmag:   4.78  , hmag:   0.00  , irastwelvemu:     0.00  , qual:   0  , ftwelve:    7.19  , ones:  3.9  , diam:    2.7  , errdiam:  0.12  , simrem: "Star	    " , hvartype: "M"	   , multflag: ""  , compid: ""      , theta:	  0 , rho:   0.00 , compmagdiff: 0.00 , notes: ""  , hdnotes: "" , hdmoent: ""  , hdmcoment: "" },$ 
{ name: "HD49293"        , baynum: ""              , hrnum: "HR2506"        , flamnum: "FL 18 Mon"        , saonum: "SAO114428"   , ppmnum: "PPM151262"   , varname: ""            , hipnum: "HIP32578"    , starname: ""                , alphah:  6.0 , alpham: 47.0 , alphas: 51.65 , plusmin:  +1 , deltag:   2.0 , deltam: 24.0 , deltas: 43.8  , orig: "iras"	   , spectype: "K0IIIa"      , parallax:     8.74  , parerr:	 0.91  , promot: " PROMOT  -0.02  -0.01" , vmag:   4.48  , hmag:   2.11  , irastwelvemu:     5.03  , qual:   3  , ftwelve:    0.00  , ones:  0.0  , diam:   1.88  , errdiam:  0.05  , simrem: "Star	    " , hvartype: "C"	   , multflag: "O"  , compid: ""      , theta:     0 , rho:   0.00 , compmagdiff: 0.00 , notes: ""  , hdnotes: "" , hdmoent: ""  , hdmcoment: "Y" },$
{ name: "HD50778"        , baynum: "the CMa"       , hrnum: "HR2574"        , flamnum: "FL 14 CMa"        , saonum: "SAO152071"   , ppmnum: "PPM217841"   , varname: ""            , hipnum: "HIP33160"    , starname: ""                , alphah:  6.0 , alpham: 54.0 , alphas:  11.4 , plusmin:  -1 , deltag:  12.0 , deltam:  2.0 , deltas: 19.1  , orig: "iras"	   , spectype: "K4III"       , parallax:    12.94  , parerr:	 0.87  , promot: " PROMOT  -0.14  -0.02" , vmag:   4.09  , hmag:    0.8  , irastwelvemu:    17.33  , qual:   3  , ftwelve:    0.00  , ones:  0.0  , diam:   3.76  , errdiam:  0.04  , simrem: "Star	    " , hvartype: "M"	   , multflag: ""  , compid: ""      , theta:	  0 , rho:   0.00 , compmagdiff: 0.00 , notes: ""  , hdnotes: "" , hdmoent: ""  , hdmcoment: "" },$ 
{ name: "HD51799"        , baynum: ""              , hrnum: "HR2608"        , flamnum: ""                 , saonum: "SAO218324"   , ppmnum: "PPM311283"   , varname: ""            , hipnum: "HIP33357"    , starname: ""                , alphah:  6.0 , alpham: 56.0 , alphas: 15.99 , plusmin:  -1 , deltag:  48.0 , deltam: 43.0 , deltas: 16.1  , orig: "iras"	   , spectype: "M1III"       , parallax:     3.07  , parerr:	 0.53  , promot: " PROMOT      0   0.01" , vmag:   4.97  , hmag:   0.77  , irastwelvemu:    21.01  , qual:   3  , ftwelve:    0.00  , ones:  0.0  , diam:   3.98  , errdiam:  0.12  , simrem: "Variable Star	   " , hvartype: "U"	  , multflag: ""  , compid: ""      , theta:	 0 , rho:   0.00 , compmagdiff: 0.00 , notes: "P" , hdnotes: "" , hdmoent: ""  , hdmcoment: "" },$ 
{ name: "HD51725"        , baynum: ""              , hrnum: ""              , flamnum: ""                 , saonum: "SAO133965"   , ppmnum: "PPM189750"   , varname: "V*V523 Mon"  , hipnum: "HIP33530"    , starname: ""                , alphah:  6.0 , alpham: 58.0 , alphas:  7.12 , plusmin:  -1 , deltag:   9.0 , deltam:  1.0 , deltas: 38.2  , orig: "msx"	   , spectype: "M5"	     , parallax:     3.45  , parerr:	 0.87  , promot: " PROMOT  -0.01   0.02" , vmag:   7.12  , hmag:   1.56  , irastwelvemu:     0.00  , qual:   0  , ftwelve:   10.63  , ones:  3.4  , diam:   3.16  , errdiam:  0.14  , simrem: "Variable Star	   " , hvartype: "U"	  , multflag: ""  , compid: ""      , theta:	 0 , rho:   0.00 , compmagdiff: 0.00 , notes: "P" , hdnotes: "" , hdmoent: ""  , hdmcoment: "" },$ 
{ name: "HD53047"        , baynum: ""              , hrnum: "HR2652"        , flamnum: "FL 23 Car"        , saonum: "SAO234854"   , ppmnum: "PPM335666"   , varname: ""            , hipnum: "HIP33779"    , starname: ""                , alphah:  7.0 , alpham:  0.0 , alphas: 51.48 , plusmin:  -1 , deltag:  51.0 , deltam: 24.0 , deltas:  9.3  , orig: "iras"	   , spectype: "M1III"       , parallax:     5.28  , parerr:	 0.52  , promot: " PROMOT  -0.02   0.02" , vmag:   5.18  , hmag:   0.99  , irastwelvemu:    17.22  , qual:   3  , ftwelve:    0.00  , ones:  0.0  , diam:   3.54  , errdiam:  0.19  , simrem: "Variable Star	   " , hvartype: "U"	  , multflag: "G"  , compid: ""      , theta:	  0 , rho:   0.00 , compmagdiff: 0.00 , notes: "P" , hdnotes: "" , hdmoent: ""  , hdmcoment: "" },$ 
{ name: "HD52432"        , baynum: ""              , hrnum: ""              , flamnum: ""                 , saonum: "SAO134049"   , ppmnum: "PPM189813"   , varname: "V*V614 Mon"  , hipnum: "HIP33794"    , starname: ""                , alphah:  7.0 , alpham:  1.0 , alphas:  1.95 , plusmin:  -1 , deltag:   3.0 , deltam: 15.0 , deltas:  9.1  , orig: "iras"	   , spectype: "C..."	     , parallax:     3.23  , parerr:	 0.96  , promot: " PROMOT      0   0.02" , vmag:   7.27  , hmag:   0.00  , irastwelvemu:    11.93  , qual:   3  , ftwelve:   12.33  , ones:  3.2  , diam:   0.00  , errdiam:  0.00  , simrem: "Carbon Star	 " , hvartype: "U"	, multflag: ""  , compid: ""	  , theta:     0 , rho:   0.00 , compmagdiff: 0.00 , notes: ""  , hdnotes: "" , hdmoent: ""  , hdmcoment: "" },$ 
{ name: "HD52666"        , baynum: ""              , hrnum: "HR2639"        , flamnum: ""                 , saonum: "SAO134076"   , ppmnum: "PPM189831"   , varname: ""            , hipnum: "HIP33878"    , starname: ""                , alphah:  7.0 , alpham:  1.0 , alphas: 56.38 , plusmin:  -1 , deltag:   5.0 , deltam: 43.0 , deltas: 19.4  , orig: "iras"	   , spectype: "M2III"       , parallax:     4.78  , parerr:	 0.76  , promot: " PROMOT  -0.02      0" , vmag:   5.23  , hmag:   0.00  , irastwelvemu:     12.9  , qual:   3  , ftwelve:   12.78  , ones:  3.2  , diam:   2.53  , errdiam:  0.21  , simrem: "Variable Star	   " , hvartype: "U"	  , multflag: ""  , compid: ""      , theta:	 0 , rho:   0.00 , compmagdiff: 0.00 , notes: ""  , hdnotes: "" , hdmoent: ""  , hdmcoment: "" },$ 
{ name: "HD54605"        , baynum: "del CMa"       , hrnum: "HR2693"        , flamnum: "FL 25 CMa"        , saonum: "SAO173047"   , ppmnum: "PPM251718"   , varname: ""            , hipnum: "HIP34444"    , starname: "WEZEN"           , alphah:  7.0 , alpham:  8.0 , alphas: 23.48 , plusmin:  -1 , deltag:  26.0 , deltam: 23.0 , deltas: 35.5  , orig: "iras"	   , spectype: "F8Iab"       , parallax:     1.82  , parerr:	 0.56  , promot: " PROMOT  -0.01      0" , vmag:   1.84  , hmag:   0.48  , irastwelvemu:    24.58  , qual:   3  , ftwelve:    0.00  , ones:  0.0  , diam:   3.67  , errdiam:  0.11  , simrem: "Variable Star	   " , hvartype: "M"	  , multflag: ""  , compid: ""      , theta:	 0 , rho:   0.00 , compmagdiff: 0.00 , notes: ""  , hdnotes: "" , hdmoent: ""  , hdmcoment: "" },$ 
{ name: "HD54300"        , baynum: ""              , hrnum: ""              , flamnum: ""                 , saonum: "SAO 96548"   , ppmnum: "PPM123601"   , varname: "V* R CMi"    , hipnum: "HIP34474"    , starname: ""                , alphah:  7.0 , alpham:  8.0 , alphas: 42.61 , plusmin:  +1 , deltag:  10.0 , deltam:  1.0 , deltas: 26.5  , orig: "iras"	   , spectype: "Spe"	     , parallax:     1.36  , parerr:	 1.34  , promot: " PROMOT  -0.01  -0.01" , vmag:   7.25  , hmag:   2.84  , irastwelvemu:    10.42  , qual:   3  , ftwelve:    0.00  , ones:  0.0  , diam:   0.29  , errdiam:  0.58  , simrem: "Variable Star of Mira Cet type	 " , hvartype: "P"	, multflag: ""  , compid: ""	  , theta:     0 , rho:   0.00 , compmagdiff: 0.00 , notes: ""  , hdnotes: "" , hdmoent: ""  , hdmcoment: "" },$ 
{ name: "HD55865"        , baynum: "gam02 Vol"     , hrnum: "HR2736"        , flamnum: ""                 , saonum: "SAO256374"   , ppmnum: "PPM369422"   , varname: ""            , hipnum: "HIP34481"    , starname: ""                , alphah:  7.0 , alpham:  8.0 , alphas: 44.87 , plusmin:  -1 , deltag:  70.0 , deltam: 29.0 , deltas: 56.1  , orig: "iras"	   , spectype: "K0III"       , parallax:    23.02  , parerr:	 0.69  , promot: " PROMOT   0.03    0.1" , vmag:   3.77  , hmag:   1.48  , irastwelvemu:     8.57  , qual:   3  , ftwelve:    0.00  , ones:  0.0  , diam:   2.39  , errdiam:  0.04  , simrem: "Eclipsing binary      " , hvartype: "D"      , multflag: "C"  , compid: ""      , theta:     0 , rho:   0.00 , compmagdiff: 0.00 , notes: ""  , hdnotes: "" , hdmoent: "Y" , hdmcoment: "" },$ 
{ name: "HD54719"        , baynum: "tau Gem"       , hrnum: "HR2697"        , flamnum: "FL 46 Gem"        , saonum: "SAO 59858"   , ppmnum: "PPM72528"    , varname: ""            , hipnum: "HIP34693"    , starname: ""                , alphah:  7.0 , alpham: 11.0 , alphas:  8.37 , plusmin:  +1 , deltag:  30.0 , deltam: 14.0 , deltas: 42.6  , orig: "iras"	   , spectype: "K2III"       , parallax:    10.81  , parerr:	 0.97  , promot: " PROMOT  -0.04  -0.06" , vmag:    4.4  , hmag:   0.00  , irastwelvemu:     7.26  , qual:   3  , ftwelve:    0.00  , ones:  0.0  , diam:   2.57  , errdiam:  0.01  , simrem: "Variable Star	   " , hvartype: "C"	  , multflag: ""  , compid: ""      , theta:	 0 , rho:   0.00 , compmagdiff: 0.00 , notes: ""  , hdnotes: "" , hdmoent: ""  , hdmcoment: "" },$ 
{ name: "HD57890"        , baynum: ""              , hrnum: ""              , flamnum: ""                 , saonum: "SAO173565"   , ppmnum: "PPM252234"   , varname: "V* GH CMa"   , hipnum: "HIP35746"    , starname: ""                , alphah:  7.0 , alpham: 22.0 , alphas: 23.09 , plusmin:  -1 , deltag:  20.0 , deltam: 30.0 , deltas: 24.0  , orig: "msx"	   , spectype: "M4III"       , parallax:     4.05  , parerr:	 0.84  , promot: " PROMOT  -0.02   0.02" , vmag:   7.07  , hmag:   1.17  , irastwelvemu:     0.00  , qual:   0  , ftwelve:   16.02  , ones:  3.2  , diam:   3.82  , errdiam:  0.11  , simrem: "Variable Star	   " , hvartype: "U"	  , multflag: ""  , compid: ""      , theta:	 0 , rho:   0.00 , compmagdiff: 0.00 , notes: ""  , hdnotes: "" , hdmoent: ""  , hdmcoment: "" },$ 
{ name: "HD58207"        , baynum: "iot Gem"       , hrnum: "HR2821"        , flamnum: "FL 60 Gem"        , saonum: "SAO 79374"   , ppmnum: "PPM97492"    , varname: ""            , hipnum: "HIP36046"    , starname: ""                , alphah:  7.0 , alpham: 25.0 , alphas:  43.6 , plusmin:  +1 , deltag:  27.0 , deltam: 47.0 , deltas: 53.1  , orig: "iras"	   , spectype: "G9IIIb"      , parallax:     25.9  , parerr:	 0.91  , promot: " PROMOT  -0.12  -0.09" , vmag:   3.79  , hmag:   1.52  , irastwelvemu:     7.85  , qual:   3  , ftwelve:    0.00  , ones:  0.0  , diam:   2.43  , errdiam:  0.07  , simrem: "Variable Star	   " , hvartype: ""	 , multflag: ""  , compid: ""	   , theta:	0 , rho:   0.00 , compmagdiff: 0.00 , notes: ""  , hdnotes: "" , hdmoent: ""  , hdmcoment: "" },$ 
{ name: "HD58972"        , baynum: "gam CMi"       , hrnum: "HR2854"        , flamnum: "FL 4 CMi"         , saonum: "SAO115478"   , ppmnum: "PPM152692"   , varname: ""            , hipnum: "HIP36284"    , starname: ""                , alphah:  7.0 , alpham: 28.0 , alphas:  9.79 , plusmin:  +1 , deltag:   8.0 , deltam: 55.0 , deltas: 31.9  , orig: "iras"	   , spectype: "K3III"       , parallax:      8.2  , parerr:	 0.93  , promot: " PROMOT  -0.06   0.02" , vmag:   4.34  , hmag:   1.02  , irastwelvemu:    14.74  , qual:   3  , ftwelve:    0.00  , ones:  0.0  , diam:   3.31  , errdiam:  0.07  , simrem: "Spectroscopic binary	  " , hvartype: "U"	 , multflag: ""  , compid: ""	   , theta:	0 , rho:   0.00 , compmagdiff: 0.00 , notes: ""  , hdnotes: "" , hdmoent: ""  , hdmcoment: "" },$ 
{ name: "HD59381"        , baynum: ""              , hrnum: "HR2867"        , flamnum: ""                 , saonum: "SAO152941"   , ppmnum: "PPM218725"   , varname: ""            , hipnum: "HIP36396"    , starname: ""                , alphah:  7.0 , alpham: 29.0 , alphas: 22.11 , plusmin:  -1 , deltag:  10.0 , deltam: 19.0 , deltas: 36.0  , orig: "iras"	   , spectype: "K5III"       , parallax:     3.52  , parerr:	 0.81  , promot: " PROMOT  -0.01  -0.03" , vmag:   5.75  , hmag:   2.15  , irastwelvemu:     5.39  , qual:   3  , ftwelve:    0.00  , ones:  0.0  , diam:   2.13  , errdiam:  0.14  , simrem: "Variable Star	   " , hvartype: "U"	  , multflag: "G"  , compid: ""      , theta:	  0 , rho:   0.00 , compmagdiff: 0.00 , notes: ""  , hdnotes: "" , hdmoent: ""  , hdmcoment: "" },$ 
{ name: "HD60522"        , baynum: "ups Gem"       , hrnum: "HR2905"        , flamnum: "FL 69 Gem"        , saonum: "SAO 79533"   , ppmnum: "PPM97726"    , varname: ""            , hipnum: "HIP36962"    , starname: ""                , alphah:  7.0 , alpham: 35.0 , alphas: 55.35 , plusmin:  +1 , deltag:  26.0 , deltam: 53.0 , deltas: 44.7  , orig: "iras"	   , spectype: "M0III"       , parallax:    13.57  , parerr:	 0.87  , promot: " PROMOT  -0.03  -0.11" , vmag:   4.08  , hmag:   0.00  , irastwelvemu:     24.6  , qual:   3  , ftwelve:    0.00  , ones:  0.0  , diam:   3.75  , errdiam:  0.07  , simrem: "Variable Star	   " , hvartype: "U"	  , multflag: "G"  , compid: ""      , theta:	  0 , rho:   0.00 , compmagdiff: 0.00 , notes: ""  , hdnotes: "" , hdmoent: ""  , hdmcoment: "" },$ 
{ name: "HD61421"        , baynum: "alf CMi"       , hrnum: "HR2943"        , flamnum: "FL 10 CMi"        , saonum: "SAO115756"   , ppmnum: "PPM153068"   , varname: ""            , hipnum: "HIP37279"    , starname: "PROCYON A"       , alphah:  7.0 , alpham: 39.0 , alphas: 18.12 , plusmin:  +1 , deltag:   5.0 , deltam: 13.0 , deltas: 30.0  , orig: "iras"	   , spectype: "F5IV-V"      , parallax:   285.93  , parerr:	 0.88  , promot: " PROMOT  -0.71  -1.03" , vmag:   0.34  , hmag:  -0.64  , irastwelvemu:     54.8  , qual:   3  , ftwelve:    0.00  , ones:  0.0  , diam:   5.17  , errdiam:  0.00  , simrem: "Spectroscopic binary	  " , hvartype: ""	, multflag: "O"  , compid: ""	   , theta:	0 , rho:   0.00 , compmagdiff: 0.00 , notes: "D" , hdnotes: "Procyon.  The long period of the astrometric orbit (40 years) prevented adjustment of the orbital parameters, which were thus all adopted from the literature (see Part O of the Double and Multiple Systems Annex). The given astrometric standard errors consequently do not include the uncertainties of the adopted orbit used to reduce the observations to the centre of mass of the system." , hdmoent: ""  , hdmcoment: "Y" },$
{ name: "HD61772"        , baynum: ""              , hrnum: "HR2959"        , flamnum: "FL 140 Pup"       , saonum: "SAO153227"   , ppmnum: "PPM219016"   , varname: ""            , hipnum: "HIP37379"    , starname: ""                , alphah:  7.0 , alpham: 40.0 , alphas: 23.21 , plusmin:  -1 , deltag:  15.0 , deltam: 15.0 , deltas: 50.1  , orig: "iras"	   , spectype: "K3III"       , parallax:     4.82  , parerr:	 0.74  , promot: " PROMOT  -0.02  -0.03" , vmag:   4.98  , hmag:   0.00  , irastwelvemu:      9.1  , qual:   3  , ftwelve:    0.00  , ones:  0.0  , diam:    2.9  , errdiam:  0.24  , simrem: "Star	    " , hvartype: ""	  , multflag: ""  , compid: ""      , theta:	 0 , rho:   0.00 , compmagdiff: 0.00 , notes: ""  , hdnotes: "" , hdmoent: ""  , hdmcoment: "" },$ 
{ name: "HD61935"        , baynum: "alf Mon"       , hrnum: "HR2970"        , flamnum: "FL 26 Mon"        , saonum: "SAO134986"   , ppmnum: "PPM190531"   , varname: ""            , hipnum: "HIP37447"    , starname: ""                , alphah:  7.0 , alpham: 41.0 , alphas: 14.83 , plusmin:  -1 , deltag:   9.0 , deltam: 33.0 , deltas:  4.1  , orig: "iras"	   , spectype: "G9III"       , parallax:    22.61  , parerr:	  0.8  , promot: " PROMOT  -0.08  -0.02" , vmag:   3.93  , hmag:    1.7  , irastwelvemu:     7.07  , qual:   3  , ftwelve:    0.00  , ones:  0.0  , diam:   2.21  , errdiam:  0.01  , simrem: "Star	    " , hvartype: "C"	   , multflag: ""  , compid: ""      , theta:	  0 , rho:   0.00 , compmagdiff: 0.00 , notes: ""  , hdnotes: "" , hdmoent: ""  , hdmcoment: "" },$ 
{ name: "HD62082"        , baynum: ""              , hrnum: "HR2976"        , flamnum: ""                 , saonum: "SAO174298"   , ppmnum: "PPM252955"   , varname: ""            , hipnum: "HIP37465"    , starname: ""                , alphah:  7.0 , alpham: 41.0 , alphas: 23.53 , plusmin:  -1 , deltag:  22.0 , deltam: 20.0 , deltas: 12.2  , orig: "iras"	   , spectype: "M0/M1III"    , parallax:     3.79  , parerr:	 0.81  , promot: " PROMOT   0.02  -0.01" , vmag:    6.2  , hmag:   1.85  , irastwelvemu:     7.39  , qual:   3  , ftwelve:    7.03  , ones:  3.5  , diam:   2.59  , errdiam:  0.11  , simrem: "Variable Star	   " , hvartype: "U"	  , multflag: ""  , compid: ""      , theta:	 0 , rho:   0.00 , compmagdiff: 0.00 , notes: ""  , hdnotes: "" , hdmoent: ""  , hdmcoment: "" },$ 
{ name: "HD63295"        , baynum: "zet Vol"       , hrnum: "HR3024"        , flamnum: ""                 , saonum: "SAO256438"   , ppmnum: "PPM369660"   , varname: ""            , hipnum: "HIP37504"    , starname: ""                , alphah:  7.0 , alpham: 41.0 , alphas: 49.26 , plusmin:  -1 , deltag:  72.0 , deltam: 36.0 , deltas: 21.9  , orig: "iras"	   , spectype: "K0III"       , parallax:    24.36  , parerr:	 0.48  , promot: " PROMOT   0.03   0.02" , vmag:   3.96  , hmag:   0.00  , irastwelvemu:     7.61  , qual:   3  , ftwelve:    0.00  , ones:  0.0  , diam:   2.14  , errdiam:  0.09  , simrem: "Eclipsing binary      " , hvartype: "M"      , multflag: ""  , compid: ""      , theta:     0 , rho:   0.00 , compmagdiff: 0.00 , notes: ""  , hdnotes: "" , hdmoent: ""  , hdmcoment: "" },$ 
{ name: "HD62044"        , baynum: "sig Gem"       , hrnum: "HR2973"        , flamnum: "FL 75 Gem"        , saonum: "SAO 79638"   , ppmnum: "PPM97883"    , varname: "V* sig Gem"  , hipnum: "HIP37629"    , starname: ""                , alphah:  7.0 , alpham: 43.0 , alphas: 18.73 , plusmin:  +1 , deltag:  28.0 , deltam: 53.0 , deltas:  0.6  , orig: "iras"	   , spectype: "K1III"       , parallax:    26.68  , parerr:	 0.79  , promot: " PROMOT   0.07  -0.23" , vmag:   4.28  , hmag:   0.00  , irastwelvemu:     8.53  , qual:   3  , ftwelve:    0.00  , ones:  0.0  , diam:   2.11  , errdiam:  0.14  , simrem: "Variable of RS CVn type     " , hvartype: "U"	  , multflag: ""  , compid: ""      , theta:	 0 , rho:   0.00 , compmagdiff: 0.00 , notes: ""  , hdnotes: "" , hdmoent: ""  , hdmcoment: "" },$ 
{ name: "HD62576"        , baynum: ""              , hrnum: "HR2993"        , flamnum: "FL 1 Pup"         , saonum: "SAO174391"   , ppmnum: "PPM253043"   , varname: ""            , hipnum: "HIP37648"    , starname: ""                , alphah:  7.0 , alpham: 43.0 , alphas: 32.39 , plusmin:  -1 , deltag:  28.0 , deltam: 24.0 , deltas: 39.2  , orig: "msx"	   , spectype: "K5III"       , parallax:     3.34  , parerr:	 0.59  , promot: " PROMOT  -0.02   0.02" , vmag:   4.63  , hmag:   0.91  , irastwelvemu:     0.00  , qual:   0  , ftwelve:   16.45  , ones:  3.2  , diam:   3.89  , errdiam:  0.12  , simrem: "Variable Star	   " , hvartype: "U"	  , multflag: ""  , compid: ""      , theta:	 0 , rho:   0.00 , compmagdiff: 0.00 , notes: ""  , hdnotes: "" , hdmoent: ""  , hdmcoment: "" },$ 
{ name: "HD62285"        , baynum: "c Gem"         , hrnum: "HR2983"        , flamnum: "FL 76 Gem"        , saonum: "SAO 79650"   , ppmnum: "PPM97900"    , varname: ""            , hipnum: "HIP37704"    , starname: ""                , alphah:  7.0 , alpham: 44.0 , alphas:  6.91 , plusmin:  +1 , deltag:  25.0 , deltam: 47.0 , deltas:  3.0  , orig: "iras"	   , spectype: "K5III"       , parallax:     5.48  , parerr:	 0.73  , promot: " PROMOT  -0.02  -0.02" , vmag:   5.31  , hmag:   0.00  , irastwelvemu:     7.53  , qual:   3  , ftwelve:    0.00  , ones:  0.0  , diam:   2.52  , errdiam:  0.28  , simrem: "Variable Star	   " , hvartype: ""	 , multflag: ""  , compid: ""	   , theta:	0 , rho:   0.00 , compmagdiff: 0.00 , notes: ""  , hdnotes: "" , hdmoent: ""  , hdmcoment: "" },$ 
{ name: "HD62345"        , baynum: "kap Gem"       , hrnum: "HR2985"        , flamnum: "FL 77 Gem"        , saonum: "SAO 79653"   , ppmnum: "PPM97908"    , varname: ""            , hipnum: "HIP37740"    , starname: ""                , alphah:  7.0 , alpham: 44.0 , alphas: 26.85 , plusmin:  +1 , deltag:  24.0 , deltam: 23.0 , deltas: 52.8  , orig: "iras"	   , spectype: "G8IIIa"      , parallax:    22.73  , parerr:	 0.83  , promot: " PROMOT  -0.03  -0.06" , vmag:   3.57  , hmag:   0.00  , irastwelvemu:      8.0  , qual:   3  , ftwelve:    0.00  , ones:  0.0  , diam:   2.47  , errdiam:  0.17  , simrem: "Eclipsing binary      " , hvartype: "C"      , multflag: ""  , compid: ""      , theta:     0 , rho:   0.00 , compmagdiff: 0.00 , notes: ""  , hdnotes: "" , hdmoent: "Y" , hdmcoment: "" },$ 
{ name: "HD62509"        , baynum: "bet Gem"       , hrnum: "HR2990"        , flamnum: "FL 78 Gem"        , saonum: "SAO 79666"   , ppmnum: "PPM97924"    , varname: ""            , hipnum: "HIP37826"    , starname: "POLLUX"          , alphah:  7.0 , alpham: 45.0 , alphas: 18.95 , plusmin:  +1 , deltag:  28.0 , deltam:  1.0 , deltas: 34.3  , orig: "iras"	   , spectype: "K0IIIb"      , parallax:    96.74  , parerr:	 0.87  , promot: " PROMOT  -0.63  -0.07" , vmag:   1.15  , hmag:  -0.59  , irastwelvemu:    85.93  , qual:   3  , ftwelve:    0.00  , ones:  0.0  , diam:   6.11  , errdiam:  0.07  , simrem: "Variable Star	   " , hvartype: "M"	  , multflag: ""  , compid: ""      , theta:	 0 , rho:   0.00 , compmagdiff: 0.00 , notes: ""  , hdnotes: "" , hdmoent: ""  , hdmcoment: "" },$ 
{ name: "HD62721"        , baynum: "g Gem"         , hrnum: "HR3003"        , flamnum: "FL 81 Gem"        , saonum: "SAO 97221"   , ppmnum: "PPM124413"   , varname: ""            , hipnum: "HIP37908"    , starname: ""                , alphah:  7.0 , alpham: 46.0 , alphas:  7.45 , plusmin:  +1 , deltag:  18.0 , deltam: 30.0 , deltas: 36.2  , orig: "iras"	   , spectype: "K4III"       , parallax:     9.55  , parerr:	 0.83  , promot: " PROMOT  -0.07  -0.06" , vmag:   4.88  , hmag:   0.00  , irastwelvemu:     9.55  , qual:   3  , ftwelve:    0.00  , ones:  0.0  , diam:   2.75  , errdiam:  0.15  , simrem: "Star	    " , hvartype: "M"	   , multflag: ""  , compid: ""      , theta:	  0 , rho:   0.00 , compmagdiff: 0.00 , notes: "G" , hdnotes: "" , hdmoent: ""  , hdmcoment: "" },$ 
{ name: "HD62898"        , baynum: "pi. Gem"       , hrnum: "HR3013"        , flamnum: "FL 80 Gem"        , saonum: "SAO 60340"   , ppmnum: "PPM73110"    , varname: ""            , hipnum: "HIP38016"    , starname: ""                , alphah:  7.0 , alpham: 47.0 , alphas: 30.32 , plusmin:  +1 , deltag:  33.0 , deltam: 24.0 , deltas: 56.5  , orig: "iras"	   , spectype: "M0III"       , parallax:      5.8  , parerr:	 0.81  , promot: " PROMOT  -0.03  -0.05" , vmag:   5.15  , hmag:   0.00  , irastwelvemu:    12.24  , qual:   3  , ftwelve:    0.00  , ones:  0.0  , diam:   2.45  , errdiam:  0.13  , simrem: "Variable Star	   " , hvartype: "U"	  , multflag: ""  , compid: ""      , theta:	 0 , rho:   0.00 , compmagdiff: 0.00 , notes: ""  , hdnotes: "" , hdmoent: ""  , hdmcoment: "" },$ 
{ name: "HD63640"        , baynum: ""              , hrnum: "HR3041"        , flamnum: ""                 , saonum: "SAO219006"   , ppmnum: "PPM312172"   , varname: "V* T Pup"    , hipnum: "HIP38074"    , starname: ""                , alphah:  7.0 , alpham: 48.0 , alphas:  8.55 , plusmin:  -1 , deltag:  40.0 , deltam: 39.0 , deltas:  8.6  , orig: "iras"	   , spectype: "M2III"       , parallax:     5.43  , parerr:	 0.55  , promot: " PROMOT  -0.01  -0.03" , vmag:   6.17  , hmag:   1.76  , irastwelvemu:     8.36  , qual:   3  , ftwelve:    0.00  , ones:  0.0  , diam:   2.81  , errdiam:  0.11  , simrem: "Variable Star	   " , hvartype: "U"	  , multflag: ""  , compid: ""      , theta:	 0 , rho:   0.00 , compmagdiff: 0.00 , notes: ""  , hdnotes: "" , hdmoent: ""  , hdmcoment: "" },$ 
{ name: "HD63700"        , baynum: "ksi Pup"       , hrnum: "HR3045"        , flamnum: "FL 7 Pup"         , saonum: "SAO174601"   , ppmnum: "PPM253258"   , varname: ""            , hipnum: "HIP38170"    , starname: ""                , alphah:  7.0 , alpham: 49.0 , alphas: 17.66 , plusmin:  -1 , deltag:  24.0 , deltam: 51.0 , deltas: 35.2  , orig: "msx"	   , spectype: "G6Ia"	     , parallax:     2.42  , parerr:	 0.74  , promot: " PROMOT  -0.01      0" , vmag:   3.34  , hmag:   1.01  , irastwelvemu:     0.00  , qual:   0  , ftwelve:   14.09  , ones:  3.2  , diam:   3.24  , errdiam:  0.15  , simrem: "Eclipsing binary      " , hvartype: "U"      , multflag: ""  , compid: ""      , theta:     0 , rho:   0.00 , compmagdiff: 0.00 , notes: ""  , hdnotes: "" , hdmoent: ""  , hdmcoment: "" },$ 
{ name: "HD63852"        , baynum: ""              , hrnum: "HR3052"        , flamnum: ""                 , saonum: "SAO198487"   , ppmnum: "PPM284474"   , varname: ""            , hipnum: "HIP38200"    , starname: ""                , alphah:  7.0 , alpham: 49.0 , alphas:  35.4 , plusmin:  -1 , deltag:  33.0 , deltam: 17.0 , deltas: 20.2  , orig: "msx"	   , spectype: "K5III"       , parallax:     4.72  , parerr:	 0.58  , promot: " PROMOT  -0.05      0" , vmag:   5.62  , hmag:   0.00  , irastwelvemu:     0.00  , qual:   0  , ftwelve:     7.7  , ones:  3.9  , diam:   2.38  , errdiam:  0.22  , simrem: "Variable Star	   " , hvartype: "U"	  , multflag: ""  , compid: ""      , theta:	 0 , rho:   0.00 , compmagdiff: 0.00 , notes: ""  , hdnotes: "" , hdmoent: ""  , hdmcoment: "" },$ 
{ name: "HD63696"        , baynum: ""              , hrnum: ""              , flamnum: ""                 , saonum: "SAO153453"   , ppmnum: "PPM219248"   , varname: ""            , hipnum: "HIP38206"    , starname: ""                , alphah:  7.0 , alpham: 49.0 , alphas: 39.98 , plusmin:  -1 , deltag:  14.0 , deltam:  5.0 , deltas:  7.3  , orig: "iras"	   , spectype: "K5III"       , parallax:     3.47  , parerr:	  0.8  , promot: " PROMOT  -0.07   0.01" , vmag:   6.37  , hmag:   0.00  , irastwelvemu:     5.02  , qual:   3  , ftwelve:    0.00  , ones:  0.0  , diam:   0.00  , errdiam:  0.00  , simrem: "Variable Star	   " , hvartype: "U"	  , multflag: ""  , compid: ""      , theta:	 0 , rho:   0.00 , compmagdiff: 0.00 , notes: ""  , hdnotes: "" , hdmoent: ""  , hdmcoment: "" },$ 
{ name: "HD63915"        , baynum: ""              , hrnum: ""              , flamnum: ""                 , saonum: "SAO174636"   , ppmnum: "PPM253293"   , varname: ""            , hipnum: ""            , starname: ""                , alphah:  7.0 , alpham: 50.0 , alphas: 19.54 , plusmin:  -1 , deltag:  27.0 , deltam: 58.0 , deltas: 21.0  , orig: "msx"	   , spectype: "M5II/III"    , parallax:     0.00  , parerr:	 0.00  , promot: " PROMOT  -0.01  -0.01" , vmag:   7.85  , hmag:   0.00  , irastwelvemu:     0.00  , qual:   0  , ftwelve:    6.05  , ones:  4.1  , diam:   0.00  , errdiam:  0.00  , simrem: "Variable Star	   " , hvartype: ""	 , multflag: ""  , compid: ""	   , theta:	0 , rho:   0.00 , compmagdiff: 0.00 , notes: ""  , hdnotes: "" , hdmoent: ""  , hdmcoment: "" },$ 
{ name: "HD64440"        , baynum: "a Pup"         , hrnum: "HR3080"        , flamnum: ""                 , saonum: "SAO219082"   , ppmnum: "PPM312247"   , varname: ""            , hipnum: "HIP38414"    , starname: ""                , alphah:  7.0 , alpham: 52.0 , alphas: 13.03 , plusmin:  -1 , deltag:  40.0 , deltam: 34.0 , deltas: 32.8  , orig: "iras"	   , spectype: "K1.5II+..."  , parallax:     9.46  , parerr:	  0.5  , promot: " PROMOT  -0.02      0" , vmag:   3.72  , hmag:   0.00  , irastwelvemu:    10.73  , qual:   3  , ftwelve:    0.00  , ones:  0.0  , diam:   2.45  , errdiam:  0.12  , simrem: "Spectroscopic binary	  " , hvartype: ""	, multflag: "G"  , compid: ""	   , theta:	0 , rho:   0.00 , compmagdiff: 0.00 , notes: "D" , hdnotes: "An orbital solution based on elements by S.B.Parsons, Astrophys.J.Supp. Ser., 53, 553, 1983, gives a semi-major axis of 33 mas for the photocentre." , hdmoent: ""  , hdmcoment: "" },$ 
{ name: "HD65183"        , baynum: ""              , hrnum: "HR3099"        , flamnum: ""                 , saonum: "SAO198609"   , ppmnum: "PPM284597"   , varname: "V* PX Pup"   , hipnum: "HIP38792"    , starname: ""                , alphah:  7.0 , alpham: 56.0 , alphas: 22.72 , plusmin:  -1 , deltag:  30.0 , deltam: 17.0 , deltas:  4.5  , orig: "msx"	   , spectype: "M6III"       , parallax:     2.67  , parerr:	 0.71  , promot: " PROMOT      0  -0.03" , vmag:    6.4  , hmag:   0.00  , irastwelvemu:     0.00  , qual:   0  , ftwelve:   30.67  , ones:  3.0  , diam:   1.43  , errdiam:  0.21  , simrem: "Variable Star	   " , hvartype: "U"	  , multflag: ""  , compid: ""      , theta:	 0 , rho:   0.00 , compmagdiff: 0.00 , notes: ""  , hdnotes: "" , hdmoent: ""  , hdmcoment: "" },$ 
{ name: "HD65953"        , baynum: ""              , hrnum: "HR3141"        , flamnum: "FL 28 Mon"        , saonum: "SAO135380"   , ppmnum: "PPM177237"   , varname: "V*V645 Mon"  , hipnum: "HIP39211"    , starname: ""                , alphah:  8.0 , alpham:  1.0 , alphas: 13.33 , plusmin:  -1 , deltag:   1.0 , deltam: 23.0 , deltas: 33.4  , orig: "iras"	   , spectype: "K4III"       , parallax:      6.9  , parerr:	 0.94  , promot: " PROMOT   0.06  -0.08" , vmag:   4.69  , hmag:   0.00  , irastwelvemu:     11.9  , qual:   3  , ftwelve:    0.00  , ones:  0.0  , diam:   3.00  , errdiam:  0.06  , simrem: "Variable Star	   " , hvartype: "M"	  , multflag: ""  , compid: ""      , theta:	 0 , rho:   0.00 , compmagdiff: 0.00 , notes: ""  , hdnotes: "" , hdmoent: ""  , hdmcoment: "" },$ 
{ name: "HD66435"        , baynum: ""              , hrnum: "HR3155"        , flamnum: ""                 , saonum: "SAO198725"   , ppmnum: "PPM284712"   , varname: ""            , hipnum: "HIP39299"    , starname: ""                , alphah:  8.0 , alpham:  2.0 , alphas:  6.13 , plusmin:  -1 , deltag:  37.0 , deltam:  3.0 , deltas:  0.1  , orig: "msx"	   , spectype: "M1III"       , parallax:     3.96  , parerr:	 0.58  , promot: " PROMOT   0.01  -0.01" , vmag:   6.36  , hmag:   0.00  , irastwelvemu:     0.00  , qual:   0  , ftwelve:    9.88  , ones:  3.5  , diam:   1.37  , errdiam:   0.1  , simrem: "Variable Star	   " , hvartype: "U"	  , multflag: ""  , compid: ""      , theta:	 0 , rho:   0.00 , compmagdiff: 0.00 , notes: ""  , hdnotes: "" , hdmoent: ""  , hdmcoment: "" },$ 
{ name: "HD66141"        , baynum: "G CMi"         , hrnum: "HR3145"        , flamnum: ""                 , saonum: "SAO116260"   , ppmnum: "PPM153760"   , varname: ""            , hipnum: "HIP39311"    , starname: ""                , alphah:  8.0 , alpham:  2.0 , alphas: 15.94 , plusmin:  +1 , deltag:   2.0 , deltam: 20.0 , deltas:  4.5  , orig: "iras"	   , spectype: "K2III"       , parallax:    12.49  , parerr:	 0.98  , promot: " PROMOT  -0.03    0.1" , vmag:    4.4  , hmag:   0.00  , irastwelvemu:     8.53  , qual:   3  , ftwelve:    0.00  , ones:  0.0  , diam:   2.53  , errdiam:  0.07  , simrem: "Eclipsing binary      " , hvartype: "C"      , multflag: ""  , compid: ""      , theta:     0 , rho:   0.00 , compmagdiff: 0.00 , notes: ""  , hdnotes: "" , hdmoent: ""  , hdmcoment: "" },$ 
{ name: "HD67582"        , baynum: ""              , hrnum: "HR3187"        , flamnum: ""                 , saonum: "SAO219422"   , ppmnum: "PPM312586"   , varname: ""            , hipnum: "HIP39690"    , starname: ""                , alphah:  8.0 , alpham:  6.0 , alphas: 40.34 , plusmin:  -1 , deltag:  45.0 , deltam: 15.0 , deltas: 57.7  , orig: "iras"	   , spectype: "K3III"       , parallax:     2.63  , parerr:	 0.51  , promot: " PROMOT  -0.01      0" , vmag:   5.04  , hmag:   0.00  , irastwelvemu:     6.48  , qual:   3  , ftwelve:    0.00  , ones:  0.0  , diam:   2.47  , errdiam:  0.33  , simrem: "Variable Star	   " , hvartype: "M"	  , multflag: ""  , compid: ""      , theta:	 0 , rho:   0.00 , compmagdiff: 0.00 , notes: ""  , hdnotes: "" , hdmoent: ""  , hdmcoment: "" },$ 
{ name: "HD67523"        , baynum: "rho Pup"       , hrnum: "HR3185"        , flamnum: "FL 15 Pup"        , saonum: "SAO175217"   , ppmnum: "PPM253887"   , varname: "V* rho Pup"  , hipnum: "HIP39757"    , starname: ""                , alphah:  8.0 , alpham:  7.0 , alphas: 32.65 , plusmin:  -1 , deltag:  24.0 , deltam: 18.0 , deltas: 15.6  , orig: "iras"	   , spectype: "F6IIp..."    , parallax:    51.99  , parerr:	 0.66  , promot: " PROMOT  -0.09   0.05" , vmag:   2.81  , hmag:   0.00  , irastwelvemu:     5.07  , qual:   3  , ftwelve:    0.00  , ones:  0.0  , diam:   1.41  , errdiam:  0.02  , simrem: "Variable Star of delta Sct type   " , hvartype: "P"	, multflag: ""  , compid: ""	  , theta:     0 , rho:   0.00 , compmagdiff: 0.00 , notes: "P" , hdnotes: "" , hdmoent: ""  , hdmcoment: "" },$ 
{ name: "HD68553"        , baynum: "h01 Pup"       , hrnum: "HR3225"        , flamnum: ""                 , saonum: "SAO198908"   , ppmnum: "PPM284900"   , varname: "V* NS Pup"   , hipnum: "HIP40091"    , starname: ""                , alphah:  8.0 , alpham: 11.0 , alphas: 21.49 , plusmin:  -1 , deltag:  39.0 , deltam: 37.0 , deltas:  6.8  , orig: "msx"	   , spectype: "K3Ib"	     , parallax:     1.74  , parerr:	 0.52  , promot: " PROMOT  -0.01  -0.01" , vmag:   4.44  , hmag:   0.00  , irastwelvemu:     0.00  , qual:   0  , ftwelve:   16.45  , ones:  3.1  , diam:   4.01  , errdiam:  0.55  , simrem: "Variable Star	   " , hvartype: "U"	  , multflag: ""  , compid: ""      , theta:	 0 , rho:   0.00 , compmagdiff: 0.00 , notes: ""  , hdnotes: "" , hdmoent: ""  , hdmcoment: "" },$ 
{ name: "HD68623"        , baynum: ""              , hrnum: ""              , flamnum: ""                 , saonum: "SAO198918"   , ppmnum: "PPM284915"   , varname: "V*V427 Pup"  , hipnum: "HIP40144"    , starname: ""                , alphah:  8.0 , alpham: 11.0 , alphas: 53.36 , plusmin:  -1 , deltag:  35.0 , deltam: 46.0 , deltas: 22.9  , orig: "msx"	   , spectype: "M5/M6III"    , parallax:     3.44  , parerr:	  0.6  , promot: " PROMOT   0.02  -0.02" , vmag:   6.74  , hmag:   0.00  , irastwelvemu:     0.00  , qual:   0  , ftwelve:   15.13  , ones:  3.1  , diam:   0.00  , errdiam:  0.00  , simrem: "Variable of BY Dra type     " , hvartype: "U"	  , multflag: ""  , compid: ""      , theta:	 0 , rho:   0.00 , compmagdiff: 0.00 , notes: ""  , hdnotes: "" , hdmoent: ""  , hdmcoment: "" },$ 
{ name: "HD69194"        , baynum: ""              , hrnum: "HR3247"        , flamnum: "FL 16 Vel"        , saonum: "SAO235819"   , ppmnum: "PPM336742"   , varname: ""            , hipnum: "HIP40282"    , starname: ""                , alphah:  8.0 , alpham: 13.0 , alphas: 34.25 , plusmin:  -1 , deltag:  50.0 , deltam: 11.0 , deltas: 45.9  , orig: "iras"	   , spectype: "M1III"       , parallax:     4.33  , parerr:	 0.49  , promot: " PROMOT   0.01  -0.01" , vmag:   5.54  , hmag:   1.52  , irastwelvemu:     9.92  , qual:   3  , ftwelve:    0.00  , ones:  0.0  , diam:   2.76  , errdiam:  0.13  , simrem: "Variable Star	   " , hvartype: "U"	  , multflag: ""  , compid: ""      , theta:	 0 , rho:   0.00 , compmagdiff: 0.00 , notes: ""  , hdnotes: "" , hdmoent: ""  , hdmcoment: "" },$ 
{ name: "HD69142"        , baynum: "h02 Pup"       , hrnum: "HR3243"        , flamnum: ""                 , saonum: "SAO219635"   , ppmnum: "PPM312790"   , varname: ""            , hipnum: "HIP40326"    , starname: ""                , alphah:  8.0 , alpham: 14.0 , alphas:  2.92 , plusmin:  -1 , deltag:  40.0 , deltam: 20.0 , deltas: 52.4  , orig: "msx"	   , spectype: "K1II-III"    , parallax:     10.5  , parerr:	 0.52  , promot: " PROMOT   0.04  -0.07" , vmag:   4.43  , hmag:   0.00  , irastwelvemu:     0.00  , qual:   0  , ftwelve:    5.72  , ones:  4.3  , diam:   2.07  , errdiam:  0.04  , simrem: "Spectroscopic binary	  " , hvartype: ""	, multflag: "O"  , compid: ""	   , theta:	0 , rho:   0.00 , compmagdiff: 0.00 , notes: ""  , hdnotes: "" , hdmoent: ""  , hdmcoment: "Y" },$
{ name: "HD71701"        , baynum: "the Cha"       , hrnum: "HR3340"        , flamnum: ""                 , saonum: "SAO256503"   , ppmnum: "PPM369901"   , varname: ""            , hipnum: "HIP40888"    , starname: ""                , alphah:  8.0 , alpham: 20.0 , alphas: 38.54 , plusmin:  -1 , deltag:  77.0 , deltam: 29.0 , deltas:  4.1  , orig: "iras"	   , spectype: "K1III"       , parallax:    21.22  , parerr:	 0.47  , promot: " PROMOT  -0.13   0.03" , vmag:   4.35  , hmag:   0.00  , irastwelvemu:     6.05  , qual:   3  , ftwelve:    0.00  , ones:  0.0  , diam:    2.3  , errdiam:  0.04  , simrem: "Eclipsing binary      " , hvartype: "C"      , multflag: ""  , compid: ""      , theta:     0 , rho:   0.00 , compmagdiff: 0.00 , notes: ""  , hdnotes: "" , hdmoent: ""  , hdmcoment: "" },$ 
{ name: "HD70555"        , baynum: "w Pup"         , hrnum: "HR3282"        , flamnum: ""                 , saonum: "SAO199118"   , ppmnum: "PPM285122"   , varname: ""            , hipnum: "HIP40945"    , starname: ""                , alphah:  8.0 , alpham: 21.0 , alphas: 23.03 , plusmin:  -1 , deltag:  33.0 , deltam:  3.0 , deltas: 15.7  , orig: "msx"	   , spectype: "K1III"       , parallax:     3.89  , parerr:	  0.6  , promot: " PROMOT  -0.01   0.01" , vmag:   4.83  , hmag:   0.00  , irastwelvemu:     0.00  , qual:   0  , ftwelve:     5.6  , ones:  4.7  , diam:   2.54  , errdiam:  0.14  , simrem: "Star	    " , hvartype: ""	  , multflag: ""  , compid: ""      , theta:	 0 , rho:   0.00 , compmagdiff: 0.00 , notes: ""  , hdnotes: "" , hdmoent: ""  , hdmcoment: "" },$ 
{ name: "HD70276"        , baynum: ""              , hrnum: ""              , flamnum: ""                 , saonum: "SAO 97753"   , ppmnum: "PPM125169"   , varname: "V*V Cnc "    , hipnum: "HIP40977"    , starname: ""                , alphah:  8.0 , alpham: 21.0 , alphas: 42.86 , plusmin:  +1 , deltag:  17.0 , deltam: 17.0 , deltas:  6.8  , orig: "iras"	   , spectype: "Sevar"       , parallax:    26.58  , parerr:	42.74  , promot: " PROMOT      0   0.01" , vmag:    7.5  , hmag:   0.00  , irastwelvemu:     5.89  , qual:   3  , ftwelve:    0.00  , ones:  0.0  , diam:   0.14  , errdiam:  0.07  , simrem: "Variable Star of Mira Cet type	 " , hvartype: "P"	, multflag: "X"  , compid: ""	   , theta:	0 , rho:   0.00 , compmagdiff: 0.00 , notes: "Y" , hdnotes: "" , hdmoent: ""  , hdmcoment: "" },$ 
{ name: "HD70946"        , baynum: ""              , hrnum: "HR3296"        , flamnum: ""                 , saonum: "SAO199166"   , ppmnum: "PPM285170"   , varname: "V*V436 Pup"  , hipnum: "HIP41107"    , starname: ""                , alphah:  8.0 , alpham: 23.0 , alphas: 16.93 , plusmin:  -1 , deltag:  38.0 , deltam: 17.0 , deltas:  9.9  , orig: "iras"	   , spectype: "M1III"       , parallax:     2.33  , parerr:	 0.55  , promot: " PROMOT   0.02  -0.01" , vmag:   6.33  , hmag:   0.00  , irastwelvemu:     9.75  , qual:   3  , ftwelve:     9.4  , ones:  3.3  , diam:   1.45  , errdiam:  0.23  , simrem: "Variable Star	   " , hvartype: "U"	  , multflag: ""  , compid: ""      , theta:	 0 , rho:   0.00 , compmagdiff: 0.00 , notes: ""  , hdnotes: "" , hdmoent: ""  , hdmcoment: "" },$ 
{ name: "HD71250"        , baynum: ""              , hrnum: "HR3319"        , flamnum: "FL 27 Cnc"        , saonum: "SAO 97819"   , ppmnum: "PPM125269"   , varname: "V* BP Cnc"   , hipnum: "HIP41400"    , starname: ""                , alphah:  8.0 , alpham: 26.0 , alphas: 43.94 , plusmin:  +1 , deltag:  12.0 , deltam: 39.0 , deltas: 16.6  , orig: "iras"	   , spectype: "M3III"       , parallax:      3.1  , parerr:	  1.1  , promot: " PROMOT  -0.03   -0.1" , vmag:   5.59  , hmag:   0.00  , irastwelvemu:    20.51  , qual:   3  , ftwelve:    0.00  , ones:  0.0  , diam:   4.39  , errdiam:  0.06  , simrem: "Variable Star	   " , hvartype: "U"	  , multflag: ""  , compid: ""      , theta:	 0 , rho:   0.00 , compmagdiff: 0.00 , notes: "P" , hdnotes: "" , hdmoent: ""  , hdmcoment: "" },$ 
{ name: "HD72094"        , baynum: "the Cnc"       , hrnum: "HR3357"        , flamnum: "FL 31 Cnc"        , saonum: "SAO 97881"   , ppmnum: "PPM125369"   , varname: ""            , hipnum: "HIP41822"    , starname: ""                , alphah:  8.0 , alpham: 31.0 , alphas: 35.73 , plusmin:  +1 , deltag:  18.0 , deltam:  5.0 , deltas: 39.9  , orig: "iras"	   , spectype: "K5III"       , parallax:      6.6  , parerr:	 0.92  , promot: " PROMOT  -0.06  -0.06" , vmag:   5.37  , hmag:   0.00  , irastwelvemu:     9.16  , qual:   3  , ftwelve:    0.00  , ones:  0.0  , diam:   2.52  , errdiam:  0.01  , simrem: "Eclipsing binary      " , hvartype: "U"      , multflag: ""  , compid: ""      , theta:     0 , rho:   0.00 , compmagdiff: 0.00 , notes: ""  , hdnotes: "" , hdmoent: ""  , hdmcoment: "" },$ 
{ name: "HD72342"        , baynum: ""              , hrnum: ""              , flamnum: ""                 , saonum: "SAO116873"   , ppmnum: "PPM154624"   , varname: ""            , hipnum: ""            , starname: ""                , alphah:  8.0 , alpham: 32.0 , alphas: 35.01 , plusmin:  +1 , deltag:   8.0 , deltam: 29.0 , deltas: 20.0  , orig: "iras"	   , spectype: "M..."	     , parallax:     0.00  , parerr:	 0.00  , promot: " PROMOT      0      0" , vmag:    8.5  , hmag:   0.00  , irastwelvemu:     5.22  , qual:   3  , ftwelve:    0.00  , ones:  0.0  , diam:   0.41  , errdiam:  0.12  , simrem: "Eclipsing binary      " , hvartype: ""	   , multflag: ""  , compid: ""      , theta:	  0 , rho:   0.00 , compmagdiff: 0.00 , notes: ""  , hdnotes: "" , hdmoent: ""  , hdmcoment: "" },$ 
{ name: "HD73341"        , baynum: ""              , hrnum: ""              , flamnum: ""                 , saonum: "SAO236108"   , ppmnum: "PPM337052"   , varname: "V* NUVel"    , hipnum: "HIP42161"    , starname: ""                , alphah:  8.0 , alpham: 35.0 , alphas: 41.05 , plusmin:  -1 , deltag:  52.0 , deltam: 19.0 , deltas: 20.3  , orig: "msx"	   , spectype: "M3/M4III"    , parallax:     1.88  , parerr:	 0.63  , promot: " PROMOT      0      0" , vmag:   7.58  , hmag:   0.00  , irastwelvemu:     0.00  , qual:   0  , ftwelve:    7.55  , ones:  3.1  , diam:   0.00  , errdiam:  0.00  , simrem: "Pulsating variable Star     " , hvartype: "U"	  , multflag: ""  , compid: ""      , theta:	 0 , rho:   0.00 , compmagdiff: 0.00 , notes: "P" , hdnotes: "" , hdmoent: ""  , hdmcoment: "" },$ 
{ name: "HD73840"        , baynum: "a Hya"         , hrnum: "HR3431"        , flamnum: "FL 6 Hya"         , saonum: "SAO154515"   , ppmnum: "PPM220446"   , varname: ""            , hipnum: "HIP42509"    , starname: ""                , alphah:  8.0 , alpham: 40.0 , alphas:  1.47 , plusmin:  -1 , deltag:  12.0 , deltam: 28.0 , deltas: 31.3  , orig: "iras"	   , spectype: "K3III"       , parallax:     7.78  , parerr:	 0.82  , promot: " PROMOT  -0.09  -0.01" , vmag:   4.99  , hmag:   0.00  , irastwelvemu:     6.85  , qual:   3  , ftwelve:    0.00  , ones:  0.0  , diam:   2.46  , errdiam:  0.12  , simrem: "Star	    " , hvartype: ""	  , multflag: ""  , compid: ""      , theta:	 0 , rho:   0.00 , compmagdiff: 0.00 , notes: ""  , hdnotes: "" , hdmoent: ""  , hdmcoment: "" },$ 
{ name: "HD74006"        , baynum: "bet Pyx"       , hrnum: "HR3438"        , flamnum: ""                 , saonum: "SAO199490"   , ppmnum: "PPM285512"   , varname: ""            , hipnum: "HIP42515"    , starname: ""                , alphah:  8.0 , alpham: 40.0 , alphas:  6.14 , plusmin:  -1 , deltag:  35.0 , deltam: 18.0 , deltas: 30.1  , orig: "iras"	   , spectype: "G7Ib-II"     , parallax:      8.4  , parerr:	 0.55  , promot: " PROMOT   0.01  -0.02" , vmag:   3.97  , hmag:   0.00  , irastwelvemu:     5.23  , qual:   3  , ftwelve:    0.00  , ones:  0.0  , diam:   1.98  , errdiam:  0.05  , simrem: "Eclipsing binary      " , hvartype: "C"      , multflag: ""  , compid: ""      , theta:     0 , rho:   0.00 , compmagdiff: 0.00 , notes: ""  , hdnotes: "" , hdmoent: ""  , hdmcoment: "" },$ 
{ name: "HD74167"        , baynum: ""              , hrnum: "HR3444"        , flamnum: ""                 , saonum: "SAO220261"   , ppmnum: "PPM313394"   , varname: ""            , hipnum: "HIP42564"    , starname: ""                , alphah:  8.0 , alpham: 40.0 , alphas: 35.26 , plusmin:  -1 , deltag:  45.0 , deltam: 11.0 , deltas: 28.0  , orig: "msx"	   , spectype: "M0III"       , parallax:     3.43  , parerr:	 0.55  , promot: " PROMOT   0.01  -0.01" , vmag:   5.69  , hmag:   1.71  , irastwelvemu:     0.00  , qual:   0  , ftwelve:     7.9  , ones:  3.8  , diam:   2.62  , errdiam:  0.12  , simrem: "Variable Star	   " , hvartype: "U"	  , multflag: ""  , compid: ""      , theta:	 0 , rho:   0.00 , compmagdiff: 0.00 , notes: ""  , hdnotes: "" , hdmoent: ""  , hdmcoment: "" },$ 
{ name: "HD74180"        , baynum: "b Vel"         , hrnum: "HR3445"        , flamnum: ""                 , saonum: "SAO220265"   , ppmnum: "PPM313395"   , varname: ""            , hipnum: "HIP42570"    , starname: ""                , alphah:  8.0 , alpham: 40.0 , alphas: 37.57 , plusmin:  -1 , deltag:  46.0 , deltam: 38.0 , deltas: 55.5  , orig: "msx"	   , spectype: "F3Ia"	     , parallax:     1.05  , parerr:	 0.49  , promot: " PROMOT      0      0" , vmag:   3.82  , hmag:   0.00  , irastwelvemu:     0.00  , qual:   0  , ftwelve:    7.05  , ones:  4.2  , diam:   2.38  , errdiam:  0.39  , simrem: "Variable Star	   " , hvartype: "U"	  , multflag: ""  , compid: ""      , theta:	 0 , rho:   0.00 , compmagdiff: 0.00 , notes: ""  , hdnotes: "" , hdmoent: ""  , hdmcoment: "" },$ 
{ name: "HD74157"        , baynum: ""              , hrnum: ""              , flamnum: ""                 , saonum: "SAO136193"   , ppmnum: "PPM191616"   , varname: "V* MW Hya"   , hipnum: "HIP42700"    , starname: ""                , alphah:  8.0 , alpham: 42.0 , alphas:  9.37 , plusmin:  -1 , deltag:   3.0 , deltam:  2.0 , deltas: 59.7  , orig: "iras"	   , spectype: "M..."	     , parallax:     1.07  , parerr:	 1.05  , promot: " PROMOT   0.01  -0.02" , vmag:    7.5  , hmag:   0.00  , irastwelvemu:     7.16  , qual:   3  , ftwelve:    0.00  , ones:  0.0  , diam:   0.00  , errdiam:  0.00  , simrem: "Variable Star of irregular type   " , hvartype: "U"	, multflag: ""  , compid: ""	  , theta:     0 , rho:   0.00 , compmagdiff: 0.00 , notes: ""  , hdnotes: "" , hdmoent: ""  , hdmcoment: "" },$ 
{ name: "HD74772"        , baynum: "d Vel"         , hrnum: "HR3477"        , flamnum: ""                 , saonum: "SAO220371"   , ppmnum: "PPM313500"   , varname: ""            , hipnum: "HIP42884"    , starname: ""                , alphah:  8.0 , alpham: 44.0 , alphas: 23.95 , plusmin:  -1 , deltag:  42.0 , deltam: 38.0 , deltas: 57.4  , orig: "iras"	   , spectype: "G5III"       , parallax:    14.27  , parerr:	 0.54  , promot: " PROMOT  -0.02   0.02" , vmag:   4.06  , hmag:   0.00  , irastwelvemu:     5.05  , qual:   3  , ftwelve:    0.00  , ones:  0.0  , diam:   1.74  , errdiam:  0.03  , simrem: "Eclipsing binary      " , hvartype: "C"      , multflag: ""  , compid: ""      , theta:     0 , rho:   0.00 , compmagdiff: 0.00 , notes: ""  , hdnotes: "" , hdmoent: ""  , hdmcoment: "" },$ 
{ name: "HD74442"        , baynum: "del Cnc"       , hrnum: "HR3461"        , flamnum: "FL 47 Cnc"        , saonum: "SAO 98087"   , ppmnum: "PPM125682"   , varname: ""            , hipnum: "HIP42911"    , starname: ""                , alphah:  8.0 , alpham: 44.0 , alphas:  41.1 , plusmin:  +1 , deltag:  18.0 , deltam:  9.0 , deltas: 15.5  , orig: "iras"	   , spectype: "K0III"       , parallax:    23.97  , parerr:	 0.83  , promot: " PROMOT  -0.02  -0.23" , vmag:   3.94  , hmag:   0.00  , irastwelvemu:     7.77  , qual:   3  , ftwelve:    0.00  , ones:  0.0  , diam:   2.34  , errdiam:  0.08  , simrem: "High proper-motion Star     " , hvartype: ""	 , multflag: ""  , compid: ""	   , theta:	0 , rho:   0.00 , compmagdiff: 0.00 , notes: ""  , hdnotes: "" , hdmoent: ""  , hdmcoment: "" },$ 
{ name: "HD74956"        , baynum: "del Vel"       , hrnum: "HR3485"        , flamnum: ""                 , saonum: "SAO236232"   , ppmnum: "PPM337198"   , varname: ""            , hipnum: "HIP42913"    , starname: ""                , alphah:  8.0 , alpham: 44.0 , alphas: 42.23 , plusmin:  -1 , deltag:  54.0 , deltam: 42.0 , deltas: 31.8  , orig: "iras"	   , spectype: "A1V"	     , parallax:     40.9  , parerr:	 0.38  , promot: " PROMOT   0.02  -0.08" , vmag:   1.95  , hmag:   1.78  , irastwelvemu:     5.77  , qual:   3  , ftwelve:    0.00  , ones:  0.0  , diam:   1.45  , errdiam:  0.01  , simrem: "Eclipsing binary      " , hvartype: "D"      , multflag: "C"  , compid: "AB"	 , theta:  5	, rho:  0.74	, compmagdiff:  3.58  , notes: ""  , hdnotes: "" , hdmoent: "Y" , hdmcoment: "" },$ 
{ name: "HD74739"        , baynum: "iot Cnc"       , hrnum: "HR3475"        , flamnum: "FL 48 Cnc"        , saonum: "SAO 80416"   , ppmnum: "PPM99032"    , varname: ""            , hipnum: "HIP43103"    , starname: ""                , alphah:  8.0 , alpham: 46.0 , alphas: 41.82 , plusmin:  +1 , deltag:  28.0 , deltam: 45.0 , deltas: 35.6  , orig: "iras"	   , spectype: "G8Iab"       , parallax:    10.94  , parerr:	 1.35  , promot: " PROMOT  -0.02  -0.05" , vmag:   4.03  , hmag:   0.00  , irastwelvemu:     5.63  , qual:   3  , ftwelve:    0.00  , ones:  0.0  , diam:   2.11  , errdiam:  0.07  , simrem: "Eclipsing binary      " , hvartype: "D"      , multflag: "C"  , compid: ""      , theta:     0 , rho:   0.00 , compmagdiff: 0.00 , notes: ""  , hdnotes: "" , hdmoent: "Y" , hdmcoment: "" },$ 
{ name: "HD74874"        , baynum: "eps Hya"       , hrnum: "HR3482"        , flamnum: "FL 11 Hya"        , saonum: "SAO117112"   , ppmnum: "PPM154963"   , varname: "V* eps Hya"  , hipnum: "HIP43109"    , starname: ""                , alphah:  8.0 , alpham: 46.0 , alphas: 46.51 , plusmin:  +1 , deltag:   6.0 , deltam: 25.0 , deltas:  7.7  , orig: "iras"	   , spectype: "G5III"       , parallax:    24.13  , parerr:	 1.29  , promot: " PROMOT  -0.23  -0.04" , vmag:   3.38  , hmag:   0.00  , irastwelvemu:     7.63  , qual:   3  , ftwelve:    0.00  , ones:  0.0  , diam:   1.98  , errdiam:  0.06  , simrem: "Variable of BY Dra type     " , hvartype: "D"	  , multflag: "C"  , compid: "AC"      , theta:  291  , rho:  2.87    , compmagdiff:  3.1   , notes: "W" , hdnotes: "Component A is really the photocentre of AB. The double-star analysis indicates that it is the fainter (C) component which is variable." , hdmoent: "Y" , hdmcoment: "" },$ 
{ name: "HD75156"        , baynum: ""              , hrnum: ""              , flamnum: ""                 , saonum: "SAO 98143"   , ppmnum: "PPM125772"   , varname: "V* FX Cnc"   , hipnum: "HIP43251"    , starname: ""                , alphah:  8.0 , alpham: 48.0 , alphas: 39.54 , plusmin:  +1 , deltag:  12.0 , deltam: 32.0 , deltas: 49.0  , orig: "iras"	   , spectype: "M0"	     , parallax:     2.24  , parerr:	 1.08  , promot: " PROMOT  -0.02      0" , vmag:   6.66  , hmag:   0.00  , irastwelvemu:     6.33  , qual:   3  , ftwelve:    0.00  , ones:  0.0  , diam:    1.2  , errdiam:  0.21  , simrem: "Variable of BY Dra type     " , hvartype: "U"	  , multflag: ""  , compid: ""      , theta:	 0 , rho:   0.00 , compmagdiff: 0.00 , notes: "P" , hdnotes: "" , hdmoent: ""  , hdmcoment: "" },$ 
{ name: "HD76294"        , baynum: "zet Hya"       , hrnum: "HR3547"        , flamnum: "FL 16 Hya"        , saonum: "SAO117264"   , ppmnum: "PPM155196"   , varname: ""            , hipnum: "HIP43813"    , starname: ""                , alphah:  8.0 , alpham: 55.0 , alphas: 23.63 , plusmin:  +1 , deltag:   5.0 , deltam: 56.0 , deltas: 44.0  , orig: "iras"	   , spectype: "G9II-III"    , parallax:    21.64  , parerr:	 0.99  , promot: " PROMOT   -0.1   0.01" , vmag:   3.13  , hmag:   0.95  , irastwelvemu:    13.74  , qual:   3  , ftwelve:    0.00  , ones:  0.0  , diam:   3.09  , errdiam:  0.02  , simrem: "Star	    " , hvartype: "C"	   , multflag: ""  , compid: ""      , theta:	  0 , rho:   0.00 , compmagdiff: 0.00 , notes: ""  , hdnotes: "" , hdmoent: ""  , hdmcoment: "" },$ 
{ name: "HD78004"        , baynum: "c Vel"         , hrnum: "HR3614"        , flamnum: ""                 , saonum: "SAO220803"   , ppmnum: "PPM313920"   , varname: ""            , hipnum: "HIP44511"    , starname: ""                , alphah:  9.0 , alpham:  4.0 , alphas:  9.28 , plusmin:  -1 , deltag:  47.0 , deltam:  5.0 , deltas: 51.9  , orig: "iras"	   , spectype: "K2III"       , parallax:    10.55  , parerr:	 0.53  , promot: " PROMOT  -0.05  -0.02" , vmag:   3.76  , hmag:   1.28  , irastwelvemu:    10.77  , qual:   3  , ftwelve:    9.76  , ones:  3.1  , diam:   2.76  , errdiam:  0.04  , simrem: "Star	    " , hvartype: ""	  , multflag: ""  , compid: ""      , theta:	 0 , rho:   0.00 , compmagdiff: 0.00 , notes: ""  , hdnotes: "" , hdmoent: ""  , hdmcoment: "" },$ 
{ name: "HD80007"        , baynum: "bet Car"       , hrnum: "HR3685"        , flamnum: ""                 , saonum: "SAO250495"   , ppmnum: "PPM357200"   , varname: ""            , hipnum: "HIP45238"    , starname: ""                , alphah:  9.0 , alpham: 13.0 , alphas: 11.98 , plusmin:  -1 , deltag:  69.0 , deltam: 43.0 , deltas:  1.9  , orig: "iras"	   , spectype: "A2IV"	     , parallax:    29.34  , parerr:	 0.47  , promot: " PROMOT  -0.15    0.1" , vmag:    1.7  , hmag:   1.52  , irastwelvemu:     6.85  , qual:   3  , ftwelve:    0.00  , ones:  0.0  , diam:   1.63  , errdiam:  0.03  , simrem: "Star	    " , hvartype: "M"	   , multflag: ""  , compid: ""      , theta:	  0 , rho:   0.00 , compmagdiff: 0.00 , notes: ""  , hdnotes: "" , hdmoent: ""  , hdmcoment: "" },$ 
{ name: "HD80108"        , baynum: ""              , hrnum: "HR3692"        , flamnum: ""                 , saonum: "SAO221014"   , ppmnum: "PPM314148"   , varname: ""            , hipnum: "HIP45505"    , starname: ""                , alphah:  9.0 , alpham: 16.0 , alphas: 23.04 , plusmin:  -1 , deltag:  44.0 , deltam: 15.0 , deltas: 56.6  , orig: "msx"	   , spectype: "K3Ib"	     , parallax:     0.81  , parerr:	 0.54  , promot: " PROMOT      0      0" , vmag:   5.13  , hmag:   1.48  , irastwelvemu:     0.00  , qual:   0  , ftwelve:    9.57  , ones:  3.7  , diam:   2.96  , errdiam:  0.51  , simrem: "Variable Star	   " , hvartype: "U"	  , multflag: ""  , compid: ""      , theta:	 0 , rho:   0.00 , compmagdiff: 0.00 , notes: ""  , hdnotes: "" , hdmoent: ""  , hdmcoment: "" },$ 
{ name: "HD80404"        , baynum: "iot Car"       , hrnum: "HR3699"        , flamnum: ""                 , saonum: "SAO236808"   , ppmnum: "PPM337789"   , varname: ""            , hipnum: "HIP45556"    , starname: ""                , alphah:  9.0 , alpham: 17.0 , alphas:  5.41 , plusmin:  -1 , deltag:  59.0 , deltam: 16.0 , deltas: 30.8  , orig: "iras"	   , spectype: "A8Ib"	     , parallax:     4.71  , parerr:	 0.46  , promot: " PROMOT  -0.02   0.01" , vmag:   2.25  , hmag:   1.58  , irastwelvemu:     7.23  , qual:   3  , ftwelve:    0.00  , ones:  0.0  , diam:   1.78  , errdiam:  0.12  , simrem: "Variable Star	   " , hvartype: ""	 , multflag: ""  , compid: ""	   , theta:	0 , rho:   0.00 , compmagdiff: 0.00 , notes: ""  , hdnotes: "" , hdmoent: ""  , hdmcoment: "" },$ 
{ name: "HD80493"        , baynum: "alf Lyn"       , hrnum: "HR3705"        , flamnum: "FL 40 Lyn"        , saonum: "SAO 61414"   , ppmnum: "PPM74424"    , varname: ""            , hipnum: "HIP45860"    , starname: ""                , alphah:  9.0 , alpham: 21.0 , alphas:   3.3 , plusmin:  +1 , deltag:  34.0 , deltam: 23.0 , deltas: 33.2  , orig: "iras"	   , spectype: "K7III"       , parallax:    14.69  , parerr:	 0.81  , promot: " PROMOT  -0.22   0.01" , vmag:   3.16  , hmag:   0.00  , irastwelvemu:    59.95  , qual:   3  , ftwelve:    0.00  , ones:  0.0  , diam:   6.63  , errdiam:  0.07  , simrem: "Variable Star	   " , hvartype: "M"	  , multflag: ""  , compid: ""      , theta:	 0 , rho:   0.00 , compmagdiff: 0.00 , notes: ""  , hdnotes: "" , hdmoent: ""  , hdmcoment: "" },$ 
{ name: "HD81034"        , baynum: ""              , hrnum: "HR3726"        , flamnum: ""                 , saonum: "SAO221103"   , ppmnum: "PPM314241"   , varname: ""            , hipnum: "HIP45924"    , starname: ""                , alphah:  9.0 , alpham: 21.0 , alphas: 50.99 , plusmin:  -1 , deltag:  42.0 , deltam: 11.0 , deltas: 41.5  , orig: "msx"	   , spectype: "M1III"       , parallax:     5.77  , parerr:	 0.57  , promot: " PROMOT   0.05  -0.06" , vmag:    5.6  , hmag:   1.33  , irastwelvemu:     0.00  , qual:   0  , ftwelve:   11.41  , ones:  3.1  , diam:   3.37  , errdiam:   0.1  , simrem: "Variable Star	   " , hvartype: "U"	  , multflag: ""  , compid: ""      , theta:	 0 , rho:   0.00 , compmagdiff: 0.00 , notes: ""  , hdnotes: "" , hdmoent: ""  , hdmcoment: "" },$ 
{ name: "HD81146"        , baynum: "kap Leo"       , hrnum: "HR3731"        , flamnum: "FL 1 Leo"         , saonum: "SAO 80807"   , ppmnum: "PPM99550"    , varname: ""            , hipnum: "HIP46146"    , starname: ""                , alphah:  9.0 , alpham: 24.0 , alphas: 39.26 , plusmin:  +1 , deltag:  26.0 , deltam: 10.0 , deltas: 56.4  , orig: "iras"	   , spectype: "K2III"       , parallax:    15.28  , parerr:	 0.83  , promot: " PROMOT  -0.03  -0.05" , vmag:   4.47  , hmag:   1.75  , irastwelvemu:     6.87  , qual:   3  , ftwelve:    0.00  , ones:  0.0  , diam:    2.3  , errdiam:  0.07  , simrem: "Double or multiple star     " , hvartype: "C"	  , multflag: ""  , compid: ""      , theta:	 0 , rho:   0.00 , compmagdiff: 0.00 , notes: ""  , hdnotes: "" , hdmoent: ""  , hdmcoment: "" },$ 
{ name: "HD81575"        , baynum: ""              , hrnum: ""              , flamnum: ""                 , saonum: "SAO221146"   , ppmnum: "PPM314288"   , varname: "V* GKVel"    , hipnum: "HIP46194"    , starname: ""                , alphah:  9.0 , alpham: 25.0 , alphas:  7.86 , plusmin:  -1 , deltag:  43.0 , deltam: 58.0 , deltas: 35.8  , orig: "iras"	   , spectype: "M3III"       , parallax:     4.13  , parerr:	  0.6  , promot: " PROMOT  -0.03   0.03" , vmag:   6.39  , hmag:   1.29  , irastwelvemu:    14.04  , qual:   3  , ftwelve:    0.00  , ones:  0.0  , diam:   3.49  , errdiam:   0.1  , simrem: "Variable Star	   " , hvartype: "U"	  , multflag: ""  , compid: ""      , theta:	 0 , rho:   0.00 , compmagdiff: 0.00 , notes: "P" , hdnotes: "" , hdmoent: ""  , hdmcoment: "" },$ 
{ name: "HD81420"        , baynum: ""              , hrnum: "HR3738"        , flamnum: "FL 28 Hya"        , saonum: "SAO136832"   , ppmnum: "PPM192352"   , varname: ""            , hipnum: "HIP46221"    , starname: ""                , alphah:  9.0 , alpham: 25.0 , alphas: 24.04 , plusmin:  -1 , deltag:   5.0 , deltam:  7.0 , deltas:  2.6  , orig: "iras"	   , spectype: "K5III"       , parallax:     4.83  , parerr:	 0.89  , promot: " PROMOT  -0.02  -0.02" , vmag:   5.59  , hmag:   1.29  , irastwelvemu:     5.15  , qual:   3  , ftwelve:    0.00  , ones:  0.0  , diam:   3.41  , errdiam:  0.02  , simrem: "Star	    " , hvartype: ""	  , multflag: ""  , compid: ""      , theta:	 0 , rho:   0.00 , compmagdiff: 0.00 , notes: ""  , hdnotes: "" , hdmoent: ""  , hdmcoment: "" },$ 
{ name: "HD81797"        , baynum: "alf Hya"       , hrnum: "HR3748"        , flamnum: "FL 30 Hya"        , saonum: "SAO136871"   , ppmnum: "PPM192393"   , varname: ""            , hipnum: "HIP46390"    , starname: "ALPHARD"         , alphah:  9.0 , alpham: 27.0 , alphas: 35.24 , plusmin:  -1 , deltag:   8.0 , deltam: 39.0 , deltas: 31.0  , orig: "iras"	   , spectype: "K3II-III"    , parallax:     18.4  , parerr:	 0.78  , promot: " PROMOT  -0.02   0.03" , vmag:  2.00   , hmag:  -1.09  , irastwelvemu:   108.69  , qual:   3  , ftwelve:    0.00  , ones:  0.0  , diam:   9.05  , errdiam:  0.05  , simrem: "Variable Star	   " , hvartype: "M"	  , multflag: ""  , compid: ""      , theta:	 0 , rho:   0.00 , compmagdiff: 0.00 , notes: ""  , hdnotes: "" , hdmoent: ""  , hdmcoment: "" },$ 
{ name: "HD82150"        , baynum: "eps Ant"       , hrnum: "HR3765"        , flamnum: ""                 , saonum: "SAO200416"   , ppmnum: "PPM286515"   , varname: ""            , hipnum: "HIP46515"    , starname: ""                , alphah:  9.0 , alpham: 29.0 , alphas: 14.72 , plusmin:  -1 , deltag:  35.0 , deltam: 57.0 , deltas:  4.8  , orig: "msx"	   , spectype: "K3IIIa"      , parallax:     4.66  , parerr:	 0.57  , promot: " PROMOT  -0.02  -0.01" , vmag:   4.51  , hmag:   1.46  , irastwelvemu:     0.00  , qual:   0  , ftwelve:    8.73  , ones:  3.1  , diam:   2.81  , errdiam:  0.12  , simrem: "Star	    " , hvartype: ""	  , multflag: ""  , compid: ""      , theta:	 0 , rho:   0.00 , compmagdiff: 0.00 , notes: ""  , hdnotes: "" , hdmoent: ""  , hdmcoment: "" },$ 
{ name: "HD82308"        , baynum: "lam Leo"       , hrnum: "HR3773"        , flamnum: "FL 4 Leo"         , saonum: "SAO 80885"   , ppmnum: "PPM99651"    , varname: ""            , hipnum: "HIP46750"    , starname: ""                , alphah:  9.0 , alpham: 31.0 , alphas: 43.23 , plusmin:  +1 , deltag:  22.0 , deltam: 58.0 , deltas:  4.7  , orig: "iras"	   , spectype: "K5III"       , parallax:     9.69  , parerr:	 0.89  , promot: " PROMOT  -0.03  -0.04" , vmag:   4.32  , hmag:   0.00  , irastwelvemu:    20.06  , qual:   3  , ftwelve:    0.00  , ones:  0.0  , diam:   3.84  , errdiam:  0.07  , simrem: "Variable Star	   " , hvartype: "M"	  , multflag: ""  , compid: ""      , theta:	 0 , rho:   0.00 , compmagdiff: 0.00 , notes: ""  , hdnotes: "" , hdmoent: ""  , hdmcoment: "" },$ 
{ name: "HD82381"        , baynum: "h Leo"         , hrnum: "HR3779"        , flamnum: "FL 6 Leo"         , saonum: "SAO117751"   , ppmnum: "PPM155930"   , varname: ""            , hipnum: "HIP46774"    , starname: ""                , alphah:  9.0 , alpham: 31.0 , alphas: 57.58 , plusmin:  +1 , deltag:   9.0 , deltam: 42.0 , deltas: 56.8  , orig: "iras"	   , spectype: "K2.5IIIb"    , parallax:     6.76  , parerr:	 0.85  , promot: " PROMOT  -0.01  -0.01" , vmag:   5.08  , hmag:   0.00  , irastwelvemu:     5.97  , qual:   3  , ftwelve:    0.00  , ones:  0.0  , diam:   2.05  , errdiam:  0.06  , simrem: "Eclipsing binary      " , hvartype: ""	   , multflag: ""  , compid: ""      , theta:	  0 , rho:   0.00 , compmagdiff: 0.00 , notes: ""  , hdnotes: "" , hdmoent: ""  , hdmcoment: "" },$ 
{ name: "HD83425"        , baynum: ""              , hrnum: "HR3834"        , flamnum: "FL 2 Sex"         , saonum: "SAO117821"   , ppmnum: "PPM156043"   , varname: ""            , hipnum: "HIP47310"    , starname: ""                , alphah:  9.0 , alpham: 38.0 , alphas: 27.29 , plusmin:  +1 , deltag:   4.0 , deltam: 38.0 , deltas: 57.5  , orig: "iras"	   , spectype: "K3III"       , parallax:     11.9  , parerr:	 0.95  , promot: " PROMOT  -0.16  -0.06" , vmag:   4.68  , hmag:   1.65  , irastwelvemu:     7.63  , qual:   3  , ftwelve:    0.00  , ones:  0.0  , diam:   2.44  , errdiam:  0.02  , simrem: "Star	    " , hvartype: ""	  , multflag: ""  , compid: ""      , theta:	 0 , rho:   0.00 , compmagdiff: 0.00 , notes: ""  , hdnotes: "" , hdmoent: ""  , hdmcoment: "" },$ 
{ name: "HD83618"        , baynum: "iot Hya"       , hrnum: "HR3845"        , flamnum: "FL 35 Hya"        , saonum: "SAO137035"   , ppmnum: "PPM177936"   , varname: ""            , hipnum: "HIP47431"    , starname: ""                , alphah:  9.0 , alpham: 39.0 , alphas: 51.36 , plusmin:  -1 , deltag:   1.0 , deltam:  8.0 , deltas: 34.1  , orig: "iras"	   , spectype: "K2.5III"     , parallax:    11.83  , parerr:	  0.8  , promot: " PROMOT   0.05  -0.07" , vmag:   3.91  , hmag:   0.00  , irastwelvemu:    13.64  , qual:   3  , ftwelve:    0.00  , ones:  0.0  , diam:   3.23  , errdiam:  0.02  , simrem: "Variable Star	   " , hvartype: ""	 , multflag: ""  , compid: ""	   , theta:	0 , rho:   0.00 , compmagdiff: 0.00 , notes: ""  , hdnotes: "" , hdmoent: ""  , hdmcoment: "" },$ 
{ name: "HD84810"        , baynum: "l Car"         , hrnum: "HR3884"        , flamnum: ""                 , saonum: "SAO250683"   , ppmnum: "PPM357533"   , varname: "V* l Car"    , hipnum: "HIP47854"    , starname: ""                , alphah:  9.0 , alpham: 45.0 , alphas: 14.81 , plusmin:  -1 , deltag:  62.0 , deltam: 30.0 , deltas: 28.4  , orig: "iras"	   , spectype: "G3Ib"	     , parallax:     2.16  , parerr:	 0.47  , promot: " PROMOT  -0.02      0" , vmag:    3.4  , hmag:   1.32  , irastwelvemu:    12.34  , qual:   3  , ftwelve:    0.00  , ones:  0.0  , diam:   2.82  , errdiam:   0.3  , simrem: "Classical Cepheid (delta Cep type)" , hvartype: "P"	, multflag: ""  , compid: ""	  , theta:     0 , rho:   0.00 , compmagdiff: 0.00 , notes: ""  , hdnotes: "" , hdmoent: ""  , hdmcoment: "" },$ 
{ name: "HD84441"        , baynum: "eps Leo"       , hrnum: "HR3873"        , flamnum: "FL 17 Leo"        , saonum: "SAO 81004"   , ppmnum: "PPM99836"    , varname: ""            , hipnum: "HIP47908"    , starname: ""                , alphah:  9.0 , alpham: 45.0 , alphas: 51.07 , plusmin:  +1 , deltag:  23.0 , deltam: 46.0 , deltas: 27.3  , orig: "iras"	   , spectype: "G1II"	     , parallax:    13.01  , parerr:	 0.88  , promot: " PROMOT  -0.05  -0.02" , vmag:   2.98  , hmag:    1.2  , irastwelvemu:    11.63  , qual:   3  , ftwelve:    0.00  , ones:  0.0  , diam:   2.59  , errdiam:  0.02  , simrem: "Variable Star	   " , hvartype: ""	 , multflag: ""  , compid: ""	   , theta:	0 , rho:   0.00 , compmagdiff: 0.00 , notes: ""  , hdnotes: "" , hdmoent: ""  , hdmcoment: "" },$ 
{ name: "HD85436"        , baynum: "m Vel"         , hrnum: ""              , flamnum: ""                 , saonum: "SAO237390"   , ppmnum: "PPM338378"   , varname: ""            , hipnum: "HIP48265"    , starname: ""                , alphah:  9.0 , alpham: 50.0 , alphas: 19.68 , plusmin:  -1 , deltag:  50.0 , deltam: 26.0 , deltas:  7.4  , orig: "msx"	   , spectype: "M2/M3III"    , parallax:     0.00  , parerr:	 0.00  , promot: " PROMOT  -0.01  -0.01" , vmag:   7.46  , hmag:   2.22  , irastwelvemu:     0.00  , qual:   0  , ftwelve:    5.56  , ones:  4.3  , diam:   2.34  , errdiam:  0.07  , simrem: "Star	    " , hvartype: ""	  , multflag: ""  , compid: ""      , theta:	 0 , rho:   0.00 , compmagdiff: 0.00 , notes: ""  , hdnotes: "" , hdmoent: ""  , hdmcoment: "" },$ 
{ name: "HD85622"        , baynum: ""              , hrnum: "HR3912"        , flamnum: ""                 , saonum: "SAO221553"   , ppmnum: "PPM314752"   , varname: ""            , hipnum: "HIP48374"    , starname: ""                , alphah:  9.0 , alpham: 51.0 , alphas: 40.67 , plusmin:  -1 , deltag:  46.0 , deltam: 32.0 , deltas: 51.4  , orig: "iras"	   , spectype: "G5Ib"	     , parallax:     3.01  , parerr:	 0.56  , promot: " PROMOT  -0.01      0" , vmag:   4.59  , hmag:    2.1  , irastwelvemu:     5.19  , qual:   3  , ftwelve:    0.00  , ones:  0.0  , diam:   1.87  , errdiam:  0.15  , simrem: "Spectroscopic binary	  " , hvartype: "M"	 , multflag: ""  , compid: ""	   , theta:	0 , rho:   0.00 , compmagdiff: 0.00 , notes: ""  , hdnotes: "" , hdmoent: ""  , hdmcoment: "" },$ 
{ name: "HD85503"        , baynum: "mu. Leo"       , hrnum: "HR3905"        , flamnum: "FL 24 Leo"        , saonum: "SAO 81064"   , ppmnum: "PPM99922"    , varname: ""            , hipnum: "HIP48455"    , starname: ""                , alphah:  9.0 , alpham: 52.0 , alphas: 45.82 , plusmin:  +1 , deltag:  26.0 , deltam:  0.0 , deltas: 25.0  , orig: "iras"	   , spectype: "K2III"       , parallax:    24.52  , parerr:	 0.87  , promot: " PROMOT  -0.22  -0.06" , vmag:   3.88  , hmag:   0.00  , irastwelvemu:    10.22  , qual:   3  , ftwelve:    0.00  , ones:  0.0  , diam:    3.3  , errdiam:  0.01  , simrem: "High proper-motion Star     " , hvartype: "C"	  , multflag: ""  , compid: ""      , theta:	 0 , rho:   0.00 , compmagdiff: 0.00 , notes: ""  , hdnotes: "" , hdmoent: ""  , hdmcoment: "" },$ 
{ name: "HD85709"        , baynum: ""              , hrnum: "HR3915"        , flamnum: ""                 , saonum: "SAO117975"   , ppmnum: "PPM156301"   , varname: ""            , hipnum: "HIP48519"    , starname: ""                , alphah:  9.0 , alpham: 53.0 , alphas: 42.93 , plusmin:  +1 , deltag:   5.0 , deltam: 57.0 , deltas: 30.9  , orig: "iras"	   , spectype: "M2III"       , parallax:     2.33  , parerr:	  0.8  , promot: " PROMOT      0  -0.01" , vmag:   5.95  , hmag:   0.00  , irastwelvemu:    10.07  , qual:   3  , ftwelve:    0.00  , ones:  0.0  , diam:   1.68  , errdiam:  0.06  , simrem: "Variable Star	   " , hvartype: "U"	  , multflag: ""  , compid: ""      , theta:	 0 , rho:   0.00 , compmagdiff: 0.00 , notes: "P" , hdnotes: "" , hdmoent: ""  , hdmcoment: "" },$ 
{ name: "HD85951"        , baynum: ""              , hrnum: "HR3923"        , flamnum: ""                 , saonum: "SAO155588"   , ppmnum: "PPM222192"   , varname: ""            , hipnum: "HIP48615"    , starname: ""                , alphah:  9.0 , alpham: 54.0 , alphas: 52.21 , plusmin:  -1 , deltag:  19.0 , deltam:  0.0 , deltas: 33.7  , orig: "msx"	   , spectype: "K5III"       , parallax:     4.62  , parerr:	 0.76  , promot: " PROMOT  -0.05  -0.04" , vmag:   4.95  , hmag:   1.18  , irastwelvemu:     0.00  , qual:   0  , ftwelve:   12.95  , ones:  3.2  , diam:   3.35  , errdiam:  0.15  , simrem: "Star	    " , hvartype: "U"	   , multflag: ""  , compid: ""      , theta:	  0 , rho:   0.00 , compmagdiff: 0.00 , notes: ""  , hdnotes: "" , hdmoent: ""  , hdmcoment: "" },$ 
{ name: "HD87870"        , baynum: ""              , hrnum: ""              , flamnum: ""                 , saonum: "SAO178437"   , ppmnum: "PPM257234"   , varname: "V* IO Hya"   , hipnum: "HIP49610"    , starname: ""                , alphah: 10.0 , alpham:  7.0 , alphas: 32.17 , plusmin:  -1 , deltag:  22.0 , deltam: 29.0 , deltas: 22.6  , orig: "msx"	   , spectype: "M4III"       , parallax:     4.17  , parerr:	 0.81  , promot: " PROMOT  -0.02  -0.01" , vmag:   7.11  , hmag:   1.61  , irastwelvemu:     0.00  , qual:   0  , ftwelve:    9.98  , ones:  3.2  , diam:    3.1  , errdiam:  0.22  , simrem: "Variable Star	   " , hvartype: "U"	  , multflag: "G"  , compid: ""      , theta:	  0 , rho:   0.00 , compmagdiff: 0.00 , notes: "P" , hdnotes: "" , hdmoent: ""  , hdmcoment: "" },$ 
{ name: "HD87837"        , baynum: "A Leo"         , hrnum: "HR3980"        , flamnum: "FL 31 Leo"        , saonum: "SAO 98964"   , ppmnum: "PPM156539"   , varname: ""            , hipnum: "HIP49637"    , starname: ""                , alphah: 10.0 , alpham:  7.0 , alphas: 54.27 , plusmin:  +1 , deltag:   9.0 , deltam: 59.0 , deltas: 51.0  , orig: "iras"	   , spectype: "K4III"       , parallax:    11.89  , parerr:	 0.72  , promot: " PROMOT  -0.08  -0.05" , vmag:   4.38  , hmag:   0.00  , irastwelvemu:    12.24  , qual:   3  , ftwelve:    0.00  , ones:  0.0  , diam:   3.45  , errdiam:  0.03  , simrem: "Eclipsing binary      " , hvartype: ""	   , multflag: ""  , compid: ""      , theta:	  0 , rho:   0.00 , compmagdiff: 0.00 , notes: ""  , hdnotes: "" , hdmoent: ""  , hdmcoment: "" },$ 
{ name: "HD87901"        , baynum: "alf Leo"       , hrnum: "HR3982"        , flamnum: "FL 32 Leo"        , saonum: "SAO 98967"   , ppmnum: "PPM127140"   , varname: ""            , hipnum: "HIP49669"    , starname: "REGULUS"         , alphah: 10.0 , alpham:  8.0 , alphas: 22.31 , plusmin:  +1 , deltag:  11.0 , deltam: 58.0 , deltas:  1.9  , orig: "iras"	   , spectype: "B7V"	     , parallax:    42.09  , parerr:	 0.79  , promot: " PROMOT  -0.25      0" , vmag:   1.35  , hmag:   1.56  , irastwelvemu:     6.58  , qual:   3  , ftwelve:    0.00  , ones:  0.0  , diam:   1.36  , errdiam:  0.00  , simrem: "Variable Star	   " , hvartype: ""	 , multflag: ""  , compid: ""	   , theta:	0 , rho:   0.00 , compmagdiff: 0.00 , notes: ""  , hdnotes: "" , hdmoent: ""  , hdmcoment: "" },$ 
{ name: "HD88284"        , baynum: "lam Hya"       , hrnum: "HR3994"        , flamnum: "FL 41 Hya"        , saonum: "SAO155785"   , ppmnum: "PPM222562"   , varname: ""            , hipnum: "HIP49841"    , starname: ""                , alphah: 10.0 , alpham: 10.0 , alphas: 35.28 , plusmin:  -1 , deltag:  12.0 , deltam: 21.0 , deltas: 14.7  , orig: "msx"	   , spectype: "K0III"       , parallax:    28.44  , parerr:	 0.96  , promot: " PROMOT  -0.21   -0.1" , vmag:   3.61  , hmag:   1.49  , irastwelvemu:     0.00  , qual:   0  , ftwelve:    7.92  , ones:  3.3  , diam:   2.39  , errdiam:  0.03  , simrem: "Spectroscopic binary	  " , hvartype: ""	, multflag: "O"  , compid: ""	   , theta:	0 , rho:   0.00 , compmagdiff: 0.00 , notes: ""  , hdnotes: "" , hdmoent: ""  , hdmcoment: "Y" },$
{ name: "HD88647"        , baynum: ""              , hrnum: "HR4007"        , flamnum: ""                 , saonum: "SAO237773"   , ppmnum: "PPM338751"   , varname: "V*V368 Car"  , hipnum: "HIP49926"    , starname: ""                , alphah: 10.0 , alpham: 11.0 , alphas: 35.46 , plusmin:  -1 , deltag:  58.0 , deltam: 49.0 , deltas: 39.9  , orig: "msx"	   , spectype: "M3III"       , parallax:     4.32  , parerr:	 0.54  , promot: " PROMOT  -0.05   0.01" , vmag:    6.4  , hmag:   1.14  , irastwelvemu:     0.00  , qual:   0  , ftwelve:   15.63  , ones:  3.1  , diam:   3.57  , errdiam:   0.1  , simrem: "Variable Star	   " , hvartype: "U"	  , multflag: ""  , compid: ""      , theta:	 0 , rho:   0.00 , compmagdiff: 0.00 , notes: ""  , hdnotes: "" , hdmoent: ""  , hdmcoment: "" },$ 
{ name: "HD89056"        , baynum: ""              , hrnum: "HR4035"        , flamnum: "FL 37 Leo"        , saonum: "SAO 99034"   , ppmnum: "PPM127263"   , varname: ""            , hipnum: "HIP50333"    , starname: ""                , alphah: 10.0 , alpham: 16.0 , alphas: 40.74 , plusmin:  +1 , deltag:  13.0 , deltam: 43.0 , deltas: 42.0  , orig: "iras"	   , spectype: "M1III"       , parallax:     6.53  , parerr:	 0.87  , promot: " PROMOT  -0.02  -0.02" , vmag:   5.44  , hmag:   0.00  , irastwelvemu:    10.03  , qual:   3  , ftwelve:    0.00  , ones:  0.0  , diam:   2.19  , errdiam:   0.2  , simrem: "Star	    " , hvartype: "M"	   , multflag: ""  , compid: ""      , theta:	  0 , rho:   0.00 , compmagdiff: 0.00 , notes: ""  , hdnotes: "" , hdmoent: ""  , hdmcoment: "" },$ 
{ name: "HD89388"        , baynum: "q Car"         , hrnum: "HR4050"        , flamnum: ""                 , saonum: "SAO250905"   , ppmnum: "PPM357895"   , varname: "V*V337 Car"  , hipnum: "HIP50371"    , starname: ""                , alphah: 10.0 , alpham: 17.0 , alphas:  4.98 , plusmin:  -1 , deltag:  61.0 , deltam: 19.0 , deltas: 56.3  , orig: "iras"	   , spectype: "K3IIa"       , parallax:     4.43  , parerr:	 0.49  , promot: " PROMOT  -0.02      0" , vmag:   3.38  , hmag:   0.19  , irastwelvemu:    33.19  , qual:   3  , ftwelve:   34.87  , ones:  3.0  , diam:   5.17  , errdiam:   0.1  , simrem: "Variable Star	   " , hvartype: "M"	  , multflag: ""  , compid: ""      , theta:	 0 , rho:   0.00 , compmagdiff: 0.00 , notes: ""  , hdnotes: "" , hdmoent: ""  , hdmcoment: "" },$ 
{ name: "HD89353"        , baynum: ""              , hrnum: "HR4049"        , flamnum: ""                 , saonum: "SAO178644"   , ppmnum: "PPM257470"   , varname: "V* AG Ant"   , hipnum: "HIP50456"    , starname: ""                , alphah: 10.0 , alpham: 18.0 , alphas:  7.59 , plusmin:  -1 , deltag:  28.0 , deltam: 59.0 , deltas: 31.2  , orig: "iras"	   , spectype: "B9.5Ib-II"   , parallax:      1.5  , parerr:	 0.63  , promot: " PROMOT  -0.02   0.01" , vmag:   5.53  , hmag:   4.04  , irastwelvemu:    33.28  , qual:   3  , ftwelve:    0.00  , ones:  0.0  , diam:   0.57  , errdiam:  0.97  , simrem: "Post-AGB Star	   " , hvartype: "U"	  , multflag: ""  , compid: ""      , theta:	 0 , rho:   0.00 , compmagdiff: 0.00 , notes: "P" , hdnotes: "" , hdmoent: ""  , hdmcoment: "" },$ 
{ name: "HD89682"        , baynum: ""              , hrnum: "HR4063"        , flamnum: ""                 , saonum: "SAO237916"   , ppmnum: "PPM338896"   , varname: "V* GZVel"    , hipnum: "HIP50555"    , starname: ""                , alphah: 10.0 , alpham: 19.0 , alphas: 36.75 , plusmin:  -1 , deltag:  55.0 , deltam:  1.0 , deltas: 45.5  , orig: "iras"	   , spectype: "K3II"	     , parallax:     2.19  , parerr:	 0.48  , promot: " PROMOT  -0.01  -0.01" , vmag:   4.58  , hmag:   1.27  , irastwelvemu:    11.86  , qual:   3  , ftwelve:   11.83  , ones:  3.2  , diam:   3.11  , errdiam:   0.2  , simrem: "Variable Star	   " , hvartype: "U"	  , multflag: ""  , compid: ""      , theta:	 0 , rho:   0.00 , compmagdiff: 0.00 , notes: ""  , hdnotes: "" , hdmoent: ""  , hdmcoment: "" },$ 
{ name: "HD89484"        , baynum: "gam01 Leo"     , hrnum: "HR4057"        , flamnum: "FL 41 Leo"        , saonum: "SAO 81298"   , ppmnum: "PPM127320"   , varname: ""            , hipnum: "HIP50583"    , starname: ""                , alphah: 10.0 , alpham: 19.0 , alphas: 58.43 , plusmin:  +1 , deltag:  19.0 , deltam: 50.0 , deltas: 28.5  , orig: "iras"	   , spectype: "K1IIIb"      , parallax:     19.0  , parerr:	  6.0  , promot: " PROMOT   0.31  -0.15" , vmag:   2.61  , hmag:  -0.48  , irastwelvemu:    59.21  , qual:   3  , ftwelve:    0.00  , ones:  0.0  , diam:   6.64  , errdiam:  0.01  , simrem: "Variable Star	   " , hvartype: "U"	  , multflag: "C"  , compid: "AB"      , theta:  124  , rho:  4.58    , compmagdiff:  1.15  , notes: "W" , hdnotes: "The double-star analysis indicates that it is the fainter (B) component which is variable." , hdmoent: ""  , hdmcoment: "" },$ 
{ name: "HD89945"        , baynum: ""              , hrnum: ""              , flamnum: ""                 , saonum: "SAO137524"   , ppmnum: "PPM193363"   , varname: "V* UV Sex"   , hipnum: "HIP50827"    , starname: ""                , alphah: 10.0 , alpham: 22.0 , alphas: 41.78 , plusmin:  -1 , deltag:   9.0 , deltam: 23.0 , deltas: 42.5  , orig: "msx"	   , spectype: "M3III"       , parallax:     4.27  , parerr:	 0.92  , promot: " PROMOT  -0.02   0.01" , vmag:   7.09  , hmag:   2.22  , irastwelvemu:     0.00  , qual:   0  , ftwelve:    5.15  , ones:  4.0  , diam:   2.26  , errdiam:  0.11  , simrem: "Variable of BY Dra type     " , hvartype: "U"	  , multflag: ""  , compid: ""      , theta:	 0 , rho:   0.00 , compmagdiff: 0.00 , notes: "P" , hdnotes: "" , hdmoent: ""  , hdmcoment: "" },$ 
{ name: "HD90362"        , baynum: ""              , hrnum: "HR4092"        , flamnum: ""                 , saonum: "SAO137557"   , ppmnum: "PPM193410"   , varname: ""            , hipnum: "HIP51046"    , starname: ""                , alphah: 10.0 , alpham: 25.0 , alphas: 44.27 , plusmin:  -1 , deltag:   7.0 , deltam:  3.0 , deltas: 35.4  , orig: "msx"	   , spectype: "M0III"       , parallax:     9.91  , parerr:	 0.83  , promot: " PROMOT  -0.14   0.12" , vmag:   5.61  , hmag:   1.95  , irastwelvemu:     0.00  , qual:   0  , ftwelve:    5.63  , ones:  3.6  , diam:   2.21  , errdiam:  0.08  , simrem: "Eclipsing binary      " , hvartype: "U"      , multflag: ""  , compid: ""      , theta:     0 , rho:   0.00 , compmagdiff: 0.00 , notes: ""  , hdnotes: "" , hdmoent: ""  , hdmcoment: "" },$ 
{ name: "HD90432"        , baynum: "mu. Hya"       , hrnum: "HR4094"        , flamnum: "FL 42 Hya"        , saonum: "SAO155980"   , ppmnum: "PPM222953"   , varname: ""            , hipnum: "HIP51069"    , starname: ""                , alphah: 10.0 , alpham: 26.0 , alphas:  5.43 , plusmin:  -1 , deltag:  16.0 , deltam: 50.0 , deltas: 10.7  , orig: "iras"	   , spectype: "K4III"       , parallax:    13.14  , parerr:	 0.79  , promot: " PROMOT  -0.13  -0.08" , vmag:   3.83  , hmag:   0.51  , irastwelvemu:    22.08  , qual:   3  , ftwelve:    0.00  , ones:  0.0  , diam:   4.45  , errdiam:  0.07  , simrem: "Variable Star	   " , hvartype: "U"	  , multflag: ""  , compid: ""      , theta:	 0 , rho:   0.00 , compmagdiff: 0.00 , notes: ""  , hdnotes: "" , hdmoent: ""  , hdmcoment: "" },$ 
{ name: "HD90610"        , baynum: "alf Ant"       , hrnum: "HR4104"        , flamnum: ""                 , saonum: "SAO201405"   , ppmnum: "PPM287713"   , varname: ""            , hipnum: "HIP51172"    , starname: ""                , alphah: 10.0 , alpham: 27.0 , alphas:   9.1 , plusmin:  -1 , deltag:  31.0 , deltam:  4.0 , deltas:  4.0  , orig: "iras"	   , spectype: "K4III"       , parallax:      8.9  , parerr:	 0.68  , promot: " PROMOT  -0.08   0.01" , vmag:   4.28  , hmag:   1.01  , irastwelvemu:    13.86  , qual:   3  , ftwelve:    0.00  , ones:  0.0  , diam:   3.37  , errdiam:  0.11  , simrem: "Variable Star	   " , hvartype: "U"	  , multflag: ""  , compid: ""      , theta:	 0 , rho:   0.00 , compmagdiff: 0.00 , notes: ""  , hdnotes: "" , hdmoent: ""  , hdmcoment: "" },$ 
{ name: "HD91550"        , baynum: ""              , hrnum: "HR4145"        , flamnum: "FL 44 Hya"        , saonum: "SAO178979"   , ppmnum: "PPM257847"   , varname: ""            , hipnum: "HIP51718"    , starname: ""                , alphah: 10.0 , alpham: 34.0 , alphas:  0.88 , plusmin:  -1 , deltag:  23.0 , deltam: 44.0 , deltas: 42.6  , orig: "iras"	   , spectype: "K5III"       , parallax:     5.15  , parerr:	 0.67  , promot: " PROMOT  -0.01   0.02" , vmag:   5.09  , hmag:   1.45  , irastwelvemu:     10.3  , qual:   3  , ftwelve:    0.00  , ones:  0.0  , diam:   2.86  , errdiam:  0.18  , simrem: "Eclipsing binary      " , hvartype: "M"      , multflag: ""  , compid: ""      , theta:     0 , rho:   0.00 , compmagdiff: 0.00 , notes: ""  , hdnotes: "" , hdmoent: ""  , hdmcoment: "" },$ 
{ name: "HD91942"        , baynum: "r Car"         , hrnum: "HR4159"        , flamnum: ""                 , saonum: "SAO238222"   , ppmnum: "PPM339204"   , varname: ""            , hipnum: "HIP51849"    , starname: ""                , alphah: 10.0 , alpham: 35.0 , alphas:  35.3 , plusmin:  -1 , deltag:  57.0 , deltam: 33.0 , deltas: 27.5  , orig: "msx"	   , spectype: "K3.5II"      , parallax:     2.37  , parerr:	 0.52  , promot: " PROMOT  -0.02      0" , vmag:   4.46  , hmag:   1.03  , irastwelvemu:     0.00  , qual:   0  , ftwelve:   14.53  , ones:  3.1  , diam:   3.49  , errdiam:  0.19  , simrem: "Variable Star	   " , hvartype: "M"	  , multflag: ""  , compid: ""      , theta:	 0 , rho:   0.00 , compmagdiff: 0.00 , notes: ""  , hdnotes: "" , hdmoent: "Y" , hdmcoment: "" },$ 
{ name: "HD92036"        , baynum: ""              , hrnum: "HR4162"        , flamnum: ""                 , saonum: "SAO179041"   , ppmnum: "PPM257916"   , varname: ""            , hipnum: "HIP51979"    , starname: ""                , alphah: 10.0 , alpham: 37.0 , alphas: 13.72 , plusmin:  -1 , deltag:  27.0 , deltam: 24.0 , deltas: 45.5  , orig: "iras"	   , spectype: "M2III"       , parallax:      6.8  , parerr:	 0.85  , promot: " PROMOT  -0.11   0.01" , vmag:   4.89  , hmag:   0.89  , irastwelvemu:    17.61  , qual:   3  , ftwelve:    0.00  , ones:  0.0  , diam:   3.67  , errdiam:  0.14  , simrem: "Variable Star	   " , hvartype: "U"	  , multflag: ""  , compid: ""      , theta:	 0 , rho:   0.00 , compmagdiff: 0.00 , notes: ""  , hdnotes: "" , hdmoent: ""  , hdmcoment: "" },$ 
{ name: "HD92314"        , baynum: ""              , hrnum: ""              , flamnum: ""                 , saonum: "SAO251040"   , ppmnum: "PPM358129"   , varname: "V*V515 Car"  , hipnum: "HIP52046"    , starname: ""                , alphah: 10.0 , alpham: 38.0 , alphas:  7.12 , plusmin:  -1 , deltag:  60.0 , deltam: 32.0 , deltas: 56.3  , orig: "msx"	   , spectype: "M3III"       , parallax:     0.67  , parerr:	 0.75  , promot: " PROMOT  -0.02  -0.01" , vmag:    7.9  , hmag:   2.38  , irastwelvemu:     0.00  , qual:   0  , ftwelve:    5.00  , ones:  4.2  , diam:    2.2  , errdiam:  0.69  , simrem: "Variable of BY Dra type     " , hvartype: "U"	  , multflag: ""  , compid: ""      , theta:	 0 , rho:   0.00 , compmagdiff: 0.00 , notes: ""  , hdnotes: "" , hdmoent: ""  , hdmcoment: "" },$ 
{ name: "HD92397"        , baynum: "t02 Car"       , hrnum: "HR4177"        , flamnum: ""                 , saonum: "SAO238295"   , ppmnum: "PPM339274"   , varname: ""            , hipnum: "HIP52102"    , starname: ""                , alphah: 10.0 , alpham: 38.0 , alphas: 45.00 , plusmin:  -1 , deltag:  59.0 , deltam: 10.0 , deltas: 58.8  , orig: "iras"	   , spectype: "K4.5III"     , parallax:     1.76  , parerr:	 0.72  , promot: " PROMOT  -0.01      0" , vmag:   4.87  , hmag:   1.08  , irastwelvemu:    14.48  , qual:   3  , ftwelve:   14.56  , ones:  3.1  , diam:   3.32  , errdiam:  0.25  , simrem: "Eclipsing binary      " , hvartype: "D"      , multflag: "C"  , compid: ""      , theta:     0 , rho:   0.00 , compmagdiff: 0.00 , notes: ""  , hdnotes: "" , hdmoent: "Y" , hdmcoment: "" },$ 
{ name: "HD92436"        , baynum: ""              , hrnum: "HR4179"        , flamnum: ""                 , saonum: "SAO238304"   , ppmnum: "PPM339284"   , varname: ""            , hipnum: "HIP52127"    , starname: ""                , alphah: 10.0 , alpham: 38.0 , alphas: 59.62 , plusmin:  -1 , deltag:  58.0 , deltam: 49.0 , deltas:  0.7  , orig: "msx"	   , spectype: "M1III"       , parallax:     5.03  , parerr:	 1.18  , promot: " PROMOT  -0.08      0" , vmag:  6.00   , hmag:   1.57  , irastwelvemu:     0.00  , qual:   0  , ftwelve:    9.46  , ones:  3.2  , diam:   2.99  , errdiam:  0.09  , simrem: "Eclipsing binary      " , hvartype: "D"      , multflag: "C"  , compid: ""      , theta:     0 , rho:   0.00 , compmagdiff: 0.00 , notes: ""  , hdnotes: "" , hdmoent: "Y" , hdmcoment: "" },$ 
{ name: "HD93070"        , baynum: "w Car"         , hrnum: "HR4200"        , flamnum: ""                 , saonum: "SAO251090"   , ppmnum: "PPM358201"   , varname: "V*V520 Car"  , hipnum: "HIP52468"    , starname: ""                , alphah: 10.0 , alpham: 43.0 , alphas: 32.29 , plusmin:  -1 , deltag:  60.0 , deltam: 33.0 , deltas: 59.8  , orig: "msx"	   , spectype: "K4III"       , parallax:     3.06  , parerr:	  0.5  , promot: " PROMOT  -0.03      0" , vmag:   4.58  , hmag:   0.73  , irastwelvemu:     0.00  , qual:   0  , ftwelve:    21.7  , ones:  3.1  , diam:   4.15  , errdiam:  0.14  , simrem: "Variable Star	   " , hvartype: "U"	  , multflag: ""  , compid: ""      , theta:	 0 , rho:   0.00 , compmagdiff: 0.00 , notes: "P" , hdnotes: "" , hdmoent: ""  , hdmcoment: "" },$ 
{ name: "HD93655"        , baynum: ""              , hrnum: "HR4224"        , flamnum: ""                 , saonum: "SAO137800"   , ppmnum: "PPM178297"   , varname: ""            , hipnum: "HIP52863"    , starname: ""                , alphah: 10.0 , alpham: 48.0 , alphas: 40.56 , plusmin:  -1 , deltag:   1.0 , deltam: 57.0 , deltas: 32.0  , orig: "msx"	   , spectype: "M2III"       , parallax:     6.14  , parerr:	  0.9  , promot: " PROMOT  -0.01  -0.01" , vmag:   5.94  , hmag:   1.96  , irastwelvemu:     0.00  , qual:   0  , ftwelve:    6.28  , ones:  3.5  , diam:   2.25  , errdiam:  0.01  , simrem: "Star	    " , hvartype: "M"	   , multflag: ""  , compid: ""      , theta:	  0 , rho:   0.00 , compmagdiff: 0.00 , notes: ""  , hdnotes: "" , hdmoent: ""  , hdmcoment: "" },$ 
{ name: "HD93813"        , baynum: "nu. Hya"       , hrnum: "HR4232"        , flamnum: ""                 , saonum: "SAO156256"   , ppmnum: "PPM223512"   , varname: ""            , hipnum: "HIP52943"    , starname: ""                , alphah: 10.0 , alpham: 49.0 , alphas: 37.49 , plusmin:  -1 , deltag:  16.0 , deltam: 11.0 , deltas: 37.1  , orig: "iras"	   , spectype: "K0/K1III"    , parallax:    23.54  , parerr:	 0.81  , promot: " PROMOT   0.09    0.2" , vmag:   3.11  , hmag:   0.37  , irastwelvemu:    24.37  , qual:   3  , ftwelve:    0.00  , ones:  0.0  , diam:   4.23  , errdiam:  0.04  , simrem: "High proper-motion Star     " , hvartype: ""	 , multflag: ""  , compid: ""	   , theta:	0 , rho:   0.00 , compmagdiff: 0.00 , notes: ""  , hdnotes: "" , hdmoent: ""  , hdmcoment: "" },$ 
{ name: "HD94452"        , baynum: ""              , hrnum: ""              , flamnum: ""                 , saonum: "SAO251169"   , ppmnum: "PPM358321"   , varname: ""            , hipnum: "HIP53300"    , starname: ""                , alphah: 10.0 , alpham: 52.0 , alphas:  51.2 , plusmin:  -1 , deltag:  62.0 , deltam:  0.0 , deltas: 32.8  , orig: "msx"	   , spectype: "M5II/III"    , parallax:     0.00  , parerr:	 0.00  , promot: " PROMOT  -0.02      0" , vmag:   8.42  , hmag:   2.25  , irastwelvemu:     0.00  , qual:   0  , ftwelve:    6.09  , ones:  3.8  , diam:   2.32  , errdiam:  0.07  , simrem: "Star	    " , hvartype: "U"	   , multflag: ""  , compid: ""      , theta:	  0 , rho:   0.00 , compmagdiff: 0.00 , notes: ""  , hdnotes: "" , hdmoent: ""  , hdmcoment: "" },$ 
{ name: "HD94264"        , baynum: ""              , hrnum: "HR4247"        , flamnum: "FL 46 LMi"        , saonum: "SAO62297"    , ppmnum: "PPM75534"    , varname: ""            , hipnum: "HIP53229"    , starname: ""                , alphah: 10.0 , alpham: 53.0 , alphas: 18.71 , plusmin:  +1 , deltag:  34.0 , deltam: 12.0 , deltas: 53.5  , orig: "iras"	   , spectype: "K0III"       , parallax:     33.4  , parerr:	 0.78  , promot: " PROMOT   0.09  -0.28" , vmag:   3.83  , hmag:   1.41  , irastwelvemu:     8.74  , qual:   3  , ftwelve:    0.00  , ones:  0.0  , diam:   2.46  , errdiam:  0.02  , simrem: "Variable Star	   " , hvartype: "C"	  , multflag: ""  , compid: ""      , theta:	 0 , rho:   0.00 , compmagdiff: 0.00 , notes: ""  , hdnotes: "" , hdmoent: ""  , hdmcoment: "" },$ 
{ name: "HD94510"        , baynum: "u Car"         , hrnum: "HR4257"        , flamnum: ""                 , saonum: "SAO238574"   , ppmnum: "PPM339549"   , varname: ""            , hipnum: "HIP53253"    , starname: ""                , alphah: 10.0 , alpham: 53.0 , alphas: 29.66 , plusmin:  -1 , deltag:  58.0 , deltam: 51.0 , deltas: 11.4  , orig: "msx"	   , spectype: "K1III"       , parallax:    33.71  , parerr:	 0.57  , promot: " PROMOT   0.07   0.03" , vmag:   3.79  , hmag:   1.67  , irastwelvemu:     0.00  , qual:   0  , ftwelve:    6.92  , ones:  3.4  , diam:   2.09  , errdiam:  0.01  , simrem: "Variable Star	   " , hvartype: ""	 , multflag: ""  , compid: ""	   , theta:	0 , rho:   0.00 , compmagdiff: 0.00 , notes: ""  , hdnotes: "" , hdmoent: ""  , hdmcoment: "" },$ 
{ name: "HD94683"        , baynum: ""              , hrnum: "HR4266"        , flamnum: ""                 , saonum: "SAO251173"   , ppmnum: "PPM358327"   , varname: ""            , hipnum: "HIP53334"    , starname: ""                , alphah: 10.0 , alpham: 54.0 , alphas:  29.6 , plusmin:  -1 , deltag:  61.0 , deltam: 49.0 , deltas: 35.8  , orig: "iras"	   , spectype: "K4V"	     , parallax:     1.96  , parerr:	 0.59  , promot: " PROMOT   0.01      0" , vmag:   5.97  , hmag:   1.98  , irastwelvemu:     7.15  , qual:   3  , ftwelve:    6.83  , ones:  3.5  , diam:   2.44  , errdiam:  0.23  , simrem: "Eclipsing binary      " , hvartype: "U"      , multflag: ""  , compid: ""      , theta:     0 , rho:   0.00 , compmagdiff: 0.00 , notes: ""  , hdnotes: "" , hdmoent: ""  , hdmcoment: "" },$ 
{ name: "HD95272"        , baynum: "alf Crt"       , hrnum: "HR4287"        , flamnum: "FL 7 Crt"         , saonum: "SAO156375"   , ppmnum: "PPM223763"   , varname: ""            , hipnum: "HIP53740"    , starname: ""                , alphah: 10.0 , alpham: 59.0 , alphas: 46.46 , plusmin:  -1 , deltag:  18.0 , deltam: 17.0 , deltas: 55.6  , orig: "iras"	   , spectype: "K1III"       , parallax:    18.71  , parerr:	 1.03  , promot: " PROMOT  -0.47   0.12" , vmag:   4.07  , hmag:   1.71  , irastwelvemu:     8.16  , qual:   3  , ftwelve:    0.00  , ones:  0.0  , diam:   2.19  , errdiam:  0.05  , simrem: "High proper-motion Star     " , hvartype: ""	 , multflag: ""  , compid: ""	   , theta:	0 , rho:   0.00 , compmagdiff: 0.00 , notes: ""  , hdnotes: "" , hdmoent: ""  , hdmcoment: "" },$ 
{ name: "HD95578"        , baynum: "p02 Leo"       , hrnum: "HR4299"        , flamnum: "FL 61 Leo"        , saonum: "SAO137947"   , ppmnum: "PPM178358"   , varname: ""            , hipnum: "HIP53907"    , starname: ""                , alphah: 11.0 , alpham:  1.0 , alphas: 49.67 , plusmin:  -1 , deltag:   2.0 , deltam: 29.0 , deltas:  4.5  , orig: "iras"	   , spectype: "M0III"       , parallax:     6.34  , parerr:	 0.78  , promot: " PROMOT   0.01  -0.04" , vmag:   4.74  , hmag:   0.00  , irastwelvemu:    15.28  , qual:   3  , ftwelve:    0.00  , ones:  0.0  , diam:   2.84  , errdiam:  0.04  , simrem: "Variable Star	   " , hvartype: "U"	  , multflag: ""  , compid: ""      , theta:	 0 , rho:   0.00 , compmagdiff: 0.00 , notes: ""  , hdnotes: "" , hdmoent: ""  , hdmcoment: "" },$ 
{ name: "HD96918"        , baynum: "x Car"         , hrnum: "HR4337"        , flamnum: ""                 , saonum: "SAO238813"   , ppmnum: "PPM339804"   , varname: "V*V382 Car"  , hipnum: "HIP54463"    , starname: ""                , alphah: 11.0 , alpham:  8.0 , alphas: 35.39 , plusmin:  -1 , deltag:  58.0 , deltam: 58.0 , deltas: 30.1  , orig: "msx"	   , spectype: "G0Ia0"       , parallax:     0.55  , parerr:	 0.54  , promot: " PROMOT  -0.01      0" , vmag:   3.92  , hmag:   1.65  , irastwelvemu:     0.00  , qual:   0  , ftwelve:    9.66  , ones:  3.2  , diam:   2.56  , errdiam:  0.75  , simrem: "Classical Cepheid (delta Cep type)" , hvartype: "U"	, multflag: ""  , compid: ""	  , theta:     0 , rho:   0.00 , compmagdiff: 0.00 , notes: ""  , hdnotes: "" , hdmoent: ""  , hdmcoment: "" },$ 
{ name: "HD96760"        , baynum: ""              , hrnum: ""              , flamnum: ""                 , saonum: "SAO81696"    , ppmnum: "PPM100931"   , varname: ""            , hipnum: ""            , starname: ""                , alphah: 11.0 , alpham:  8.0 , alphas: 56.44 , plusmin:  +1 , deltag:  20.0 , deltam: 15.0 , deltas: 28.0  , orig: "msx"	   , spectype: "M..."	     , parallax:     0.00  , parerr:	 0.00  , promot: " PROMOT  -0.02      0" , vmag:   8.64  , hmag:   0.00  , irastwelvemu:     0.00  , qual:   0  , ftwelve:    5.56  , ones:  3.7  , diam:    0.4  , errdiam:  0.14  , simrem: "Star	    " , hvartype: ""	  , multflag: ""  , compid: ""      , theta:	 0 , rho:   0.00 , compmagdiff: 0.00 , notes: ""  , hdnotes: "" , hdmoent: ""  , hdmcoment: "" },$ 
{ name: "HD97068"        , baynum: ""              , hrnum: ""              , flamnum: ""                 , saonum: "SAO99480"    , ppmnum: "PPM128037"   , varname: "V* FI Leo"   , hipnum: "HIP54613"    , starname: ""                , alphah: 11.0 , alpham: 10.0 , alphas: 36.77 , plusmin:  +1 , deltag:  11.0 , deltam: 18.0 , deltas:  5.9  , orig: "msx"	   , spectype: "M3"	     , parallax:     2.06  , parerr:	  1.2  , promot: " PROMOT  -0.03  -0.02" , vmag:   7.23  , hmag:   1.74  , irastwelvemu:     0.00  , qual:   0  , ftwelve:    9.85  , ones:  3.2  , diam:   2.22  , errdiam:  0.05  , simrem: "Pulsating variable Star     " , hvartype: "U"	  , multflag: ""  , compid: ""      , theta:	 0 , rho:   0.00 , compmagdiff: 0.00 , notes: "P" , hdnotes: "" , hdmoent: "Y" , hdmcoment: "" },$ 
{ name: "HD97451"        , baynum: ""              , hrnum: ""              , flamnum: ""                 , saonum: "SAO238855"   , ppmnum: "PPM339848"   , varname: "V*V532 Car"  , hipnum: "HIP54708"    , starname: ""                , alphah: 11.0 , alpham: 12.0 , alphas:  3.54 , plusmin:  -1 , deltag:  58.0 , deltam: 25.0 , deltas: 24.1  , orig: "msx"	   , spectype: "M4III"       , parallax:     4.43  , parerr:	 0.71  , promot: " PROMOT  -0.03  -0.02" , vmag:   6.35  , hmag:   0.75  , irastwelvemu:     0.00  , qual:   0  , ftwelve:   24.11  , ones:  3.0  , diam:   4.55  , errdiam:  0.16  , simrem: "Variable of BY Dra type     " , hvartype: "U"	  , multflag: ""  , compid: ""      , theta:	 0 , rho:   0.00 , compmagdiff: 0.00 , notes: "P" , hdnotes: "" , hdmoent: ""  , hdmcoment: "" },$ 
{ name: "HD97576"        , baynum: ""              , hrnum: "HR4354"        , flamnum: ""                 , saonum: "SAO222647"   , ppmnum: "PPM316173"   , varname: ""            , hipnum: "HIP54811"    , starname: ""                , alphah: 11.0 , alpham: 13.0 , alphas: 14.69 , plusmin:  -1 , deltag:  44.0 , deltam: 22.0 , deltas: 20.0  , orig: "iras"	   , spectype: "K7III"       , parallax:     3.88  , parerr:	  0.7  , promot: " PROMOT      0      0" , vmag:   5.79  , hmag:   0.00  , irastwelvemu:     6.96  , qual:   3  , ftwelve:    0.00  , ones:  0.0  , diam:    4.1  , errdiam:  0.26  , simrem: "Star	    " , hvartype: "U"	   , multflag: ""  , compid: ""      , theta:	  0 , rho:   0.00 , compmagdiff: 0.00 , notes: ""  , hdnotes: "" , hdmoent: ""  , hdmcoment: "" },$ 
{ name: "HD97778"        , baynum: ""              , hrnum: "HR4362"        , flamnum: "FL 72 Leo"        , saonum: "SAO81736"    , ppmnum: "PPM101007"   , varname: "V* FN Leo"   , hipnum: "HIP54951"    , starname: ""                , alphah: 11.0 , alpham: 15.0 , alphas: 12.23 , plusmin:  +1 , deltag:  23.0 , deltam:  5.0 , deltas: 43.8  , orig: "msx"	   , spectype: "M3IIb"       , parallax:     0.49  , parerr:	  1.3  , promot: " PROMOT  -0.02  -0.01" , vmag:   4.58  , hmag:   0.00  , irastwelvemu:     0.00  , qual:   0  , ftwelve:   35.64  , ones:  3.0  , diam:   2.89  , errdiam:   0.1  , simrem: "Pulsating variable Star     " , hvartype: "U"	  , multflag: "V"  , compid: ""      , theta:	  0 , rho:   0.00 , compmagdiff: 0.00 , notes: ""  , hdnotes: "" , hdmoent: ""  , hdmcoment: "" },$ 
{ name: "HD98292"        , baynum: ""              , hrnum: "HR4379"        , flamnum: ""                 , saonum: "SAO251341"   , ppmnum: "PPM358610"   , varname: "V*V535 Car"  , hipnum: "HIP55140"    , starname: ""                , alphah: 11.0 , alpham: 17.0 , alphas: 19.04 , plusmin:  -1 , deltag:  67.0 , deltam: 49.0 , deltas: 24.6  , orig: "iras"	   , spectype: "M2III"       , parallax:     1.92  , parerr:	 0.57  , promot: " PROMOT   0.02  -0.02" , vmag:   6.09  , hmag:   1.42  , irastwelvemu:    11.85  , qual:   3  , ftwelve:    0.00  , ones:  0.0  , diam:   3.03  , errdiam:  1.75  , simrem: "Variable Star	   " , hvartype: "U"	  , multflag: ""  , compid: ""      , theta:	 0 , rho:   0.00 , compmagdiff: 0.00 , notes: ""  , hdnotes: "" , hdmoent: ""  , hdmcoment: "" },$ 
{ name: "HD98262"        , baynum: "nu. UMa"       , hrnum: "HR4377"        , flamnum: "FL 54 UMa"        , saonum: "SAO62486"    , ppmnum: "PPM75790"    , varname: ""            , hipnum: "HIP55219"    , starname: ""                , alphah: 11.0 , alpham: 18.0 , alphas: 28.74 , plusmin:  +1 , deltag:  33.0 , deltam:  5.0 , deltas: 39.5  , orig: "iras"	   , spectype: "K3III"       , parallax:     7.74  , parerr:	 0.79  , promot: " PROMOT  -0.04   0.02" , vmag:    3.5  , hmag:   0.00  , irastwelvemu:    24.64  , qual:   3  , ftwelve:    0.00  , ones:  0.0  , diam:    4.4  , errdiam:  0.04  , simrem: "Eclipsing binary      " , hvartype: ""	   , multflag: ""  , compid: ""      , theta:	  0 , rho:   0.00 , compmagdiff: 0.00 , notes: ""  , hdnotes: "" , hdmoent: ""  , hdmcoment: "" },$ 
{ name: "HD98430"        , baynum: "del Crt"       , hrnum: "HR4382"        , flamnum: "FL 12 Crt"        , saonum: "SAO156605"   , ppmnum: "PPM224248"   , varname: ""            , hipnum: "HIP55282"    , starname: ""                , alphah: 11.0 , alpham: 19.0 , alphas: 20.45 , plusmin:  -1 , deltag:  14.0 , deltam: 46.0 , deltas: 42.8  , orig: "iras"	   , spectype: "K0III"       , parallax:    16.75  , parerr:	 0.82  , promot: " PROMOT  -0.13    0.2" , vmag:   3.56  , hmag:   1.02  , irastwelvemu:    13.29  , qual:   3  , ftwelve:    0.00  , ones:  0.0  , diam:   2.99  , errdiam:  0.06  , simrem: "High proper-motion Star     " , hvartype: ""	 , multflag: ""  , compid: ""	   , theta:	0 , rho:   0.00 , compmagdiff: 0.00 , notes: ""  , hdnotes: "" , hdmoent: ""  , hdmcoment: "" },$ 
{ name: "HD99167"        , baynum: "eps Crt"       , hrnum: "HR4402"        , flamnum: "FL 14 Crt"        , saonum: "SAO156658"   , ppmnum: "PPM224361"   , varname: ""            , hipnum: "HIP55687"    , starname: ""                , alphah: 11.0 , alpham: 24.0 , alphas: 36.59 , plusmin:  -1 , deltag:  10.0 , deltam: 51.0 , deltas: 33.6  , orig: "iras"	   , spectype: "K5III"       , parallax:     8.95  , parerr:	 0.74  , promot: " PROMOT  -0.03   0.02" , vmag:   4.82  , hmag:   1.14  , irastwelvemu:    12.86  , qual:   3  , ftwelve:    0.00  , ones:  0.0  , diam:   3.45  , errdiam:  0.01  , simrem: "Star	    " , hvartype: "M"	   , multflag: ""  , compid: ""      , theta:	  0 , rho:   0.00 , compmagdiff: 0.00 , notes: ""  , hdnotes: "" , hdmoent: ""  , hdmcoment: "" },$ 
{ name: "HD99363"        , baynum: ""              , hrnum: ""              , flamnum: ""                 , saonum: "SAO156672"   , ppmnum: "PPM224390"   , varname: "V* UX Crt"   , hipnum: "HIP55795"    , starname: ""                , alphah: 11.0 , alpham: 25.0 , alphas: 54.00 , plusmin:  -1 , deltag:  13.0 , deltam: 45.0 , deltas:  4.7  , orig: "iras"	   , spectype: "M1III"       , parallax:     1.21  , parerr:	 0.86  , promot: " PROMOT  -0.05   0.02" , vmag:   6.56  , hmag:    2.2  , irastwelvemu:     5.73  , qual:   3  , ftwelve:    0.00  , ones:  0.0  , diam:   2.24  , errdiam:  0.11  , simrem: "Variable Star	   " , hvartype: "U"	  , multflag: ""  , compid: ""      , theta:	 0 , rho:   0.00 , compmagdiff: 0.00 , notes: "P" , hdnotes: "" , hdmoent: ""  , hdmcoment: "" },$ 
{ name: "HD224889"       , baynum: "the Oct"       , hrnum: "HR9084"        , flamnum: ""                 , saonum: "SAO258207"   , ppmnum: "PPM366760"   , varname: ""            , hipnum: "HIP122"      , starname: ""                , alphah:  0.0 , alpham:  1.0 , alphas:  35.7 , plusmin:  -1 , deltag:  77.0 , deltam:  3.0 , deltas: 56.6  , orig: "iras"	   , spectype: "K3III"       , parallax:    14.77  , parerr:	 0.47  , promot: " PROMOT  -0.05  -0.17" , vmag:   4.79  , hmag:   1.95  , irastwelvemu:     6.02  , qual:   3  , ftwelve:    0.00  , ones:  0.0  , diam:   2.11  , errdiam:  0.09  , simrem: "Star	    " , hvartype: ""	  , multflag: ""  , compid: ""      , theta:	 0 , rho:   0.00 , compmagdiff: 0.00 , notes: ""  , hdnotes: "" , hdmoent: ""  , hdmcoment: "" },$ 
{ name: "HD224935"       , baynum: ""              , hrnum: "HR9089"        , flamnum: "FL 30 Psc"        , saonum: "SAO147042"   , ppmnum: "PPM181772"   , varname: "V* YY Psc"   , hipnum: "HIP154"      , starname: ""                , alphah:  0.0 , alpham:  1.0 , alphas: 57.62 , plusmin:  -1 , deltag:   6.0 , deltam:  0.0 , deltas: 50.7  , orig: "iras"	   , spectype: "M3III"       , parallax:     7.86  , parerr:	 0.94  , promot: " PROMOT   0.05  -0.04" , vmag:   4.41  , hmag:  -0.25  , irastwelvemu:    59.93  , qual:   3  , ftwelve:    0.00  , ones:  0.0  , diam:    7.1  , errdiam:  0.07  , simrem: "Variable Star	   " , hvartype: "U"	  , multflag: ""  , compid: ""      , theta:	 0 , rho:   0.00 , compmagdiff: 0.00 , notes: ""  , hdnotes: "" , hdmoent: ""  , hdmcoment: "" },$ 
{ name: "HD281813"       , baynum: ""              , hrnum: ""              , flamnum: ""                 , saonum: "SAO76508"    , ppmnum: "PPM358810"   , varname: ""            , hipnum: "HIP19715"    , starname: ""                , alphah:  4.0 , alpham: 13.0 , alphas: 24.45 , plusmin:  +1 , deltag:  29.0 , deltam:  7.0 , deltas: 22.5  , orig: "iras"	   , spectype: "M5"	     , parallax:     1.91  , parerr:	  1.0  , promot: " PROMOT   0.01  -0.02" , vmag:   7.99  , hmag:   1.43  , irastwelvemu:     9.28  , qual:   3  , ftwelve:    0.00  , ones:  0.0  , diam:   2.88  , errdiam:   1.4  , simrem: "Double or multiple star     " , hvartype: "U"	  , multflag: "C"  , compid: "AB"      , theta:  350  , rho:  0.11    , compmagdiff:  0.55  , notes: ""  , hdnotes: "" , hdmoent: "Y" , hdmcoment: "" },$ 
{ name: "HD100407"       , baynum: "ksi Hya"       , hrnum: "HR4450"        , flamnum: ""                 , saonum: "SAO202558"   , ppmnum: "PPM289049"   , varname: ""            , hipnum: "HIP56343"    , starname: ""                , alphah: 11.0 , alpham: 33.0 , alphas:  0.12 , plusmin:  -1 , deltag:  31.0 , deltam: 51.0 , deltas: 27.4  , orig: "iras"	   , spectype: "G7III"       , parallax:    25.23  , parerr:	 0.83  , promot: " PROMOT  -0.21  -0.04" , vmag:   3.54  , hmag:   1.51  , irastwelvemu:     8.07  , qual:   3  , ftwelve:    0.00  , ones:  0.0  , diam:   2.35  , errdiam:  0.04  , simrem: "High proper-motion Star     " , hvartype: "M"	  , multflag: ""  , compid: ""      , theta:	 0 , rho:   0.00 , compmagdiff: 0.00 , notes: ""  , hdnotes: "" , hdmoent: ""  , hdmcoment: "" },$ 
{ name: "HD100713"       , baynum: ""              , hrnum: ""              , flamnum: ""                 , saonum: "SAO251463"   , ppmnum: "PPM93343"    , varname: ""            , hipnum: "HIP56519"    , starname: ""                , alphah: 11.0 , alpham: 34.0 , alphas: 51.08 , plusmin:  -1 , deltag:  60.0 , deltam: 47.0 , deltas: 10.1  , orig: "msx"	   , spectype: "M4III"       , parallax:     0.00  , parerr:	 0.00  , promot: " PROMOT      0   0.02" , vmag:   7.37  , hmag:   2.29  , irastwelvemu:     0.00  , qual:   0  , ftwelve:    5.44  , ones:  4.0  , diam:   2.18  , errdiam:  0.07  , simrem: "Variable Star	   " , hvartype: "C"	  , multflag: ""  , compid: ""      , theta:	 0 , rho:   0.00 , compmagdiff: 0.00 , notes: ""  , hdnotes: "" , hdmoent: ""  , hdmcoment: "" },$ 
{ name: "HD100920"       , baynum: "ups Leo"       , hrnum: "HR4471"        , flamnum: "FL 91 Leo"        , saonum: "SAO138298"   , ppmnum: "PPM178542"   , varname: ""            , hipnum: "HIP56647"    , starname: ""                , alphah: 11.0 , alpham: 36.0 , alphas: 56.93 , plusmin:  +1 , deltag:   0.0 , deltam: 49.0 , deltas: 25.5  , orig: "iras"	   , spectype: "G9III"       , parallax:    18.31  , parerr:	 0.89  , promot: " PROMOT      0   0.04" , vmag:   4.31  , hmag:    2.1  , irastwelvemu:     5.25  , qual:   3  , ftwelve:    0.00  , ones:  0.0  , diam:   1.79  , errdiam:  0.01  , simrem: "Star	    " , hvartype: "C"	   , multflag: ""  , compid: ""      , theta:	  0 , rho:   0.00 , compmagdiff: 0.00 , notes: ""  , hdnotes: "" , hdmoent: ""  , hdmcoment: "" },$ 
{ name: "HD101104"       , baynum: ""              , hrnum: ""              , flamnum: ""                 , saonum: "SAO251497"   , ppmnum: "PPM358852"   , varname: "V*V913 Cen"  , hipnum: "HIP56702"    , starname: ""                , alphah: 11.0 , alpham: 37.0 , alphas: 34.06 , plusmin:  -1 , deltag:  60.0 , deltam: 54.0 , deltas: 11.6  , orig: "iras"	   , spectype: "M6"	     , parallax:     5.67  , parerr:	 0.67  , promot: " PROMOT  -0.08  -0.01" , vmag:   6.64  , hmag:   0.19  , irastwelvemu:    36.92  , qual:   3  , ftwelve:    0.00  , ones:  0.0  , diam:   5.99  , errdiam:  0.13  , simrem: "Variable of BY Dra type     " , hvartype: "U"	  , multflag: ""  , compid: ""      , theta:	 0 , rho:   0.00 , compmagdiff: 0.00 , notes: "P" , hdnotes: "" , hdmoent: "Y" , hdmcoment: "" },$ 
{ name: "HD101666"       , baynum: ""              , hrnum: "HR4503"        , flamnum: ""                 , saonum: "SAO202717"   , ppmnum: "PPM289242"   , varname: ""            , hipnum: "HIP57047"    , starname: ""                , alphah: 11.0 , alpham: 41.0 , alphas: 43.95 , plusmin:  -1 , deltag:  32.0 , deltam: 29.0 , deltas: 57.9  , orig: "iras"	   , spectype: "K5III+..."   , parallax:     7.59  , parerr:	 0.76  , promot: " PROMOT  -0.01  -0.03" , vmag:   5.22  , hmag:   1.93  , irastwelvemu:     6.36  , qual:   3  , ftwelve:    0.00  , ones:  0.0  , diam:   2.31  , errdiam:  0.12  , simrem: "Eclipsing binary      " , hvartype: ""	   , multflag: ""  , compid: ""      , theta:	  0 , rho:   0.00 , compmagdiff: 0.00 , notes: ""  , hdnotes: "" , hdmoent: ""  , hdmcoment: "" },$ 
{ name: "HD102461"       , baynum: ""              , hrnum: "HR4526"        , flamnum: ""                 , saonum: "SAO239373"   , ppmnum: "PPM340396"   , varname: "V*V918 Cen"  , hipnum: "HIP57512"    , starname: ""                , alphah: 11.0 , alpham: 47.0 , alphas: 19.14 , plusmin:  -1 , deltag:  57.0 , deltam: 41.0 , deltas: 47.4  , orig: "iras"	   , spectype: "K5III"       , parallax:     3.97  , parerr:	 0.61  , promot: " PROMOT  -0.03   0.02" , vmag:   5.44  , hmag:   1.51  , irastwelvemu:      9.6  , qual:   3  , ftwelve:    0.00  , ones:  0.0  , diam:   2.96  , errdiam:  0.18  , simrem: "Variable Star	   " , hvartype: "U"	  , multflag: ""  , compid: ""      , theta:	 0 , rho:   0.00 , compmagdiff: 0.00 , notes: "P" , hdnotes: "" , hdmoent: ""  , hdmcoment: "" },$ 
{ name: "HD102839"       , baynum: ""              , hrnum: "HR4538"        , flamnum: ""                 , saonum: "SAO251604"   , ppmnum: "PPM371263"   , varname: ""            , hipnum: "HIP57696"    , starname: ""                , alphah: 11.0 , alpham: 49.0 , alphas: 56.61 , plusmin:  -1 , deltag:  70.0 , deltam: 13.0 , deltas: 32.9  , orig: "iras"	   , spectype: "G6Ib"	     , parallax:     2.24  , parerr:	 0.58  , promot: " PROMOT  -0.02      0" , vmag:   4.99  , hmag:   2.11  , irastwelvemu:     5.86  , qual:   3  , ftwelve:    0.00  , ones:  0.0  , diam:   2.01  , errdiam:  0.56  , simrem: "Star	    " , hvartype: "M"	   , multflag: ""  , compid: ""      , theta:	  0 , rho:   0.00 , compmagdiff: 0.00 , notes: ""  , hdnotes: "" , hdmoent: ""  , hdmcoment: "" },$ 
{ name: "HD102964"       , baynum: "B Cen"         , hrnum: "HR4546"        , flamnum: ""                 , saonum: "SAO223062"   , ppmnum: "PPM316836"   , varname: ""            , hipnum: "HIP57803"    , starname: ""                , alphah: 11.0 , alpham: 51.0 , alphas:  8.69 , plusmin:  -1 , deltag:  45.0 , deltam: 10.0 , deltas: 24.5  , orig: "iras"	   , spectype: "K3III"       , parallax:     7.03  , parerr:	 0.72  , promot: " PROMOT  -0.08  -0.02" , vmag:   4.47  , hmag:   1.68  , irastwelvemu:     7.57  , qual:   3  , ftwelve:    0.00  , ones:  0.0  , diam:   2.44  , errdiam:  0.13  , simrem: "Star	    " , hvartype: ""	  , multflag: ""  , compid: ""      , theta:	 0 , rho:   0.00 , compmagdiff: 0.00 , notes: ""  , hdnotes: "" , hdmoent: ""  , hdmcoment: "" },$ 
{ name: "HD103661"       , baynum: "o Leo"         , hrnum: ""              , flamnum: "FL 95 Leo"        , saonum: "SAO99874"    , ppmnum: "PPM128664"   , varname: "V* WX Leo"   , hipnum: "HIP58203"    , starname: ""                , alphah: 11.0 , alpham: 56.0 , alphas: 12.32 , plusmin:  +1 , deltag:  15.0 , deltam: 43.0 , deltas: 44.3  , orig: "iras"	   , spectype: "M3"	     , parallax:      1.7  , parerr:	 1.22  , promot: " PROMOT   0.01  -0.04" , vmag:   8.11  , hmag:   0.00  , irastwelvemu:     5.09  , qual:   3  , ftwelve:    0.00  , ones:  0.0  , diam:   0.51  , errdiam:  0.05  , simrem: "Pulsating variable Star     " , hvartype: "U"	  , multflag: ""  , compid: ""      , theta:	 0 , rho:   0.00 , compmagdiff: 0.00 , notes: ""  , hdnotes: "" , hdmoent: ""  , hdmcoment: "" },$ 
{ name: "HD104207"       , baynum: ""              , hrnum: ""              , flamnum: ""                 , saonum: "SAO99901"    , ppmnum: "PPM128704"   , varname: "V* GK Com"   , hipnum: "HIP58519"    , starname: ""                , alphah: 12.0 , alpham:  0.0 , alphas:   4.7 , plusmin:  +1 , deltag:  19.0 , deltam: 25.0 , deltas:  9.7  , orig: "iras"	   , spectype: "M3"	     , parallax:     2.04  , parerr:	 0.87  , promot: " PROMOT  -0.09  -0.04" , vmag:   6.99  , hmag:   0.00  , irastwelvemu:    10.24  , qual:   3  , ftwelve:    0.00  , ones:  0.0  , diam:   0.87  , errdiam:  0.05  , simrem: "Variable Star	   " , hvartype: "U"	  , multflag: ""  , compid: ""      , theta:	 0 , rho:   0.00 , compmagdiff: 0.00 , notes: ""  , hdnotes: "" , hdmoent: ""  , hdmcoment: "" },$ 
{ name: "HD104933"       , baynum: ""              , hrnum: "HR4607"        , flamnum: ""                 , saonum: "SAO251723"   , ppmnum: "PPM359174"   , varname: ""            , hipnum: "HIP58921"    , starname: ""                , alphah: 12.0 , alpham:  4.0 , alphas: 57.22 , plusmin:  -1 , deltag:  60.0 , deltam: 58.0 , deltas:  5.7  , orig: "msx"	   , spectype: "M2III"       , parallax:     4.93  , parerr:	 0.58  , promot: " PROMOT  -0.04  -0.04" , vmag:   5.99  , hmag:   1.69  , irastwelvemu:     0.00  , qual:   0  , ftwelve:    8.56  , ones:  3.2  , diam:   2.81  , errdiam:  0.14  , simrem: "Variable Star	   " , hvartype: "U"	  , multflag: ""  , compid: ""      , theta:	 0 , rho:   0.00 , compmagdiff: 0.00 , notes: ""  , hdnotes: "" , hdmoent: ""  , hdmcoment: "" },$ 
{ name: "HD107218"       , baynum: "R Crv"         , hrnum: ""              , flamnum: ""                 , saonum: "SAO157212"   , ppmnum: "PPM225676"   , varname: "V* UW Crv"   , hipnum: "HIP60117"    , starname: ""                , alphah: 12.0 , alpham: 19.0 , alphas: 42.59 , plusmin:  -1 , deltag:  19.0 , deltam: 11.0 , deltas: 56.0  , orig: "iras"	   , spectype: "M4III"       , parallax:    -0.06  , parerr:	 1.06  , promot: " PROMOT  -0.01   0.02" , vmag:   8.34  , hmag:   2.42  , irastwelvemu:     5.35  , qual:   3  , ftwelve:    0.00  , ones:  0.0  , diam:   2.13  , errdiam:  0.07  , simrem: "Variable Star of irregular type   " , hvartype: "U"	, multflag: ""  , compid: ""	  , theta:     0 , rho:   0.00 , compmagdiff: 0.00 , notes: ""  , hdnotes: "" , hdmoent: ""  , hdmcoment: "" },$ 
{ name: "HD107446"       , baynum: "eps Cru"       , hrnum: "HR4700"        , flamnum: ""                 , saonum: "SAO251862"   , ppmnum: "PPM359351"   , varname: ""            , hipnum: "HIP60260"    , starname: ""                , alphah: 12.0 , alpham: 21.0 , alphas: 21.61 , plusmin:  -1 , deltag:  60.0 , deltam: 24.0 , deltas:  4.1  , orig: "iras"	   , spectype: "K3.5III"     , parallax:     14.3  , parerr:	 0.56  , promot: " PROMOT  -0.18   0.08" , vmag:   3.59  , hmag:   0.48  , irastwelvemu:     22.6  , qual:   3  , ftwelve:   22.62  , ones:  3.0  , diam:   4.23  , errdiam:  0.05  , simrem: "Variable Star	   " , hvartype: ""	 , multflag: ""  , compid: ""	   , theta:	0 , rho:   0.00 , compmagdiff: 0.00 , notes: ""  , hdnotes: "" , hdmoent: ""  , hdmcoment: "" },$ 
{ name: "HD108381"       , baynum: "gam Com"       , hrnum: "HR4737"        , flamnum: "FL 15 Com"        , saonum: "SAO82313"    , ppmnum: "PPM101903"   , varname: ""            , hipnum: "HIP60742"    , starname: ""                , alphah: 12.0 , alpham: 26.0 , alphas: 56.27 , plusmin:  +1 , deltag:  28.0 , deltam: 16.0 , deltas:  6.3  , orig: "iras"	   , spectype: "K1III"       , parallax:    19.18  , parerr:	 0.83  , promot: " PROMOT  -0.08  -0.09" , vmag:   4.35  , hmag:   0.00  , irastwelvemu:      5.9  , qual:   3  , ftwelve:    0.00  , ones:  0.0  , diam:   2.18  , errdiam:  0.07  , simrem: "Star in Cluster      " , hvartype: "C"	   , multflag: ""  , compid: ""      , theta:	  0 , rho:   0.00 , compmagdiff: 0.00 , notes: ""  , hdnotes: "" , hdmoent: ""  , hdmcoment: "" },$ 
{ name: "HD108759"       , baynum: ""              , hrnum: "HR4755"        , flamnum: ""                 , saonum: "SAO223471"   , ppmnum: "PPM317496"   , varname: "V*V928 Cen"  , hipnum: "HIP60979"    , starname: ""                , alphah: 12.0 , alpham: 29.0 , alphas: 57.89 , plusmin:  -1 , deltag:  41.0 , deltam: 44.0 , deltas:  9.2  , orig: "iras"	   , spectype: "M2II-III"    , parallax:     3.55  , parerr:	 0.76  , promot: " PROMOT      0  -0.03" , vmag:   6.05  , hmag:   1.37  , irastwelvemu:    12.57  , qual:   3  , ftwelve:    0.00  , ones:  0.0  , diam:   3.35  , errdiam:   0.2  , simrem: "Variable Star	   " , hvartype: "U"	  , multflag: ""  , compid: ""      , theta:	 0 , rho:   0.00 , compmagdiff: 0.00 , notes: "P" , hdnotes: "" , hdmoent: ""  , hdmcoment: "" },$ 
{ name: "HD108821"       , baynum: ""              , hrnum: "HR4759"        , flamnum: ""                 , saonum: "SAO180850"   , ppmnum: "PPM260421"   , varname: ""            , hipnum: "HIP61015"    , starname: ""                , alphah: 12.0 , alpham: 30.0 , alphas: 17.45 , plusmin:  -1 , deltag:  23.0 , deltam: 41.0 , deltas: 47.1  , orig: "iras"	   , spectype: "M0III"       , parallax:     3.63  , parerr:	 0.74  , promot: " PROMOT  -0.02  -0.01" , vmag:   5.64  , hmag:    1.7  , irastwelvemu:     8.05  , qual:   3  , ftwelve:    0.00  , ones:  0.0  , diam:   2.59  , errdiam:  0.17  , simrem: "Variable Star	   " , hvartype: "U"	  , multflag: ""  , compid: ""      , theta:	 0 , rho:   0.00 , compmagdiff: 0.00 , notes: ""  , hdnotes: "" , hdmoent: ""  , hdmcoment: "" },$ 
{ name: "HD109379"       , baynum: "bet Crv"       , hrnum: "HR4786"        , flamnum: "FL 9 Crv"         , saonum: "SAO180915"   , ppmnum: "PPM260512"   , varname: ""            , hipnum: "HIP61359"    , starname: ""                , alphah: 12.0 , alpham: 34.0 , alphas: 23.23 , plusmin:  -1 , deltag:  23.0 , deltam: 23.0 , deltas: 48.3  , orig: "iras"	   , spectype: "G5II"	     , parallax:    23.34  , parerr:	  0.8  , promot: " PROMOT      0  -0.06" , vmag:   2.65  , hmag:   0.76  , irastwelvemu:    16.35  , qual:   3  , ftwelve:    0.00  , ones:  0.0  , diam:   3.29  , errdiam:  0.07  , simrem: "Variable Star	   " , hvartype: ""	 , multflag: ""  , compid: ""	   , theta:	0 , rho:   0.00 , compmagdiff: 0.00 , notes: ""  , hdnotes: "" , hdmoent: ""  , hdmcoment: "" },$ 
{ name: "HD110380"       , baynum: "gam Vir"       , hrnum: "HR4826"        , flamnum: "FL 29 Vir"        , saonum: "SAO138917"   , ppmnum: "PPM178847"   , varname: ""            , hipnum: "HIP61941"    , starname: ""                , alphah: 12.0 , alpham: 41.0 , alphas: 39.64 , plusmin:  -1 , deltag:   1.0 , deltam: 26.0 , deltas: 57.8  , orig: "iras"	   , spectype: "F0V"	     , parallax:    84.53  , parerr:	 1.18  , promot: " PROMOT  -0.62  -0.06" , vmag:   3.56  , hmag:    1.9  , irastwelvemu:     5.31  , qual:   3  , ftwelve:    0.00  , ones:  0.0  , diam:   1.59  , errdiam:  0.07  , simrem: "High proper-motion Star     " , hvartype: "D"	  , multflag: "C"  , compid: "AB"      , theta:  284  , rho:  2.7     , compmagdiff:  0.05  , notes: ""  , hdnotes: "" , hdmoent: "Y" , hdmcoment: "" },$ 
{ name: "HD112142"       , baynum: "psi Vir"       , hrnum: "HR4902"        , flamnum: "FL 40 Vir"        , saonum: "SAO139033"   , ppmnum: "PPM195950"   , varname: "V* psiVir"   , hipnum: "HIP62985"    , starname: ""                , alphah: 12.0 , alpham: 54.0 , alphas: 21.16 , plusmin:  -1 , deltag:   9.0 , deltam: 32.0 , deltas: 20.4  , orig: "iras"	   , spectype: "M3III"       , parallax:     7.82  , parerr:	 0.82  , promot: " PROMOT  -0.03  -0.02" , vmag:   4.81  , hmag:   0.33  , irastwelvemu:    32.43  , qual:   3  , ftwelve:    0.00  , ones:  0.0  , diam:   5.36  , errdiam:  0.12  , simrem: "Variable Star	   " , hvartype: "U"	  , multflag: ""  , compid: ""      , theta:	 0 , rho:   0.00 , compmagdiff: 0.00 , notes: ""  , hdnotes: "" , hdmoent: ""  , hdmcoment: "" },$ 
{ name: "HD112213"       , baynum: ""              , hrnum: "HR4906"        , flamnum: ""                 , saonum: "SAO223760"   , ppmnum: "PPM317934"   , varname: ""            , hipnum: "HIP63066"    , starname: ""                , alphah: 12.0 , alpham: 55.0 , alphas: 19.43 , plusmin:  -1 , deltag:  42.0 , deltam: 54.0 , deltas: 56.6  , orig: "iras"	   , spectype: "M0III"       , parallax:     5.42  , parerr:	 0.82  , promot: " PROMOT  -0.04  -0.02" , vmag:   5.48  , hmag:   1.46  , irastwelvemu:    10.77  , qual:   3  , ftwelve:    0.00  , ones:  0.0  , diam:   2.95  , errdiam:  0.18  , simrem: "Variable Star	   " , hvartype: "U"	  , multflag: ""  , compid: ""      , theta:	 0 , rho:   0.00 , compmagdiff: 0.00 , notes: ""  , hdnotes: "" , hdmoent: ""  , hdmcoment: "" },$ 
{ name: "HD112985"       , baynum: "del Mus"       , hrnum: "HR4923"        , flamnum: ""                 , saonum: "SAO257000"   , ppmnum: "PPM371724"   , varname: ""            , hipnum: "HIP63613"    , starname: ""                , alphah: 13.0 , alpham:  2.0 , alphas: 16.26 , plusmin:  -1 , deltag:  71.0 , deltam: 32.0 , deltas: 55.9  , orig: "iras"	   , spectype: "K2III"       , parallax:    35.91  , parerr:	 0.73  , promot: " PROMOT   0.27  -0.03" , vmag:   3.62  , hmag:  1.00   , irastwelvemu:     13.1  , qual:   3  , ftwelve:    0.00  , ones:  0.0  , diam:   3.19  , errdiam:  0.06  , simrem: "Spectroscopic binary	  " , hvartype: ""	, multflag: "O"  , compid: ""	   , theta:	0 , rho:   0.00 , compmagdiff: 0.00 , notes: ""  , hdnotes: "" , hdmoent: "Y" , hdmcoment: "Y" },$
{ name: "HD113996"       , baynum: "Com"           , hrnum: "HR4954"        , flamnum: "FL 41 Com"        , saonum: "SAO82659"    , ppmnum: "PPM102390"   , varname: ""            , hipnum: "HIP64022"    , starname: ""                , alphah: 13.0 , alpham:  7.0 , alphas: 10.73 , plusmin:  +1 , deltag:  27.0 , deltam: 37.0 , deltas: 29.1  , orig: "iras"	   , spectype: "K5III"       , parallax:    10.75  , parerr:	 0.75  , promot: " PROMOT   0.03  -0.08" , vmag:    4.8  , hmag:   1.43  , irastwelvemu:     10.0  , qual:   3  , ftwelve:    0.00  , ones:  0.0  , diam:    2.9  , errdiam:  0.07  , simrem: "Star	    " , hvartype: ""	  , multflag: ""  , compid: ""      , theta:	 0 , rho:   0.00 , compmagdiff: 0.00 , notes: ""  , hdnotes: "" , hdmoent: ""  , hdmcoment: "" },$ 
{ name: "HD115211"       , baynum: ""              , hrnum: "HR5002"        , flamnum: ""                 , saonum: "SAO252240"   , ppmnum: "PPM359998"   , varname: ""            , hipnum: "HIP64820"    , starname: ""                , alphah: 13.0 , alpham: 17.0 , alphas: 13.01 , plusmin:  -1 , deltag:  66.0 , deltam: 47.0 , deltas:  0.4  , orig: "msx"	   , spectype: "K2Ib-II"     , parallax:     2.75  , parerr:	 0.62  , promot: " PROMOT  -0.01  -0.02" , vmag:   4.87  , hmag:   1.71  , irastwelvemu:     0.00  , qual:   0  , ftwelve:    6.96  , ones:  3.6  , diam:   2.52  , errdiam:  0.36  , simrem: "Variable Star	   " , hvartype: ""	 , multflag: ""  , compid: ""	   , theta:	0 , rho:   0.00 , compmagdiff: 0.00 , notes: ""  , hdnotes: "" , hdmoent: ""  , hdmcoment: "" },$ 
{ name: "HD115521"       , baynum: "sig Vir"       , hrnum: "HR5015"        , flamnum: "FL 60 Vir"        , saonum: "SAO119855"   , ppmnum: "PPM159630"   , varname: ""            , hipnum: "HIP64852"    , starname: ""                , alphah: 13.0 , alpham: 17.0 , alphas: 36.28 , plusmin:  +1 , deltag:   5.0 , deltam: 28.0 , deltas: 11.5  , orig: "iras"	   , spectype: "M2III"       , parallax:     6.03  , parerr:	 0.73  , promot: " PROMOT  -0.01   0.02" , vmag:    4.8  , hmag:   0.67  , irastwelvemu:    23.07  , qual:   3  , ftwelve:    0.00  , ones:  0.0  , diam:   4.05  , errdiam:  0.06  , simrem: "Variable Star	   " , hvartype: "U"	  , multflag: ""  , compid: ""      , theta:	 0 , rho:   0.00 , compmagdiff: 0.00 , notes: "P" , hdnotes: "" , hdmoent: ""  , hdmcoment: "" },$ 
{ name: "HD115659"       , baynum: "gam Hya"       , hrnum: "HR5020"        , flamnum: "FL 46 Hya"        , saonum: "SAO181543"   , ppmnum: "PPM261484"   , varname: ""            , hipnum: "HIP64962"    , starname: ""                , alphah: 13.0 , alpham: 18.0 , alphas:  55.3 , plusmin:  -1 , deltag:  23.0 , deltam: 10.0 , deltas: 17.4  , orig: "iras"	   , spectype: "G8III"       , parallax:    24.69  , parerr:	  0.7  , promot: " PROMOT   0.07  -0.05" , vmag:  3.00   , hmag:   1.03  , irastwelvemu:    13.06  , qual:   3  , ftwelve:    0.00  , ones:  0.0  , diam:   2.88  , errdiam:  0.07  , simrem: "Variable Star	   " , hvartype: ""	 , multflag: ""  , compid: ""	   , theta:	0 , rho:   0.00 , compmagdiff: 0.00 , notes: ""  , hdnotes: "" , hdmoent: ""  , hdmcoment: "" },$ 
{ name: "HD116658"       , baynum: "alf Vir"       , hrnum: "HR5056"        , flamnum: "FL 67 Vir"        , saonum: "SAO157923"   , ppmnum: "PPM227262"   , varname: "V* alfVir"   , hipnum: "HIP65474"    , starname: "SPICA"           , alphah: 13.0 , alpham: 25.0 , alphas: 11.58 , plusmin:  -1 , deltag:  11.0 , deltam:  9.0 , deltas: 40.8  , orig: "iras"	   , spectype: "B1III-IV+.." , parallax:    12.44  , parerr:	 0.86  , promot: " PROMOT  -0.04  -0.03" , vmag:   1.04  , hmag:   1.59  , irastwelvemu:     6.18  , qual:   3  , ftwelve:    0.00  , ones:  0.0  , diam:   0.85  , errdiam:  0.12  , simrem: "Ellipsoidal variable Star     " , hvartype: "P"      , multflag: ""  , compid: ""      , theta:     0 , rho:   0.00 , compmagdiff: 0.00 , notes: "P" , hdnotes: "" , hdmoent: ""  , hdmcoment: "" },$ 
{ name: "HD116492"       , baynum: ""              , hrnum: ""              , flamnum: ""                 , saonum: ""            , ppmnum: "PPM779463"   , varname: ""            , hipnum: "HIP65431"    , starname: ""                , alphah: 13.0 , alpham: 25.0 , alphas: 30.38 , plusmin:  -1 , deltag:  63.0 , deltam: 25.0 , deltas: 14.8  , orig: "msx"	   , spectype: "M4"	     , parallax:     0.00  , parerr:	 0.00  , promot: " PROMOT   0.01  -0.02" , vmag:   9.49  , hmag:   2.31  , irastwelvemu:     0.00  , qual:   0  , ftwelve:    6.11  , ones:  3.5  , diam:   2.27  , errdiam:  0.07  , simrem: "Star	    " , hvartype: "C"	   , multflag: "X"  , compid: ""      , theta:     0 , rho:   0.00 , compmagdiff: 0.00 , notes: ""  , hdnotes: "" , hdmoent: ""  , hdmcoment: "" },$ 
{ name: "HD116870"       , baynum: "i Vir"         , hrnum: "HR5064"        , flamnum: "FL 68 Vir"        , saonum: "SAO157938"   , ppmnum: "PPM227300"   , varname: ""            , hipnum: "HIP65581"    , starname: ""                , alphah: 13.0 , alpham: 26.0 , alphas: 43.17 , plusmin:  -1 , deltag:  12.0 , deltam: 42.0 , deltas: 27.6  , orig: "iras"	   , spectype: "K5III"       , parallax:     6.46  , parerr:	 0.82  , promot: " PROMOT  -0.14  -0.02" , vmag:   5.27  , hmag:   1.76  , irastwelvemu:     7.73  , qual:   3  , ftwelve:    0.00  , ones:  0.0  , diam:   2.44  , errdiam:  0.12  , simrem: "Variable Star	   " , hvartype: "U"	  , multflag: ""  , compid: ""      , theta:	 0 , rho:   0.00 , compmagdiff: 0.00 , notes: ""  , hdnotes: "" , hdmoent: ""  , hdmcoment: "" },$ 
{ name: "HD117041"       , baynum: ""              , hrnum: ""              , flamnum: ""                 , saonum: ""            , ppmnum: "PPM371912"   , varname: ""            , hipnum: ""            , starname: ""                , alphah: 13.0 , alpham: 30.0 , alphas: 25.41 , plusmin:  -1 , deltag:  73.0 , deltam: 58.0 , deltas: 31.5  , orig: "iras"	   , spectype: "M6III"       , parallax:     0.00  , parerr:	 0.00  , promot: " PROMOT  -0.03  -0.01" , vmag:    8.9  , hmag:   2.54  , irastwelvemu:     5.15  , qual:   3  , ftwelve:    0.00  , ones:  0.0  , diam:   2.04  , errdiam:  0.07  , simrem: "Star	    " , hvartype: ""	  , multflag: ""  , compid: ""      , theta:	 0 , rho:   0.00 , compmagdiff: 0.00 , notes: ""  , hdnotes: "" , hdmoent: ""  , hdmcoment: "" },$ 
{ name: "HD117440"       , baynum: "d Cen"         , hrnum: "HR5089"        , flamnum: ""                 , saonum: "SAO204545"   , ppmnum: "PPM291480"   , varname: ""            , hipnum: "HIP65936"    , starname: ""                , alphah: 13.0 , alpham: 31.0 , alphas:  2.66 , plusmin:  -1 , deltag:  39.0 , deltam: 24.0 , deltas: 26.3  , orig: "iras"	   , spectype: "G9Ib..."     , parallax:      2.6  , parerr:	 0.75  , promot: " PROMOT  -0.02  -0.02" , vmag:    3.9  , hmag:   1.41  , irastwelvemu:     9.73  , qual:   3  , ftwelve:    0.00  , ones:  0.0  , diam:   2.69  , errdiam:  0.21  , simrem: "Variable Star	   " , hvartype: "D"	  , multflag: "C"  , compid: "AB"      , theta:   98  , rho:  0.22    , compmagdiff:  0.4   , notes: ""  , hdnotes: "" , hdmoent: "Y" , hdmcoment: "" },$ 
{ name: "HD118508"       , baynum: ""              , hrnum: "HR5123"        , flamnum: ""                 , saonum: "SAO82905"    , ppmnum: "PPM102731"   , varname: ""            , hipnum: "HIP66417"    , starname: ""                , alphah: 13.0 , alpham: 36.0 , alphas: 59.08 , plusmin:  +1 , deltag:  24.0 , deltam: 36.0 , deltas: 47.9  , orig: "iras"	   , spectype: "M2III"       , parallax:     6.45  , parerr:	 0.78  , promot: " PROMOT  -0.03  -0.01" , vmag:   5.74  , hmag:   1.65  , irastwelvemu:     8.42  , qual:   3  , ftwelve:    0.00  , ones:  0.0  , diam:   2.57  , errdiam:  0.07  , simrem: "Variable Star	   " , hvartype: "U"	  , multflag: ""  , compid: ""      , theta:	 0 , rho:   0.00 , compmagdiff: 0.00 , notes: ""  , hdnotes: "" , hdmoent: ""  , hdmcoment: "" },$ 
{ name: "HD120323"       , baynum: "g Cen"         , hrnum: "HR5192"        , flamnum: "FL 2 Cen"         , saonum: "SAO204875"   , ppmnum: "PPM291859"   , varname: "V*V806 Cen"  , hipnum: "HIP67457"    , starname: ""                , alphah: 13.0 , alpham: 49.0 , alphas: 26.72 , plusmin:  -1 , deltag:  34.0 , deltam: 27.0 , deltas:  2.8  , orig: "iras"	   , spectype: "M4.5III"     , parallax:    18.39  , parerr:	 0.74  , promot: " PROMOT  -0.04  -0.06" , vmag:   4.19  , hmag:  -1.42  , irastwelvemu:   176.14  , qual:   3  , ftwelve:    0.00  , ones:  0.0  , diam:   9.16  , errdiam:  0.07  , simrem: "Variable Star	   " , hvartype: "U"	  , multflag: ""  , compid: ""      , theta:	 0 , rho:   0.00 , compmagdiff: 0.00 , notes: ""  , hdnotes: "" , hdmoent: ""  , hdmcoment: "" },$ 
{ name: "HD120477"       , baynum: "ups Boo"       , hrnum: "HR5200"        , flamnum: "FL 5 Boo"         , saonum: "SAO100725"   , ppmnum: "PPM130100"   , varname: ""            , hipnum: "HIP67459"    , starname: ""                , alphah: 13.0 , alpham: 49.0 , alphas: 28.64 , plusmin:  +1 , deltag:  15.0 , deltam: 47.0 , deltas: 52.5  , orig: "iras"	   , spectype: "K5.5III"     , parallax:    13.29  , parerr:	 0.81  , promot: " PROMOT   -0.1   0.04" , vmag:   4.05  , hmag:   0.54  , irastwelvemu:    23.28  , qual:   3  , ftwelve:    0.00  , ones:  0.0  , diam:   4.46  , errdiam:  0.02  , simrem: "Variable Star	   " , hvartype: "M"	  , multflag: ""  , compid: ""      , theta:	 0 , rho:   0.00 , compmagdiff: 0.00 , notes: ""  , hdnotes: "" , hdmoent: ""  , hdmcoment: "" },$ 
{ name: "HD120539"       , baynum: "e Boo"         , hrnum: "HR5201"        , flamnum: "FL 6 Boo"         , saonum: "SAO83015"    , ppmnum: "PPM102876"   , varname: ""            , hipnum: "HIP67480"    , starname: ""                , alphah: 13.0 , alpham: 49.0 , alphas: 42.83 , plusmin:  +1 , deltag:  21.0 , deltam: 15.0 , deltas: 50.8  , orig: "iras"	   , spectype: "K4III"       , parallax:     8.86  , parerr:	 1.52  , promot: " PROMOT   0.02   0.01" , vmag:   4.93  , hmag:   1.73  , irastwelvemu:      7.7  , qual:   3  , ftwelve:    0.00  , ones:  0.0  , diam:   2.42  , errdiam:  0.05  , simrem: "Star	    " , hvartype: ""	  , multflag: "X"  , compid: ""      , theta:	  0 , rho:   0.00 , compmagdiff: 0.00 , notes: "D" , hdnotes: "An orbital solution based on elements by R.F.Griffin, J.Astrophys.Astr., 6, 77, 1985, gives a semi-major axis of 7 mas for the photocentre." , hdmoent: ""  , hdmcoment: "" },$ 
{ name: "HD120404"       , baynum: ""              , hrnum: "HR5194"        , flamnum: ""                 , saonum: "SAO252481"   , ppmnum: "PPM360368"   , varname: ""            , hipnum: "HIP67664"    , starname: ""                , alphah: 13.0 , alpham: 51.0 , alphas: 47.43 , plusmin:  -1 , deltag:  69.0 , deltam: 24.0 , deltas:  4.5  , orig: "iras"	   , spectype: "K7III"       , parallax:      4.0  , parerr:	 0.55  , promot: " PROMOT   0.01  -0.02" , vmag:   5.77  , hmag:   1.59  , irastwelvemu:     9.28  , qual:   3  , ftwelve:    0.00  , ones:  0.0  , diam:   2.94  , errdiam:  0.44  , simrem: "Star	    " , hvartype: "U"	   , multflag: ""  , compid: ""      , theta:	  0 , rho:   0.00 , compmagdiff: 0.00 , notes: ""  , hdnotes: "" , hdmoent: ""  , hdmcoment: "" },$ 
{ name: "HD120933"       , baynum: ""              , hrnum: "HR5219"        , flamnum: ""                 , saonum: "SAO63793"    , ppmnum: "PPM77486"    , varname: "V* AW CVn"   , hipnum: "HIP67665"    , starname: ""                , alphah: 13.0 , alpham: 51.0 , alphas: 47.48 , plusmin:  +1 , deltag:  34.0 , deltam: 26.0 , deltas: 39.3  , orig: "iras"	   , spectype: "K5III"       , parallax:      5.4  , parerr:	 0.67  , promot: " PROMOT  -0.02  -0.04" , vmag:   4.77  , hmag:   0.00  , irastwelvemu:    33.81  , qual:   3  , ftwelve:    0.00  , ones:  0.0  , diam:   5.47  , errdiam:  0.07  , simrem: "Variable Star	   " , hvartype: "U"	  , multflag: ""  , compid: ""      , theta:	 0 , rho:   0.00 , compmagdiff: 0.00 , notes: "P" , hdnotes: "" , hdmoent: ""  , hdmcoment: "" },$ 
{ name: "HD121370"       , baynum: "eta Boo"       , hrnum: "HR5235"        , flamnum: "FL 8 Boo"         , saonum: "SAO100766"   , ppmnum: "PPM130166"   , varname: ""            , hipnum: "HIP67927"    , starname: ""                , alphah: 13.0 , alpham: 54.0 , alphas: 41.08 , plusmin:  +1 , deltag:  18.0 , deltam: 23.0 , deltas: 51.8  , orig: "iras"	   , spectype: "G0IV"	     , parallax:    88.17  , parerr:	 0.75  , promot: " PROMOT  -0.06  -0.36" , vmag:   2.68  , hmag:   1.39  , irastwelvemu:     9.13  , qual:   3  , ftwelve:    0.00  , ones:  0.0  , diam:   2.19  , errdiam:  0.01  , simrem: "Spectroscopic binary	  " , hvartype: "M"	 , multflag: "O"  , compid: ""      , theta:	 0 , rho:   0.00 , compmagdiff: 0.00 , notes: ""  , hdnotes: "" , hdmoent: ""  , hdmcoment: "Y" },$
{ name: "HD122451"       , baynum: "bet Cen"       , hrnum: "HR5267"        , flamnum: ""                 , saonum: "SAO252582"   , ppmnum: "PPM360515"   , varname: "V* bet Cen"  , hipnum: "HIP68702"    , starname: "AGENA"           , alphah: 14.0 , alpham:  3.0 , alphas:  49.4 , plusmin:  -1 , deltag:  60.0 , deltam: 22.0 , deltas: 22.9  , orig: "iras"	   , spectype: "B1III"       , parallax:     6.21  , parerr:	 0.56  , promot: " PROMOT  -0.02  -0.03" , vmag:    0.6  , hmag:   1.22  , irastwelvemu:     7.88  , qual:   3  , ftwelve:    7.05  , ones:  3.4  , diam:   0.93  , errdiam:  0.21  , simrem: "Variable Star of beta Cep type	 " , hvartype: "U"	, multflag: "C"  , compid: "AB"      , theta:  234  , rho:  0.87    , compmagdiff:  3.37  , notes: ""  , hdnotes: "" , hdmoent: "Y" , hdmcoment: "" },$ 
{ name: "HD123123"       , baynum: "pi. Hya"       , hrnum: "HR5287"        , flamnum: "FL 49 Hya"        , saonum: "SAO182244"   , ppmnum: "PPM262489"   , varname: ""            , hipnum: "HIP68895"    , starname: ""                , alphah: 14.0 , alpham:  6.0 , alphas:  22.3 , plusmin:  -1 , deltag:  26.0 , deltam: 40.0 , deltas: 56.5  , orig: "iras"	   , spectype: "K2III"       , parallax:    32.17  , parerr:	 0.77  , promot: " PROMOT   0.04  -0.14" , vmag:   3.26  , hmag:   0.77  , irastwelvemu:    16.16  , qual:   3  , ftwelve:    0.00  , ones:  0.0  , diam:   3.43  , errdiam:  0.06  , simrem: "Star	    " , hvartype: ""	  , multflag: ""  , compid: ""      , theta:	 0 , rho:   0.00 , compmagdiff: 0.00 , notes: ""  , hdnotes: "" , hdmoent: "Y" , hdmcoment: "" },$ 
{ name: "HD123139"       , baynum: "the Cen"       , hrnum: "HR5288"        , flamnum: "FL 5 Cen"         , saonum: "SAO205188"   , ppmnum: "PPM292214"   , varname: ""            , hipnum: "HIP68933"    , starname: ""                , alphah: 14.0 , alpham:  6.0 , alphas: 40.95 , plusmin:  -1 , deltag:  36.0 , deltam: 22.0 , deltas: 11.8  , orig: "iras"	   , spectype: "K0IIIb"      , parallax:    53.52  , parerr:	 0.79  , promot: " PROMOT  -0.52  -0.52" , vmag:   2.06  , hmag:  -0.18  , irastwelvemu:    39.64  , qual:   3  , ftwelve:    0.00  , ones:  0.0  , diam:   5.17  , errdiam:  0.02  , simrem: "High proper-motion Star     " , hvartype: "C"	  , multflag: ""  , compid: ""      , theta:	 0 , rho:   0.00 , compmagdiff: 0.00 , notes: ""  , hdnotes: "" , hdmoent: ""  , hdmcoment: "" },$ 
{ name: "HD124294"       , baynum: "kap Vir"       , hrnum: "HR5315"        , flamnum: "FL 98 Vir"        , saonum: "SAO158427"   , ppmnum: "PPM228460"   , varname: ""            , hipnum: "HIP69427"    , starname: ""                , alphah: 14.0 , alpham: 12.0 , alphas: 53.75 , plusmin:  -1 , deltag:  10.0 , deltam: 16.0 , deltas: 25.3  , orig: "iras"	   , spectype: "K2.5IIIb"    , parallax:    14.59  , parerr:	 0.95  , promot: " PROMOT   0.01   0.14" , vmag:   4.19  , hmag:   1.12  , irastwelvemu:    12.47  , qual:   3  , ftwelve:    0.00  , ones:  0.0  , diam:   3.12  , errdiam:  0.06  , simrem: "Variable Star	   " , hvartype: "C"	  , multflag: ""  , compid: ""      , theta:	 0 , rho:   0.00 , compmagdiff: 0.00 , notes: ""  , hdnotes: "" , hdmoent: ""  , hdmcoment: "" },$ 
{ name: "HD124897"       , baynum: "alf Boo"       , hrnum: "HR5340"        , flamnum: "FL 16 Boo"        , saonum: "SAO100944"   , ppmnum: "PPM130442"   , varname: ""            , hipnum: "HIP69673"    , starname: "ARCTURUS"        , alphah: 14.0 , alpham: 15.0 , alphas: 39.67 , plusmin:  +1 , deltag:  19.0 , deltam: 10.0 , deltas: 56.7  , orig: "iras"	   , spectype: "K1.5III"     , parallax:    88.85  , parerr:	 0.74  , promot: " PROMOT   -1.1     -2" , vmag:  -0.04  , hmag:  -2.88  , irastwelvemu:   546.97  , qual:   3  , ftwelve:    0.00  , ones:  0.0  , diam:  19.26  , errdiam:  0.01  , simrem: "Variable Star	   " , hvartype: "U"	  , multflag: "C"  , compid: "AB"      , theta:  198  , rho:  0.26    , compmagdiff:  3.33  , notes: ""  , hdnotes: "" , hdmoent: "Y" , hdmcoment: "" },$ 
{ name: "HD125180"       , baynum: ""              , hrnum: "HR5352"        , flamnum: "FL 101 Vir"       , saonum: "SAO100956"   , ppmnum: "PPM130465"   , varname: "V* CY Boo"   , hipnum: "HIP69829"    , starname: ""                , alphah: 14.0 , alpham: 17.0 , alphas: 28.45 , plusmin:  +1 , deltag:  15.0 , deltam: 15.0 , deltas: 48.2  , orig: "iras"	   , spectype: "M3III"       , parallax:     3.22  , parerr:	 0.76  , promot: " PROMOT   0.01   0.01" , vmag:   5.87  , hmag:   1.69  , irastwelvemu:      8.6  , qual:   3  , ftwelve:    0.00  , ones:  0.0  , diam:   2.58  , errdiam:  0.07  , simrem: "Variable Star	   " , hvartype: "U"	  , multflag: ""  , compid: ""      , theta:	 0 , rho:   0.00 , compmagdiff: 0.00 , notes: ""  , hdnotes: "" , hdmoent: ""  , hdmcoment: "" },$ 
{ name: "HD125687"       , baynum: ""              , hrnum: ""              , flamnum: ""                 , saonum: "SAO241679"   , ppmnum: "PPM342798"   , varname: "V*V1003 Cen" , hipnum: "HIP70290"    , starname: ""                , alphah: 14.0 , alpham: 22.0 , alphas: 52.24 , plusmin:  -1 , deltag:  55.0 , deltam: 57.0 , deltas: 44.4  , orig: "msx"	   , spectype: "M5II"	     , parallax:     0.94  , parerr:	 0.88  , promot: " PROMOT  -0.01      0" , vmag:    7.9  , hmag:   1.24  , irastwelvemu:     0.00  , qual:   0  , ftwelve:   19.69  , ones:  3.6  , diam:   3.92  , errdiam:  0.88  , simrem: "Variable Star	   " , hvartype: "U"	  , multflag: ""  , compid: ""      , theta:	 0 , rho:   0.00 , compmagdiff: 0.00 , notes: ""  , hdnotes: "" , hdmoent: ""  , hdmcoment: "" },$ 
{ name: "HD124882"       , baynum: "del Oct"       , hrnum: "HR5339"        , flamnum: ""                 , saonum: "SAO258698"   , ppmnum: "PPM377680"   , varname: ""            , hipnum: "HIP70638"    , starname: ""                , alphah: 14.0 , alpham: 26.0 , alphas: 55.23 , plusmin:  -1 , deltag:  83.0 , deltam: 40.0 , deltas:  4.4  , orig: "iras"	   , spectype: "K2III"       , parallax:     11.7  , parerr:	 0.49  , promot: " PROMOT  -0.09  -0.01" , vmag:   4.32  , hmag:   1.36  , irastwelvemu:     9.91  , qual:   3  , ftwelve:    0.00  , ones:  0.0  , diam:   2.79  , errdiam:   0.1  , simrem: "Variable Star	   " , hvartype: ""	 , multflag: ""  , compid: ""	   , theta:	0 , rho:   0.00 , compmagdiff: 0.00 , notes: ""  , hdnotes: "" , hdmoent: ""  , hdmcoment: "" },$ 
{ name: "HD126927"       , baynum: ""              , hrnum: "HR5410"        , flamnum: "FL 106 Vir"       , saonum: "SAO139957"   , ppmnum: "PPM197585"   , varname: ""            , hipnum: "HIP70794"    , starname: ""                , alphah: 14.0 , alpham: 28.0 , alphas: 41.72 , plusmin:  -1 , deltag:   6.0 , deltam: 54.0 , deltas:  1.9  , orig: "iras"	   , spectype: "K5III"       , parallax:     6.81  , parerr:	 0.76  , promot: " PROMOT  -0.02  -0.06" , vmag:   5.43  , hmag:   2.04  , irastwelvemu:     5.55  , qual:   3  , ftwelve:    0.00  , ones:  0.0  , diam:   2.14  , errdiam:  0.12  , simrem: "Star	    " , hvartype: ""	  , multflag: ""  , compid: ""      , theta:	 0 , rho:   0.00 , compmagdiff: 0.00 , notes: ""  , hdnotes: "" , hdmoent: ""  , hdmcoment: "" },$ 
{ name: "HD127093"       , baynum: ""              , hrnum: ""              , flamnum: ""                 , saonum: "SAO83375"    , ppmnum: "PPM103351"   , varname: "V* DX Boo"   , hipnum: "HIP70800"    , starname: ""                , alphah: 14.0 , alpham: 28.0 , alphas: 46.03 , plusmin:  +1 , deltag:  25.0 , deltam: 51.0 , deltas: 14.0  , orig: "iras"	   , spectype: "MIII"	     , parallax:      3.7  , parerr:	 0.84  , promot: " PROMOT   0.02  -0.02" , vmag:   6.73  , hmag:   1.88  , irastwelvemu:     7.25  , qual:   3  , ftwelve:    0.00  , ones:  0.0  , diam:   2.66  , errdiam:  0.07  , simrem: "Variable Star of irregular type   " , hvartype: "U"	, multflag: ""  , compid: ""	  , theta:     0 , rho:   0.00 , compmagdiff: 0.00 , notes: ""  , hdnotes: "" , hdmoent: ""  , hdmcoment: "" },$ 
{ name: "HD127665"       , baynum: "rho Boo"       , hrnum: "HR5429"        , flamnum: "FL 25 Boo"        , saonum: "SAO64202"    , ppmnum: "PPM77975"    , varname: ""            , hipnum: "HIP71053"    , starname: ""                , alphah: 14.0 , alpham: 31.0 , alphas: 49.79 , plusmin:  +1 , deltag:  30.0 , deltam: 22.0 , deltas: 17.2  , orig: "iras"	   , spectype: "K3III"       , parallax:    21.92  , parerr:	 0.81  , promot: " PROMOT   -0.1   0.12" , vmag:   3.58  , hmag:   0.00  , irastwelvemu:    17.99  , qual:   3  , ftwelve:    0.00  , ones:  0.0  , diam:   3.74  , errdiam:  0.04  , simrem: "Variable Star	   " , hvartype: ""	 , multflag: ""  , compid: ""	   , theta:	0 , rho:   0.00 , compmagdiff: 0.00 , notes: ""  , hdnotes: "" , hdmoent: ""  , hdmcoment: "" },$ 
{ name: "HD128193"       , baynum: ""              , hrnum: ""              , flamnum: ""                 , saonum: ""            , ppmnum: "PPM780097"   , varname: "V*V1011 Cen" , hipnum: "HIP71563"    , starname: ""                , alphah: 14.0 , alpham: 38.0 , alphas: 10.15 , plusmin:  -1 , deltag:  62.0 , deltam: 43.0 , deltas:  3.8  , orig: "msx"	   , spectype: "M4/M5"       , parallax:     2.93  , parerr:	 1.32  , promot: " PROMOT  -0.01   0.01" , vmag:   8.79  , hmag:   2.43  , irastwelvemu:     0.00  , qual:   0  , ftwelve:    5.09  , ones:  3.9  , diam:   2.18  , errdiam:  0.41  , simrem: "Variable Star of irregular type   " , hvartype: "U"	, multflag: ""  , compid: ""	  , theta:     0 , rho:   0.00 , compmagdiff: 0.00 , notes: ""  , hdnotes: "" , hdmoent: ""  , hdmcoment: "" },$ 
{ name: "HD129456"       , baynum: "c01 Cen"       , hrnum: "HR5485"        , flamnum: ""                 , saonum: "SAO205871"   , ppmnum: "PPM292985"   , varname: ""            , hipnum: "HIP72010"    , starname: ""                , alphah: 14.0 , alpham: 43.0 , alphas: 39.44 , plusmin:  -1 , deltag:  35.0 , deltam: 10.0 , deltas: 25.2  , orig: "iras"	   , spectype: "K5III"       , parallax:    15.89  , parerr:	 0.71  , promot: " PROMOT  -0.07  -0.19" , vmag:   4.05  , hmag:   1.04  , irastwelvemu:     14.9  , qual:   3  , ftwelve:    0.00  , ones:  0.0  , diam:   3.27  , errdiam:   0.1  , simrem: "High proper-motion Star     " , hvartype: ""	 , multflag: ""  , compid: ""	   , theta:	0 , rho:   0.00 , compmagdiff: 0.00 , notes: ""  , hdnotes: "" , hdmoent: ""  , hdmcoment: "" },$ 
{ name: "HD129989"       , baynum: "eps Boo"       , hrnum: "HR5506"        , flamnum: "FL 36 Boo"        , saonum: "SAO83500"    , ppmnum: "PPM103553"   , varname: ""            , hipnum: "HIP72105"    , starname: ""                , alphah: 14.0 , alpham: 44.0 , alphas: 59.21 , plusmin:  +1 , deltag:  27.0 , deltam:  4.0 , deltas: 27.4  , orig: "iras"	   , spectype: "K0II-III"    , parallax:     13.0  , parerr:	  7.0  , promot: " PROMOT  -0.05   0.01" , vmag:    2.7  , hmag:   0.27  , irastwelvemu:    31.92  , qual:   3  , ftwelve:    0.00  , ones:  0.0  , diam:    4.2  , errdiam:  0.06  , simrem: "Eclipsing binary      " , hvartype: "D"      , multflag: "C"  , compid: "AB"	 , theta:  341  , rho:  2.87	, compmagdiff:  2.19  , notes: ""  , hdnotes: "" , hdmoent: "Y" , hdmcoment: "" },$ 
{ name: "HD129902"       , baynum: ""              , hrnum: "HR5496"        , flamnum: ""                 , saonum: "SAO140116"   , ppmnum: "PPM179374"   , varname: ""            , hipnum: "HIP72122"    , starname: ""                , alphah: 14.0 , alpham: 45.0 , alphas: 11.71 , plusmin:  -1 , deltag:   1.0 , deltam: 25.0 , deltas:  3.1  , orig: "iras"	   , spectype: "M1III"       , parallax:     6.38  , parerr:	 1.26  , promot: " PROMOT  -0.06  -0.01" , vmag:   6.07  , hmag:   1.96  , irastwelvemu:     6.31  , qual:   3  , ftwelve:    0.00  , ones:  0.0  , diam:   2.27  , errdiam:  0.12  , simrem: "Star	    " , hvartype: "U"	   , multflag: ""  , compid: ""      , theta:	  0 , rho:   0.00 , compmagdiff: 0.00 , notes: ""  , hdnotes: "" , hdmoent: ""  , hdmcoment: "" },$ 
{ name: "HD130694"       , baynum: "E Hya"         , hrnum: "HR5526"        , flamnum: "FL 58 Hya"        , saonum: "SAO182911"   , ppmnum: "PPM263452"   , varname: ""            , hipnum: "HIP72571"    , starname: ""                , alphah: 14.0 , alpham: 50.0 , alphas: 17.31 , plusmin:  -1 , deltag:  27.0 , deltam: 57.0 , deltas: 37.3  , orig: "iras"	   , spectype: "K4III"       , parallax:    10.68  , parerr:	 0.83  , promot: " PROMOT  -0.24  -0.06" , vmag:   4.42  , hmag:   1.19  , irastwelvemu:    12.12  , qual:   3  , ftwelve:    0.00  , ones:  0.0  , diam:    3.1  , errdiam:  0.14  , simrem: "High proper-motion Star     " , hvartype: ""	 , multflag: ""  , compid: ""	   , theta:	0 , rho:   0.00 , compmagdiff: 0.00 , notes: ""  , hdnotes: "" , hdmoent: ""  , hdmcoment: "" },$ 
{ name: "HD131217"       , baynum: ""              , hrnum: ""              , flamnum: ""                 , saonum: "SAO252955"   , ppmnum: "PPM361081"   , varname: "V* CR Cir"   , hipnum: "HIP72989"    , starname: ""                , alphah: 14.0 , alpham: 54.0 , alphas: 56.94 , plusmin:  -1 , deltag:  61.0 , deltam:  4.0 , deltas: 33.0  , orig: "msx"	   , spectype: "M2/M3II"     , parallax:     4.24  , parerr:	 1.02  , promot: " PROMOT  -0.01      0" , vmag:   7.51  , hmag:   2.31  , irastwelvemu:     0.00  , qual:   0  , ftwelve:    5.26  , ones:  3.8  , diam:   2.25  , errdiam:  0.29  , simrem: "S Star	    " , hvartype: "U"	   , multflag: ""  , compid: ""      , theta:	  0 , rho:   0.00 , compmagdiff: 0.00 , notes: ""  , hdnotes: "" , hdmoent: ""  , hdmcoment: "" },$ 
{ name: "HD131109"       , baynum: "R Aps"         , hrnum: "HR5540"        , flamnum: ""                 , saonum: "SAO257212"   , ppmnum: "PPM372479"   , varname: "V* R Aps"    , hipnum: "HIP73223"    , starname: ""                , alphah: 14.0 , alpham: 57.0 , alphas: 52.98 , plusmin:  -1 , deltag:  76.0 , deltam: 39.0 , deltas: 45.6  , orig: "iras"	   , spectype: "K4III"       , parallax:     7.62  , parerr:	 0.56  , promot: " PROMOT  -0.07  -0.02" , vmag:   5.38  , hmag:   2.16  , irastwelvemu:     5.02  , qual:   3  , ftwelve:    0.00  , ones:  0.0  , diam:   2.03  , errdiam:  0.15  , simrem: "Variable Star	   " , hvartype: ""	 , multflag: ""  , compid: ""	   , theta:	0 , rho:   0.00 , compmagdiff: 0.00 , notes: ""  , hdnotes: "" , hdmoent: ""  , hdmcoment: "" },$ 
{ name: "HD133124"       , baynum: "ome Boo"       , hrnum: "HR5600"        , flamnum: "FL 41 Boo"        , saonum: "SAO83624"    , ppmnum: "PPM103744"   , varname: ""            , hipnum: "HIP73568"    , starname: ""                , alphah: 15.0 , alpham:  2.0 , alphas:  6.51 , plusmin:  +1 , deltag:  25.0 , deltam:  0.0 , deltas: 29.3  , orig: "iras"	   , spectype: "K4III"       , parallax:     9.07  , parerr:	 0.74  , promot: " PROMOT  -0.01  -0.05" , vmag:    4.8  , hmag:    1.4  , irastwelvemu:     9.99  , qual:   3  , ftwelve:    0.00  , ones:  0.0  , diam:   2.87  , errdiam:  0.07  , simrem: "Star	    " , hvartype: "M"	   , multflag: ""  , compid: ""      , theta:	  0 , rho:   0.00 , compmagdiff: 0.00 , notes: ""  , hdnotes: "" , hdmoent: ""  , hdmcoment: "" },$ 
{ name: "HD133165"       , baynum: ""              , hrnum: "HR5601"        , flamnum: "FL 110 Vir"       , saonum: "SAO120809"   , ppmnum: "PPM161209"   , varname: ""            , hipnum: "HIP73620"    , starname: ""                , alphah: 15.0 , alpham:  2.0 , alphas: 54.04 , plusmin:  +1 , deltag:   2.0 , deltam:  5.0 , deltas: 28.7  , orig: "iras"	   , spectype: "K0.5IIIb"    , parallax:    17.78  , parerr:	  0.9  , promot: " PROMOT  -0.06   0.01" , vmag:    4.4  , hmag:   2.05  , irastwelvemu:     5.41  , qual:   3  , ftwelve:    0.00  , ones:  0.0  , diam:    1.8  , errdiam:  0.03  , simrem: "Variable Star	   " , hvartype: ""	 , multflag: ""  , compid: ""	   , theta:	0 , rho:   0.00 , compmagdiff: 0.00 , notes: ""  , hdnotes: "" , hdmoent: ""  , hdmcoment: "" },$ 
{ name: "HD133216"       , baynum: "sig Lib"       , hrnum: "HR5603"        , flamnum: "FL 20 Lib"        , saonum: "SAO183139"   , ppmnum: "PPM263746"   , varname: "V* sig Lib"  , hipnum: "HIP73714"    , starname: ""                , alphah: 15.0 , alpham:  4.0 , alphas:  4.22 , plusmin:  -1 , deltag:  25.0 , deltam: 16.0 , deltas: 55.1  , orig: "iras"	   , spectype: "M3/M4III"    , parallax:    11.17  , parerr:	 0.98  , promot: " PROMOT  -0.07  -0.05" , vmag:    3.3  , hmag:  -1.21  , irastwelvemu:   138.41  , qual:   3  , ftwelve:    0.00  , ones:  0.0  , diam:  11.18  , errdiam:  0.14  , simrem: "Variable Star	   " , hvartype: ""	 , multflag: ""  , compid: ""	   , theta:	0 , rho:   0.00 , compmagdiff: 0.00 , notes: ""  , hdnotes: "" , hdmoent: ""  , hdmcoment: "" },$ 
{ name: "HD133582"       , baynum: "psi Boo"       , hrnum: "HR5616"        , flamnum: "FL 43 Boo"        , saonum: "SAO83645"    , ppmnum: "PPM103769"   , varname: ""            , hipnum: "HIP73745"    , starname: ""                , alphah: 15.0 , alpham:  4.0 , alphas: 26.74 , plusmin:  +1 , deltag:  26.0 , deltam: 56.0 , deltas: 51.5  , orig: "iras"	   , spectype: "K2III"       , parallax:    13.04  , parerr:	 0.68  , promot: " PROMOT  -0.18  -0.01" , vmag:   4.52  , hmag:   0.00  , irastwelvemu:     7.43  , qual:   3  , ftwelve:    0.00  , ones:  0.0  , diam:   2.35  , errdiam:  0.06  , simrem: "Star	    " , hvartype: "C"	   , multflag: ""  , compid: ""      , theta:	  0 , rho:   0.00 , compmagdiff: 0.00 , notes: ""  , hdnotes: "" , hdmoent: ""  , hdmcoment: "" },$ 
{ name: "HD133774"       , baynum: "nu. Lib"       , hrnum: "HR5622"        , flamnum: "FL 21 Lib"        , saonum: "SAO159028"   , ppmnum: "PPM229760"   , varname: ""            , hipnum: "HIP73945"    , starname: ""                , alphah: 15.0 , alpham:  6.0 , alphas:  37.6 , plusmin:  -1 , deltag:  16.0 , deltam: 15.0 , deltas: 24.5  , orig: "iras"	   , spectype: "K5III"       , parallax:     4.26  , parerr:	  0.8  , promot: " PROMOT  -0.05  -0.03" , vmag:    5.2  , hmag:   1.62  , irastwelvemu:     8.44  , qual:   3  , ftwelve:    0.00  , ones:  0.0  , diam:   2.77  , errdiam:   0.4  , simrem: "Star	    " , hvartype: ""	  , multflag: ""  , compid: ""      , theta:	 0 , rho:   0.00 , compmagdiff: 0.00 , notes: ""  , hdnotes: "" , hdmoent: ""  , hdmcoment: "" },$ 
{ name: "HD134505"       , baynum: "zet Lup"       , hrnum: "HR5649"        , flamnum: ""                 , saonum: "SAO242304"   , ppmnum: "PPM343507"   , varname: ""            , hipnum: "HIP74395"    , starname: ""                , alphah: 15.0 , alpham: 12.0 , alphas: 17.09 , plusmin:  -1 , deltag:  52.0 , deltam:  5.0 , deltas: 57.3  , orig: "iras"	   , spectype: "G8III"       , parallax:    28.06  , parerr:	 0.71  , promot: " PROMOT  -0.11  -0.07" , vmag:   3.41  , hmag:   1.39  , irastwelvemu:      9.3  , qual:   3  , ftwelve:    0.00  , ones:  0.0  , diam:   2.48  , errdiam:  0.03  , simrem: "Eclipsing binary      " , hvartype: "C"      , multflag: ""  , compid: ""      , theta:     0 , rho:   0.00 , compmagdiff: 0.00 , notes: ""  , hdnotes: "" , hdmoent: "Y" , hdmcoment: "" },$ 
{ name: "HD134468"       , baynum: ""              , hrnum: "HR5645"        , flamnum: ""                 , saonum: "SAO253059"   , ppmnum: "PPM361267"   , varname: ""            , hipnum: "HIP74470"    , starname: ""                , alphah: 15.0 , alpham: 13.0 , alphas:  1.02 , plusmin:  -1 , deltag:  61.0 , deltam: 44.0 , deltas: 37.6  , orig: "msx"	   , spectype: "K4Ib"	     , parallax:     0.43  , parerr:	 0.74  , promot: " PROMOT      0  -0.01" , vmag:   6.32  , hmag:   1.94  , irastwelvemu:     0.00  , qual:   0  , ftwelve:     7.4  , ones:  3.4  , diam:    2.5  , errdiam:  1.03  , simrem: "Star	    " , hvartype: "U"	   , multflag: ""  , compid: ""      , theta:	  0 , rho:   0.00 , compmagdiff: 0.00 , notes: ""  , hdnotes: "" , hdmoent: ""  , hdmcoment: "" },$ 
{ name: "HD135291"       , baynum: "eps Cir"       , hrnum: "HR5666"        , flamnum: ""                 , saonum: "SAO253088"   , ppmnum: "PPM361320"   , varname: ""            , hipnum: "HIP74837"    , starname: ""                , alphah: 15.0 , alpham: 17.0 , alphas: 38.89 , plusmin:  -1 , deltag:  63.0 , deltam: 36.0 , deltas: 37.7  , orig: "iras"	   , spectype: "K2.5III"     , parallax:     8.74  , parerr:	 0.62  , promot: " PROMOT   0.01   0.01" , vmag:   4.85  , hmag:   2.11  , irastwelvemu:      5.0  , qual:   3  , ftwelve:    0.00  , ones:  0.0  , diam:   1.98  , errdiam:  0.15  , simrem: "Star	    " , hvartype: "C"	   , multflag: ""  , compid: ""      , theta:	  0 , rho:   0.00 , compmagdiff: 0.00 , notes: ""  , hdnotes: "" , hdmoent: ""  , hdmcoment: "" },$ 
{ name: "HD135758"       , baynum: "f Lup"         , hrnum: "HR5686"        , flamnum: "FL 2 Lup"         , saonum: "SAO183346"   , ppmnum: "PPM293678"   , varname: ""            , hipnum: "HIP74857"    , starname: ""                , alphah: 15.0 , alpham: 17.0 , alphas: 49.84 , plusmin:  -1 , deltag:  30.0 , deltam:  8.0 , deltas: 55.2  , orig: "iras"	   , spectype: "K0III"       , parallax:    10.59  , parerr:	  1.0  , promot: " PROMOT  -0.01  -0.01" , vmag:   4.35  , hmag:   2.05  , irastwelvemu:     5.41  , qual:   3  , ftwelve:    0.00  , ones:  0.0  , diam:   1.95  , errdiam:  0.14  , simrem: "Variable Star	   " , hvartype: ""	 , multflag: ""  , compid: ""	   , theta:	0 , rho:   0.00 , compmagdiff: 0.00 , notes: ""  , hdnotes: "" , hdmoent: ""  , hdmcoment: "" },$ 
{ name: "HD135902"       , baynum: ""              , hrnum: ""              , flamnum: ""                 , saonum: "SAO242421"   , ppmnum: "PPM343625"   , varname: "V* CY Cir"   , hipnum: "HIP75054"    , starname: ""                , alphah: 15.0 , alpham: 20.0 , alphas: 13.00 , plusmin:  -1 , deltag:  57.0 , deltam: 23.0 , deltas: 52.9  , orig: "msx"	   , spectype: "M3III"       , parallax:     1.85  , parerr:	 0.99  , promot: " PROMOT  -0.04  -0.04" , vmag:   7.11  , hmag:   2.11  , irastwelvemu:     0.00  , qual:   0  , ftwelve:    6.25  , ones:  3.5  , diam:   2.44  , errdiam:  0.38  , simrem: "Variable Star of irregular type   " , hvartype: "U"	, multflag: ""  , compid: ""	  , theta:     0 , rho:   0.00 , compmagdiff: 0.00 , notes: ""  , hdnotes: "" , hdmoent: ""  , hdmcoment: "" },$ 
{ name: "HD137066"       , baynum: ""              , hrnum: "HR5725"        , flamnum: ""                 , saonum: "SAO253174"   , ppmnum: "PPM361455"   , varname: "V* LX TrA"   , hipnum: "HIP75665"    , starname: ""                , alphah: 15.0 , alpham: 27.0 , alphas: 33.08 , plusmin:  -1 , deltag:  64.0 , deltam: 31.0 , deltas: 53.4  , orig: "iras"	   , spectype: "K7III"       , parallax:      4.8  , parerr:	 0.68  , promot: " PROMOT  -0.03  -0.03" , vmag:   5.73  , hmag:   1.77  , irastwelvemu:     7.75  , qual:   3  , ftwelve:    0.00  , ones:  0.0  , diam:   2.61  , errdiam:  0.25  , simrem: "Variable Star	   " , hvartype: "P"	  , multflag: ""  , compid: ""      , theta:	 0 , rho:   0.00 , compmagdiff: 0.00 , notes: ""  , hdnotes: "" , hdmoent: ""  , hdmcoment: "" },$ 
{ name: "HD138140"       , baynum: ""              , hrnum: ""              , flamnum: ""                 , saonum: "SAO242663"   , ppmnum: "PPM343882"   , varname: ""            , hipnum: ""            , starname: ""                , alphah: 15.0 , alpham: 32.0 , alphas: 16.52 , plusmin:  -1 , deltag:  50.0 , deltam: 52.0 , deltas: 16.3  , orig: "iras"	   , spectype: "M4III"       , parallax:     0.00  , parerr:	 0.00  , promot: " PROMOT      0  -0.02" , vmag:   7.47  , hmag:   1.85  , irastwelvemu:     8.61  , qual:   3  , ftwelve:    8.43  , ones:  3.7  , diam:   2.77  , errdiam:  0.07  , simrem: "Star	    " , hvartype: ""	  , multflag: ""  , compid: ""      , theta:	 0 , rho:   0.00 , compmagdiff: 0.00 , notes: ""  , hdnotes: "" , hdmoent: ""  , hdmcoment: "" },$ 
{ name: "HD138492"       , baynum: ""              , hrnum: ""              , flamnum: ""                 , saonum: "SAO206758"   , ppmnum: "PPM293993"   , varname: ""            , hipnum: ""            , starname: ""                , alphah: 15.0 , alpham: 33.0 , alphas: 46.94 , plusmin:  -1 , deltag:  37.0 , deltam: 38.0 , deltas: 23.8  , orig: "iras"	   , spectype: "M3III"       , parallax:     0.00  , parerr:	 0.00  , promot: " PROMOT   0.01  -0.03" , vmag:   7.67  , hmag:   2.21  , irastwelvemu:     5.86  , qual:   3  , ftwelve:    0.00  , ones:  0.0  , diam:   2.36  , errdiam:  0.07  , simrem: "Star	    " , hvartype: ""	  , multflag: ""  , compid: ""      , theta:	 0 , rho:   0.00 , compmagdiff: 0.00 , notes: ""  , hdnotes: "" , hdmoent: ""  , hdmcoment: "" },$ 
{ name: "HD138905"       , baynum: "gam Lib"       , hrnum: "HR5787"        , flamnum: "FL 38 Lib"        , saonum: "SAO159370"   , ppmnum: "PPM230451"   , varname: ""            , hipnum: "HIP76333"    , starname: ""                , alphah: 15.0 , alpham: 35.0 , alphas: 31.58 , plusmin:  -1 , deltag:  14.0 , deltam: 47.0 , deltas: 22.3  , orig: "iras"	   , spectype: "K0III"       , parallax:    21.42  , parerr:	  0.9  , promot: " PROMOT   0.06      0" , vmag:   3.93  , hmag:    1.6  , irastwelvemu:     7.28  , qual:   3  , ftwelve:    0.00  , ones:  0.0  , diam:   2.21  , errdiam:  0.07  , simrem: "Double or multiple star     " , hvartype: ""	 , multflag: ""  , compid: ""	   , theta:	0 , rho:   0.00 , compmagdiff: 0.00 , notes: ""  , hdnotes: "" , hdmoent: ""  , hdmcoment: "" },$ 
{ name: "HD138816"       , baynum: ""              , hrnum: "HR5784"        , flamnum: ""                 , saonum: "SAO225957"   , ppmnum: "PPM320766"   , varname: ""            , hipnum: "HIP76397"    , starname: ""                , alphah: 15.0 , alpham: 36.0 , alphas:  12.1 , plusmin:  -1 , deltag:  44.0 , deltam: 23.0 , deltas: 48.6  , orig: "iras"	   , spectype: "K4.5III"     , parallax:     4.95  , parerr:	 0.92  , promot: " PROMOT  -0.05  -0.05" , vmag:   5.45  , hmag:   2.11  , irastwelvemu:      5.1  , qual:   3  , ftwelve:    0.00  , ones:  0.0  , diam:    2.1  , errdiam:  0.27  , simrem: "Variable Star	   " , hvartype: ""	 , multflag: ""  , compid: ""	   , theta:	0 , rho:   0.00 , compmagdiff: 0.00 , notes: ""  , hdnotes: "" , hdmoent: ""  , hdmcoment: "" },$ 
{ name: "HD138538"       , baynum: "eps TrA"       , hrnum: "HR5771"        , flamnum: ""                 , saonum: "SAO253226"   , ppmnum: "PPM361547"   , varname: ""            , hipnum: "HIP76440"    , starname: ""                , alphah: 15.0 , alpham: 36.0 , alphas: 43.22 , plusmin:  -1 , deltag:  66.0 , deltam: 19.0 , deltas:  1.3  , orig: "iras"	   , spectype: "K1.5III"     , parallax:    15.09  , parerr:	 0.62  , promot: " PROMOT   0.03  -0.07" , vmag:   4.11  , hmag:   1.58  , irastwelvemu:     7.96  , qual:   3  , ftwelve:    0.00  , ones:  0.0  , diam:   2.43  , errdiam:  0.09  , simrem: "Eclipsing binary      " , hvartype: "U"      , multflag: ""  , compid: ""      , theta:     0 , rho:   0.00 , compmagdiff: 0.00 , notes: ""  , hdnotes: "" , hdmoent: ""  , hdmcoment: "" },$ 
{ name: "HD139127"       , baynum: "ome Lup"       , hrnum: "HR5797"        , flamnum: ""                 , saonum: "SAO226004"   , ppmnum: "PPM320817"   , varname: ""            , hipnum: "HIP76552"    , starname: ""                , alphah: 15.0 , alpham: 38.0 , alphas:  3.21 , plusmin:  -1 , deltag:  42.0 , deltam: 34.0 , deltas:  2.5  , orig: "iras"	   , spectype: "K4.5III"     , parallax:    14.19  , parerr:	 0.73  , promot: " PROMOT  -0.15   0.06" , vmag:   4.35  , hmag:   1.21  , irastwelvemu:    12.33  , qual:   3  , ftwelve:    0.00  , ones:  0.0  , diam:   3.07  , errdiam:  0.11  , simrem: "Eclipsing binary      " , hvartype: "C"      , multflag: ""  , compid: ""      , theta:     0 , rho:   0.00 , compmagdiff: 0.00 , notes: ""  , hdnotes: "" , hdmoent: ""  , hdmcoment: "" },$ 
{ name: "HD139997"       , baynum: "kap Lib"       , hrnum: "HR5838"        , flamnum: "FL 43 Lib"        , saonum: "SAO159442"   , ppmnum: "PPM230614"   , varname: ""            , hipnum: "HIP76880"    , starname: ""                , alphah: 15.0 , alpham: 41.0 , alphas:  56.8 , plusmin:  -1 , deltag:  19.0 , deltam: 40.0 , deltas: 43.8  , orig: "iras"	   , spectype: "K5III"       , parallax:     8.16  , parerr:	 1.29  , promot: " PROMOT  -0.04  -0.11" , vmag:   4.77  , hmag:   1.03  , irastwelvemu:    14.53  , qual:   3  , ftwelve:    0.00  , ones:  0.0  , diam:   3.46  , errdiam:  0.38  , simrem: "Variable Star	   " , hvartype: "C"	  , multflag: ""  , compid: ""      , theta:	 0 , rho:   0.00 , compmagdiff: 0.00 , notes: ""  , hdnotes: "" , hdmoent: ""  , hdmcoment: "" },$ 
{ name: "HD140573"       , baynum: "alf Ser"       , hrnum: "HR5854"        , flamnum: "FL 24 Ser"        , saonum: "SAO121157"   , ppmnum: "PPM161854"   , varname: ""            , hipnum: "HIP77070"    , starname: "UNUKALHAI"       , alphah: 15.0 , alpham: 44.0 , alphas: 16.07 , plusmin:  +1 , deltag:   6.0 , deltam: 25.0 , deltas: 32.3  , orig: "iras"	   , spectype: "K2IIIb"      , parallax:    44.54  , parerr:	 0.71  , promot: " PROMOT   0.14   0.04" , vmag:   2.64  , hmag:   0.19  , irastwelvemu:    28.64  , qual:   3  , ftwelve:    0.00  , ones:  0.0  , diam:   4.61  , errdiam:  0.04  , simrem: "Eclipsing binary      " , hvartype: "M"      , multflag: "G"  , compid: ""      , theta:     0 , rho:   0.00 , compmagdiff: 0.00 , notes: ""  , hdnotes: "" , hdmoent: ""  , hdmcoment: "" },$ 
{ name: "HD140224"       , baynum: ""              , hrnum: ""              , flamnum: ""                 , saonum: ""            , ppmnum: "PPM772064"   , varname: ""            , hipnum: ""            , starname: ""                , alphah: 15.0 , alpham: 45.0 , alphas:  2.82 , plusmin:  -1 , deltag:  54.0 , deltam: 52.0 , deltas:  2.2  , orig: "msx"	   , spectype: "M3Ib/II"     , parallax:     0.00  , parerr:	 0.00  , promot: " PROMOT      0      0" , vmag:   9.46  , hmag:   2.47  , irastwelvemu:     0.00  , qual:   0  , ftwelve:    5.68  , ones:  3.6  , diam:   2.09  , errdiam:  0.07  , simrem: "Star	    " , hvartype: "C"	   , multflag: ""  , compid: ""      , theta:	  0 , rho:   0.00 , compmagdiff: 0.00 , notes: ""  , hdnotes: "" , hdmoent: ""  , hdmcoment: "" },$ 
{ name: "HD140708"       , baynum: ""              , hrnum: ""              , flamnum: ""                 , saonum: "SAO253302"   , ppmnum: "PPM361665"   , varname: ""            , hipnum: "HIP77463"    , starname: ""                , alphah: 15.0 , alpham: 48.0 , alphas: 17.25 , plusmin:  -1 , deltag:  60.0 , deltam: 28.0 , deltas: 32.7  , orig: "msx"	   , spectype: "M3/M4II"     , parallax:     0.00  , parerr:	 0.00  , promot: " PROMOT  -0.01  -0.01" , vmag:   8.58  , hmag:   2.35  , irastwelvemu:     0.00  , qual:   0  , ftwelve:    5.71  , ones:  4.5  , diam:   2.21  , errdiam:  0.07  , simrem: "Star	    " , hvartype: "C"	   , multflag: ""  , compid: ""      , theta:	  0 , rho:   0.00 , compmagdiff: 0.00 , notes: ""  , hdnotes: "" , hdmoent: ""  , hdmcoment: "" },$ 
{ name: "HD141054"       , baynum: ""              , hrnum: ""              , flamnum: ""                 , saonum: "SAO243008"   , ppmnum: "PPM344248"   , varname: ""            , hipnum: "HIP77480"    , starname: ""                , alphah: 15.0 , alpham: 49.0 , alphas: 13.68 , plusmin:  -1 , deltag:  52.0 , deltam: 12.0 , deltas: 57.0  , orig: "msx"	   , spectype: "M2/M3III"    , parallax:      1.6  , parerr:	 1.03  , promot: " PROMOT  -0.01   0.03" , vmag:   7.35  , hmag:    2.4  , irastwelvemu:     0.00  , qual:   0  , ftwelve:     5.1  , ones:  3.8  , diam:   2.12  , errdiam:  0.42  , simrem: "Variable Star	   " , hvartype: "U"	  , multflag: ""  , compid: ""      , theta:	 0 , rho:   0.00 , compmagdiff: 0.00 , notes: ""  , hdnotes: "" , hdmoent: ""  , hdmcoment: "" },$ 
{ name: "HD141992"       , baynum: "rho Ser"       , hrnum: "HR5899"        , flamnum: "FL 38 Ser"        , saonum: "SAO84037"    , ppmnum: "PPM104370"   , varname: ""            , hipnum: "HIP77661"    , starname: ""                , alphah: 15.0 , alpham: 51.0 , alphas: 15.91 , plusmin:  +1 , deltag:  20.0 , deltam: 58.0 , deltas: 40.5  , orig: "iras"	   , spectype: "K5III"       , parallax:     8.26  , parerr:	 0.71  , promot: " PROMOT  -0.05   0.02" , vmag:   4.75  , hmag:   1.24  , irastwelvemu:    12.57  , qual:   3  , ftwelve:    0.00  , ones:  0.0  , diam:   3.16  , errdiam:  0.04  , simrem: "Variable Star	   " , hvartype: "M"	  , multflag: ""  , compid: ""      , theta:	 0 , rho:   0.00 , compmagdiff: 0.00 , notes: ""  , hdnotes: "" , hdmoent: ""  , hdmcoment: "" },$ 
{ name: "HD142198"       , baynum: "the Lib"       , hrnum: "HR5908"        , flamnum: "FL 46 Lib"        , saonum: "SAO159563"   , ppmnum: "PPM230911"   , varname: ""            , hipnum: "HIP77853"    , starname: ""                , alphah: 15.0 , alpham: 53.0 , alphas: 49.54 , plusmin:  -1 , deltag:  16.0 , deltam: 43.0 , deltas: 45.5  , orig: "iras"	   , spectype: "K0III"       , parallax:    20.02  , parerr:	 0.88  , promot: " PROMOT    0.1   0.13" , vmag:   4.14  , hmag:   1.85  , irastwelvemu:     6.28  , qual:   3  , ftwelve:    0.00  , ones:  0.0  , diam:   1.95  , errdiam:  0.17  , simrem: "Star	    " , hvartype: "C"	   , multflag: ""  , compid: ""      , theta:	  0 , rho:   0.00 , compmagdiff: 0.00 , notes: ""  , hdnotes: "" , hdmoent: ""  , hdmcoment: "" },$ 
{ name: "HD142804"       , baynum: ""              , hrnum: ""              , flamnum: ""                 , saonum: "SAO159598"   , ppmnum: "PPM230994"   , varname: ""            , hipnum: "HIP78120"    , starname: ""                , alphah: 15.0 , alpham: 57.0 , alphas:  5.21 , plusmin:  -1 , deltag:  16.0 , deltam:  2.0 , deltas:  3.9  , orig: "iras"	   , spectype: "M1III"       , parallax:     3.96  , parerr:	 0.86  , promot: " PROMOT   0.01  -0.04" , vmag:   6.57  , hmag:   1.83  , irastwelvemu:     8.15  , qual:   3  , ftwelve:    0.00  , ones:  0.0  , diam:   2.77  , errdiam:  0.61  , simrem: "Variable Star	   " , hvartype: "U"	  , multflag: ""  , compid: ""      , theta:	 0 , rho:   0.00 , compmagdiff: 0.00 , notes: ""  , hdnotes: "" , hdmoent: ""  , hdmcoment: "" },$ 
{ name: "HD144386"       , baynum: ""              , hrnum: ""              , flamnum: ""                 , saonum: "SAO243355"   , ppmnum: "PPM344592"   , varname: "V*V365 Nor"  , hipnum: "HIP79055"    , starname: ""                , alphah: 16.0 , alpham:  8.0 , alphas: 10.84 , plusmin:  -1 , deltag:  53.0 , deltam:  4.0 , deltas: 44.2  , orig: "msx"	   , spectype: "K4II"	     , parallax:     -0.5  , parerr:	 0.82  , promot: " PROMOT      0      0" , vmag:   6.94  , hmag:   2.18  , irastwelvemu:     0.00  , qual:   0  , ftwelve:    6.56  , ones:  3.4  , diam:   2.38  , errdiam:  0.07  , simrem: "Variable Star of irregular type   " , hvartype: "U"	, multflag: ""  , compid: ""	  , theta:     0 , rho:   0.00 , compmagdiff: 0.00 , notes: ""  , hdnotes: "" , hdmoent: ""  , hdmcoment: "" },$ 
{ name: "HD145897"       , baynum: "chi Sco"       , hrnum: "HR6048"        , flamnum: "FL 17 Sco"        , saonum: "SAO159793"   , ppmnum: "PPM231387"   , varname: ""            , hipnum: "HIP79540"    , starname: ""                , alphah: 16.0 , alpham: 13.0 , alphas:  50.9 , plusmin:  -1 , deltag:  11.0 , deltam: 50.0 , deltas: 15.9  , orig: "iras"	   , spectype: "K3III"       , parallax:     7.43  , parerr:	 0.91  , promot: " PROMOT  -0.01  -0.01" , vmag:   5.25  , hmag:   2.17  , irastwelvemu:     5.21  , qual:   3  , ftwelve:    0.00  , ones:  0.0  , diam:   1.99  , errdiam:  0.46  , simrem: "Star	    " , hvartype: "C"	   , multflag: ""  , compid: ""      , theta:	  0 , rho:   0.00 , compmagdiff: 0.00 , notes: ""  , hdnotes: "" , hdmoent: ""  , hdmcoment: "" },$ 
{ name: "HD145544"       , baynum: "del TrA"       , hrnum: "HR6030"        , flamnum: ""                 , saonum: "SAO253474"   , ppmnum: "PPM361956"   , varname: ""            , hipnum: "HIP79664"    , starname: ""                , alphah: 16.0 , alpham: 15.0 , alphas: 26.27 , plusmin:  -1 , deltag:  63.0 , deltam: 41.0 , deltas:  8.4  , orig: "iras"	   , spectype: "G2Ib-II"     , parallax:     5.25  , parerr:	 0.61  , promot: " PROMOT   0.01  -0.01" , vmag:   3.86  , hmag:   1.56  , irastwelvemu:     9.15  , qual:   3  , ftwelve:    0.00  , ones:  0.0  , diam:   2.45  , errdiam:   0.2  , simrem: "Eclipsing binary      " , hvartype: "C"      , multflag: ""  , compid: ""      , theta:     0 , rho:   0.00 , compmagdiff: 0.00 , notes: ""  , hdnotes: "" , hdmoent: ""  , hdmcoment: "" },$ 
{ name: "HD146003"       , baynum: ""              , hrnum: "HR6055"        , flamnum: ""                 , saonum: "SAO243526"   , ppmnum: "PPM344765"   , varname: "V*V368 Nor"  , hipnum: "HIP79754"    , starname: ""                , alphah: 16.0 , alpham: 16.0 , alphas: 43.28 , plusmin:  -1 , deltag:  53.0 , deltam: 48.0 , deltas: 40.0  , orig: "msx"	   , spectype: "M2III"       , parallax:     4.05  , parerr:	 0.82  , promot: " PROMOT      0      0" , vmag:   5.48  , hmag:   0.84  , irastwelvemu:     0.00  , qual:   0  , ftwelve:   20.17  , ones:  3.1  , diam:   4.26  , errdiam:  0.29  , simrem: "Variable Star	   " , hvartype: "U"	  , multflag: ""  , compid: ""      , theta:	 0 , rho:   0.00 , compmagdiff: 0.00 , notes: "P" , hdnotes: "" , hdmoent: "Y" , hdmcoment: "" },$ 
{ name: "HD146791"       , baynum: "eps Oph"       , hrnum: "HR6075"        , flamnum: "FL 2 Oph"         , saonum: "SAO141086"   , ppmnum: "PPM199508"   , varname: ""            , hipnum: "HIP79882"    , starname: ""                , alphah: 16.0 , alpham: 18.0 , alphas: 19.29 , plusmin:  -1 , deltag:   4.0 , deltam: 41.0 , deltas: 33.0  , orig: "iras"	   , spectype: "G9.5IIIb"    , parallax:    30.34  , parerr:	 0.79  , promot: " PROMOT   0.08   0.04" , vmag:   3.24  , hmag:   1.09  , irastwelvemu:    13.36  , qual:   3  , ftwelve:    0.00  , ones:  0.0  , diam:   2.87  , errdiam:  0.06  , simrem: "Eclipsing binary      " , hvartype: "M"      , multflag: ""  , compid: ""      , theta:     0 , rho:   0.00 , compmagdiff: 0.00 , notes: ""  , hdnotes: "" , hdmoent: ""  , hdmcoment: "" },$ 
{ name: "HD146686"       , baynum: "gam02 Nor"     , hrnum: "HR6072"        , flamnum: ""                 , saonum: "SAO243643"   , ppmnum: "PPM344876"   , varname: ""            , hipnum: "HIP80000"    , starname: ""                , alphah: 16.0 , alpham: 19.0 , alphas: 50.42 , plusmin:  -1 , deltag:  50.0 , deltam:  9.0 , deltas: 19.8  , orig: "msx"	   , spectype: "G8III"       , parallax:    25.58  , parerr:	 0.86  , promot: " PROMOT  -0.16  -0.06" , vmag:   4.02  , hmag:   1.73  , irastwelvemu:     0.00  , qual:   0  , ftwelve:    6.29  , ones:  3.4  , diam:   2.27  , errdiam:  0.05  , simrem: "Eclipsing binary      " , hvartype: ""	   , multflag: ""  , compid: ""      , theta:	  0 , rho:   0.00 , compmagdiff: 0.00 , notes: ""  , hdnotes: "" , hdmoent: ""  , hdmcoment: "" },$ 
{ name: "HD147084"       , baynum: "omi Sco"       , hrnum: "HR6081"        , flamnum: "FL 19 Sco"        , saonum: "SAO184329"   , ppmnum: "PPM265428"   , varname: ""            , hipnum: "HIP80079"    , starname: ""                , alphah: 16.0 , alpham: 20.0 , alphas: 38.18 , plusmin:  -1 , deltag:  24.0 , deltam: 10.0 , deltas:  9.6  , orig: "iras"	   , spectype: "A4II/III"    , parallax:     2.77  , parerr:	 0.76  , promot: " PROMOT      0  -0.03" , vmag:   4.55  , hmag:   1.79  , irastwelvemu:     7.82  , qual:   3  , ftwelve:    0.00  , ones:  0.0  , diam:    2.2  , errdiam:  1.83  , simrem: "Variable Star	   " , hvartype: "M"	  , multflag: ""  , compid: ""      , theta:	 0 , rho:   0.00 , compmagdiff: 0.00 , notes: ""  , hdnotes: "" , hdmoent: ""  , hdmcoment: "" },$ 
{ name: "HD147749"       , baynum: "nu.01 CrB"     , hrnum: "HR6107"        , flamnum: "FL 20 CrB"        , saonum: "SAO65257"    , ppmnum: "PPM79256"    , varname: ""            , hipnum: "HIP80197"    , starname: ""                , alphah: 16.0 , alpham: 22.0 , alphas: 21.43 , plusmin:  +1 , deltag:  33.0 , deltam: 47.0 , deltas: 56.6  , orig: "iras"	   , spectype: "M2III"       , parallax:     5.87  , parerr:	 0.58  , promot: " PROMOT      0  -0.04" , vmag:   5.23  , hmag:   0.00  , irastwelvemu:    14.93  , qual:   3  , ftwelve:    0.00  , ones:  0.0  , diam:   3.39  , errdiam:  0.07  , simrem: "Variable Star	   " , hvartype: "U"	  , multflag: ""  , compid: ""      , theta:	 0 , rho:   0.00 , compmagdiff: 0.00 , notes: ""  , hdnotes: "" , hdmoent: ""  , hdmcoment: "" },$ 
{ name: "HD147767"       , baynum: "nu.02 CrB"     , hrnum: "HR6108"        , flamnum: "FL 21 CrB"        , saonum: "SAO65259"    , ppmnum: "PPM79260"    , varname: ""            , hipnum: "HIP80214"    , starname: ""                , alphah: 16.0 , alpham: 22.0 , alphas: 29.22 , plusmin:  +1 , deltag:  33.0 , deltam: 42.0 , deltas: 12.5  , orig: "iras"	   , spectype: "K5III"       , parallax:     5.98  , parerr:	 0.58  , promot: " PROMOT  -0.01   0.06" , vmag:   5.41  , hmag:   0.00  , irastwelvemu:     6.69  , qual:   3  , ftwelve:    0.00  , ones:  0.0  , diam:   2.36  , errdiam:  0.07  , simrem: "Eclipsing binary      " , hvartype: "M"      , multflag: ""  , compid: ""      , theta:     0 , rho:   0.00 , compmagdiff: 0.00 , notes: "G" , hdnotes: "" , hdmoent: ""  , hdmcoment: "" },$ 
{ name: "HD147929"       , baynum: ""              , hrnum: ""              , flamnum: ""                 , saonum: "SAO141157"   , ppmnum: "PPM179809"   , varname: ""            , hipnum: "HIP80398"    , starname: ""                , alphah: 16.0 , alpham: 24.0 , alphas: 52.06 , plusmin:  -1 , deltag:   2.0 , deltam: 28.0 , deltas: 16.6  , orig: "iras"	   , spectype: "M..."	     , parallax:     0.00  , parerr:	 0.00  , promot: " PROMOT      0  -0.02" , vmag:   8.12  , hmag:    2.4  , irastwelvemu:     5.17  , qual:   3  , ftwelve:    0.00  , ones:  0.0  , diam:   2.00  , errdiam:  0.07  , simrem: "Star	    " , hvartype: "C"	   , multflag: ""  , compid: ""      , theta:	  0 , rho:   0.00 , compmagdiff: 0.00 , notes: ""  , hdnotes: "" , hdmoent: ""  , hdmcoment: "" },$ 
{ name: "HD148390"       , baynum: ""              , hrnum: ""              , flamnum: ""                 , saonum: "SAO121614"   , ppmnum: "PPM162664"   , varname: ""            , hipnum: "HIP80610"    , starname: ""                , alphah: 16.0 , alpham: 27.0 , alphas: 32.27 , plusmin:  +1 , deltag:   2.0 , deltam: 52.0 , deltas: 14.3  , orig: "iras"	   , spectype: "K5"	     , parallax:     5.96  , parerr:	 0.86  , promot: " PROMOT   0.01  -0.02" , vmag:    6.4  , hmag:    2.2  , irastwelvemu:     5.38  , qual:   3  , ftwelve:    0.00  , ones:  0.0  , diam:   2.06  , errdiam:  0.22  , simrem: "Star	    " , hvartype: "U"	   , multflag: ""  , compid: ""      , theta:	  0 , rho:   0.00 , compmagdiff: 0.00 , notes: ""  , hdnotes: "" , hdmoent: ""  , hdmcoment: "" },$ 
{ name: "HD148513"       , baynum: ""              , hrnum: "HR6136"        , flamnum: ""                 , saonum: "SAO121623"   , ppmnum: "PPM162683"   , varname: ""            , hipnum: "HIP80693"    , starname: ""                , alphah: 16.0 , alpham: 28.0 , alphas: 33.98 , plusmin:  +1 , deltag:   0.0 , deltam: 39.0 , deltas: 54.0  , orig: "iras"	   , spectype: "K4III"       , parallax:     7.72  , parerr:	 0.87  , promot: " PROMOT  -0.01  -0.07" , vmag:    5.4  , hmag:   2.19  , irastwelvemu:     5.02  , qual:   3  , ftwelve:    0.00  , ones:  0.0  , diam:   2.02  , errdiam:  0.19  , simrem: "Star	    " , hvartype: ""	  , multflag: ""  , compid: ""      , theta:	 0 , rho:   0.00 , compmagdiff: 0.00 , notes: ""  , hdnotes: "" , hdmoent: ""  , hdmcoment: "" },$ 
{ name: "HD148478"       , baynum: "alf Sco"       , hrnum: "HR6134"        , flamnum: "FL 21 Sco"        , saonum: "SAO184415"   , ppmnum: "PPM265579"   , varname: "V* alf Sco"  , hipnum: "HIP80763"    , starname: "ANTARES"         , alphah: 16.0 , alpham: 29.0 , alphas: 24.46 , plusmin:  -1 , deltag:  26.0 , deltam: 25.0 , deltas: 55.2  , orig: "iras"	   , spectype: "M1.5Ib"      , parallax:      5.4  , parerr:	 1.68  , promot: " PROMOT  -0.01  -0.02" , vmag:   1.09  , hmag:  -3.66  , irastwelvemu:  2205.52  , qual:   3  , ftwelve:    0.00  , ones:  0.0  , diam:  25.92  , errdiam:  1.45  , simrem: "Variable of BY Dra type     " , hvartype: "U"	  , multflag: "X"  , compid: ""      , theta:	  0 , rho:   0.00 , compmagdiff: 0.00 , notes: ""  , hdnotes: "" , hdmoent: ""  , hdmcoment: "" },$ 
{ name: "HD148856"       , baynum: "bet Her"       , hrnum: "HR6148"        , flamnum: "FL 27 Her"        , saonum: "SAO84411"    , ppmnum: "PPM104935"   , varname: ""            , hipnum: "HIP80816"    , starname: ""                , alphah: 16.0 , alpham: 30.0 , alphas:  13.2 , plusmin:  +1 , deltag:  21.0 , deltam: 29.0 , deltas: 22.6  , orig: "iras"	   , spectype: "G7IIIa"      , parallax:    22.07  , parerr:	  1.0  , promot: " PROMOT   -0.1  -0.02" , vmag:   2.79  , hmag:   0.76  , irastwelvemu:    17.07  , qual:   3  , ftwelve:    0.00  , ones:  0.0  , diam:   3.31  , errdiam:  0.04  , simrem: "Spectroscopic binary	  " , hvartype: "M"	 , multflag: "O"  , compid: ""      , theta:	 0 , rho:   0.00 , compmagdiff: 0.00 , notes: "D" , hdnotes: "The results announced by X.P.Pan, M.Shao, M.M.Colavita, B.E.Hines, J.T.Armstrong, C.S.Denisson, M.Vivekanand, D.Mozurkewich, R.S.Simon, K.J.Johnston, BAAS, 22, 1335, 1990, do not agree with the results presented here." , hdmoent: ""  , hdmcoment: "Y" },$
{ name: "HD149401"       , baynum: ""              , hrnum: ""              , flamnum: ""                 , saonum: "SAO243994"   , ppmnum: "PPM345230"   , varname: "V*V840 Ara"  , hipnum: "HIP81376"    , starname: ""                , alphah: 16.0 , alpham: 37.0 , alphas:   8.5 , plusmin:  -1 , deltag:  52.0 , deltam: 22.0 , deltas: 54.1  , orig: "iras"	   , spectype: "M2/M3III"    , parallax:     4.93  , parerr:	 0.94  , promot: " PROMOT  -0.01  -0.03" , vmag:    6.9  , hmag:   2.09  , irastwelvemu:     6.51  , qual:   3  , ftwelve:    6.29  , ones:  3.8  , diam:   2.41  , errdiam:  0.24  , simrem: "Variable Star	   " , hvartype: "U"	  , multflag: ""  , compid: ""      , theta:	 0 , rho:   0.00 , compmagdiff: 0.00 , notes: ""  , hdnotes: "" , hdmoent: ""  , hdmcoment: "" },$ 
{ name: "HD150052"       , baynum: ""              , hrnum: ""              , flamnum: ""                 , saonum: "SAO141291"   , ppmnum: "PPM199862"   , varname: ""            , hipnum: "HIP81499"    , starname: ""                , alphah: 16.0 , alpham: 38.0 , alphas: 47.73 , plusmin:  -1 , deltag:   8.0 , deltam: 37.0 , deltas:  7.0  , orig: "iras"	   , spectype: "K5"	     , parallax:      3.7  , parerr:	 0.96  , promot: " PROMOT   0.01  -0.01" , vmag:   6.48  , hmag:   2.11  , irastwelvemu:     6.16  , qual:   3  , ftwelve:    0.00  , ones:  0.0  , diam:   2.36  , errdiam:  0.65  , simrem: "Variable Star	   " , hvartype: ""	 , multflag: ""  , compid: ""	   , theta:	0 , rho:   0.00 , compmagdiff: 0.00 , notes: ""  , hdnotes: "" , hdmoent: ""  , hdmcoment: "" },$ 
{ name: "HD150680"       , baynum: "zet Her"       , hrnum: "HR6212"        , flamnum: "FL 40 Her"        , saonum: "SAO65485"    , ppmnum: "PPM79555"    , varname: ""            , hipnum: "HIP81693"    , starname: ""                , alphah: 16.0 , alpham: 41.0 , alphas: 17.16 , plusmin:  +1 , deltag:  31.0 , deltam: 36.0 , deltas:  9.8  , orig: "iras"	   , spectype: "G0IV"	     , parallax:    92.64  , parerr:	  0.6  , promot: " PROMOT  -0.55   0.39" , vmag:   2.81  , hmag:   0.00  , irastwelvemu:     9.29  , qual:   3  , ftwelve:    0.00  , ones:  0.0  , diam:   2.21  , errdiam:  0.01  , simrem: "Spectroscopic binary	  " , hvartype: "D"	 , multflag: "C"  , compid: "AB"      , theta:   78  , rho:  1.55    , compmagdiff:  2.68  , notes: ""  , hdnotes: "" , hdmoent: "Y" , hdmcoment: "" },$ 
{ name: "HD150214"       , baynum: ""              , hrnum: ""              , flamnum: ""                 , saonum: "SAO227059"   , ppmnum: "PPM322037"   , varname: "V*V1064 Sco" , hipnum: "HIP81712"    , starname: ""                , alphah: 16.0 , alpham: 41.0 , alphas: 24.78 , plusmin:  -1 , deltag:  42.0 , deltam:  3.0 , deltas: 37.8  , orig: "msx"	   , spectype: "K4/K5III"    , parallax:     2.21  , parerr:	 1.08  , promot: " PROMOT      0      0" , vmag:   7.79  , hmag:   2.06  , irastwelvemu:     0.00  , qual:   0  , ftwelve:     7.9  , ones:  3.5  , diam:   2.64  , errdiam:  0.61  , simrem: "Variable Star	   " , hvartype: "U"	  , multflag: ""  , compid: ""      , theta:	 0 , rho:   0.00 , compmagdiff: 0.00 , notes: ""  , hdnotes: "" , hdmoent: ""  , hdmcoment: "" },$ 
{ name: "HD321898"       , baynum: ""              , hrnum: ""              , flamnum: ""                 , saonum: "SAO207953"   , ppmnum: "PPM295397"   , varname: ""            , hipnum: "HIP81842"    , starname: ""                , alphah: 16.0 , alpham: 42.0 , alphas:  58.2 , plusmin:  -1 , deltag:  38.0 , deltam: 42.0 , deltas: 40.5  , orig: "msx"	   , spectype: "M3"	     , parallax:     0.00  , parerr:	 0.00  , promot: " PROMOT   0.01  -0.01" , vmag:    9.6  , hmag:   2.02  , irastwelvemu:     0.00  , qual:   0  , ftwelve:    8.38  , ones:  3.6  , diam:   2.56  , errdiam:  0.07  , simrem: "Star	    " , hvartype: "U"	   , multflag: ""  , compid: ""      , theta:	  0 , rho:   0.00 , compmagdiff: 0.00 , notes: ""  , hdnotes: "" , hdmoent: ""  , hdmcoment: "" },$ 
{ name: "HD149324"       , baynum: "bet Aps"       , hrnum: "HR6163"        , flamnum: ""                 , saonum: "SAO257424"   , ppmnum: "PPM373182"   , varname: ""            , hipnum: "HIP81852"    , starname: ""                , alphah: 16.0 , alpham: 43.0 , alphas:  4.66 , plusmin:  -1 , deltag:  77.0 , deltam: 31.0 , deltas:  2.8  , orig: "iras"	   , spectype: "K0III"       , parallax:    20.69  , parerr:	 0.51  , promot: " PROMOT  -0.28  -0.36" , vmag:   4.24  , hmag:   1.88  , irastwelvemu:     5.93  , qual:   3  , ftwelve:    0.00  , ones:  0.0  , diam:   2.04  , errdiam:  0.06  , simrem: "High proper-motion Star     " , hvartype: ""	 , multflag: ""  , compid: ""	   , theta:	0 , rho:   0.00 , compmagdiff: 0.00 , notes: ""  , hdnotes: "" , hdmoent: ""  , hdmcoment: "" },$ 
{ name: "HD151203"       , baynum: ""              , hrnum: "HR6227"        , flamnum: ""                 , saonum: "SAO102365"   , ppmnum: "PPM132638"   , varname: ""            , hipnum: "HIP82028"    , starname: ""                , alphah: 16.0 , alpham: 45.0 , alphas: 22.52 , plusmin:  +1 , deltag:  15.0 , deltam: 44.0 , deltas: 43.0  , orig: "iras"	   , spectype: "M3III"       , parallax:     6.31  , parerr:	 0.81  , promot: " PROMOT   0.03  -0.05" , vmag:   5.64  , hmag:   0.00  , irastwelvemu:    16.87  , qual:   3  , ftwelve:    0.00  , ones:  0.0  , diam:   3.99  , errdiam:  0.05  , simrem: "Variable Star	   " , hvartype: "U"	  , multflag: ""  , compid: ""      , theta:	 0 , rho:   0.00 , compmagdiff: 0.00 , notes: ""  , hdnotes: "" , hdmoent: ""  , hdmcoment: "" },$ 
{ name: "HD151011"       , baynum: ""              , hrnum: ""              , flamnum: ""                 , saonum: "SAO160080"   , ppmnum: "PPM232122"   , varname: ""            , hipnum: "HIP82038"    , starname: ""                , alphah: 16.0 , alpham: 45.0 , alphas: 30.18 , plusmin:  -1 , deltag:  19.0 , deltam:  8.0 , deltas: 12.9  , orig: "iras"	   , spectype: "K5II"	     , parallax:      4.3  , parerr:	 1.07  , promot: " PROMOT   0.02  -0.01" , vmag:   6.67  , hmag:   1.85  , irastwelvemu:     8.57  , qual:   3  , ftwelve:    0.00  , ones:  0.0  , diam:   2.77  , errdiam:  0.62  , simrem: "Variable Star	   " , hvartype: "U"	  , multflag: ""  , compid: ""      , theta:	 0 , rho:   0.00 , compmagdiff: 0.00 , notes: ""  , hdnotes: "" , hdmoent: ""  , hdmcoment: "" },$ 
{ name: "HD151217"       , baynum: "i Her"         , hrnum: "HR6228"        , flamnum: "FL 43 Her"        , saonum: "SAO121843"   , ppmnum: "PPM163086"   , varname: ""            , hipnum: "HIP82073"    , starname: ""                , alphah: 16.0 , alpham: 45.0 , alphas: 49.89 , plusmin:  +1 , deltag:   8.0 , deltam: 34.0 , deltas: 57.4  , orig: "iras"	   , spectype: "K5III"       , parallax:      9.3  , parerr:	 0.84  , promot: " PROMOT      0   0.01" , vmag:   5.16  , hmag:    1.6  , irastwelvemu:     8.36  , qual:   3  , ftwelve:    0.00  , ones:  0.0  , diam:   2.73  , errdiam:  0.05  , simrem: "Variable Star	   " , hvartype: "M"	  , multflag: ""  , compid: ""      , theta:	 0 , rho:   0.00 , compmagdiff: 0.00 , notes: ""  , hdnotes: "" , hdmoent: ""  , hdmcoment: "" },$ 
{ name: "HD151051"       , baynum: ""              , hrnum: ""              , flamnum: ""                 , saonum: "SAO227197"   , ppmnum: "PPM322168"   , varname: ""            , hipnum: "HIP82121"    , starname: ""                , alphah: 16.0 , alpham: 46.0 , alphas: 50.31 , plusmin:  -1 , deltag:  41.0 , deltam: 28.0 , deltas: 51.9  , orig: "iras"	   , spectype: "M2/M3II"     , parallax:     0.00  , parerr:	 0.00  , promot: " PROMOT      0      0" , vmag:   7.41  , hmag:   2.28  , irastwelvemu:     5.45  , qual:   3  , ftwelve:    5.34  , ones:  3.9  , diam:   2.26  , errdiam:  0.07  , simrem: "Star	    " , hvartype: "C"	   , multflag: ""  , compid: ""      , theta:	  0 , rho:   0.00 , compmagdiff: 0.00 , notes: ""  , hdnotes: "" , hdmoent: ""  , hdmcoment: "" },$ 
{ name: "HD150798"       , baynum: "alf TrA"       , hrnum: "HR6217"        , flamnum: ""                 , saonum: "SAO253700"   , ppmnum: "PPM362330"   , varname: ""            , hipnum: "HIP82273"    , starname: ""                , alphah: 16.0 , alpham: 48.0 , alphas: 39.89 , plusmin:  -1 , deltag:  69.0 , deltam:  1.0 , deltas: 39.8  , orig: "iras"	   , spectype: "K2II-III"    , parallax:     7.85  , parerr:	 0.63  , promot: " PROMOT   0.03  -0.03" , vmag:   1.92  , hmag:  -1.08  , irastwelvemu:   100.32  , qual:   3  , ftwelve:    0.00  , ones:  0.0  , diam:   8.76  , errdiam:  0.12  , simrem: "Star	    " , hvartype: "M"	   , multflag: ""  , compid: ""      , theta:	  0 , rho:   0.00 , compmagdiff: 0.00 , notes: ""  , hdnotes: "" , hdmoent: ""  , hdmcoment: "" },$ 
{ name: "HD151249"       , baynum: "eta Ara"       , hrnum: "HR6229"        , flamnum: ""                 , saonum: "SAO244168"   , ppmnum: "PPM345419"   , varname: ""            , hipnum: "HIP82363"    , starname: ""                , alphah: 16.0 , alpham: 49.0 , alphas: 47.16 , plusmin:  -1 , deltag:  59.0 , deltam:  2.0 , deltas: 29.0  , orig: "iras"	   , spectype: "K5III"       , parallax:    10.41  , parerr:	 0.69  , promot: " PROMOT   0.04  -0.03" , vmag:   3.78  , hmag:   0.14  , irastwelvemu:    35.99  , qual:   3  , ftwelve:    0.00  , ones:  0.0  , diam:   5.34  , errdiam:  0.11  , simrem: "Eclipsing binary      " , hvartype: "M"      , multflag: ""  , compid: ""      , theta:     0 , rho:   0.00 , compmagdiff: 0.00 , notes: ""  , hdnotes: "" , hdmoent: ""  , hdmcoment: "" },$ 
{ name: "HD152173"       , baynum: ""              , hrnum: "HR6258"        , flamnum: "FL 50 Her"        , saonum: "SAO84641"    , ppmnum: "PPM105270"   , varname: ""            , hipnum: "HIP82422"    , starname: ""                , alphah: 16.0 , alpham: 50.0 , alphas: 38.96 , plusmin:  +1 , deltag:  29.0 , deltam: 48.0 , deltas: 23.5  , orig: "iras"	   , spectype: "M1III"       , parallax:     3.53  , parerr:	 0.67  , promot: " PROMOT  -0.01      0" , vmag:   5.74  , hmag:   0.00  , irastwelvemu:     6.54  , qual:   3  , ftwelve:    0.00  , ones:  0.0  , diam:    2.1  , errdiam:  0.07  , simrem: "Variable Star	   " , hvartype: "U"	  , multflag: ""  , compid: ""      , theta:	 0 , rho:   0.00 , compmagdiff: 0.00 , notes: ""  , hdnotes: "" , hdmoent: ""  , hdmcoment: "" },$ 
{ name: "HD152161"       , baynum: ""              , hrnum: "HR6257"        , flamnum: ""                 , saonum: "SAO227359"   , ppmnum: "PPM322331"   , varname: "V*V1068 Sco" , hipnum: "HIP82650"    , starname: ""                , alphah: 16.0 , alpham: 53.0 , alphas: 42.42 , plusmin:  -1 , deltag:  43.0 , deltam:  3.0 , deltas:  3.5  , orig: "iras"	   , spectype: "M3II-III"    , parallax:     2.81  , parerr:	 0.83  , promot: " PROMOT  -0.02  -0.03" , vmag:   6.06  , hmag:   0.31  , irastwelvemu:     35.2  , qual:   3  , ftwelve:   37.67  , ones:  3.0  , diam:   4.83  , errdiam:   0.5  , simrem: "Variable Star	   " , hvartype: "U"	  , multflag: ""  , compid: ""      , theta:	 0 , rho:   0.00 , compmagdiff: 0.00 , notes: ""  , hdnotes: "" , hdmoent: ""  , hdmcoment: "" },$ 
{ name: "HD152334"       , baynum: "zet02 Sco"     , hrnum: "HR6271"        , flamnum: ""                 , saonum: "SAO227402"   , ppmnum: "PPM322371"   , varname: ""            , hipnum: "HIP82729"    , starname: ""                , alphah: 16.0 , alpham: 54.0 , alphas: 35.01 , plusmin:  -1 , deltag:  42.0 , deltam: 21.0 , deltas: 40.7  , orig: "iras"	   , spectype: "K4III"       , parallax:    21.67  , parerr:	 0.85  , promot: " PROMOT  -0.13  -0.24" , vmag:   3.62  , hmag:   0.64  , irastwelvemu:    20.79  , qual:   3  , ftwelve:   21.01  , ones:  3.0  , diam:   3.99  , errdiam:  0.07  , simrem: "Variable Star	   " , hvartype: ""	 , multflag: ""  , compid: ""	   , theta:	0 , rho:   0.00 , compmagdiff: 0.00 , notes: ""  , hdnotes: "" , hdmoent: ""  , hdmcoment: "" },$ 
{ name: "HD152820"       , baynum: ""              , hrnum: "HR6288"        , flamnum: "FL 27 Sco"        , saonum: "SAO208232"   , ppmnum: "PPM295706"   , varname: ""            , hipnum: "HIP82960"    , starname: ""                , alphah: 16.0 , alpham: 57.0 , alphas: 11.18 , plusmin:  -1 , deltag:  33.0 , deltam: 15.0 , deltas: 34.2  , orig: "iras"	   , spectype: "K5III"       , parallax:      4.5  , parerr:	 0.89  , promot: " PROMOT  -0.01  -0.01" , vmag:   5.49  , hmag:   1.76  , irastwelvemu:     7.59  , qual:   3  , ftwelve:    0.00  , ones:  0.0  , diam:   2.57  , errdiam:  0.34  , simrem: "Star	    " , hvartype: "M"	   , multflag: ""  , compid: ""      , theta:	  0 , rho:   0.00 , compmagdiff: 0.00 , notes: ""  , hdnotes: "" , hdmoent: ""  , hdmcoment: "" },$ 
{ name: "HD153210"       , baynum: "kap Oph"       , hrnum: "HR6299"        , flamnum: "FL 27 Oph"        , saonum: "SAO121962"   , ppmnum: "PPM163313"   , varname: "V* kap Oph"  , hipnum: "HIP83000"    , starname: ""                , alphah: 16.0 , alpham: 57.0 , alphas:  40.1 , plusmin:  +1 , deltag:   9.0 , deltam: 22.0 , deltas: 30.1  , orig: "iras"	   , spectype: "K2III"       , parallax:    37.99  , parerr:	 0.75  , promot: " PROMOT  -0.29  -0.01" , vmag:    3.2  , hmag:   0.00  , irastwelvemu:    17.23  , qual:   3  , ftwelve:    0.00  , ones:  0.0  , diam:   3.48  , errdiam:  0.08  , simrem: "Variable Star	   " , hvartype: ""	 , multflag: ""  , compid: ""	   , theta:	0 , rho:   0.00 , compmagdiff: 0.00 , notes: ""  , hdnotes: "" , hdmoent: ""  , hdmcoment: "" },$ 
{ name: "HD152885"       , baynum: ""              , hrnum: ""              , flamnum: ""                 , saonum: "SAO208237"   , ppmnum: "PPM295714"   , varname: "V*V1071 Sco" , hipnum: "HIP83014"    , starname: ""                , alphah: 16.0 , alpham: 57.0 , alphas: 50.22 , plusmin:  -1 , deltag:  39.0 , deltam:  6.0 , deltas: 56.6  , orig: "msx"	   , spectype: "M1III"       , parallax:     2.82  , parerr:	 0.87  , promot: " PROMOT  -0.02      0" , vmag:   6.61  , hmag:   1.75  , irastwelvemu:     0.00  , qual:   0  , ftwelve:    9.21  , ones:  3.5  , diam:   2.87  , errdiam:   0.5  , simrem: "Variable of BY Dra type     " , hvartype: "U"	  , multflag: ""  , compid: ""      , theta:	 0 , rho:   0.00 , compmagdiff: 0.00 , notes: "P" , hdnotes: "" , hdmoent: ""  , hdmcoment: "" },$ 
{ name: "HD152786"       , baynum: "zet Ara"       , hrnum: "HR6285"        , flamnum: ""                 , saonum: "SAO244315"   , ppmnum: "PPM345563"   , varname: ""            , hipnum: "HIP83081"    , starname: ""                , alphah: 16.0 , alpham: 58.0 , alphas: 37.21 , plusmin:  -1 , deltag:  55.0 , deltam: 59.0 , deltas: 24.5  , orig: "iras"	   , spectype: "K3III"       , parallax:     5.68  , parerr:	 0.91  , promot: " PROMOT  -0.01  -0.04" , vmag:   3.13  , hmag:   0.00  , irastwelvemu:    56.88  , qual:   3  , ftwelve:    0.00  , ones:  0.0  , diam:   7.21  , errdiam:  0.21  , simrem: "Star	    " , hvartype: "M"	   , multflag: ""  , compid: ""      , theta:	  0 , rho:   0.00 , compmagdiff: 0.00 , notes: ""  , hdnotes: "" , hdmoent: ""  , hdmcoment: "" },$ 
{ name: "HD152980"       , baynum: "eps01 Ara"     , hrnum: "HR6295"        , flamnum: ""                 , saonum: "SAO244331"   , ppmnum: "PPM345574"   , varname: ""            , hipnum: "HIP83153"    , starname: ""                , alphah: 16.0 , alpham: 59.0 , alphas: 35.05 , plusmin:  -1 , deltag:  53.0 , deltam:  9.0 , deltas: 37.6  , orig: "iras"	   , spectype: "K4III"       , parallax:    10.72  , parerr:	 0.79  , promot: " PROMOT   0.01   0.02" , vmag:   4.07  , hmag:    0.9  , irastwelvemu:    15.45  , qual:   3  , ftwelve:    0.00  , ones:  0.0  , diam:   3.64  , errdiam:  0.12  , simrem: "Star	    " , hvartype: ""	  , multflag: ""  , compid: ""      , theta:	 0 , rho:   0.00 , compmagdiff: 0.00 , notes: ""  , hdnotes: "" , hdmoent: ""  , hdmcoment: "" },$ 
{ name: "HD153162"       , baynum: ""              , hrnum: ""              , flamnum: ""                 , saonum: "SAO244351"   , ppmnum: "PPM345602"   , varname: "V*V849 Ara"  , hipnum: "HIP83250"    , starname: ""                , alphah: 17.0 , alpham:  0.0 , alphas:  55.7 , plusmin:  -1 , deltag:  56.0 , deltam: 28.0 , deltas: 48.0  , orig: "iras"	   , spectype: "M3/M4Ib"     , parallax:     0.22  , parerr:	 1.21  , promot: " PROMOT  -0.01  -0.03" , vmag:   8.31  , hmag:    2.5  , irastwelvemu:     5.22  , qual:   3  , ftwelve:    0.00  , ones:  0.0  , diam:   2.09  , errdiam:  0.44  , simrem: "Variable Star	   " , hvartype: "U"	  , multflag: ""  , compid: ""      , theta:	 0 , rho:   0.00 , compmagdiff: 0.00 , notes: ""  , hdnotes: "" , hdmoent: "Y" , hdmcoment: "" },$ 
{ name: "HD326926"       , baynum: ""              , hrnum: ""              , flamnum: ""                 , saonum: "SAO227681"   , ppmnum: "PPM322663"   , varname: ""            , hipnum: "HIP83992"    , starname: ""                , alphah: 17.0 , alpham:  9.0 , alphas: 42.26 , plusmin:  -1 , deltag:  40.0 , deltam: 22.0 , deltas: 52.4  , orig: "msx"	   , spectype: "K6"	     , parallax:     0.00  , parerr:	 0.00  , promot: " PROMOT   0.01      0" , vmag:    8.6  , hmag:   1.62  , irastwelvemu:     0.00  , qual:   0  , ftwelve:    14.9  , ones:  3.1  , diam:   2.91  , errdiam:  0.07  , simrem: "Star	    " , hvartype: ""	  , multflag: ""  , compid: ""      , theta:	 0 , rho:   0.00 , compmagdiff: 0.00 , notes: ""  , hdnotes: "" , hdmoent: ""  , hdmcoment: "" },$ 
{ name: "HD155066"       , baynum: ""              , hrnum: ""              , flamnum: ""                 , saonum: "SAO244511"   , ppmnum: "PPM345768"   , varname: "V*V855 Ara"  , hipnum: "HIP84148"    , starname: ""                , alphah: 17.0 , alpham: 12.0 , alphas: 14.63 , plusmin:  -1 , deltag:  53.0 , deltam: 22.0 , deltas: 34.0  , orig: "iras"	   , spectype: "M4III"       , parallax:     3.35  , parerr:	  1.1  , promot: " PROMOT      0      0" , vmag:   7.38  , hmag:   2.07  , irastwelvemu:     6.82  , qual:   3  , ftwelve:    0.00  , ones:  0.0  , diam:   2.48  , errdiam:  0.32  , simrem: "Variable Star of irregular type   " , hvartype: "U"	, multflag: ""  , compid: ""	  , theta:     0 , rho:   0.00 , compmagdiff: 0.00 , notes: ""  , hdnotes: "" , hdmoent: ""  , hdmcoment: "" },$ 
{ name: "HD155644"       , baynum: ""              , hrnum: "HR6393"        , flamnum: "FL 37 Oph"        , saonum: "SAO102646"   , ppmnum: "PPM133114"   , varname: ""            , hipnum: "HIP84177"    , starname: ""                , alphah: 17.0 , alpham: 12.0 , alphas: 27.81 , plusmin:  +1 , deltag:  10.0 , deltam: 35.0 , deltas:  6.6  , orig: "iras"	   , spectype: "M2III"       , parallax:      4.2  , parerr:	 0.79  , promot: " PROMOT   0.01  -0.03" , vmag:   5.35  , hmag:   1.36  , irastwelvemu:    12.63  , qual:   3  , ftwelve:    0.00  , ones:  0.0  , diam:   2.73  , errdiam:  1.31  , simrem: "Eclipsing binary      " , hvartype: "U"      , multflag: ""  , compid: ""      , theta:     0 , rho:   0.00 , compmagdiff: 0.00 , notes: ""  , hdnotes: "" , hdmoent: ""  , hdmcoment: "" },$ 
{ name: "HD156681"       , baynum: "e Oph"         , hrnum: "HR6433"        , flamnum: ""                 , saonum: "SAO102725"   , ppmnum: "PPM133229"   , varname: ""            , hipnum: "HIP84671"    , starname: ""                , alphah: 17.0 , alpham: 18.0 , alphas: 36.99 , plusmin:  +1 , deltag:  10.0 , deltam: 51.0 , deltas: 52.1  , orig: "iras"	   , spectype: "K4Iab"       , parallax:     4.72  , parerr:	  0.8  , promot: " PROMOT      0  -0.09" , vmag:   5.04  , hmag:   1.56  , irastwelvemu:     9.17  , qual:   3  , ftwelve:    0.00  , ones:  0.0  , diam:   2.71  , errdiam:  0.44  , simrem: "Variable Star	   " , hvartype: ""	 , multflag: ""  , compid: ""	   , theta:	0 , rho:   0.00 , compmagdiff: 0.00 , notes: ""  , hdnotes: "" , hdmoent: ""  , hdmcoment: "" },$ 
{ name: "HD156705"       , baynum: ""              , hrnum: ""              , flamnum: ""                 , saonum: "SAO227851"   , ppmnum: "PPM322845"   , varname: ""            , hipnum: ""            , starname: ""                , alphah: 17.0 , alpham: 21.0 , alphas:  2.23 , plusmin:  -1 , deltag:  41.0 , deltam: 52.0 , deltas: 50.7  , orig: "msx"	   , spectype: "M4III"       , parallax:     0.00  , parerr:	 0.00  , promot: " PROMOT  -0.01  -0.07" , vmag:   8.16  , hmag:   2.03  , irastwelvemu:     0.00  , qual:   0  , ftwelve:    7.24  , ones:  3.3  , diam:   2.56  , errdiam:  0.07  , simrem: "Star	    " , hvartype: ""	  , multflag: ""  , compid: ""      , theta:	 0 , rho:   0.00 , compmagdiff: 0.00 , notes: ""  , hdnotes: "" , hdmoent: ""  , hdmcoment: "" },$ 
{ name: "HD156277"       , baynum: "zet Aps"       , hrnum: "HR6417"        , flamnum: ""                 , saonum: "SAO253882"   , ppmnum: "PPM362645"   , varname: ""            , hipnum: "HIP84969"    , starname: ""                , alphah: 17.0 , alpham: 21.0 , alphas: 59.48 , plusmin:  -1 , deltag:  67.0 , deltam: 46.0 , deltas: 14.4  , orig: "iras"	   , spectype: "K2III"       , parallax:    10.46  , parerr:	 0.66  , promot: " PROMOT  -0.03      0" , vmag:   4.78  , hmag:   2.08  , irastwelvemu:     5.15  , qual:   3  , ftwelve:    0.00  , ones:  0.0  , diam:   1.92  , errdiam:  0.09  , simrem: "Star	    " , hvartype: ""	  , multflag: ""  , compid: ""      , theta:	 0 , rho:   0.00 , compmagdiff: 0.00 , notes: ""  , hdnotes: "" , hdmoent: ""  , hdmcoment: "" },$ 
{ name: "HD157236"       , baynum: ""              , hrnum: "HR6459"        , flamnum: "FL 43 Oph"        , saonum: "SAO185350"   , ppmnum: "PPM266801"   , varname: ""            , hipnum: "HIP85084"    , starname: ""                , alphah: 17.0 , alpham: 23.0 , alphas: 21.59 , plusmin:  -1 , deltag:  28.0 , deltam:  8.0 , deltas: 34.2  , orig: "iras"	   , spectype: "K5III"       , parallax:     5.44  , parerr:	 0.88  , promot: " PROMOT   0.01  -0.03" , vmag:   5.32  , hmag:   1.81  , irastwelvemu:     7.22  , qual:   3  , ftwelve:    7.41  , ones:  3.7  , diam:   2.49  , errdiam:  0.25  , simrem: "Star	    " , hvartype: ""	  , multflag: ""  , compid: ""      , theta:	 0 , rho:   0.00 , compmagdiff: 0.00 , notes: ""  , hdnotes: "" , hdmoent: ""  , hdmcoment: "" },$ 
{ name: "HD158228"       , baynum: ""              , hrnum: ""              , flamnum: ""                 , saonum: "SAO122405"   , ppmnum: "PPM164035"   , varname: "V*V2114 Oph" , hipnum: "HIP85450"    , starname: ""                , alphah: 17.0 , alpham: 27.0 , alphas: 44.08 , plusmin:  +1 , deltag:   8.0 , deltam: 26.0 , deltas: 31.3  , orig: "iras"	   , spectype: "M0"	     , parallax:     3.96  , parerr:	 0.82  , promot: " PROMOT      0  -0.05" , vmag:    6.5  , hmag:   0.00  , irastwelvemu:    12.47  , qual:   3  , ftwelve:    0.00  , ones:  0.0  , diam:   3.29  , errdiam:  0.47  , simrem: "Variable Star	   " , hvartype: "U"	  , multflag: ""  , compid: ""      , theta:	 0 , rho:   0.00 , compmagdiff: 0.00 , notes: ""  , hdnotes: "" , hdmoent: ""  , hdmcoment: "" },$ 
{ name: "HD158899"       , baynum: "lam Her"       , hrnum: "HR6526"        , flamnum: "FL 76 Her"        , saonum: "SAO85163"    , ppmnum: "PPM106001"   , varname: ""            , hipnum: "HIP85693"    , starname: ""                , alphah: 17.0 , alpham: 30.0 , alphas: 44.31 , plusmin:  +1 , deltag:  26.0 , deltam:  6.0 , deltas: 38.3  , orig: "iras"	   , spectype: "K4III"       , parallax:     8.88  , parerr:	 0.64  , promot: " PROMOT   0.02   0.02" , vmag:    4.4  , hmag:   1.29  , irastwelvemu:    11.02  , qual:   3  , ftwelve:    0.00  , ones:  0.0  , diam:   2.95  , errdiam:  0.09  , simrem: "Variable Star	   " , hvartype: ""	 , multflag: ""  , compid: ""	   , theta:	0 , rho:   0.00 , compmagdiff: 0.00 , notes: ""  , hdnotes: "" , hdmoent: ""  , hdmcoment: "" },$ 
{ name: "HD159187"       , baynum: ""              , hrnum: ""              , flamnum: ""                 , saonum: "SAO122500"   , ppmnum: "PPM164193"   , varname: "V*V2375 Oph" , hipnum: "HIP85905"    , starname: ""                , alphah: 17.0 , alpham: 33.0 , alphas: 16.98 , plusmin:  +1 , deltag:   0.0 , deltam:  6.0 , deltas: 11.8  , orig: "iras"	   , spectype: "M..."	     , parallax:     1.97  , parerr:	 1.06  , promot: " PROMOT  -0.01  -0.02" , vmag:   7.98  , hmag:   0.00  , irastwelvemu:     6.72  , qual:   3  , ftwelve:    0.00  , ones:  0.0  , diam:   2.39  , errdiam:  0.48  , simrem: "Variable Star of irregular type   " , hvartype: "U"	, multflag: ""  , compid: ""	  , theta:     0 , rho:   0.00 , compmagdiff: 0.00 , notes: ""  , hdnotes: "" , hdmoent: ""  , hdmcoment: "" },$ 
{ name: "HD159561"       , baynum: "alf Oph"       , hrnum: "HR6556"        , flamnum: "FL 55 Oph"        , saonum: "SAO102932"   , ppmnum: "PPM133563"   , varname: ""            , hipnum: "HIP86032"    , starname: "RASALHAGUE"      , alphah: 17.0 , alpham: 34.0 , alphas: 56.07 , plusmin:  +1 , deltag:  12.0 , deltam: 33.0 , deltas: 36.1  , orig: "iras"	   , spectype: "A5III"       , parallax:    69.84  , parerr:	 0.88  , promot: " PROMOT   0.12  -0.23" , vmag:    2.1  , hmag:   1.68  , irastwelvemu:     6.34  , qual:   3  , ftwelve:    0.00  , ones:  0.0  , diam:   1.59  , errdiam:  0.04  , simrem: "Variable Star	   " , hvartype: ""	 , multflag: "G"  , compid: ""      , theta:	 0 , rho:   0.00 , compmagdiff: 0.00 , notes: "D" , hdnotes: "An orbital solution based on elements by H.J.Augensen, W.D.Heintz, Publ. Astron.Soc.Pac., 104, 314, 1992, gives a semi-major axis of 71 mas for the photocentre." , hdmoent: ""  , hdmcoment: "" },$ 
{ name: "HD159968"       , baynum: ""              , hrnum: ""              , flamnum: ""                 , saonum: "SAO85239"    , ppmnum: "PPM106108"   , varname: "V*V959 Her"  , hipnum: "HIP86153"    , starname: ""                , alphah: 17.0 , alpham: 36.0 , alphas: 21.42 , plusmin:  +1 , deltag:  27.0 , deltam: 33.0 , deltas: 59.9  , orig: "iras"	   , spectype: "M1II"	     , parallax:     3.38  , parerr:	 0.69  , promot: " PROMOT   0.03  -0.07" , vmag:   6.42  , hmag:   0.00  , irastwelvemu:     9.59  , qual:   3  , ftwelve:    0.00  , ones:  0.0  , diam:   2.92  , errdiam:  0.18  , simrem: "Variable of BY Dra type     " , hvartype: "U"	  , multflag: ""  , compid: ""      , theta:	 0 , rho:   0.00 , compmagdiff: 0.00 , notes: "P" , hdnotes: "" , hdmoent: ""  , hdmcoment: "" },$ 
{ name: "HD159433"       , baynum: "Q Sco"         , hrnum: "HR6546"        , flamnum: ""                 , saonum: "SAO209019"   , ppmnum: "PPM296558"   , varname: ""            , hipnum: "HIP86170"    , starname: ""                , alphah: 17.0 , alpham: 36.0 , alphas: 32.83 , plusmin:  -1 , deltag:  38.0 , deltam: 38.0 , deltas:  7.1  , orig: "iras"	   , spectype: "K0IIIb"      , parallax:    22.64  , parerr:	 0.94  , promot: " PROMOT  -0.02  -0.18" , vmag:   4.27  , hmag:   1.77  , irastwelvemu:     6.45  , qual:   3  , ftwelve:     6.3  , ones:  3.8  , diam:   2.07  , errdiam:  0.06  , simrem: "High proper-motion Star     " , hvartype: "C"	  , multflag: "G"  , compid: ""      , theta:	  0 , rho:   0.00 , compmagdiff: 0.00 , notes: ""  , hdnotes: "" , hdmoent: ""  , hdmcoment: "" },$ 
{ name: "HD159532"       , baynum: "the Sco"       , hrnum: "HR6553"        , flamnum: ""                 , saonum: "SAO228201"   , ppmnum: "PPM323186"   , varname: ""            , hipnum: "HIP86228"    , starname: ""                , alphah: 17.0 , alpham: 37.0 , alphas: 19.13 , plusmin:  -1 , deltag:  42.0 , deltam: 59.0 , deltas: 52.2  , orig: "iras"	   , spectype: "F1II"	     , parallax:    11.99  , parerr:	 0.84  , promot: " PROMOT   0.02      0" , vmag:   1.86  , hmag:   0.81  , irastwelvemu:    15.56  , qual:   3  , ftwelve:    0.00  , ones:  0.0  , diam:   2.77  , errdiam:  0.08  , simrem: "Variable Star	   " , hvartype: "D"	  , multflag: "C"  , compid: "AB"      , theta:  315  , rho:  6.47    , compmagdiff:  3.39  , notes: ""  , hdnotes: "" , hdmoent: "Y" , hdmcoment: "" },$ 
{ name: "HD159881"       , baynum: ""              , hrnum: ""              , flamnum: ""                 , saonum: "SAO185573"   , ppmnum: "PPM267100"   , varname: ""            , hipnum: "HIP86317"    , starname: ""                , alphah: 17.0 , alpham: 38.0 , alphas: 11.99 , plusmin:  -1 , deltag:  28.0 , deltam:  2.0 , deltas: 48.3  , orig: "msx"	   , spectype: "K5III"       , parallax:     2.05  , parerr:	 0.97  , promot: " PROMOT   0.01  -0.01" , vmag:   6.89  , hmag:   2.01  , irastwelvemu:     0.00  , qual:   0  , ftwelve:    6.57  , ones:  3.5  , diam:   2.56  , errdiam:   0.6  , simrem: "Star	    " , hvartype: "U"	   , multflag: ""  , compid: ""      , theta:	  0 , rho:   0.00 , compmagdiff: 0.00 , notes: ""  , hdnotes: "" , hdmoent: ""  , hdmcoment: "" },$ 
{ name: "HD160677"       , baynum: ""              , hrnum: "HR6584"        , flamnum: ""                 , saonum: "SAO66231"    , ppmnum: "PPM80455"    , varname: ""            , hipnum: "HIP86462"    , starname: ""                , alphah: 17.0 , alpham: 39.0 , alphas: 57.52 , plusmin:  +1 , deltag:  31.0 , deltam: 12.0 , deltas:  8.9  , orig: "iras"	   , spectype: "M2III"       , parallax:     6.12  , parerr:	 0.58  , promot: " PROMOT  -0.02   0.01" , vmag:   6.07  , hmag:   0.00  , irastwelvemu:     6.04  , qual:   3  , ftwelve:    0.00  , ones:  0.0  , diam:   2.11  , errdiam:  0.12  , simrem: "Star	    " , hvartype: "M"	   , multflag: ""  , compid: ""      , theta:	  0 , rho:   0.00 , compmagdiff: 0.00 , notes: ""  , hdnotes: "" , hdmoent: ""  , hdmcoment: "" },$ 
{ name: "HD160668"       , baynum: ""              , hrnum: "HR6583"        , flamnum: ""                 , saonum: "SAO209172"   , ppmnum: "PPM296710"   , varname: ""            , hipnum: "HIP86698"    , starname: ""                , alphah: 17.0 , alpham: 42.0 , alphas:  51.1 , plusmin:  -1 , deltag:  36.0 , deltam: 56.0 , deltas: 44.0  , orig: "iras"	   , spectype: "K5III"       , parallax:     6.02  , parerr:	 0.88  , promot: " PROMOT      0  -0.03" , vmag:   5.54  , hmag:   2.03  , irastwelvemu:     5.89  , qual:   3  , ftwelve:    5.94  , ones:  3.8  , diam:   2.22  , errdiam:  0.23  , simrem: "Star	    " , hvartype: "M"	   , multflag: ""  , compid: ""      , theta:	  0 , rho:   0.00 , compmagdiff: 0.00 , notes: ""  , hdnotes: "" , hdmoent: ""  , hdmcoment: "" },$ 
{ name: "HD160748"       , baynum: ""              , hrnum: "HR6587"        , flamnum: ""                 , saonum: "SAO209176"   , ppmnum: "PPM296714"   , varname: ""            , hipnum: "HIP86716"    , starname: ""                , alphah: 17.0 , alpham: 43.0 , alphas:  6.86 , plusmin:  -1 , deltag:  33.0 , deltam:  3.0 , deltas:  4.6  , orig: "msx"	   , spectype: "M1III"       , parallax:     1.22  , parerr:	 0.96  , promot: " PROMOT   0.01      0" , vmag:   6.45  , hmag:   1.93  , irastwelvemu:     0.00  , qual:   0  , ftwelve:    7.19  , ones:  3.6  , diam:   2.45  , errdiam:  1.94  , simrem: "Variable Star	   " , hvartype: "U"	  , multflag: ""  , compid: ""      , theta:	 0 , rho:   0.00 , compmagdiff: 0.00 , notes: ""  , hdnotes: "" , hdmoent: ""  , hdmcoment: "" },$ 
{ name: "HD160810"       , baynum: ""              , hrnum: ""              , flamnum: ""                 , saonum: "SAO209180"   , ppmnum: "PPM296717"   , varname: ""            , hipnum: "HIP86737"    , starname: ""                , alphah: 17.0 , alpham: 43.0 , alphas: 26.00 , plusmin:  -1 , deltag:  35.0 , deltam: 17.0 , deltas: 51.6  , orig: "msx"	   , spectype: "M0III"       , parallax:     1.95  , parerr:	  1.2  , promot: " PROMOT  -0.01  -0.04" , vmag:   6.96  , hmag:   1.96  , irastwelvemu:     0.00  , qual:   0  , ftwelve:    8.27  , ones:  3.6  , diam:   2.72  , errdiam:  0.63  , simrem: "Variable Star	   " , hvartype: "U"	  , multflag: ""  , compid: ""      , theta:	 0 , rho:   0.00 , compmagdiff: 0.00 , notes: ""  , hdnotes: "" , hdmoent: ""  , hdmcoment: "" },$ 
{ name: "HD161096"       , baynum: "bet Oph"       , hrnum: "HR6603"        , flamnum: "FL 60 Oph"        , saonum: "SAO122671"   , ppmnum: "PPM164476"   , varname: ""            , hipnum: "HIP86742"    , starname: "Cebalrai"        , alphah: 17.0 , alpham: 43.0 , alphas: 28.35 , plusmin:  +1 , deltag:   4.0 , deltam: 34.0 , deltas:  2.3  , orig: "iras"	   , spectype: "K2III"       , parallax:    39.78  , parerr:	 0.75  , promot: " PROMOT  -0.04   0.16" , vmag:   2.77  , hmag:   0.33  , irastwelvemu:    26.63  , qual:   3  , ftwelve:    0.00  , ones:  0.0  , diam:   4.38  , errdiam:  0.08  , simrem: "Variable Star	   " , hvartype: ""	 , multflag: ""  , compid: ""	   , theta:	0 , rho:   0.00 , compmagdiff: 0.00 , notes: "P" , hdnotes: "" , hdmoent: ""  , hdmcoment: "" },$ 
{ name: "HD161204"       , baynum: ""              , hrnum: ""              , flamnum: ""                 , saonum: "SAO141844"   , ppmnum: "PPM200993"   , varname: ""            , hipnum: ""            , starname: ""                , alphah: 17.0 , alpham: 44.0 , alphas: 34.41 , plusmin:  -1 , deltag:   7.0 , deltam: 51.0 , deltas: 21.8  , orig: "iras"	   , spectype: "M..."	     , parallax:     0.00  , parerr:	 0.00  , promot: " PROMOT      0   0.01" , vmag:   8.52  , hmag:   2.03  , irastwelvemu:      8.6  , qual:   3  , ftwelve:    0.00  , ones:  0.0  , diam:   2.54  , errdiam:  0.07  , simrem: "Variable Star	   " , hvartype: ""	 , multflag: ""  , compid: ""	   , theta:	0 , rho:   0.00 , compmagdiff: 0.00 , notes: ""  , hdnotes: "" , hdmoent: ""  , hdmcoment: "" },$ 
{ name: "HD160635"       , baynum: "eta Pav"       , hrnum: "HR6582"        , flamnum: ""                 , saonum: "SAO254020"   , ppmnum: "PPM362896"   , varname: ""            , hipnum: "HIP86929"    , starname: ""                , alphah: 17.0 , alpham: 45.0 , alphas: 43.99 , plusmin:  -1 , deltag:  64.0 , deltam: 43.0 , deltas: 25.9  , orig: "iras"	   , spectype: "K2II"	     , parallax:     8.79  , parerr:	 0.65  , promot: " PROMOT      0  -0.05" , vmag:    3.6  , hmag:    1.1  , irastwelvemu:    12.53  , qual:   3  , ftwelve:    0.00  , ones:  0.0  , diam:   2.94  , errdiam:  0.11  , simrem: "Star	    " , hvartype: ""	  , multflag: ""  , compid: ""      , theta:	 0 , rho:   0.00 , compmagdiff: 0.00 , notes: ""  , hdnotes: "" , hdmoent: ""  , hdmcoment: "" },$ 
{ name: "HD161797"       , baynum: "mu. Her"       , hrnum: "HR6623"        , flamnum: "FL 86 Her"        , saonum: "SAO85397"    , ppmnum: "PPM106324"   , varname: ""            , hipnum: "HIP86974"    , starname: ""                , alphah: 17.0 , alpham: 46.0 , alphas: 27.53 , plusmin:  +1 , deltag:  27.0 , deltam: 43.0 , deltas: 14.4  , orig: "iras"	   , spectype: "G5IV"	     , parallax:   119.05  , parerr:	 0.62  , promot: " PROMOT  -0.29  -0.75" , vmag:   3.41  , hmag:   0.00  , irastwelvemu:     6.01  , qual:   3  , ftwelve:    0.00  , ones:  0.0  , diam:   1.92  , errdiam:  0.01  , simrem: "High proper-motion Star     " , hvartype: ""	 , multflag: ""  , compid: ""	   , theta:	0 , rho:   0.00 , compmagdiff: 0.00 , notes: ""  , hdnotes: "" , hdmoent: ""  , hdmcoment: "" },$ 
{ name: "HD161849"       , baynum: ""              , hrnum: ""              , flamnum: ""                 , saonum: "SAO160832"   , ppmnum: "PPM233619"   , varname: ""            , hipnum: ""            , starname: ""                , alphah: 17.0 , alpham: 48.0 , alphas: 41.67 , plusmin:  -1 , deltag:  19.0 , deltam: 46.0 , deltas: 46.6  , orig: "iras"	   , spectype: "M2III"       , parallax:     0.00  , parerr:	 0.00  , promot: " PROMOT   0.02      0" , vmag:   8.57  , hmag:   2.37  , irastwelvemu:     5.29  , qual:   3  , ftwelve:    0.00  , ones:  0.0  , diam:   2.16  , errdiam:  0.07  , simrem: "Star	    " , hvartype: ""	  , multflag: ""  , compid: ""      , theta:	 0 , rho:   0.00 , compmagdiff: 0.00 , notes: ""  , hdnotes: "" , hdmoent: ""  , hdmcoment: "" },$ 
{ name: "HD161892"       , baynum: "G Sco"         , hrnum: "HR6630"        , flamnum: ""                 , saonum: "SAO209318"   , ppmnum: "PPM296857"   , varname: "V* G Sco"    , hipnum: "HIP87261"    , starname: ""                , alphah: 17.0 , alpham: 49.0 , alphas: 51.48 , plusmin:  -1 , deltag:  37.0 , deltam:  2.0 , deltas: 35.9  , orig: "iras"	   , spectype: "K2III"       , parallax:    25.71  , parerr:	 0.87  , promot: " PROMOT   0.04   0.03" , vmag:   3.19  , hmag:   0.61  , irastwelvemu:    16.37  , qual:   3  , ftwelve:    0.00  , ones:  0.0  , diam:   3.69  , errdiam:  0.06  , simrem: "Eclipsing binary      " , hvartype: ""	   , multflag: ""  , compid: ""      , theta:	  0 , rho:   0.00 , compmagdiff: 0.00 , notes: ""  , hdnotes: "" , hdmoent: ""  , hdmcoment: "" },$ 
{ name: "HD316665"       , baynum: ""              , hrnum: ""              , flamnum: ""                 , saonum: "SAO185920"   , ppmnum: "PPM267494"   , varname: "V*V776 Sgr"  , hipnum: ""            , starname: ""                , alphah: 17.0 , alpham: 55.0 , alphas: 13.24 , plusmin:  -1 , deltag:  28.0 , deltam:  0.0 , deltas: 21.8  , orig: "msx"	   , spectype: "K7"	     , parallax:     0.00  , parerr:	 0.00  , promot: " PROMOT   0.01  -0.01" , vmag:    9.1  , hmag:   2.24  , irastwelvemu:     0.00  , qual:   0  , ftwelve:    7.56  , ones:  3.3  , diam:   2.28  , errdiam:  0.07  , simrem: "Pulsating variable Star     " , hvartype: ""	 , multflag: ""  , compid: ""	   , theta:	0 , rho:   0.00 , compmagdiff: 0.00 , notes: ""  , hdnotes: "" , hdmoent: ""  , hdmcoment: "" },$ 
{ name: "HD163993"       , baynum: "ksi Her"       , hrnum: "HR6703"        , flamnum: "FL 92 Her"        , saonum: "SAO85590"    , ppmnum: "PPM106582"   , varname: "V* ksi Her"  , hipnum: "HIP87933"    , starname: ""                , alphah: 17.0 , alpham: 57.0 , alphas: 45.89 , plusmin:  +1 , deltag:  29.0 , deltam: 14.0 , deltas: 52.4  , orig: "iras"	   , spectype: "G8III"       , parallax:    24.12  , parerr:	 0.52  , promot: " PROMOT   0.08  -0.02" , vmag:   3.71  , hmag:   1.67  , irastwelvemu:     7.08  , qual:   3  , ftwelve:    0.00  , ones:  0.0  , diam:   2.16  , errdiam:  0.03  , simrem: "Variable Star	   " , hvartype: "P"	  , multflag: ""  , compid: ""      , theta:	 0 , rho:   0.00 , compmagdiff: 0.00 , notes: ""  , hdnotes: "" , hdmoent: ""  , hdmcoment: "" },$ 
{ name: "HD163376"       , baynum: ""              , hrnum: "HR6682"        , flamnum: ""                 , saonum: "SAO228578"   , ppmnum: "PPM323580"   , varname: ""            , hipnum: "HIP87936"    , starname: ""                , alphah: 17.0 , alpham: 57.0 , alphas: 47.81 , plusmin:  -1 , deltag:  41.0 , deltam: 42.0 , deltas: 58.7  , orig: "iras"	   , spectype: "M0III"       , parallax:     5.96  , parerr:	 0.71  , promot: " PROMOT  -0.02  -0.01" , vmag:    4.9  , hmag:    0.9  , irastwelvemu:    17.13  , qual:   3  , ftwelve:    0.00  , ones:  0.0  , diam:   3.79  , errdiam:  0.12  , simrem: "Variable Star	   " , hvartype: "U"	  , multflag: ""  , compid: ""      , theta:	 0 , rho:   0.00 , compmagdiff: 0.00 , notes: ""  , hdnotes: "" , hdmoent: ""  , hdmcoment: "" },$ 
{ name: "HD163917"       , baynum: "nu. Oph"       , hrnum: "HR6698"        , flamnum: "FL 64 Oph"        , saonum: "SAO142004"   , ppmnum: "PPM201263"   , varname: ""            , hipnum: "HIP88048"    , starname: ""                , alphah: 17.0 , alpham: 59.0 , alphas:  1.59 , plusmin:  -1 , deltag:   9.0 , deltam: 46.0 , deltas: 25.1  , orig: "iras"	   , spectype: "G9III"       , parallax:    21.35  , parerr:	 0.79  , promot: " PROMOT  -0.01  -0.12" , vmag:   3.33  , hmag:   1.21  , irastwelvemu:    11.41  , qual:   3  , ftwelve:    0.00  , ones:  0.0  , diam:   2.75  , errdiam:  0.11  , simrem: "Star	    " , hvartype: ""	  , multflag: ""  , compid: ""      , theta:	 0 , rho:   0.00 , compmagdiff: 0.00 , notes: ""  , hdnotes: "" , hdmoent: ""  , hdmcoment: "" },$ 
{ name: "HD163755"       , baynum: ""              , hrnum: "HR6693"        , flamnum: ""                 , saonum: "SAO209553"   , ppmnum: "PPM297085"   , varname: ""            , hipnum: "HIP88060"    , starname: ""                , alphah: 17.0 , alpham: 59.0 , alphas:  5.57 , plusmin:  -1 , deltag:  30.0 , deltam: 15.0 , deltas: 12.7  , orig: "msx"	   , spectype: "M1Ib"	     , parallax:      5.0  , parerr:	  9.0  , promot: " PROMOT      0  -0.02" , vmag:   4.99  , hmag:   0.88  , irastwelvemu:     0.00  , qual:   0  , ftwelve:   19.93  , ones:  3.1  , diam:   3.18  , errdiam:  0.96  , simrem: "Eclipsing binary      " , hvartype: "U"      , multflag: "C"  , compid: "AB"	 , theta:  105  , rho:  5.49	, compmagdiff:  1.85  , notes: ""  , hdnotes: "" , hdmoent: "Y" , hdmcoment: "" },$ 
{ name: "HD164064"       , baynum: ""              , hrnum: "HR6706"        , flamnum: ""                 , saonum: "SAO142012"   , ppmnum: "PPM201278"   , varname: ""            , hipnum: "HIP88101"    , starname: ""                , alphah: 17.0 , alpham: 59.0 , alphas: 36.76 , plusmin:  -1 , deltag:   4.0 , deltam: 49.0 , deltas: 16.1  , orig: "iras"	   , spectype: "K5III"       , parallax:      5.9  , parerr:	 0.69  , promot: " PROMOT  -0.02  -0.09" , vmag:   5.86  , hmag:   2.24  , irastwelvemu:     5.02  , qual:   3  , ftwelve:    0.00  , ones:  0.0  , diam:   2.07  , errdiam:  0.52  , simrem: "Variable Star	   " , hvartype: ""	 , multflag: ""  , compid: ""	   , theta:	0 , rho:   0.00 , compmagdiff: 0.00 , notes: ""  , hdnotes: "" , hdmoent: ""  , hdmcoment: "" },$ 
{ name: "HD164349"       , baynum: ""              , hrnum: "HR6713"        , flamnum: "FL 93 Her"        , saonum: "SAO103285"   , ppmnum: "PPM134105"   , varname: ""            , hipnum: "HIP88128"    , starname: ""                , alphah: 18.0 , alpham:  0.0 , alphas:  3.42 , plusmin:  +1 , deltag:  16.0 , deltam: 45.0 , deltas:  3.3  , orig: "iras"	   , spectype: "K0.5IIb"     , parallax:     4.97  , parerr:	 0.82  , promot: " PROMOT  -0.01  -0.01" , vmag:   4.67  , hmag:   0.00  , irastwelvemu:      5.4  , qual:   3  , ftwelve:    0.00  , ones:  0.0  , diam:   1.99  , errdiam:  0.14  , simrem: "Star	    " , hvartype: ""	  , multflag: ""  , compid: ""      , theta:	 0 , rho:   0.00 , compmagdiff: 0.00 , notes: ""  , hdnotes: "" , hdmoent: ""  , hdmcoment: "" },$ 
{ name: "HD164358"       , baynum: ""              , hrnum: "HR6715"        , flamnum: "FL 6 Sgr"         , saonum: "SAO160998"   , ppmnum: "PPM233913"   , varname: ""            , hipnum: "HIP88258"    , starname: ""                , alphah: 18.0 , alpham:  1.0 , alphas: 23.12 , plusmin:  -1 , deltag:  17.0 , deltam:  9.0 , deltas: 24.7  , orig: "iras"	   , spectype: "K2III"       , parallax:     1.76  , parerr:	 1.09  , promot: " PROMOT      0  -0.01" , vmag:   6.29  , hmag:   2.11  , irastwelvemu:      5.9  , qual:   3  , ftwelve:    6.25  , ones:  3.9  , diam:    2.2  , errdiam:  1.02  , simrem: "Star	    " , hvartype: ""	  , multflag: ""  , compid: ""      , theta:	 0 , rho:   0.00 , compmagdiff: 0.00 , notes: ""  , hdnotes: "" , hdmoent: ""  , hdmcoment: "" },$ 
{ name: "HD164579"       , baynum: ""              , hrnum: ""              , flamnum: ""                 , saonum: "SAO161017"   , ppmnum: "PPM233945"   , varname: "V* QQ Ser"   , hipnum: "HIP88326"    , starname: ""                , alphah: 18.0 , alpham:  2.0 , alphas: 22.24 , plusmin:  -1 , deltag:  12.0 , deltam: 19.0 , deltas:  6.1  , orig: "iras"	   , spectype: "M2III"       , parallax:     2.81  , parerr:	 1.04  , promot: " PROMOT  -0.01      0" , vmag:    7.7  , hmag:  2.00   , irastwelvemu:     7.68  , qual:   3  , ftwelve:    6.87  , ones:  4.3  , diam:   2.67  , errdiam:  1.44  , simrem: "Variable Star of irregular type   " , hvartype: "U"	, multflag: ""  , compid: ""	  , theta:     0 , rho:   0.00 , compmagdiff: 0.00 , notes: ""  , hdnotes: "" , hdmoent: ""  , hdmcoment: "" },$ 
{ name: "HD164857"       , baynum: ""              , hrnum: ""              , flamnum: ""                 , saonum: ""            , ppmnum: "PPM233972"   , varname: ""            , hipnum: ""            , starname: ""                , alphah: 18.0 , alpham:  3.0 , alphas: 56.48 , plusmin:  -1 , deltag:  16.0 , deltam: 56.0 , deltas:  6.9  , orig: "iras"	   , spectype: "M2/M3"       , parallax:     0.00  , parerr:	 0.00  , promot: " PROMOT   0.01      0" , vmag:   9.66  , hmag:   2.11  , irastwelvemu:     8.06  , qual:   3  , ftwelve:    0.00  , ones:  0.0  , diam:   2.45  , errdiam:  0.07  , simrem: "Star	    " , hvartype: ""	  , multflag: ""  , compid: ""      , theta:	 0 , rho:   0.00 , compmagdiff: 0.00 , notes: ""  , hdnotes: "" , hdmoent: ""  , hdmcoment: "" },$ 
{ name: "HD165135"       , baynum: "gam Sgr"       , hrnum: "HR6746"        , flamnum: "FL 10 Sgr"        , saonum: "SAO209696"   , ppmnum: "PPM297231"   , varname: ""            , hipnum: "HIP88635"    , starname: ""                , alphah: 18.0 , alpham:  5.0 , alphas: 48.49 , plusmin:  -1 , deltag:  30.0 , deltam: 25.0 , deltas: 26.7  , orig: "iras"	   , spectype: "K0III"       , parallax:    33.94  , parerr:	 0.87  , promot: " PROMOT  -0.05  -0.19" , vmag:   2.99  , hmag:   0.73  , irastwelvemu:     16.3  , qual:   3  , ftwelve:   17.44  , ones:  3.1  , diam:   3.33  , errdiam:  0.05  , simrem: "Variable Star	   " , hvartype: "C"	  , multflag: ""  , compid: ""      , theta:	 0 , rho:   0.00 , compmagdiff: 0.00 , notes: ""  , hdnotes: "" , hdmoent: ""  , hdmcoment: "" },$ 
{ name: "HD167036"       , baynum: ""              , hrnum: "HR6816"        , flamnum: "FL 14 Sgr"        , saonum: "SAO186509"   , ppmnum: "PPM268095"   , varname: ""            , hipnum: "HIP89369"    , starname: ""                , alphah: 18.0 , alpham: 14.0 , alphas:  15.9 , plusmin:  -1 , deltag:  21.0 , deltam: 42.0 , deltas: 47.4  , orig: "msx"	   , spectype: "K2III"       , parallax:     6.45  , parerr:	 0.95  , promot: " PROMOT  -0.01  -0.02" , vmag:   5.49  , hmag:   1.96  , irastwelvemu:     0.00  , qual:   0  , ftwelve:    6.27  , ones:  3.7  , diam:   2.26  , errdiam:  0.27  , simrem: "Variable Star	   " , hvartype: "M"	  , multflag: ""  , compid: ""      , theta:	 0 , rho:   0.00 , compmagdiff: 0.00 , notes: ""  , hdnotes: "" , hdmoent: ""  , hdmcoment: "" },$ 
{ name: "HD167121"       , baynum: ""              , hrnum: ""              , flamnum: ""                 , saonum: "SAO186531"   , ppmnum: "PPM268121"   , varname: ""            , hipnum: "HIP89429"    , starname: ""                , alphah: 18.0 , alpham: 15.0 , alphas:  5.11 , plusmin:  -1 , deltag:  29.0 , deltam: 49.0 , deltas: 22.8  , orig: "iras"	   , spectype: "M1III"       , parallax:     4.54  , parerr:	 0.84  , promot: " PROMOT  -0.01  -0.01" , vmag:    6.7  , hmag:   2.16  , irastwelvemu:     6.16  , qual:   3  , ftwelve:    0.00  , ones:  0.0  , diam:   2.31  , errdiam:  0.32  , simrem: "Variable Star	   " , hvartype: "U"	  , multflag: ""  , compid: ""      , theta:	 0 , rho:   0.00 , compmagdiff: 0.00 , notes: ""  , hdnotes: "" , hdmoent: ""  , hdmcoment: "" },$ 
{ name: "HD167618"       , baynum: "eta Sgr"       , hrnum: "HR6832"        , flamnum: ""                 , saonum: "SAO209957"   , ppmnum: "PPM297508"   , varname: "V* eta Sgr"  , hipnum: "HIP89642"    , starname: ""                , alphah: 18.0 , alpham: 17.0 , alphas: 37.64 , plusmin:  -1 , deltag:  36.0 , deltam: 45.0 , deltas: 42.1  , orig: "iras"	   , spectype: "M3.5III"     , parallax:    21.87  , parerr:	 0.92  , promot: " PROMOT  -0.14  -0.17" , vmag:   3.11  , hmag:  -1.31  , irastwelvemu:    148.9  , qual:   3  , ftwelve:    0.00  , ones:  0.0  , diam:  11.33  , errdiam:  0.04  , simrem: "Variable Star	   " , hvartype: "U"	  , multflag: ""  , compid: ""      , theta:	 0 , rho:   0.00 , compmagdiff: 0.00 , notes: ""  , hdnotes: "" , hdmoent: ""  , hdmcoment: "" },$ 
{ name: "HD168532"       , baynum: ""              , hrnum: "HR6860"        , flamnum: "FL 105 Her"       , saonum: "SAO85921"    , ppmnum: "PPM107067"   , varname: ""            , hipnum: "HIP89773"    , starname: ""                , alphah: 18.0 , alpham: 19.0 , alphas: 10.68 , plusmin:  +1 , deltag:  24.0 , deltam: 26.0 , deltas: 45.8  , orig: "iras"	   , spectype: "K4Iab"       , parallax:     2.55  , parerr:	 0.59  , promot: " PROMOT   0.01   0.01" , vmag:   5.29  , hmag:   1.98  , irastwelvemu:     6.17  , qual:   3  , ftwelve:    0.00  , ones:  0.0  , diam:   2.27  , errdiam:  0.21  , simrem: "Spectroscopic binary	  " , hvartype: "M"	 , multflag: ""  , compid: ""	   , theta:	0 , rho:   0.00 , compmagdiff: 0.00 , notes: ""  , hdnotes: "" , hdmoent: ""  , hdmcoment: "" },$ 
{ name: "HD168415"       , baynum: ""              , hrnum: "HR6858"        , flamnum: ""                 , saonum: "SAO161348"   , ppmnum: "PPM234386"   , varname: ""            , hipnum: "HIP89851"    , starname: ""                , alphah: 18.0 , alpham: 20.0 , alphas:  8.79 , plusmin:  -1 , deltag:  15.0 , deltam: 49.0 , deltas: 54.1  , orig: "msx"	   , spectype: "K3III"       , parallax:     6.93  , parerr:	 0.78  , promot: " PROMOT   0.04  -0.04" , vmag:    5.4  , hmag:   2.01  , irastwelvemu:     0.00  , qual:   0  , ftwelve:    6.03  , ones:  3.4  , diam:    2.2  , errdiam:   0.3  , simrem: "Star	    " , hvartype: ""	  , multflag: ""  , compid: ""      , theta:	 0 , rho:   0.00 , compmagdiff: 0.00 , notes: ""  , hdnotes: "" , hdmoent: ""  , hdmcoment: "" },$ 
{ name: "HD168454"       , baynum: "del Sgr"       , hrnum: "HR6859"        , flamnum: "FL 19 Sgr"        , saonum: "SAO186681"   , ppmnum: "PPM268275"   , varname: ""            , hipnum: "HIP89931"    , starname: ""                , alphah: 18.0 , alpham: 20.0 , alphas: 59.64 , plusmin:  -1 , deltag:  29.0 , deltam: 49.0 , deltas: 41.2  , orig: "iras"	   , spectype: "K3IIIa"      , parallax:    10.67  , parerr:	 0.93  , promot: " PROMOT   0.04  -0.03" , vmag:   2.71  , hmag:  -0.19  , irastwelvemu:    43.66  , qual:   3  , ftwelve:    0.00  , ones:  0.0  , diam:   5.78  , errdiam:  0.15  , simrem: "Eclipsing binary      " , hvartype: ""	   , multflag: ""  , compid: ""      , theta:	  0 , rho:   0.00 , compmagdiff: 0.00 , notes: ""  , hdnotes: "" , hdmoent: ""  , hdmcoment: "" },$ 
{ name: "HD168723"       , baynum: "eta Ser"       , hrnum: "HR6869"        , flamnum: "FL 58 Ser"        , saonum: "SAO142241"   , ppmnum: "PPM201654"   , varname: ""            , hipnum: "HIP89962"    , starname: ""                , alphah: 18.0 , alpham: 21.0 , alphas:  18.6 , plusmin:  -1 , deltag:   2.0 , deltam: 53.0 , deltas: 55.8  , orig: "iras"	   , spectype: "K0III-IV"    , parallax:    52.81  , parerr:	 0.75  , promot: " PROMOT  -0.55   -0.7" , vmag:   3.26  , hmag:   1.07  , irastwelvemu:    12.01  , qual:   3  , ftwelve:    0.00  , ones:  0.0  , diam:   2.87  , errdiam:  0.04  , simrem: "Variable Star	   " , hvartype: "C"	  , multflag: ""  , compid: ""      , theta:	 0 , rho:   0.00 , compmagdiff: 0.00 , notes: ""  , hdnotes: "" , hdmoent: ""  , hdmcoment: "" },$ 
{ name: "HD168592"       , baynum: ""              , hrnum: "HR6862"        , flamnum: ""                 , saonum: "SAO210048"   , ppmnum: "PPM297606"   , varname: ""            , hipnum: "HIP90037"    , starname: ""                , alphah: 18.0 , alpham: 22.0 , alphas: 18.57 , plusmin:  -1 , deltag:  38.0 , deltam: 39.0 , deltas: 24.8  , orig: "iras"	   , spectype: "K4.5III"     , parallax:     6.48  , parerr:	 0.78  , promot: " PROMOT  -0.03  -0.03" , vmag:   5.09  , hmag:   1.02  , irastwelvemu:     7.54  , qual:   3  , ftwelve:    0.00  , ones:  0.0  , diam:   3.65  , errdiam:  0.11  , simrem: "Star	    " , hvartype: ""	  , multflag: ""  , compid: ""      , theta:	 0 , rho:   0.00 , compmagdiff: 0.00 , notes: ""  , hdnotes: "" , hdmoent: ""  , hdmcoment: "" },$ 
{ name: "HD168339"       , baynum: "ksi Pav"       , hrnum: "HR6855"        , flamnum: ""                 , saonum: "SAO254226"   , ppmnum: "PPM363303"   , varname: ""            , hipnum: "HIP90098"    , starname: ""                , alphah: 18.0 , alpham: 23.0 , alphas: 13.62 , plusmin:  -1 , deltag:  61.0 , deltam: 29.0 , deltas: 38.0  , orig: "iras"	   , spectype: "K4III"       , parallax:     7.76  , parerr:	 0.77  , promot: " PROMOT      0      0" , vmag:   4.38  , hmag:   1.01  , irastwelvemu:    14.22  , qual:   3  , ftwelve:    0.00  , ones:  0.0  , diam:   3.32  , errdiam:  0.12  , simrem: "Spectroscopic binary	  " , hvartype: "U"	 , multflag: "G"  , compid: ""      , theta:	 0 , rho:   0.00 , compmagdiff: 0.00 , notes: ""  , hdnotes: "" , hdmoent: ""  , hdmcoment: "" },$ 
{ name: "HD168988"       , baynum: ""              , hrnum: ""              , flamnum: ""                 , saonum: "SAO186750"   , ppmnum: "PPM268339"   , varname: "V*V4393 Sgr" , hipnum: "HIP90113"    , starname: ""                , alphah: 18.0 , alpham: 23.0 , alphas: 19.93 , plusmin:  -1 , deltag:  20.0 , deltam: 39.0 , deltas: 13.1  , orig: "msx"	   , spectype: "K5/M0III"    , parallax:    -0.39  , parerr:	 1.03  , promot: " PROMOT  -0.01      0" , vmag:   7.68  , hmag:   2.43  , irastwelvemu:     0.00  , qual:   0  , ftwelve:    5.04  , ones:  4.2  , diam:   2.13  , errdiam:  0.07  , simrem: "Variable Star	   " , hvartype: "U"	  , multflag: ""  , compid: ""      , theta:	 0 , rho:   0.00 , compmagdiff: 0.00 , notes: ""  , hdnotes: "" , hdmoent: ""  , hdmcoment: "" },$ 
{ name: "HD169414"       , baynum: ""              , hrnum: "HR6895"        , flamnum: "FL 109 Her"       , saonum: "SAO86003"    , ppmnum: "PPM107183"   , varname: ""            , hipnum: "HIP90139"    , starname: ""                , alphah: 18.0 , alpham: 23.0 , alphas: 41.89 , plusmin:  +1 , deltag:  21.0 , deltam: 46.0 , deltas: 11.1  , orig: "iras"	   , spectype: "K2III"       , parallax:     25.4  , parerr:	 0.65  , promot: " PROMOT   0.21  -0.25" , vmag:   3.84  , hmag:   0.00  , irastwelvemu:    11.68  , qual:   3  , ftwelve:    0.00  , ones:  0.0  , diam:   2.87  , errdiam:  0.03  , simrem: "Variable Star	   " , hvartype: "C"	  , multflag: ""  , compid: ""      , theta:	 0 , rho:   0.00 , compmagdiff: 0.00 , notes: ""  , hdnotes: "" , hdmoent: ""  , hdmcoment: "" },$ 
{ name: "HD169022"       , baynum: "eps Sgr"       , hrnum: "HR6879"        , flamnum: "FL 20 Sgr"        , saonum: "SAO210091"   , ppmnum: "PPM297655"   , varname: ""            , hipnum: "HIP90185"    , starname: "KAUS AUSTRALIS"  , alphah: 18.0 , alpham: 24.0 , alphas: 10.32 , plusmin:  -1 , deltag:  34.0 , deltam: 23.0 , deltas:  4.6  , orig: "iras"	   , spectype: "B9.5III"     , parallax:    22.55  , parerr:	 1.02  , promot: " PROMOT  -0.04  -0.12" , vmag:    1.8  , hmag:   1.74  , irastwelvemu:     5.94  , qual:   3  , ftwelve:    0.00  , ones:  0.0  , diam:   1.42  , errdiam:  0.04  , simrem: "Eclipsing binary      " , hvartype: ""	   , multflag: ""  , compid: ""      , theta:	  0 , rho:   0.00 , compmagdiff: 0.00 , notes: ""  , hdnotes: "" , hdmoent: ""  , hdmcoment: "" },$ 
{ name: "HD169274"       , baynum: ""              , hrnum: ""              , flamnum: ""                 , saonum: "SAO161436"   , ppmnum: "PPM234496"   , varname: ""            , hipnum: "HIP90230"    , starname: ""                , alphah: 18.0 , alpham: 24.0 , alphas: 38.34 , plusmin:  -1 , deltag:  19.0 , deltam: 43.0 , deltas: 58.3  , orig: "msx"	   , spectype: "K5III"       , parallax:      1.2  , parerr:	 1.24  , promot: " PROMOT  -0.02  -0.01" , vmag:   7.56  , hmag:   2.43  , irastwelvemu:     5.07  , qual:   3  , ftwelve:    5.39  , ones:  4.0  , diam:    2.2  , errdiam:  1.34  , simrem: "Variable Star	   " , hvartype: "U"	  , multflag: ""  , compid: ""      , theta:	 0 , rho:   0.00 , compmagdiff: 0.00 , notes: ""  , hdnotes: "" , hdmoent: ""  , hdmcoment: "" },$ 
{ name: "HD169334"       , baynum: ""              , hrnum: ""              , flamnum: ""                 , saonum: "SAO161447"   , ppmnum: "PPM234506"   , varname: ""            , hipnum: ""            , starname: ""                , alphah: 18.0 , alpham: 24.0 , alphas: 53.02 , plusmin:  -1 , deltag:  16.0 , deltam: 16.0 , deltas: 35.4  , orig: "msx"	   , spectype: "M0III"       , parallax:     0.00  , parerr:	 0.00  , promot: " PROMOT  -0.02      0" , vmag:   8.04  , hmag:   2.39  , irastwelvemu:     0.00  , qual:   0  , ftwelve:     5.8  , ones:  3.7  , diam:   2.18  , errdiam:  0.07  , simrem: "Star	    " , hvartype: ""	  , multflag: ""  , compid: ""      , theta:	 0 , rho:   0.00 , compmagdiff: 0.00 , notes: ""  , hdnotes: "" , hdmoent: ""  , hdmcoment: "" },$ 
{ name: "HD169420"       , baynum: ""              , hrnum: "HR6896"        , flamnum: "FL 21 Sgr"        , saonum: "SAO186794"   , ppmnum: "PPM268387"   , varname: ""            , hipnum: "HIP90289"    , starname: ""                , alphah: 18.0 , alpham: 25.0 , alphas: 21.04 , plusmin:  -1 , deltag:  20.0 , deltam: 32.0 , deltas: 30.0  , orig: "iras"	   , spectype: "K1/K2III"    , parallax:     5.46  , parerr:	  1.2  , promot: " PROMOT   0.01  -0.03" , vmag:   4.87  , hmag:   1.49  , irastwelvemu:     9.84  , qual:   3  , ftwelve:     9.4  , ones:  3.3  , diam:   2.47  , errdiam:  0.38  , simrem: "Double or multiple star     " , hvartype: "D"	  , multflag: "C"  , compid: "AB"      , theta:  284  , rho:  1.66    , compmagdiff:  2.42  , notes: ""  , hdnotes: "" , hdmoent: "Y" , hdmcoment: "" },$ 
{ name: "HD169916"       , baynum: "lam Sgr"       , hrnum: "HR6913"        , flamnum: "FL 22 Sgr"        , saonum: "SAO186841"   , ppmnum: "PPM268438"   , varname: ""            , hipnum: "HIP90496"    , starname: ""                , alphah: 18.0 , alpham: 27.0 , alphas: 58.24 , plusmin:  -1 , deltag:  25.0 , deltam: 25.0 , deltas: 18.1  , orig: "iras"	   , spectype: "K1IIIb"      , parallax:     42.2  , parerr:	  0.9  , promot: " PROMOT  -0.04  -0.19" , vmag:   2.83  , hmag:   0.45  , irastwelvemu:    21.62  , qual:   3  , ftwelve:    0.00  , ones:  0.0  , diam:   3.75  , errdiam:  0.04  , simrem: "Star	    " , hvartype: ""	  , multflag: ""  , compid: ""      , theta:	 0 , rho:   0.00 , compmagdiff: 0.00 , notes: ""  , hdnotes: "" , hdmoent: ""  , hdmcoment: "" },$ 
{ name: "HD170016"       , baynum: ""              , hrnum: ""              , flamnum: ""                 , saonum: "SAO186852"   , ppmnum: "PPM268451"   , varname: ""            , hipnum: "HIP90516"    , starname: ""                , alphah: 18.0 , alpham: 28.0 , alphas: 10.14 , plusmin:  -1 , deltag:  21.0 , deltam: 14.0 , deltas: 19.3  , orig: "msx"	   , spectype: "M3III"       , parallax:      2.6  , parerr:	 2.64  , promot: " PROMOT  -0.01  -0.03" , vmag:   8.74  , hmag:   2.07  , irastwelvemu:     0.00  , qual:   0  , ftwelve:    7.96  , ones:  3.9  , diam:   2.66  , errdiam:  0.74  , simrem: "Eclipsing binary      " , hvartype: ""	   , multflag: ""  , compid: ""      , theta:	  0 , rho:   0.00 , compmagdiff: 0.00 , notes: ""  , hdnotes: "" , hdmoent: ""  , hdmcoment: "" },$ 
{ name: "HD169767"       , baynum: "zet Tel"       , hrnum: "HR6905"        , flamnum: ""                 , saonum: "SAO229047"   , ppmnum: "PPM324133"   , varname: ""            , hipnum: "HIP90568"    , starname: ""                , alphah: 18.0 , alpham: 28.0 , alphas: 49.86 , plusmin:  -1 , deltag:  49.0 , deltam:  4.0 , deltas: 14.1  , orig: "iras"	   , spectype: "G9III"       , parallax:     25.6  , parerr:	 0.78  , promot: " PROMOT   0.14  -0.24" , vmag:   4.13  , hmag:   1.79  , irastwelvemu:     6.21  , qual:   3  , ftwelve:    0.00  , ones:  0.0  , diam:   2.12  , errdiam:  0.04  , simrem: "High proper-motion Star     " , hvartype: "C"	  , multflag: ""  , compid: ""      , theta:	 0 , rho:   0.00 , compmagdiff: 0.00 , notes: ""  , hdnotes: "" , hdmoent: ""  , hdmcoment: "" },$ 
{ name: "HD170975"       , baynum: ""              , hrnum: "HR6959"        , flamnum: ""                 , saonum: "SAO161587"   , ppmnum: "PPM234686"   , varname: "V*V450 Sct"  , hipnum: "HIP90913"    , starname: ""                , alphah: 18.0 , alpham: 32.0 , alphas: 43.32 , plusmin:  -1 , deltag:  14.0 , deltam: 51.0 , deltas: 56.4  , orig: "msx"	   , spectype: "K3Iab"       , parallax:     2.57  , parerr:	 0.77  , promot: " PROMOT  -0.01      0" , vmag:   5.51  , hmag:   1.26  , irastwelvemu:     0.00  , qual:   0  , ftwelve:   14.61  , ones:  3.1  , diam:   3.62  , errdiam:  0.75  , simrem: "Variable of BY Dra type     " , hvartype: "U"	  , multflag: ""  , compid: ""      , theta:	 0 , rho:   0.00 , compmagdiff: 0.00 , notes: "P" , hdnotes: "" , hdmoent: ""  , hdmcoment: "" },$ 
{ name: "HD171115"       , baynum: ""              , hrnum: "HR6961"        , flamnum: "FL 24 Sgr"        , saonum: "SAO186981"   , ppmnum: "PPM268587"   , varname: ""            , hipnum: "HIP91004"    , starname: ""                , alphah: 18.0 , alpham: 33.0 , alphas: 53.49 , plusmin:  -1 , deltag:  24.0 , deltam:  1.0 , deltas: 56.2  , orig: "iras"	   , spectype: "K3III"       , parallax:     0.95  , parerr:	 0.97  , promot: " PROMOT      0  -0.01" , vmag:   5.51  , hmag:   1.52  , irastwelvemu:      9.7  , qual:   3  , ftwelve:    0.00  , ones:  0.0  , diam:   3.01  , errdiam:   0.5  , simrem: "Star	    " , hvartype: ""	  , multflag: ""  , compid: ""      , theta:	 0 , rho:   0.00 , compmagdiff: 0.00 , notes: ""  , hdnotes: "" , hdmoent: ""  , hdmcoment: "" },$ 
{ name: "HD171443"       , baynum: "alf Sct"       , hrnum: "HR6973"        , flamnum: ""                 , saonum: "SAO142408"   , ppmnum: "PPM201884"   , varname: ""            , hipnum: "HIP91117"    , starname: ""                , alphah: 18.0 , alpham: 35.0 , alphas: 12.43 , plusmin:  -1 , deltag:   8.0 , deltam: 14.0 , deltas: 38.7  , orig: "msx"	   , spectype: "K3III"       , parallax:    18.72  , parerr:	 0.81  , promot: " PROMOT  -0.02  -0.31" , vmag:   3.85  , hmag:   0.97  , irastwelvemu:     0.00  , qual:   0  , ftwelve:   14.51  , ones:  3.1  , diam:   3.44  , errdiam:  0.16  , simrem: "Variable Star	   " , hvartype: ""	 , multflag: ""  , compid: ""	   , theta:	0 , rho:   0.00 , compmagdiff: 0.00 , notes: ""  , hdnotes: "" , hdmoent: ""  , hdmcoment: "" },$ 
{ name: "HD172137"       , baynum: ""              , hrnum: ""              , flamnum: ""                 , saonum: "SAO161694"   , ppmnum: "PPM234839"   , varname: ""            , hipnum: "HIP91448"    , starname: ""                , alphah: 18.0 , alpham: 39.0 , alphas:  2.52 , plusmin:  -1 , deltag:  15.0 , deltam:  2.0 , deltas: 21.4  , orig: "iras"	   , spectype: "M1III"       , parallax:     3.35  , parerr:	 0.98  , promot: " PROMOT  -0.02   0.02" , vmag:   7.49  , hmag:   2.11  , irastwelvemu:     6.78  , qual:   3  , ftwelve:    6.58  , ones:  4.1  , diam:   2.51  , errdiam:  0.59  , simrem: "Variable Star	   " , hvartype: "U"	  , multflag: ""  , compid: ""      , theta:	 0 , rho:   0.00 , compmagdiff: 0.00 , notes: ""  , hdnotes: "" , hdmoent: ""  , hdmcoment: "" },$ 
{ name: "HD171967"       , baynum: ""              , hrnum: "HR6991"        , flamnum: ""                 , saonum: "SAO229172"   , ppmnum: "PPM324302"   , varname: "V*V718 CrA"  , hipnum: "HIP91494"    , starname: ""                , alphah: 18.0 , alpham: 39.0 , alphas: 35.16 , plusmin:  -1 , deltag:  43.0 , deltam: 11.0 , deltas:  9.2  , orig: "iras"	   , spectype: "M2III"       , parallax:     3.99  , parerr:	 0.73  , promot: " PROMOT  -0.05  -0.05" , vmag:   5.45  , hmag:   1.07  , irastwelvemu:    15.52  , qual:   3  , ftwelve:    0.00  , ones:  0.0  , diam:   3.82  , errdiam:  0.17  , simrem: "Variable Star	   " , hvartype: "P"	  , multflag: ""  , compid: ""      , theta:	 0 , rho:   0.00 , compmagdiff: 0.00 , notes: ""  , hdnotes: "" , hdmoent: ""  , hdmcoment: "" },$ 
{ name: "HD172768"       , baynum: ""              , hrnum: ""              , flamnum: ""                 , saonum: "SAO142518"   , ppmnum: "PPM202046"   , varname: "V*V453 Sct"  , hipnum: "HIP91728"    , starname: ""                , alphah: 18.0 , alpham: 42.0 , alphas:  17.9 , plusmin:  -1 , deltag:   7.0 , deltam: 20.0 , deltas: 14.4  , orig: "msx"	   , spectype: "M0"	     , parallax:     1.45  , parerr:	 0.87  , promot: " PROMOT   0.03      0" , vmag:   6.99  , hmag:   1.87  , irastwelvemu:     0.00  , qual:   0  , ftwelve:    8.24  , ones:  3.3  , diam:   2.72  , errdiam:  1.52  , simrem: "Variable Star of irregular type   " , hvartype: "U"	, multflag: "C"  , compid: "AB"      , theta:  125  , rho:  0.13    , compmagdiff:  0.53  , notes: "D" , hdnotes: "Ambiguous double-star solution. An alternative solution for AB gives: magnitude diff. = 3.61, pos.angle = 304 deg, separation = 3.40 arcsec." , hdmoent: "Y" , hdmcoment: "" },$ 
{ name: "HD171759"       , baynum: "zet Pav"       , hrnum: "HR6982"        , flamnum: ""                 , saonum: "SAO257620"   , ppmnum: "PPM373937"   , varname: ""            , hipnum: "HIP91792"    , starname: ""                , alphah: 18.0 , alpham: 43.0 , alphas:  2.14 , plusmin:  -1 , deltag:  71.0 , deltam: 25.0 , deltas: 41.2  , orig: "iras"	   , spectype: "K0III"       , parallax:    15.55  , parerr:	 0.55  , promot: " PROMOT   0.01  -0.16" , vmag:   4.01  , hmag:    1.4  , irastwelvemu:     9.45  , qual:   3  , ftwelve:    0.00  , ones:  0.0  , diam:   2.57  , errdiam:  0.07  , simrem: "Eclipsing binary      " , hvartype: "C"      , multflag: ""  , compid: ""      , theta:     0 , rho:   0.00 , compmagdiff: 0.00 , notes: ""  , hdnotes: "" , hdmoent: ""  , hdmcoment: "" },$ 
{ name: "HD173074"       , baynum: ""              , hrnum: ""              , flamnum: ""                 , saonum: "SAO142553"   , ppmnum: "PPM180415"   , varname: ""            , hipnum: "HIP91855"    , starname: ""                , alphah: 18.0 , alpham: 43.0 , alphas: 37.37 , plusmin:  -1 , deltag:   1.0 , deltam: 33.0 , deltas: 32.5  , orig: "iras"	   , spectype: "M..."	     , parallax:     3.76  , parerr:	 1.08  , promot: " PROMOT   0.01  -0.01" , vmag:   7.22  , hmag:   2.16  , irastwelvemu:     6.32  , qual:   3  , ftwelve:    5.93  , ones:  3.7  , diam:   2.45  , errdiam:  0.47  , simrem: "Star	    " , hvartype: "U"	   , multflag: ""  , compid: ""      , theta:	  0 , rho:   0.00 , compmagdiff: 0.00 , notes: ""  , hdnotes: "" , hdmoent: ""  , hdmcoment: "" },$ 
{ name: "HD173460"       , baynum: ""              , hrnum: "HR7046"        , flamnum: "FL 28 Sgr"        , saonum: "SAO187255"   , ppmnum: "PPM268874"   , varname: ""            , hipnum: "HIP92111"    , starname: ""                , alphah: 18.0 , alpham: 46.0 , alphas: 20.61 , plusmin:  -1 , deltag:  22.0 , deltam: 23.0 , deltas: 31.8  , orig: "iras"	   , spectype: "K5III"       , parallax:     2.55  , parerr:	 1.03  , promot: " PROMOT   0.03      0" , vmag:   5.39  , hmag:   1.67  , irastwelvemu:     8.66  , qual:   3  , ftwelve:    0.00  , ones:  0.0  , diam:   2.66  , errdiam:  0.59  , simrem: "Eclipsing binary      " , hvartype: "M"      , multflag: ""  , compid: ""      , theta:     0 , rho:   0.00 , compmagdiff: 0.00 , notes: ""  , hdnotes: "" , hdmoent: ""  , hdmcoment: "" },$ 
{ name: "HD173484"       , baynum: ""              , hrnum: ""              , flamnum: ""                 , saonum: "SAO187263"   , ppmnum: "PPM268886"   , varname: "V*V4406 Sgr" , hipnum: "HIP92142"    , starname: ""                , alphah: 18.0 , alpham: 46.0 , alphas: 47.24 , plusmin:  -1 , deltag:  29.0 , deltam: 37.0 , deltas: 53.9  , orig: "iras"	   , spectype: "M4III"       , parallax:     4.61  , parerr:	 1.08  , promot: " PROMOT  -0.02  -0.03" , vmag:   6.92  , hmag:   1.42  , irastwelvemu:    13.17  , qual:   3  , ftwelve:    0.00  , ones:  0.0  , diam:   3.35  , errdiam:  0.31  , simrem: "Variable of BY Dra type     " , hvartype: "U"	  , multflag: ""  , compid: ""      , theta:	 0 , rho:   0.00 , compmagdiff: 0.00 , notes: "P" , hdnotes: "" , hdmoent: ""  , hdmcoment: "" },$ 
{ name: "HD173764"       , baynum: "bet Sct"       , hrnum: "HR7063"        , flamnum: ""                 , saonum: "SAO142618"   , ppmnum: "PPM202135"   , varname: ""            , hipnum: "HIP92175"    , starname: ""                , alphah: 18.0 , alpham: 47.0 , alphas: 10.47 , plusmin:  -1 , deltag:   4.0 , deltam: 44.0 , deltas: 52.3  , orig: "msx"	   , spectype: "G4IIa"       , parallax:     4.73  , parerr:	 0.79  , promot: " PROMOT  -0.01  -0.02" , vmag:   4.23  , hmag:   1.81  , irastwelvemu:     0.00  , qual:   0  , ftwelve:    6.13  , ones:  3.7  , diam:    2.1  , errdiam:  0.58  , simrem: "Spectroscopic binary	  " , hvartype: "C"	 , multflag: "O"  , compid: ""      , theta:	 0 , rho:   0.00 , compmagdiff: 0.00 , notes: ""  , hdnotes: "" , hdmoent: ""  , hdmcoment: "Y" },$
{ name: "HD174116"       , baynum: ""              , hrnum: "HR7078"        , flamnum: "FL 29 Sgr"        , saonum: "SAO187324"   , ppmnum: "PPM268946"   , varname: ""            , hipnum: "HIP92390"    , starname: ""                , alphah: 18.0 , alpham: 49.0 , alphas: 40.11 , plusmin:  -1 , deltag:  20.0 , deltam: 19.0 , deltas: 28.8  , orig: "iras"	   , spectype: "K2III"       , parallax:     4.35  , parerr:	 0.92  , promot: " PROMOT      0   0.04" , vmag:   5.23  , hmag:   1.99  , irastwelvemu:     6.06  , qual:   3  , ftwelve:    0.00  , ones:  0.0  , diam:   2.12  , errdiam:  0.42  , simrem: "Variable Star	   " , hvartype: ""	 , multflag: ""  , compid: ""	   , theta:	0 , rho:   0.00 , compmagdiff: 0.00 , notes: ""  , hdnotes: "" , hdmoent: ""  , hdmcoment: "" },$ 
{ name: "HD174796"       , baynum: ""              , hrnum: ""              , flamnum: ""                 , saonum: "SAO142731"   , ppmnum: "PPM202244"   , varname: ""            , hipnum: "HIP92628"    , starname: ""                , alphah: 18.0 , alpham: 52.0 , alphas:  25.7 , plusmin:  -1 , deltag:   3.0 , deltam: 43.0 , deltas: 32.3  , orig: "iras"	   , spectype: "K5"	     , parallax:     3.78  , parerr:	 0.93  , promot: " PROMOT  -0.01  -0.02" , vmag:   7.17  , hmag:   2.37  , irastwelvemu:      5.0  , qual:   3  , ftwelve:    0.00  , ones:  0.0  , diam:    2.1  , errdiam:  1.77  , simrem: "Star	    " , hvartype: "U"	   , multflag: ""  , compid: ""      , theta:	  0 , rho:   0.00 , compmagdiff: 0.00 , notes: ""  , hdnotes: "" , hdmoent: ""  , hdmcoment: "" },$ 
{ name: "HD175100"       , baynum: ""              , hrnum: ""              , flamnum: ""                 , saonum: "SAO124013"   , ppmnum: "PPM166751"   , varname: "V*V1435 Aql" , hipnum: "HIP92715"    , starname: ""                , alphah: 18.0 , alpham: 53.0 , alphas:  29.9 , plusmin:  +1 , deltag:   9.0 , deltam: 39.0 , deltas: 30.8  , orig: "msx"	   , spectype: "M..."	     , parallax:     1.21  , parerr:	 1.06  , promot: " PROMOT   0.01  -0.01" , vmag:   7.46  , hmag:   2.06  , irastwelvemu:     0.00  , qual:   0  , ftwelve:    6.71  , ones:  3.8  , diam:   2.31  , errdiam:  2.81  , simrem: "Variable Star of irregular type   " , hvartype: "U"	, multflag: ""  , compid: ""	  , theta:     0 , rho:   0.00 , compmagdiff: 0.00 , notes: ""  , hdnotes: "" , hdmoent: ""  , hdmcoment: "" },$ 
{ name: "HD174974"       , baynum: "nu.01 Sgr"     , hrnum: "HR7116"        , flamnum: "FL 32 Sgr"        , saonum: "SAO187426"   , ppmnum: "PPM269055"   , varname: ""            , hipnum: "HIP92761"    , starname: ""                , alphah: 18.0 , alpham: 54.0 , alphas: 10.18 , plusmin:  -1 , deltag:  22.0 , deltam: 44.0 , deltas: 41.4  , orig: "iras"	   , spectype: "K1II"	     , parallax:     1.76  , parerr:	 0.85  , promot: " PROMOT   0.01  -0.01" , vmag:   4.86  , hmag:   1.97  , irastwelvemu:      6.3  , qual:   3  , ftwelve:    0.00  , ones:  0.0  , diam:   2.18  , errdiam:  0.66  , simrem: "Double or multiple star     " , hvartype: "M"	  , multflag: ""  , compid: ""      , theta:	 0 , rho:   0.00 , compmagdiff: 0.00 , notes: ""  , hdnotes: "" , hdmoent: ""  , hdmcoment: "" },$ 
{ name: "HD175309"       , baynum: ""              , hrnum: ""              , flamnum: ""                 , saonum: "SAO104242"   , ppmnum: "PPM135447"   , varname: "V*V913 Aql"  , hipnum: "HIP92787"    , starname: ""                , alphah: 18.0 , alpham: 54.0 , alphas: 28.96 , plusmin:  +1 , deltag:  10.0 , deltam: 37.0 , deltas: 57.0  , orig: "msx"	   , spectype: "M5"	     , parallax:     0.95  , parerr:	 0.98  , promot: " PROMOT      0   0.01" , vmag:   7.44  , hmag:   1.13  , irastwelvemu:     0.00  , qual:   0  , ftwelve:   19.72  , ones:  3.1  , diam:   3.38  , errdiam:  1.14  , simrem: "Variable of BY Dra type     " , hvartype: "U"	  , multflag: ""  , compid: ""      , theta:	 0 , rho:   0.00 , compmagdiff: 0.00 , notes: ""  , hdnotes: "" , hdmoent: ""  , hdmcoment: "" },$ 
{ name: "HD175775"       , baynum: "ksi02 Sgr"     , hrnum: "HR7150"        , flamnum: "FL 37 Sgr"        , saonum: "SAO187504"   , ppmnum: "PPM269132"   , varname: ""            , hipnum: "HIP93085"    , starname: ""                , alphah: 18.0 , alpham: 57.0 , alphas:  43.8 , plusmin:  -1 , deltag:  21.0 , deltam:  6.0 , deltas: 24.0  , orig: "iras"	   , spectype: "G8/K0II/III" , parallax:     8.76  , parerr:	 0.99  , promot: " PROMOT   0.04  -0.01" , vmag:   3.53  , hmag:   1.01  , irastwelvemu:    13.74  , qual:   3  , ftwelve:    0.00  , ones:  0.0  , diam:   3.26  , errdiam:  0.23  , simrem: "Star	    " , hvartype: ""	  , multflag: "G"  , compid: ""      , theta:	  0 , rho:   0.00 , compmagdiff: 0.00 , notes: ""  , hdnotes: "" , hdmoent: ""  , hdmcoment: "" },$ 
{ name: "HD175329"       , baynum: "ome Pav"       , hrnum: "HR7127"        , flamnum: ""                 , saonum: "SAO254423"   , ppmnum: "PPM363691"   , varname: ""            , hipnum: "HIP93163"    , starname: ""                , alphah: 18.0 , alpham: 58.0 , alphas: 36.45 , plusmin:  -1 , deltag:  60.0 , deltam: 12.0 , deltas:  2.0  , orig: "iras"	   , spectype: "K2IIICNvar." , parallax:     6.32  , parerr:	 0.76  , promot: " PROMOT  -0.13   0.03" , vmag:   5.14  , hmag:   2.04  , irastwelvemu:     5.82  , qual:   3  , ftwelve:    0.00  , ones:  0.0  , diam:   2.08  , errdiam:  0.14  , simrem: "Star	    " , hvartype: "U"	   , multflag: ""  , compid: ""      , theta:	  0 , rho:   0.00 , compmagdiff: 0.00 , notes: ""  , hdnotes: "" , hdmoent: ""  , hdmcoment: "" },$ 
{ name: "HD176124"       , baynum: ""              , hrnum: ""              , flamnum: ""                 , saonum: "SAO162049"   , ppmnum: "PPM235314"   , varname: ""            , hipnum: "HIP93224"    , starname: ""                , alphah: 18.0 , alpham: 59.0 , alphas: 23.82 , plusmin:  -1 , deltag:  19.0 , deltam: 16.0 , deltas: 45.7  , orig: "iras"	   , spectype: "M3III"       , parallax:      1.1  , parerr:	 0.91  , promot: " PROMOT   0.02   0.01" , vmag:    6.6  , hmag:    1.2  , irastwelvemu:     14.3  , qual:   3  , ftwelve:    0.00  , ones:  0.0  , diam:   3.61  , errdiam:  0.66  , simrem: "Star	    " , hvartype: "U"	   , multflag: ""  , compid: ""      , theta:	  0 , rho:   0.00 , compmagdiff: 0.00 , notes: ""  , hdnotes: "" , hdmoent: ""  , hdmcoment: "" },$ 
{ name: "HD176411"       , baynum: "eps Aql"       , hrnum: "HR7176"        , flamnum: "FL 13 Aql"        , saonum: "SAO104318"   , ppmnum: "PPM135586"   , varname: ""            , hipnum: "HIP93244"    , starname: ""                , alphah: 18.0 , alpham: 59.0 , alphas:  37.2 , plusmin:  +1 , deltag:  15.0 , deltam:  4.0 , deltas:  5.0  , orig: "iras"	   , spectype: "K1III"       , parallax:    21.22  , parerr:	 0.77  , promot: " PROMOT  -0.05  -0.07" , vmag:   4.03  , hmag:   0.00  , irastwelvemu:     7.43  , qual:   3  , ftwelve:    0.00  , ones:  0.0  , diam:   2.14  , errdiam:  0.07  , simrem: "Eclipsing binary      " , hvartype: ""	   , multflag: "O"  , compid: ""      , theta:     0 , rho:   0.00 , compmagdiff: 0.00 , notes: ""  , hdnotes: "" , hdmoent: ""  , hdmcoment: "Y" },$
{ name: "HD176541"       , baynum: ""              , hrnum: "HR7183"        , flamnum: ""                 , saonum: "SAO86675"    , ppmnum: "PPM269274"   , varname: "V*V387Vul"   , hipnum: "HIP93270"    , starname: ""                , alphah: 18.0 , alpham: 59.0 , alphas: 58.11 , plusmin:  +1 , deltag:  22.0 , deltam: 48.0 , deltas: 52.2  , orig: "iras"	   , spectype: "M3III"       , parallax:     4.31  , parerr:	 0.67  , promot: " PROMOT  -0.02   0.01" , vmag:   6.35  , hmag:   1.14  , irastwelvemu:     15.6  , qual:   3  , ftwelve:    0.00  , ones:  0.0  , diam:    3.5  , errdiam:  0.22  , simrem: "Variable Star of irregular type   " , hvartype: "U"	, multflag: ""  , compid: ""	  , theta:     0 , rho:   0.00 , compmagdiff: 0.00 , notes: ""  , hdnotes: "" , hdmoent: ""  , hdmcoment: "" },$ 
{ name: "HD176670"       , baynum: "lam Lyr"       , hrnum: "HR7192"        , flamnum: "FL 15 Lyr"        , saonum: "SAO67682"    , ppmnum: "PPM82162"    , varname: ""            , hipnum: "HIP93279"    , starname: ""                , alphah: 19.0 , alpham:  0.0 , alphas:  0.83 , plusmin:  +1 , deltag:  32.0 , deltam:  8.0 , deltas: 43.9  , orig: "iras"	   , spectype: "K2.5III"     , parallax:     2.12  , parerr:	 0.55  , promot: " PROMOT   0.01   0.01" , vmag:   4.95  , hmag:   0.00  , irastwelvemu:     6.85  , qual:   3  , ftwelve:    0.00  , ones:  0.0  , diam:   2.82  , errdiam:  0.19  , simrem: "Variable Star	   " , hvartype: ""	 , multflag: ""  , compid: ""	   , theta:	0 , rho:   0.00 , compmagdiff: 0.00 , notes: ""  , hdnotes: "" , hdmoent: ""  , hdmcoment: "" },$ 
{ name: "HD176678"       , baynum: "i Aql"         , hrnum: "HR7193"        , flamnum: "FL 12 Aql"        , saonum: "SAO142931"   , ppmnum: "PPM202441"   , varname: ""            , hipnum: "HIP93429"    , starname: ""                , alphah: 19.0 , alpham:  1.0 , alphas: 40.83 , plusmin:  -1 , deltag:   5.0 , deltam: 44.0 , deltas: 20.8  , orig: "iras"	   , spectype: "K1III"       , parallax:    21.95  , parerr:	 0.92  , promot: " PROMOT  -0.02  -0.03" , vmag:   4.03  , hmag:   1.59  , irastwelvemu:     7.61  , qual:   3  , ftwelve:    0.00  , ones:  0.0  , diam:   2.35  , errdiam:  0.13  , simrem: "Variable Star	   " , hvartype: "C"	  , multflag: ""  , compid: ""      , theta:	 0 , rho:   0.00 , compmagdiff: 0.00 , notes: ""  , hdnotes: "" , hdmoent: ""  , hdmcoment: "" },$ 
{ name: "HD177241"       , baynum: "omi Sgr"       , hrnum: "HR7217"        , flamnum: "FL 39 Sgr"        , saonum: "SAO187643"   , ppmnum: "PPM269274"   , varname: ""            , hipnum: "HIP93683"    , starname: ""                , alphah: 19.0 , alpham:  4.0 , alphas: 40.98 , plusmin:  -1 , deltag:  21.0 , deltam: 44.0 , deltas: 29.4  , orig: "iras"	   , spectype: "K0III"       , parallax:    23.49  , parerr:	 0.78  , promot: " PROMOT  -0.08  -0.06" , vmag:   3.77  , hmag:   1.45  , irastwelvemu:      8.1  , qual:   3  , ftwelve:    0.00  , ones:  0.0  , diam:   2.35  , errdiam:  0.09  , simrem: "Eclipsing binary      " , hvartype: "C"      , multflag: ""  , compid: ""      , theta:     0 , rho:   0.00 , compmagdiff: 0.00 , notes: ""  , hdnotes: "" , hdmoent: ""  , hdmcoment: "" },$ 
{ name: "HD177494"       , baynum: ""              , hrnum: ""              , flamnum: ""                 , saonum: "SAO124235"   , ppmnum: "PPM167118"   , varname: ""            , hipnum: ""            , starname: ""                , alphah: 19.0 , alpham:  4.0 , alphas: 46.92 , plusmin:  +1 , deltag:   2.0 , deltam: 59.0 , deltas:  2.8  , orig: "msx"	   , spectype: "M..."	     , parallax:     0.00  , parerr:	 0.00  , promot: " PROMOT      0  -0.01" , vmag:   8.67  , hmag:   2.31  , irastwelvemu:     0.00  , qual:   0  , ftwelve:    5.81  , ones:  3.7  , diam:   2.23  , errdiam:  0.07  , simrem: "Variable Star	   " , hvartype: ""	 , multflag: ""  , compid: ""	   , theta:	0 , rho:   0.00 , compmagdiff: 0.00 , notes: ""  , hdnotes: "" , hdmoent: ""  , hdmcoment: "" },$ 
{ name: "HD177716"       , baynum: "tau Sgr"       , hrnum: "HR7234"        , flamnum: "FL 40 Sgr"        , saonum: "SAO187683"   , ppmnum: "PPM269319"   , varname: ""            , hipnum: "HIP93864"    , starname: ""                , alphah: 19.0 , alpham:  6.0 , alphas: 56.41 , plusmin:  -1 , deltag:  27.0 , deltam: 40.0 , deltas: 13.5  , orig: "iras"	   , spectype: "K1IIIb"      , parallax:    27.09  , parerr:	 1.48  , promot: " PROMOT  -0.05  -0.25" , vmag:   3.32  , hmag:   0.69  , irastwelvemu:    17.99  , qual:   3  , ftwelve:    0.00  , ones:  0.0  , diam:   3.72  , errdiam:  0.07  , simrem: "High proper-motion Star     " , hvartype: ""	 , multflag: "O"  , compid: ""      , theta:	 0 , rho:   0.00 , compmagdiff: 0.00 , notes: ""  , hdnotes: "" , hdmoent: ""  , hdmcoment: "Y" },$
{ name: "HD178131"       , baynum: ""              , hrnum: ""              , flamnum: ""                 , saonum: "SAO143042"   , ppmnum: "PPM180561"   , varname: ""            , hipnum: "HIP93919"    , starname: ""                , alphah: 19.0 , alpham:  7.0 , alphas: 26.39 , plusmin:  -1 , deltag:   1.0 , deltam:  7.0 , deltas: 32.3  , orig: "msx"	   , spectype: "M..."	     , parallax:      4.6  , parerr:	 0.97  , promot: " PROMOT      0  -0.04" , vmag:   7.62  , hmag:   2.14  , irastwelvemu:     0.00  , qual:   0  , ftwelve:    5.92  , ones:  4.1  , diam:   2.41  , errdiam:  0.38  , simrem: "Variable Star	   " , hvartype: "U"	  , multflag: ""  , compid: ""      , theta:	 0 , rho:   0.00 , compmagdiff: 0.00 , notes: ""  , hdnotes: "" , hdmoent: ""  , hdmcoment: "" },$ 
{ name: "HD178690"       , baynum: ""              , hrnum: ""              , flamnum: ""                 , saonum: "SAO86859"    , ppmnum: "PPM108469"   , varname: ""            , hipnum: "HIP94030"    , starname: ""                , alphah: 19.0 , alpham:  8.0 , alphas:  37.7 , plusmin:  +1 , deltag:  24.0 , deltam: 10.0 , deltas: 45.5  , orig: "iras"	   , spectype: "K2"	     , parallax:     0.89  , parerr:	 0.75  , promot: " PROMOT   0.01      0" , vmag:   6.73  , hmag:   2.29  , irastwelvemu:     5.45  , qual:   3  , ftwelve:    0.00  , ones:  0.0  , diam:   2.22  , errdiam:  1.74  , simrem: "Carbon Star	 " , hvartype: "U"	, multflag: ""  , compid: ""	  , theta:     0 , rho:   0.00 , compmagdiff: 0.00 , notes: ""  , hdnotes: "" , hdmoent: ""  , hdmcoment: "" },$ 
{ name: "HD178524"       , baynum: "pi. Sgr"       , hrnum: "HR7264"        , flamnum: "FL 41 Sgr"        , saonum: "SAO187756"   , ppmnum: "PPM269391"   , varname: ""            , hipnum: "HIP94141"    , starname: ""                , alphah: 19.0 , alpham:  9.0 , alphas: 45.83 , plusmin:  -1 , deltag:  21.0 , deltam:  1.0 , deltas: 25.0  , orig: "iras"	   , spectype: "F2II/III"    , parallax:     7.41  , parerr:	 0.69  , promot: " PROMOT      0  -0.04" , vmag:   2.89  , hmag:   1.88  , irastwelvemu:     5.63  , qual:   3  , ftwelve:    0.00  , ones:  0.0  , diam:   1.58  , errdiam:  0.27  , simrem: "Double or multiple star     " , hvartype: ""	 , multflag: ""  , compid: ""	   , theta:	0 , rho:   0.00 , compmagdiff: 0.00 , notes: ""  , hdnotes: "" , hdmoent: ""  , hdmcoment: "" },$ 
{ name: "HD178345"       , baynum: "bet CrA"       , hrnum: "HR7259"        , flamnum: ""                 , saonum: "SAO211005"   , ppmnum: "PPM298639"   , varname: ""            , hipnum: "HIP94160"    , starname: ""                , alphah: 19.0 , alpham: 10.0 , alphas:  1.76 , plusmin:  -1 , deltag:  39.0 , deltam: 20.0 , deltas: 26.9  , orig: "iras"	   , spectype: "K0II"	     , parallax:     6.42  , parerr:	  0.9  , promot: " PROMOT      0  -0.04" , vmag:   4.12  , hmag:   1.58  , irastwelvemu:     8.62  , qual:   3  , ftwelve:    0.00  , ones:  0.0  , diam:   2.46  , errdiam:  0.13  , simrem: "Star	    " , hvartype: ""	  , multflag: ""  , compid: ""      , theta:	 0 , rho:   0.00 , compmagdiff: 0.00 , notes: ""  , hdnotes: "" , hdmoent: ""  , hdmcoment: "" },$ 
{ name: "HD179820"       , baynum: ""              , hrnum: ""              , flamnum: ""                 , saonum: "SAO124413"   , ppmnum: "PPM167430"   , varname: "V*V842 Aql"  , hipnum: ""            , starname: ""                , alphah: 19.0 , alpham: 13.0 , alphas: 54.43 , plusmin:  +1 , deltag:   2.0 , deltam: 37.0 , deltas: 30.8  , orig: "msx"	   , spectype: "M..."	     , parallax:     0.00  , parerr:	 0.00  , promot: " PROMOT  -0.01  -0.01" , vmag:   8.98  , hmag:   1.55  , irastwelvemu:     0.00  , qual:   0  , ftwelve:   14.00  , ones:  3.1  , diam:   3.17  , errdiam:  0.07  , simrem: "Pulsating variable Star     " , hvartype: ""	 , multflag: ""  , compid: ""	   , theta:	0 , rho:   0.00 , compmagdiff: 0.00 , notes: ""  , hdnotes: "" , hdmoent: ""  , hdmcoment: "" },$ 
{ name: "HD179987"       , baynum: ""              , hrnum: ""              , flamnum: ""                 , saonum: "SAO104631"   , ppmnum: "PPM135998"   , varname: ""            , hipnum: "HIP94524"    , starname: ""                , alphah: 19.0 , alpham: 14.0 , alphas: 18.27 , plusmin:  +1 , deltag:  11.0 , deltam: 42.0 , deltas: 46.0  , orig: "iras"	   , spectype: "K2"	     , parallax:     2.12  , parerr:	  0.8  , promot: " PROMOT      0      0" , vmag:   6.82  , hmag:    2.9  , irastwelvemu:     5.21  , qual:   1  , ftwelve:    0.00  , ones:  0.0  , diam:   1.43  , errdiam:  1.83  , simrem: "Star	    " , hvartype: ""	  , multflag: ""  , compid: ""      , theta:	 0 , rho:   0.00 , compmagdiff: 0.00 , notes: ""  , hdnotes: "" , hdmoent: ""  , hdmcoment: "" },$ 
{ name: "HD180377"       , baynum: ""              , hrnum: ""              , flamnum: ""                 , saonum: "SAO104662"   , ppmnum: "PPM136030"   , varname: ""            , hipnum: "HIP94646"    , starname: ""                , alphah: 19.0 , alpham: 15.0 , alphas: 33.36 , plusmin:  +1 , deltag:  18.0 , deltam: 30.0 , deltas: 58.9  , orig: "msx"	   , spectype: "M2III"       , parallax:     3.04  , parerr:	 0.79  , promot: " PROMOT  -0.01      0" , vmag:   6.48  , hmag:   2.04  , irastwelvemu:     0.00  , qual:   0  , ftwelve:    6.18  , ones:  3.8  , diam:   2.43  , errdiam:  0.31  , simrem: "Eclipsing binary      " , hvartype: "U"      , multflag: ""  , compid: ""      , theta:     0 , rho:   0.00 , compmagdiff: 0.00 , notes: ""  , hdnotes: "" , hdmoent: ""  , hdmcoment: "" },$ 
{ name: "HD180810"       , baynum: ""              , hrnum: ""              , flamnum: ""                 , saonum: "SAO68067"    , ppmnum: "PPM82623"    , varname: ""            , hipnum: ""            , starname: ""                , alphah: 19.0 , alpham: 16.0 , alphas:  43.5 , plusmin:  +1 , deltag:  31.0 , deltam:  8.0 , deltas: 22.2  , orig: "iras"	   , spectype: "M..."	     , parallax:     0.00  , parerr:	 0.00  , promot: " PROMOT  -0.02  -0.02" , vmag:   7.41  , hmag:   0.00  , irastwelvemu:     6.61  , qual:   3  , ftwelve:    0.00  , ones:  0.0  , diam:    2.4  , errdiam:  0.07  , simrem: "Star	    " , hvartype: ""	  , multflag: ""  , compid: ""      , theta:	 0 , rho:   0.00 , compmagdiff: 0.00 , notes: ""  , hdnotes: "" , hdmoent: ""  , hdmcoment: "" },$ 
{ name: "HD181070"       , baynum: ""              , hrnum: ""              , flamnum: ""                 , saonum: "SAO104704"   , ppmnum: "PPM136088"   , varname: ""            , hipnum: "HIP94894"    , starname: ""                , alphah: 19.0 , alpham: 18.0 , alphas: 30.89 , plusmin:  +1 , deltag:  15.0 , deltam: 32.0 , deltas: 32.0  , orig: "msx"	   , spectype: "M..."	     , parallax:     0.00  , parerr:	 0.00  , promot: " PROMOT      0      0" , vmag:   9.26  , hmag:   2.47  , irastwelvemu:     0.00  , qual:   0  , ftwelve:     5.2  , ones:  3.9  , diam:   2.09  , errdiam:  0.07  , simrem: "Star	    " , hvartype: ""	  , multflag: ""  , compid: ""      , theta:	 0 , rho:   0.00 , compmagdiff: 0.00 , notes: ""  , hdnotes: "" , hdmoent: ""  , hdmcoment: "" },$ 
{ name: "HD181410"       , baynum: ""              , hrnum: ""              , flamnum: ""                 , saonum: "SAO87068"    , ppmnum: "PPM108770"   , varname: "V*V389Vul"   , hipnum: "HIP94969"    , starname: ""                , alphah: 19.0 , alpham: 19.0 , alphas: 31.89 , plusmin:  +1 , deltag:  22.0 , deltam: 34.0 , deltas: 14.7  , orig: "msx"	   , spectype: "M3"	     , parallax:     3.69  , parerr:	  0.8  , promot: " PROMOT   0.01  -0.01" , vmag:   7.09  , hmag:   0.73  , irastwelvemu:     0.00  , qual:   0  , ftwelve:   25.64  , ones:  3.0  , diam:   4.72  , errdiam:  0.25  , simrem: "Variable of BY Dra type     " , hvartype: "U"	  , multflag: ""  , compid: ""      , theta:	 0 , rho:   0.00 , compmagdiff: 0.00 , notes: "P" , hdnotes: "" , hdmoent: ""  , hdmcoment: "" },$ 
{ name: "HD181925"       , baynum: ""              , hrnum: "HR7350"        , flamnum: ""                 , saonum: "SAO229660"   , ppmnum: "PPM325068"   , varname: ""            , hipnum: "HIP95396"    , starname: ""                , alphah: 19.0 , alpham: 24.0 , alphas: 21.48 , plusmin:  -1 , deltag:  43.0 , deltam: 43.0 , deltas: 19.4  , orig: "iras"	   , spectype: "M1.5III"     , parallax:     5.63  , parerr:	 0.86  , promot: " PROMOT   0.02  -0.04" , vmag:   6.16  , hmag:   2.12  , irastwelvemu:     5.47  , qual:   3  , ftwelve:    0.00  , ones:  0.0  , diam:   2.11  , errdiam:  0.14  , simrem: "Star	    " , hvartype: "M"	   , multflag: ""  , compid: ""      , theta:	  0 , rho:   0.00 , compmagdiff: 0.00 , notes: ""  , hdnotes: "" , hdmoent: ""  , hdmcoment: "" },$ 
{ name: "HD182429"       , baynum: ""              , hrnum: ""              , flamnum: ""                 , saonum: "SAO162590"   , ppmnum: "PPM235963"   , varname: ""            , hipnum: ""            , starname: ""                , alphah: 19.0 , alpham: 25.0 , alphas:   8.1 , plusmin:  -1 , deltag:  13.0 , deltam: 26.0 , deltas: 20.6  , orig: "iras"	   , spectype: "M2III"       , parallax:     0.00  , parerr:	 0.00  , promot: " PROMOT   0.01  -0.01" , vmag:   7.68  , hmag:   2.07  , irastwelvemu:     6.87  , qual:   3  , ftwelve:    0.00  , ones:  0.0  , diam:   2.48  , errdiam:  0.07  , simrem: "Star	    " , hvartype: ""	  , multflag: ""  , compid: ""      , theta:	 0 , rho:   0.00 , compmagdiff: 0.00 , notes: ""  , hdnotes: "" , hdmoent: ""  , hdmcoment: "" },$ 
{ name: "HD183439"       , baynum: "alf Vul"       , hrnum: "HR7405"        , flamnum: "FL 6 Vul"         , saonum: "SAO87261"    , ppmnum: "PPM109083"   , varname: ""            , hipnum: "HIP95771"    , starname: ""                , alphah: 19.0 , alpham: 28.0 , alphas: 42.33 , plusmin:  +1 , deltag:  24.0 , deltam: 39.0 , deltas: 53.7  , orig: "iras"	   , spectype: "M0III"       , parallax:     11.0  , parerr:	 0.68  , promot: " PROMOT  -0.13   -0.1" , vmag:   4.45  , hmag:   0.00  , irastwelvemu:    20.27  , qual:   3  , ftwelve:   19.85  , ones:  3.1  , diam:   3.76  , errdiam:  0.09  , simrem: "Eclipsing binary      " , hvartype: "U"      , multflag: ""  , compid: ""      , theta:     0 , rho:   0.00 , compmagdiff: 0.00 , notes: ""  , hdnotes: "" , hdmoent: ""  , hdmcoment: "" },$ 
{ name: "HD183912"       , baynum: "bet01 Cyg"     , hrnum: "HR7417"        , flamnum: "FL 6 Cyg"         , saonum: "SAO87301"    , ppmnum: "PPM109139"   , varname: ""            , hipnum: "HIP95947"    , starname: "ALBIREO"         , alphah: 19.0 , alpham: 30.0 , alphas: 43.28 , plusmin:  +1 , deltag:  27.0 , deltam: 57.0 , deltas: 34.9  , orig: "msx"	   , spectype: "K3II+..."    , parallax:     8.46  , parerr:	 0.58  , promot: " PROMOT      0      0" , vmag:   3.09  , hmag:   0.00  , irastwelvemu:     0.00  , qual:   0  , ftwelve:   27.25  , ones:  3.1  , diam:   4.04  , errdiam:  0.14  , simrem: "Double or multiple star     " , hvartype: "D"	  , multflag: "C"  , compid: "AC"      , theta:  152  , rho:  0.39    , compmagdiff:  2.12  , notes: ""  , hdnotes: "" , hdmoent: "Y" , hdmcoment: "" },$ 
{ name: "HD183799"       , baynum: ""              , hrnum: ""              , flamnum: ""                 , saonum: "SAO211345"   , ppmnum: "PPM299094"   , varname: "V*V4419 Sgr" , hipnum: "HIP96111"    , starname: ""                , alphah: 19.0 , alpham: 32.0 , alphas: 28.51 , plusmin:  -1 , deltag:  30.0 , deltam: 52.0 , deltas: 10.1  , orig: "iras"	   , spectype: "M4III"       , parallax:     4.25  , parerr:	 0.98  , promot: " PROMOT   0.04  -0.02" , vmag:   6.67  , hmag:   1.22  , irastwelvemu:    14.91  , qual:   3  , ftwelve:    0.00  , ones:  0.0  , diam:   3.65  , errdiam:  0.28  , simrem: "Variable of BY Dra type     " , hvartype: "U"	  , multflag: ""  , compid: ""      , theta:	 0 , rho:   0.00 , compmagdiff: 0.00 , notes: "P" , hdnotes: "" , hdmoent: ""  , hdmcoment: "" },$ 
{ name: "HD184406"       , baynum: "mu. Aql"       , hrnum: "HR7429"        , flamnum: "FL 38 Aql"        , saonum: "SAO124799"   , ppmnum: "PPM168141"   , varname: ""            , hipnum: "HIP96229"    , starname: ""                , alphah: 19.0 , alpham: 34.0 , alphas:  5.35 , plusmin:  +1 , deltag:   7.0 , deltam: 22.0 , deltas: 44.2  , orig: "iras"	   , spectype: "K3IIIb"      , parallax:     29.5  , parerr:	 0.78  , promot: " PROMOT   0.21  -0.16" , vmag:   4.45  , hmag:   1.89  , irastwelvemu:      6.0  , qual:   3  , ftwelve:    0.00  , ones:  0.0  , diam:   2.16  , errdiam:  0.04  , simrem: "Variable Star	   " , hvartype: "C"	  , multflag: ""  , compid: ""      , theta:	 0 , rho:   0.00 , compmagdiff: 0.00 , notes: ""  , hdnotes: "" , hdmoent: ""  , hdmcoment: "" },$ 
{ name: "HD185622"       , baynum: ""              , hrnum: "HR7475"        , flamnum: ""                 , saonum: "SAO105104"   , ppmnum: "PPM136711"   , varname: "V*V340 Sge"  , hipnum: "HIP96688"    , starname: ""                , alphah: 19.0 , alpham: 39.0 , alphas: 25.34 , plusmin:  +1 , deltag:  16.0 , deltam: 34.0 , deltas: 16.0  , orig: "msx"	   , spectype: "K4Ib"	     , parallax:     1.42  , parerr:	 0.77  , promot: " PROMOT      0  -0.01" , vmag:   6.39  , hmag:   1.79  , irastwelvemu:     0.00  , qual:   0  , ftwelve:    9.11  , ones:  3.3  , diam:   2.84  , errdiam:  1.73  , simrem: "Variable Star	   " , hvartype: "U"	  , multflag: ""  , compid: ""      , theta:	 0 , rho:   0.00 , compmagdiff: 0.00 , notes: ""  , hdnotes: "" , hdmoent: ""  , hdmcoment: "" },$ 
{ name: "HD186860"       , baynum: ""              , hrnum: ""              , flamnum: ""                 , saonum: "SAO68801"    , ppmnum: "PPM83496"    , varname: "V*V1967 Cyg" , hipnum: "HIP97235"    , starname: ""                , alphah: 19.0 , alpham: 45.0 , alphas: 42.91 , plusmin:  +1 , deltag:  30.0 , deltam: 15.0 , deltas: 25.6  , orig: "msx"	   , spectype: "MIII"	     , parallax:     1.81  , parerr:	 0.82  , promot: " PROMOT      0   0.01" , vmag:   7.61  , hmag:   0.00  , irastwelvemu:     0.00  , qual:   0  , ftwelve:    6.77  , ones:  4.1  , diam:   2.32  , errdiam:  0.63  , simrem: "Variable of BY Dra type     " , hvartype: "U"	  , multflag: ""  , compid: ""      , theta:	 0 , rho:   0.00 , compmagdiff: 0.00 , notes: "P" , hdnotes: "" , hdmoent: ""  , hdmcoment: "" },$ 
{ name: "HD187076"       , baynum: "del Sge"       , hrnum: "HR7536"        , flamnum: "FL 7 Sge"         , saonum: "SAO105259"   , ppmnum: "PPM136976"   , varname: ""            , hipnum: "HIP97365"    , starname: ""                , alphah: 19.0 , alpham: 47.0 , alphas: 23.26 , plusmin:  +1 , deltag:  18.0 , deltam: 32.0 , deltas:  3.4  , orig: "msx"	   , spectype: "M2II+..."    , parallax:     7.28  , parerr:	 0.83  , promot: " PROMOT   0.01   0.01" , vmag:   3.82  , hmag:   -0.6  , irastwelvemu:     0.00  , qual:   0  , ftwelve:   76.37  , ones:  3.0  , diam:   8.05  , errdiam:  0.13  , simrem: "Eclipsing binary      " , hvartype: "U"      , multflag: "C"  , compid: "AB"	 , theta:   62  , rho:  0.12	, compmagdiff:  0.64  , notes: ""  , hdnotes: "" , hdmoent: "Y" , hdmcoment: "" },$ 
{ name: "HD187086"       , baynum: ""              , hrnum: "HR7537"        , flamnum: ""                 , saonum: "SAO229887"   , ppmnum: "PPM325524"   , varname: ""            , hipnum: "HIP97598"    , starname: ""                , alphah: 19.0 , alpham: 50.0 , alphas: 14.06 , plusmin:  -1 , deltag:  47.0 , deltam: 33.0 , deltas: 26.6  , orig: "iras"	   , spectype: "M1III"       , parallax:     2.92  , parerr:	 1.01  , promot: " PROMOT  -0.02  -0.01" , vmag:   5.94  , hmag:   1.77  , irastwelvemu:     7.78  , qual:   3  , ftwelve:    0.00  , ones:  0.0  , diam:   2.49  , errdiam:  0.19  , simrem: "Variable Star	   " , hvartype: "U"	  , multflag: "G"  , compid: ""      , theta:	  0 , rho:   0.00 , compmagdiff: 0.00 , notes: ""  , hdnotes: "" , hdmoent: ""  , hdmcoment: "" },$ 
{ name: "HD187642"       , baynum: "alf Aql"       , hrnum: "HR7557"        , flamnum: "FL 53 Aql"        , saonum: "SAO125122"   , ppmnum: "PPM168779"   , varname: ""            , hipnum: "HIP97649"    , starname: "ALTAIR"          , alphah: 19.0 , alpham: 50.0 , alphas: 47.00 , plusmin:  +1 , deltag:   8.0 , deltam: 52.0 , deltas:  6.0  , orig: "iras"	   , spectype: "A7V"	     , parallax:   194.45  , parerr:	 0.94  , promot: " PROMOT   0.54   0.39" , vmag:   0.77  , hmag:   0.23  , irastwelvemu:    23.22  , qual:   3  , ftwelve:    0.00  , ones:  0.0  , diam:   3.22  , errdiam:  0.01  , simrem: "High proper-motion Star     " , hvartype: "P"	  , multflag: ""  , compid: ""      , theta:	 0 , rho:   0.00 , compmagdiff: 0.00 , notes: "P" , hdnotes: "" , hdmoent: ""  , hdmcoment: "" },$ 
{ name: "HD187929"       , baynum: "eta Aql"       , hrnum: "HR7570"        , flamnum: "FL 55 Aql"        , saonum: "SAO125159"   , ppmnum: "PPM168843"   , varname: "V* eta Aql"  , hipnum: "HIP97804"    , starname: ""                , alphah: 19.0 , alpham: 52.0 , alphas: 28.37 , plusmin:  +1 , deltag:   1.0 , deltam:  0.0 , deltas: 20.4  , orig: "iras"	   , spectype: "F6Iab"       , parallax:     2.78  , parerr:	 0.91  , promot: " PROMOT   0.01  -0.01" , vmag:   3.88  , hmag:   2.01  , irastwelvemu:      5.0  , qual:   3  , ftwelve:    0.00  , ones:  0.0  , diam:   1.78  , errdiam:  0.44  , simrem: "Classical Cepheid (delta Cep type)" , hvartype: "P"	, multflag: ""  , compid: ""	  , theta:     0 , rho:   0.00 , compmagdiff: 0.00 , notes: "P" , hdnotes: "" , hdmoent: ""  , hdmcoment: "" },$ 
{ name: "HD188512"       , baynum: "bet Aql"       , hrnum: "HR7602"        , flamnum: "FL 60 Aql"        , saonum: "SAO125235"   , ppmnum: "PPM168947"   , varname: ""            , hipnum: "HIP98036"    , starname: "ALSHAIN"         , alphah: 19.0 , alpham: 55.0 , alphas: 18.79 , plusmin:  +1 , deltag:   6.0 , deltam: 24.0 , deltas: 24.4  , orig: "iras"	   , spectype: "G8IV"	     , parallax:    72.95  , parerr:	 0.83  , promot: " PROMOT   0.04  -0.48" , vmag:   3.71  , hmag:   1.73  , irastwelvemu:      6.3  , qual:   3  , ftwelve:    0.00  , ones:  0.0  , diam:   1.98  , errdiam:  0.02  , simrem: "Variable Star	   " , hvartype: ""	 , multflag: ""  , compid: ""	   , theta:	0 , rho:   0.00 , compmagdiff: 0.00 , notes: ""  , hdnotes: "" , hdmoent: ""  , hdmcoment: "" },$ 
{ name: "HD188947"       , baynum: "eta Cyg"       , hrnum: "HR7615"        , flamnum: "FL 21 Cyg"        , saonum: "SAO69116"    , ppmnum: "PPM83853"    , varname: ""            , hipnum: "HIP98110"    , starname: ""                , alphah: 19.0 , alpham: 56.0 , alphas: 18.37 , plusmin:  +1 , deltag:  35.0 , deltam:  5.0 , deltas:  0.3  , orig: "iras"	   , spectype: "K0III"       , parallax:     23.4  , parerr:	 0.54  , promot: " PROMOT  -0.03  -0.03" , vmag:   3.91  , hmag:   0.00  , irastwelvemu:     7.01  , qual:   3  , ftwelve:    0.00  , ones:  0.0  , diam:   2.16  , errdiam:  0.07  , simrem: "Eclipsing binary      " , hvartype: "C"      , multflag: ""  , compid: ""      , theta:     0 , rho:   0.00 , compmagdiff: 0.00 , notes: ""  , hdnotes: "" , hdmoent: ""  , hdmcoment: "" },$ 
{ name: "HD188603"       , baynum: "b01 Sgr"       , hrnum: "HR7604"        , flamnum: "FL 59 Sgr"        , saonum: "SAO188742"   , ppmnum: "PPM270473"   , varname: ""            , hipnum: "HIP98162"    , starname: ""                , alphah: 19.0 , alpham: 56.0 , alphas: 56.83 , plusmin:  -1 , deltag:  27.0 , deltam: 10.0 , deltas: 11.6  , orig: "iras"	   , spectype: "K2.5IIb"     , parallax:      2.7  , parerr:	 0.75  , promot: " PROMOT   0.01  -0.01" , vmag:   4.54  , hmag:   1.42  , irastwelvemu:    11.45  , qual:   3  , ftwelve:    0.00  , ones:  0.0  , diam:   2.86  , errdiam:  0.29  , simrem: "Star	    " , hvartype: ""	  , multflag: ""  , compid: ""      , theta:	 0 , rho:   0.00 , compmagdiff: 0.00 , notes: ""  , hdnotes: "" , hdmoent: ""  , hdmcoment: "" },$ 
{ name: "HD189319"       , baynum: "gam Sge"       , hrnum: "HR7635"        , flamnum: "FL 12 Sge"        , saonum: "SAO105500"   , ppmnum: "PPM137344"   , varname: ""            , hipnum: "HIP98337"    , starname: ""                , alphah: 19.0 , alpham: 58.0 , alphas: 45.43 , plusmin:  +1 , deltag:  19.0 , deltam: 29.0 , deltas: 31.7  , orig: "iras"	   , spectype: "M0III"       , parallax:     11.9  , parerr:	 0.71  , promot: " PROMOT   0.06   0.02" , vmag:   3.53  , hmag:  -0.03  , irastwelvemu:    41.12  , qual:   3  , ftwelve:    0.00  , ones:  0.0  , diam:   5.55  , errdiam:  0.04  , simrem: "Variable Star	   " , hvartype: "M"	  , multflag: ""  , compid: ""      , theta:	 0 , rho:   0.00 , compmagdiff: 0.00 , notes: ""  , hdnotes: "" , hdmoent: ""  , hdmcoment: "" },$ 
{ name: "HD189577"       , baynum: ""              , hrnum: "HR7645"        , flamnum: "FL 13 Sge"        , saonum: "SAO105522"   , ppmnum: "PPM137383"   , varname: "V*VZ Sge"    , hipnum: "HIP98438"    , starname: ""                , alphah: 20.0 , alpham:  0.0 , alphas:  3.31 , plusmin:  +1 , deltag:  17.0 , deltam: 30.0 , deltas: 59.4  , orig: "iras"	   , spectype: "M4III"       , parallax:     4.37  , parerr:	 0.73  , promot: " PROMOT      0  -0.01" , vmag:   5.41  , hmag:   0.29  , irastwelvemu:    35.33  , qual:   3  , ftwelve:    0.00  , ones:  0.0  , diam:   5.05  , errdiam:  0.11  , simrem: "Variable Star	   " , hvartype: "U"	  , multflag: ""  , compid: ""      , theta:	 0 , rho:   0.00 , compmagdiff: 0.00 , notes: ""  , hdnotes: "" , hdmoent: ""  , hdmcoment: "" },$ 
{ name: "HD189140"       , baynum: ""              , hrnum: "HR7627"        , flamnum: ""                 , saonum: "SAO229977"   , ppmnum: "PPM325720"   , varname: ""            , hipnum: "HIP98485"    , starname: ""                , alphah: 20.0 , alpham:  0.0 , alphas: 26.49 , plusmin:  -1 , deltag:  43.0 , deltam:  2.0 , deltas: 35.9  , orig: "iras"	   , spectype: "M0II-III"    , parallax:     2.96  , parerr:	  0.9  , promot: " PROMOT   0.02   0.02" , vmag:   6.12  , hmag:   2.16  , irastwelvemu:     5.73  , qual:   3  , ftwelve:    0.00  , ones:  0.0  , diam:   2.06  , errdiam:  0.11  , simrem: "Variable Star	   " , hvartype: "U"	  , multflag: ""  , compid: ""      , theta:	 0 , rho:   0.00 , compmagdiff: 0.00 , notes: ""  , hdnotes: "" , hdmoent: ""  , hdmcoment: "" },$ 
{ name: "HD190248"       , baynum: "del Pav"       , hrnum: "HR7665"        , flamnum: ""                 , saonum: "SAO254733"   , ppmnum: "PPM364428"   , varname: ""            , hipnum: "HIP99240"    , starname: ""                , alphah: 20.0 , alpham:  8.0 , alphas: 43.61 , plusmin:  -1 , deltag:  66.0 , deltam: 10.0 , deltas: 55.4  , orig: "iras"	   , spectype: "G7IV"	     , parallax:   163.74  , parerr:	 0.65  , promot: " PROMOT   1.21  -1.13" , vmag:   3.56  , hmag:   1.95  , irastwelvemu:     5.29  , qual:   3  , ftwelve:    0.00  , ones:  0.0  , diam:    1.8  , errdiam:  0.01  , simrem: "Variable Star	   " , hvartype: ""	 , multflag: ""  , compid: ""	   , theta:	0 , rho:   0.00 , compmagdiff: 0.00 , notes: ""  , hdnotes: "" , hdmoent: ""  , hdmcoment: "" },$ 
{ name: "HD192876"       , baynum: "alf01 Cap"     , hrnum: "HR7747"        , flamnum: "FL 5 Cap"         , saonum: "SAO163422"   , ppmnum: "PPM237206"   , varname: ""            , hipnum: "HIP100027"   , starname: ""                , alphah: 20.0 , alpham: 17.0 , alphas: 38.87 , plusmin:  -1 , deltag:  12.0 , deltam: 30.0 , deltas: 29.6  , orig: "iras"	   , spectype: "G3Ib"	     , parallax:     4.75  , parerr:	 0.96  , promot: " PROMOT   0.02      0" , vmag:   4.25  , hmag:   2.04  , irastwelvemu:     6.21  , qual:   3  , ftwelve:    0.00  , ones:  0.0  , diam:   0.89  , errdiam:  0.91  , simrem: "Eclipsing binary      " , hvartype: "C"      , multflag: "C"  , compid: "AE"	 , theta:  355  , rho:  0.65	, compmagdiff:  4.17  , notes: ""  , hdnotes: "" , hdmoent: "Y" , hdmcoment: "" },$ 
{ name: "HD193218"       , baynum: ""              , hrnum: ""              , flamnum: ""                 , saonum: "SAO69775"    , ppmnum: "PPM84649"    , varname: "V*V2114 Cyg" , hipnum: "HIP100051"   , starname: ""                , alphah: 20.0 , alpham: 17.0 , alphas:  54.5 , plusmin:  +1 , deltag:  34.0 , deltam:  5.0 , deltas: 25.2  , orig: "msx"	   , spectype: "M5"	     , parallax:     3.74  , parerr:	 0.72  , promot: " PROMOT      0      0" , vmag:   7.33  , hmag:   1.08  , irastwelvemu:     0.00  , qual:   0  , ftwelve:   18.74  , ones:  3.1  , diam:   3.98  , errdiam:  0.39  , simrem: "Pulsating variable Star     " , hvartype: "U"	  , multflag: ""  , compid: ""      , theta:	 0 , rho:   0.00 , compmagdiff: 0.00 , notes: ""  , hdnotes: "" , hdmoent: ""  , hdmcoment: "" },$ 
{ name: "HD192947"       , baynum: "alf02 Cap"     , hrnum: "HR7754"        , flamnum: "FL 6 Cap"         , saonum: "SAO163427"   , ppmnum: "PPM237217"   , varname: ""            , hipnum: "HIP100064"   , starname: ""                , alphah: 20.0 , alpham: 18.0 , alphas:  3.26 , plusmin:  -1 , deltag:  12.0 , deltam: 32.0 , deltas: 41.5  , orig: "iras"	   , spectype: "G6/G8III"    , parallax:    30.01  , parerr:	 0.91  , promot: " PROMOT   0.06   0.01" , vmag:   3.59  , hmag:   1.52  , irastwelvemu:     7.88  , qual:   3  , ftwelve:    0.00  , ones:  0.0  , diam:   2.27  , errdiam:  0.08  , simrem: "Eclipsing binary      " , hvartype: ""	   , multflag: ""  , compid: ""      , theta:	  0 , rho:   0.00 , compmagdiff: 0.00 , notes: ""  , hdnotes: "" , hdmoent: "Y" , hdmcoment: "" },$ 
{ name: "HD193495"       , baynum: "bet Cap"       , hrnum: "HR7776"        , flamnum: "FL 9 Cap"         , saonum: "SAO163481"   , ppmnum: "PPM237293"   , varname: ""            , hipnum: "HIP100345"   , starname: ""                , alphah: 20.0 , alpham: 21.0 , alphas:  0.68 , plusmin:  -1 , deltag:  14.0 , deltam: 46.0 , deltas: 52.9  , orig: "iras"	   , spectype: "K0II+?"      , parallax:     9.48  , parerr:	 0.95  , promot: " PROMOT   0.04      0" , vmag:   3.08  , hmag:   0.99  , irastwelvemu:    13.59  , qual:   3  , ftwelve:    0.00  , ones:  0.0  , diam:   2.72  , errdiam:  0.22  , simrem: "Spectroscopic binary	  " , hvartype: ""	, multflag: "O"  , compid: ""	   , theta:	0 , rho:   0.00 , compmagdiff: 0.00 , notes: ""  , hdnotes: "" , hdmoent: "Y" , hdmcoment: "Y" },$
{ name: "HD194317"       , baynum: ""              , hrnum: "HR7806"        , flamnum: "FL 39 Cyg"        , saonum: "SAO69950"    , ppmnum: "PPM84863"    , varname: ""            , hipnum: "HIP100587"   , starname: ""                , alphah: 20.0 , alpham: 23.0 , alphas: 51.62 , plusmin:  +1 , deltag:  32.0 , deltam: 11.0 , deltas: 24.6  , orig: "iras"	   , spectype: "K3III"       , parallax:    12.77  , parerr:	 0.62  , promot: " PROMOT   0.04      0" , vmag:   4.44  , hmag:   0.00  , irastwelvemu:     8.88  , qual:   3  , ftwelve:    8.62  , ones:  3.4  , diam:   2.62  , errdiam:  0.12  , simrem: "Star	    " , hvartype: ""	  , multflag: ""  , compid: ""      , theta:	 0 , rho:   0.00 , compmagdiff: 0.00 , notes: ""  , hdnotes: "" , hdmoent: ""  , hdmcoment: "" },$ 
{ name: "HD196036"       , baynum: ""              , hrnum: ""              , flamnum: ""                 , saonum: "SAO106259"   , ppmnum: "PPM138616"   , varname: "V* MV Del"   , hipnum: "HIP101512"   , starname: ""                , alphah: 20.0 , alpham: 34.0 , alphas: 16.35 , plusmin:  +1 , deltag:  19.0 , deltam: 31.0 , deltas: 50.1  , orig: "iras"	   , spectype: "M..."	     , parallax:     1.26  , parerr:	 0.86  , promot: " PROMOT   0.01   0.01" , vmag:   7.36  , hmag:   2.22  , irastwelvemu:     5.75  , qual:   3  , ftwelve:    0.00  , ones:  0.0  , diam:   2.28  , errdiam:  0.32  , simrem: "Variable Star	   " , hvartype: "P"	  , multflag: ""  , compid: ""      , theta:	 0 , rho:   0.00 , compmagdiff: 0.00 , notes: "P" , hdnotes: "" , hdmoent: ""  , hdmcoment: "" },$ 
{ name: "HD196321"       , baynum: ""              , hrnum: "HR7873"        , flamnum: "FL 70 Aql"        , saonum: "SAO144624"   , ppmnum: "PPM204242"   , varname: ""            , hipnum: "HIP101692"   , starname: ""                , alphah: 20.0 , alpham: 36.0 , alphas: 43.63 , plusmin:  -1 , deltag:   2.0 , deltam: 32.0 , deltas: 59.9  , orig: "iras"	   , spectype: "K5II"	     , parallax:     1.48  , parerr:	 0.91  , promot: " PROMOT      0      0" , vmag:    4.9  , hmag:   1.31  , irastwelvemu:    11.58  , qual:   3  , ftwelve:    0.00  , ones:  0.0  , diam:   3.14  , errdiam:  0.24  , simrem: "Star	    " , hvartype: ""	  , multflag: ""  , compid: ""      , theta:	 0 , rho:   0.00 , compmagdiff: 0.00 , notes: ""  , hdnotes: "" , hdmoent: ""  , hdmcoment: "" },$ 
{ name: "HD196171"       , baynum: "alf Ind"       , hrnum: "HR7869"        , flamnum: ""                 , saonum: "SAO230300"   , ppmnum: "PPM326349"   , varname: ""            , hipnum: "HIP101772"   , starname: ""                , alphah: 20.0 , alpham: 37.0 , alphas: 34.03 , plusmin:  -1 , deltag:  47.0 , deltam: 17.0 , deltas: 29.4  , orig: "iras"	   , spectype: "K0IIICNvar." , parallax:    32.21  , parerr:	 0.75  , promot: " PROMOT   0.06   0.07" , vmag:   3.12  , hmag:    0.9  , irastwelvemu:     14.9  , qual:   3  , ftwelve:    0.00  , ones:  0.0  , diam:   3.09  , errdiam:  0.05  , simrem: "Eclipsing binary      " , hvartype: "M"      , multflag: ""  , compid: ""      , theta:     0 , rho:   0.00 , compmagdiff: 0.00 , notes: ""  , hdnotes: "" , hdmoent: ""  , hdmcoment: "" },$ 
{ name: "HD196777"       , baynum: "ups Cap"       , hrnum: "HR7900"        , flamnum: "FL 15 Cap"        , saonum: "SAO163779"   , ppmnum: "PPM237756"   , varname: ""            , hipnum: "HIP101984"   , starname: ""                , alphah: 20.0 , alpham: 40.0 , alphas:  2.94 , plusmin:  -1 , deltag:  18.0 , deltam:  8.0 , deltas: 19.2  , orig: "iras"	   , spectype: "M1III"       , parallax:     4.32  , parerr:	 0.91  , promot: " PROMOT  -0.02  -0.02" , vmag:   5.17  , hmag:   0.98  , irastwelvemu:    16.12  , qual:   3  , ftwelve:    0.00  , ones:  0.0  , diam:   3.65  , errdiam:  0.14  , simrem: "Variable Star	   " , hvartype: "U"	  , multflag: ""  , compid: ""      , theta:	 0 , rho:   0.00 , compmagdiff: 0.00 , notes: ""  , hdnotes: "" , hdmoent: ""  , hdmcoment: "" },$ 
{ name: "HD196917"       , baynum: ""              , hrnum: "HR7909"        , flamnum: ""                 , saonum: "SAO212345"   , ppmnum: "PPM300482"   , varname: ""            , hipnum: "HIP102092"   , starname: ""                , alphah: 20.0 , alpham: 41.0 , alphas: 23.66 , plusmin:  -1 , deltag:  31.0 , deltam: 35.0 , deltas: 53.8  , orig: "iras"	   , spectype: "M0III"       , parallax:     7.78  , parerr:	 0.78  , promot: " PROMOT    0.1  -0.05" , vmag:   5.78  , hmag:   1.94  , irastwelvemu:     6.85  , qual:   3  , ftwelve:    0.00  , ones:  0.0  , diam:   2.15  , errdiam:  0.12  , simrem: "Variable Star	   " , hvartype: "U"	  , multflag: ""  , compid: ""      , theta:	 0 , rho:   0.00 , compmagdiff: 0.00 , notes: ""  , hdnotes: "" , hdmoent: ""  , hdmcoment: "" },$ 
{ name: "HD197989"       , baynum: "eps Cyg"       , hrnum: "HR7949"        , flamnum: "FL 53 Cyg"        , saonum: "SAO70474"    , ppmnum: "PPM85489"    , varname: ""            , hipnum: "HIP102488"   , starname: ""                , alphah: 20.0 , alpham: 46.0 , alphas: 12.68 , plusmin:  +1 , deltag:  33.0 , deltam: 58.0 , deltas: 12.9  , orig: "iras"	   , spectype: "K0III"       , parallax:    45.26  , parerr:	 0.53  , promot: " PROMOT   0.35   0.33" , vmag:    2.5  , hmag:   0.18  , irastwelvemu:     29.4  , qual:   3  , ftwelve:    0.00  , ones:  0.0  , diam:   4.29  , errdiam:  0.02  , simrem: "High proper-motion Star     " , hvartype: "M"	  , multflag: ""  , compid: ""      , theta:	 0 , rho:   0.00 , compmagdiff: 0.00 , notes: ""  , hdnotes: "" , hdmoent: ""  , hdmcoment: "" },$ 
{ name: "HD197964"       , baynum: "gam02 Del"     , hrnum: "HR7948"        , flamnum: "FL 12 Del"        , saonum: "SAO106477"   , ppmnum: "PPM138996"   , varname: ""            , hipnum: "HIP102532"   , starname: ""                , alphah: 20.0 , alpham: 46.0 , alphas:  39.5 , plusmin:  +1 , deltag:  16.0 , deltam:  7.0 , deltas: 27.5  , orig: "iras"	   , spectype: "K1IV"	     , parallax:    32.14  , parerr:	 1.19  , promot: " PROMOT  -0.04   -0.2" , vmag:   4.27  , hmag:   0.00  , irastwelvemu:     6.25  , qual:   3  , ftwelve:    0.00  , ones:  0.0  , diam:   2.17  , errdiam:  0.01  , simrem: "High proper-motion Star     " , hvartype: "D"	  , multflag: "C"  , compid: ""      , theta:	  0 , rho:   0.00 , compmagdiff: 0.00 , notes: ""  , hdnotes: "" , hdmoent: "Y" , hdmcoment: "" },$ 
{ name: "HD198048"       , baynum: "zet Ind"       , hrnum: "HR7952"        , flamnum: ""                 , saonum: "SAO230391"   , ppmnum: "PPM326564"   , varname: ""            , hipnum: "HIP102790"   , starname: ""                , alphah: 20.0 , alpham: 49.0 , alphas: 28.96 , plusmin:  -1 , deltag:  46.0 , deltam: 13.0 , deltas: 36.6  , orig: "iras"	   , spectype: "K5III"       , parallax:     8.06  , parerr:	 0.83  , promot: " PROMOT   0.05   0.03" , vmag:    4.9  , hmag:   1.42  , irastwelvemu:    10.04  , qual:   3  , ftwelve:    0.00  , ones:  0.0  , diam:   2.86  , errdiam:  0.11  , simrem: "Star	    " , hvartype: ""	  , multflag: ""  , compid: ""      , theta:	 0 , rho:   0.00 , compmagdiff: 0.00 , notes: ""  , hdnotes: "" , hdmoent: ""  , hdmcoment: "" },$ 
{ name: "HD198700"       , baynum: "bet Ind"       , hrnum: "HR7986"        , flamnum: ""                 , saonum: "SAO246784"   , ppmnum: "PPM348943"   , varname: ""            , hipnum: "HIP103227"   , starname: ""                , alphah: 20.0 , alpham: 54.0 , alphas:  48.6 , plusmin:  -1 , deltag:  58.0 , deltam: 27.0 , deltas: 15.0  , orig: "iras"	   , spectype: "K1II"	     , parallax:     5.41  , parerr:	 0.73  , promot: " PROMOT   0.02  -0.02" , vmag:   3.66  , hmag:   1.14  , irastwelvemu:    13.33  , qual:   3  , ftwelve:    0.00  , ones:  0.0  , diam:    3.1  , errdiam:  0.11  , simrem: "Eclipsing binary      " , hvartype: ""	   , multflag: ""  , compid: ""      , theta:	  0 , rho:   0.00 , compmagdiff: 0.00 , notes: ""  , hdnotes: "" , hdmoent: ""  , hdmcoment: "" },$ 
{ name: "HD200043"       , baynum: ""              , hrnum: ""              , flamnum: ""                 , saonum: "SAO70771"    , ppmnum: "PPM85851"    , varname: "V*V2142 Cyg" , hipnum: "HIP103645"   , starname: ""                , alphah: 20.0 , alpham: 59.0 , alphas:  58.8 , plusmin:  +1 , deltag:  32.0 , deltam: 29.0 , deltas: 44.3  , orig: "iras"	   , spectype: "M3III"       , parallax:     3.37  , parerr:	 0.69  , promot: " PROMOT      0  -0.02" , vmag:   6.89  , hmag:   2.27  , irastwelvemu:     5.41  , qual:   3  , ftwelve:    0.00  , ones:  0.0  , diam:    2.2  , errdiam:  0.22  , simrem: "Variable of BY Dra type     " , hvartype: "U"	  , multflag: ""  , compid: ""      , theta:	 0 , rho:   0.00 , compmagdiff: 0.00 , notes: ""  , hdnotes: "" , hdmoent: ""  , hdmcoment: "" },$ 
{ name: "HD202369"       , baynum: ""              , hrnum: "HR8128"        , flamnum: "FL 29 Cap"        , saonum: "SAO164263"   , ppmnum: "PPM238605"   , varname: ""            , hipnum: "HIP104974"   , starname: ""                , alphah: 21.0 , alpham: 15.0 , alphas: 44.84 , plusmin:  -1 , deltag:  15.0 , deltam: 10.0 , deltas: 17.4  , orig: "iras"	   , spectype: "M2III"       , parallax:     5.19  , parerr:	 0.92  , promot: " PROMOT   0.03   0.01" , vmag:   5.34  , hmag:   0.74  , irastwelvemu:    21.23  , qual:   3  , ftwelve:    0.00  , ones:  0.0  , diam:   4.46  , errdiam:   0.1  , simrem: "Variable Star	   " , hvartype: "U"	  , multflag: ""  , compid: ""      , theta:	 0 , rho:   0.00 , compmagdiff: 0.00 , notes: ""  , hdnotes: "" , hdmoent: ""  , hdmcoment: "" },$ 
{ name: "HD203504"       , baynum: ""              , hrnum: "HR8173"        , flamnum: "FL 1 Peg"         , saonum: "SAO107073"   , ppmnum: "PPM140020"   , varname: ""            , hipnum: "HIP105502"   , starname: ""                , alphah: 21.0 , alpham: 22.0 , alphas:   5.2 , plusmin:  +1 , deltag:  19.0 , deltam: 48.0 , deltas: 16.2  , orig: "iras"	   , spectype: "K1III"       , parallax:    21.19  , parerr:	 0.87  , promot: " PROMOT   0.11   0.06" , vmag:   4.09  , hmag:   1.67  , irastwelvemu:     6.79  , qual:   3  , ftwelve:    0.00  , ones:  0.0  , diam:   0.16  , errdiam:  0.06  , simrem: "Eclipsing binary      " , hvartype: ""	   , multflag: ""  , compid: ""      , theta:	  0 , rho:   0.00 , compmagdiff: 0.00 , notes: ""  , hdnotes: "" , hdmoent: ""  , hdmcoment: "" },$ 
{ name: "HD204075"       , baynum: "zet Cap"       , hrnum: "HR8204"        , flamnum: "FL 34 Cap"        , saonum: "SAO190341"   , ppmnum: "PPM272494"   , varname: ""            , hipnum: "HIP105881"   , starname: ""                , alphah: 21.0 , alpham: 26.0 , alphas: 40.03 , plusmin:  -1 , deltag:  22.0 , deltam: 24.0 , deltas: 40.8  , orig: "iras"	   , spectype: "G4Ibp..."    , parallax:     8.19  , parerr:	  0.9  , promot: " PROMOT      0   0.03" , vmag:   3.75  , hmag:    1.9  , irastwelvemu:     5.61  , qual:   3  , ftwelve:    0.00  , ones:  0.0  , diam:   1.97  , errdiam:  0.12  , simrem: "Eclipsing binary      " , hvartype: "C"      , multflag: ""  , compid: ""      , theta:     0 , rho:   0.00 , compmagdiff: 0.00 , notes: ""  , hdnotes: "" , hdmoent: ""  , hdmcoment: "" },$ 
{ name: "HD204724"       , baynum: ""              , hrnum: "HR8225"        , flamnum: "FL 2 Peg"         , saonum: "SAO89752"    , ppmnum: "PPM113087"   , varname: ""            , hipnum: "HIP106140"   , starname: ""                , alphah: 21.0 , alpham: 29.0 , alphas:  56.9 , plusmin:  +1 , deltag:  23.0 , deltam: 38.0 , deltas: 19.8  , orig: "iras"	   , spectype: "M1III"       , parallax:     7.37  , parerr:	 0.64  , promot: " PROMOT   0.02   0.01" , vmag:   4.54  , hmag:    0.7  , irastwelvemu:    20.42  , qual:   3  , ftwelve:    0.00  , ones:  0.0  , diam:   4.11  , errdiam:  0.06  , simrem: "Eclipsing binary      " , hvartype: "U"      , multflag: ""  , compid: ""      , theta:     0 , rho:   0.00 , compmagdiff: 0.00 , notes: ""  , hdnotes: "" , hdmoent: ""  , hdmcoment: "" },$ 
{ name: "HD204867"       , baynum: "bet Aqr"       , hrnum: "HR8232"        , flamnum: "FL 22 Aqr"        , saonum: "SAO145457"   , ppmnum: "PPM205297"   , varname: ""            , hipnum: "HIP106278"   , starname: ""                , alphah: 21.0 , alpham: 31.0 , alphas: 33.53 , plusmin:  -1 , deltag:   5.0 , deltam: 34.0 , deltas: 16.2  , orig: "iras"	   , spectype: "G0Ib"	     , parallax:     5.33  , parerr:	 0.94  , promot: " PROMOT   0.02  -0.01" , vmag:   2.91  , hmag:   1.18  , irastwelvemu:    11.06  , qual:   3  , ftwelve:    0.00  , ones:  0.0  , diam:    2.6  , errdiam:   0.1  , simrem: "Eclipsing binary      " , hvartype: "M"      , multflag: ""  , compid: ""      , theta:     0 , rho:   0.00 , compmagdiff: 0.00 , notes: ""  , hdnotes: "" , hdmoent: ""  , hdmcoment: "" },$ 
{ name: "HD205478"       , baynum: "nu. Oct"       , hrnum: "HR8254"        , flamnum: ""                 , saonum: "SAO257948"   , ppmnum: "PPM375094"   , varname: ""            , hipnum: "HIP107089"   , starname: ""                , alphah: 21.0 , alpham: 41.0 , alphas: 28.65 , plusmin:  -1 , deltag:  77.0 , deltam: 23.0 , deltas: 24.2  , orig: "iras"	   , spectype: "K0III"       , parallax:    47.22  , parerr:	  2.9  , promot: " PROMOT   0.06  -0.24" , vmag:   3.76  , hmag:   1.53  , irastwelvemu:     7.85  , qual:   3  , ftwelve:    0.00  , ones:  0.0  , diam:   2.28  , errdiam:  0.03  , simrem: "Spectroscopic binary	  " , hvartype: ""	, multflag: "X"  , compid: ""	   , theta:	0 , rho:   0.00 , compmagdiff: 0.00 , notes: "D" , hdnotes: "An orbital solution based on elements by W.H.Christie, Astrophys.J., 83, 433, 1936, gives a semi-major axis of 30 mas and a slightly smaller parallax, 44.40 mas (standard error 0.60 mas)." , hdmoent: ""  , hdmcoment: "" },$ 
{ name: "HD206778"       , baynum: "eps Peg"       , hrnum: "HR8308"        , flamnum: "FL 8 Peg"         , saonum: "SAO127029"   , ppmnum: "PPM172188"   , varname: "V* eps Peg"  , hipnum: "HIP107315"   , starname: "ENIF"            , alphah: 21.0 , alpham: 44.0 , alphas: 11.16 , plusmin:  +1 , deltag:   9.0 , deltam: 52.0 , deltas: 30.0  , orig: "iras"	   , spectype: "K2Ib"	     , parallax:     4.85  , parerr:	 0.84  , promot: " PROMOT   0.03      0" , vmag:    2.4  , hmag:   0.00  , irastwelvemu:    72.79  , qual:   3  , ftwelve:    0.00  , ones:  0.0  , diam:   8.38  , errdiam:  0.09  , simrem: "Variable Star	   " , hvartype: "U"	  , multflag: ""  , compid: ""      , theta:	 0 , rho:   0.00 , compmagdiff: 0.00 , notes: "P" , hdnotes: "" , hdmoent: ""  , hdmcoment: "" },$ 
{ name: "HD206859"       , baynum: ""              , hrnum: "HR8313"        , flamnum: "FL 9 Peg"         , saonum: "SAO107365"   , ppmnum: "PPM140574"   , varname: ""            , hipnum: "HIP107348"   , starname: ""                , alphah: 21.0 , alpham: 44.0 , alphas:  30.7 , plusmin:  +1 , deltag:  17.0 , deltam: 21.0 , deltas:  0.1  , orig: "iras"	   , spectype: "G5Ib"	     , parallax:     3.62  , parerr:	 0.74  , promot: " PROMOT   0.01  -0.01" , vmag:   4.34  , hmag:   1.98  , irastwelvemu:      5.8  , qual:   3  , ftwelve:    0.00  , ones:  0.0  , diam:   2.04  , errdiam:  0.12  , simrem: "Variable Star	   " , hvartype: ""	 , multflag: ""  , compid: ""	   , theta:	0 , rho:   0.00 , compmagdiff: 0.00 , notes: ""  , hdnotes: "" , hdmoent: ""  , hdmcoment: "" },$ 
{ name: "HD207932"       , baynum: ""              , hrnum: "HR8350"        , flamnum: ""                 , saonum: "SAO90059"    , ppmnum: "PPM113692"   , varname: "V* HO Peg"   , hipnum: "HIP107956"   , starname: ""                , alphah: 21.0 , alpham: 52.0 , alphas: 18.18 , plusmin:  +1 , deltag:  21.0 , deltam: 16.0 , deltas: 23.4  , orig: "msx"	   , spectype: "M4III"       , parallax:     2.56  , parerr:	 0.73  , promot: " PROMOT   0.01   0.03" , vmag:   6.37  , hmag:   0.87  , irastwelvemu:     0.00  , qual:   0  , ftwelve:   20.94  , ones:  3.1  , diam:   4.27  , errdiam:  0.17  , simrem: "Variable Star	   " , hvartype: "U"	  , multflag: ""  , compid: ""      , theta:	 0 , rho:   0.00 , compmagdiff: 0.00 , notes: ""  , hdnotes: "" , hdmoent: ""  , hdmcoment: "" },$ 
{ name: "HD208631"       , baynum: ""              , hrnum: ""              , flamnum: ""                 , saonum: "SAO107539"   , ppmnum: "PPM140869"   , varname: ""            , hipnum: "HIP108345"   , starname: ""                , alphah: 21.0 , alpham: 57.0 , alphas: 18.71 , plusmin:  +1 , deltag:  17.0 , deltam: 45.0 , deltas: 44.5  , orig: "msx"	   , spectype: "M..."	     , parallax:     0.00  , parerr:	 0.00  , promot: " PROMOT  -0.03  -0.02" , vmag:    8.4  , hmag:   2.21  , irastwelvemu:     0.00  , qual:   0  , ftwelve:    5.49  , ones:  4.4  , diam:   1.45  , errdiam:   0.2  , simrem: "Star	    " , hvartype: ""	  , multflag: ""  , compid: ""      , theta:	 0 , rho:   0.00 , compmagdiff: 0.00 , notes: ""  , hdnotes: "" , hdmoent: ""  , hdmcoment: "" },$ 
{ name: "HD209709"       , baynum: ""              , hrnum: ""              , flamnum: ""                 , saonum: "SAO107646"   , ppmnum: "PPM141039"   , varname: ""            , hipnum: "HIP109009"   , starname: ""                , alphah: 22.0 , alpham:  5.0 , alphas:  3.46 , plusmin:  +1 , deltag:  14.0 , deltam: 48.0 , deltas: 57.3  , orig: "msx"	   , spectype: "M0"	     , parallax:      6.4  , parerr:	 0.78  , promot: " PROMOT  -0.03  -0.01" , vmag:   6.44  , hmag:   1.63  , irastwelvemu:     0.00  , qual:   0  , ftwelve:    9.88  , ones:  3.3  , diam:   2.94  , errdiam:  0.08  , simrem: "Variable Star	   " , hvartype: "U"	  , multflag: ""  , compid: ""      , theta:	 0 , rho:   0.00 , compmagdiff: 0.00 , notes: ""  , hdnotes: "" , hdmoent: ""  , hdmcoment: "" },$ 
{ name: "HD209750"       , baynum: "alf Aqr"       , hrnum: "HR8414"        , flamnum: "FL 34 Aqr"        , saonum: "SAO145862"   , ppmnum: "PPM181401"   , varname: ""            , hipnum: "HIP109074"   , starname: "SADALMELIK"      , alphah: 22.0 , alpham:  5.0 , alphas: 47.04 , plusmin:  +1 , deltag:   0.0 , deltam: 19.0 , deltas: 11.5  , orig: "iras"	   , spectype: "G2Ib"	     , parallax:      4.3  , parerr:	 0.83  , promot: " PROMOT   0.02  -0.01" , vmag:   2.95  , hmag:   1.01  , irastwelvemu:    13.28  , qual:   3  , ftwelve:    0.00  , ones:  0.0  , diam:   2.94  , errdiam:   0.1  , simrem: "Eclipsing binary      " , hvartype: ""	   , multflag: ""  , compid: ""      , theta:	  0 , rho:   0.00 , compmagdiff: 0.00 , notes: ""  , hdnotes: "" , hdmoent: ""  , hdmcoment: "" },$ 
{ name: "HD210090"       , baynum: ""              , hrnum: "HR8436"        , flamnum: ""                 , saonum: "SAO107676"   , ppmnum: "PPM141085"   , varname: "V* OY Peg"   , hipnum: "HIP109212"   , starname: ""                , alphah: 22.0 , alpham:  7.0 , alphas: 29.97 , plusmin:  +1 , deltag:  18.0 , deltam:  0.0 , deltas:  2.5  , orig: "msx"	   , spectype: "M1"	     , parallax:     3.45  , parerr:	  0.7  , promot: " PROMOT   0.02  -0.04" , vmag:   6.35  , hmag:   1.79  , irastwelvemu:     0.00  , qual:   0  , ftwelve:    8.47  , ones:  3.4  , diam:   2.78  , errdiam:  0.13  , simrem: "Variable Star	   " , hvartype: "U"	  , multflag: ""  , compid: ""      , theta:	 0 , rho:   0.00 , compmagdiff: 0.00 , notes: ""  , hdnotes: "" , hdmoent: ""  , hdmcoment: "" },$ 
{ name: "HD210050"       , baynum: ""              , hrnum: ""              , flamnum: ""                 , saonum: "SAO213575"   , ppmnum: "PPM302228"   , varname: "V*VX PsA"    , hipnum: "HIP109282"   , starname: ""                , alphah: 22.0 , alpham:  8.0 , alphas: 19.38 , plusmin:  -1 , deltag:  34.0 , deltam: 33.0 , deltas: 21.6  , orig: "iras"	   , spectype: "M3III"       , parallax:     3.08  , parerr:	 0.95  , promot: " PROMOT   0.01  -0.06" , vmag:   7.03  , hmag:   2.23  , irastwelvemu:     5.88  , qual:   3  , ftwelve:    0.00  , ones:  0.0  , diam:   2.23  , errdiam:  0.14  , simrem: "Variable Star	   " , hvartype: "U"	  , multflag: ""  , compid: ""      , theta:	 0 , rho:   0.00 , compmagdiff: 0.00 , notes: ""  , hdnotes: "" , hdmoent: ""  , hdmcoment: "" },$ 
{ name: "HD210502"       , baynum: ""              , hrnum: "HR8458"        , flamnum: ""                 , saonum: "SAO107712"   , ppmnum: "PPM141144"   , varname: ""            , hipnum: "HIP109471"   , starname: ""                , alphah: 22.0 , alpham: 10.0 , alphas: 37.43 , plusmin:  +1 , deltag:  11.0 , deltam: 37.0 , deltas: 28.3  , orig: "msx"	   , spectype: "M1III"       , parallax:     5.22  , parerr:	 0.85  , promot: " PROMOT  -0.03  -0.05" , vmag:   5.79  , hmag:   1.89  , irastwelvemu:     0.00  , qual:   0  , ftwelve:    6.77  , ones:  3.5  , diam:   2.36  , errdiam:  0.09  , simrem: "Variable Star	   " , hvartype: "U"	  , multflag: ""  , compid: ""      , theta:	 0 , rho:   0.00 , compmagdiff: 0.00 , notes: ""  , hdnotes: "" , hdmoent: ""  , hdmcoment: "" },$ 
{ name: "HD211416"       , baynum: "alf Tuc"       , hrnum: "HR8502"        , flamnum: ""                 , saonum: "SAO255193"   , ppmnum: "PPM365714"   , varname: ""            , hipnum: "HIP110130"   , starname: ""                , alphah: 22.0 , alpham: 18.0 , alphas: 30.09 , plusmin:  -1 , deltag:  60.0 , deltam: 15.0 , deltas: 34.5  , orig: "iras"	   , spectype: "K3III"       , parallax:    16.42  , parerr:	 0.59  , promot: " PROMOT  -0.07  -0.04" , vmag:   2.86  , hmag:  -0.16  , irastwelvemu:    41.68  , qual:   3  , ftwelve:    0.00  , ones:  0.0  , diam:    5.6  , errdiam:  0.07  , simrem: "Spectroscopic binary	  " , hvartype: "M"	 , multflag: "O"  , compid: ""      , theta:	 0 , rho:   0.00 , compmagdiff: 0.00 , notes: ""  , hdnotes: "" , hdmoent: ""  , hdmcoment: "Y" },$
{ name: "HD213119"       , baynum: ""              , hrnum: "HR8562"        , flamnum: "FL 36 Peg"        , saonum: "SAO127544"   , ppmnum: "PPM173090"   , varname: ""            , hipnum: "HIP110986"   , starname: ""                , alphah: 22.0 , alpham: 29.0 , alphas:  7.98 , plusmin:  +1 , deltag:   9.0 , deltam:  7.0 , deltas: 44.5  , orig: "msx"	   , spectype: "K5III"       , parallax:     5.63  , parerr:	 0.85  , promot: " PROMOT   0.06  -0.02" , vmag:    5.6  , hmag:   2.01  , irastwelvemu:     0.00  , qual:   0  , ftwelve:    5.17  , ones:  3.9  , diam:   2.26  , errdiam:  0.08  , simrem: "Star	    " , hvartype: ""	  , multflag: ""  , compid: ""      , theta:	 0 , rho:   0.00 , compmagdiff: 0.00 , notes: ""  , hdnotes: "" , hdmoent: ""  , hdmcoment: "" },$ 
{ name: "HD213009"       , baynum: "del01 Gru"     , hrnum: "HR8556"        , flamnum: ""                 , saonum: "SAO231154"   , ppmnum: "PPM328298"   , varname: ""            , hipnum: "HIP110997"   , starname: ""                , alphah: 22.0 , alpham: 29.0 , alphas: 16.17 , plusmin:  -1 , deltag:  43.0 , deltam: 29.0 , deltas: 44.0  , orig: "iras"	   , spectype: "G7III"       , parallax:    11.03  , parerr:	 0.85  , promot: " PROMOT   0.03      0" , vmag:   3.97  , hmag:    1.8  , irastwelvemu:      6.3  , qual:   3  , ftwelve:    0.00  , ones:  0.0  , diam:   2.07  , errdiam:  0.09  , simrem: "Eclipsing binary      " , hvartype: ""	   , multflag: ""  , compid: ""      , theta:	  0 , rho:   0.00 , compmagdiff: 0.00 , notes: ""  , hdnotes: "" , hdmoent: ""  , hdmcoment: "" },$ 
{ name: "HD215182"       , baynum: "eta Peg"       , hrnum: "HR8650"        , flamnum: "FL 44 Peg"        , saonum: "SAO90734"    , ppmnum: "PPM88121"    , varname: ""            , hipnum: "HIP112158"   , starname: ""                , alphah: 22.0 , alpham: 43.0 , alphas:  0.14 , plusmin:  +1 , deltag:  30.0 , deltam: 13.0 , deltas: 16.5  , orig: "iras"	   , spectype: "G2II-III+.." , parallax:    15.18  , parerr:	 0.79  , promot: " PROMOT   0.01  -0.02" , vmag:   2.95  , hmag:   0.00  , irastwelvemu:    13.77  , qual:   3  , ftwelve:    0.00  , ones:  0.0  , diam:   2.91  , errdiam:  0.07  , simrem: "Spectroscopic binary	  " , hvartype: ""	, multflag: "O"  , compid: ""	   , theta:	0 , rho:   0.00 , compmagdiff: 0.00 , notes: ""  , hdnotes: "" , hdmoent: ""  , hdmcoment: "Y" },$
{ name: "HD215369"       , baynum: "eta Gru"       , hrnum: "HR8655"        , flamnum: ""                 , saonum: "SAO247570"   , ppmnum: "PPM350499"   , varname: ""            , hipnum: "HIP112374"   , starname: ""                , alphah: 22.0 , alpham: 45.0 , alphas: 37.88 , plusmin:  -1 , deltag:  53.0 , deltam: 30.0 , deltas:  0.4  , orig: "iras"	   , spectype: "K2IIICNvar." , parallax:     8.27  , parerr:	 0.62  , promot: " PROMOT   0.03   0.02" , vmag:   4.86  , hmag:   2.07  , irastwelvemu:     5.13  , qual:   3  , ftwelve:    0.00  , ones:  0.0  , diam:   1.91  , errdiam:   0.1  , simrem: "Eclipsing binary      " , hvartype: "M"      , multflag: ""  , compid: ""      , theta:     0 , rho:   0.00 , compmagdiff: 0.00 , notes: ""  , hdnotes: "" , hdmoent: ""  , hdmcoment: "" },$ 
{ name: "HD215665"       , baynum: "lam Peg"       , hrnum: "HR8667"        , flamnum: "FL 47 Peg"        , saonum: "SAO90775"    , ppmnum: "PPM114805"   , varname: ""            , hipnum: "HIP112440"   , starname: ""                , alphah: 22.0 , alpham: 46.0 , alphas: 31.88 , plusmin:  +1 , deltag:  23.0 , deltam: 33.0 , deltas: 56.4  , orig: "iras"	   , spectype: "G8Iab"       , parallax:     8.26  , parerr:	  0.7  , promot: " PROMOT   0.06  -0.01" , vmag:   3.96  , hmag:   1.72  , irastwelvemu:      7.0  , qual:   3  , ftwelve:    0.00  , ones:  0.0  , diam:   2.22  , errdiam:  0.06  , simrem: "Star	    " , hvartype: ""	  , multflag: ""  , compid: ""      , theta:	 0 , rho:   0.00 , compmagdiff: 0.00 , notes: ""  , hdnotes: "" , hdmoent: ""  , hdmcoment: "" },$ 
{ name: "HD216131"       , baynum: "mu. Peg"       , hrnum: "HR8684"        , flamnum: "FL 48 Peg"        , saonum: "SAO90816"    , ppmnum: "PPM114859"   , varname: ""            , hipnum: "HIP112748"   , starname: ""                , alphah: 22.0 , alpham: 49.0 , alphas:  0.19 , plusmin:  +1 , deltag:  24.0 , deltam: 36.0 , deltas:  5.7  , orig: "iras"	   , spectype: "G8III"       , parallax:    27.95  , parerr:	 0.77  , promot: " PROMOT   0.15  -0.04" , vmag:   3.51  , hmag:   1.44  , irastwelvemu:    26.69  , qual:   3  , ftwelve:   28.53  , ones:  3.0  , diam:   2.37  , errdiam:  0.04  , simrem: "Star	    " , hvartype: ""	  , multflag: ""  , compid: ""      , theta:	 0 , rho:   0.00 , compmagdiff: 0.00 , notes: ""  , hdnotes: "" , hdmoent: ""  , hdmcoment: "" },$ 
{ name: "HD216032"       , baynum: "tau02 Aqr"     , hrnum: "HR8679"        , flamnum: "FL 71 Aqr"        , saonum: "SAO165321"   , ppmnum: "PPM240808"   , varname: ""            , hipnum: "HIP112716"   , starname: ""                , alphah: 22.0 , alpham: 49.0 , alphas:  35.5 , plusmin:  -1 , deltag:  13.0 , deltam: 35.0 , deltas: 33.5  , orig: "iras"	   , spectype: "K5III"       , parallax:     8.58  , parerr:	 0.98  , promot: " PROMOT  -0.02  -0.03" , vmag:   4.05  , hmag:   0.39  , irastwelvemu:     8.44  , qual:   3  , ftwelve:    0.00  , ones:  0.0  , diam:   4.89  , errdiam:  0.11  , simrem: "Eclipsing binary      " , hvartype: "M"      , multflag: ""  , compid: ""      , theta:     0 , rho:   0.00 , compmagdiff: 0.00 , notes: ""  , hdnotes: "" , hdmoent: ""  , hdmcoment: "" },$ 
{ name: "HD215985"       , baynum: ""              , hrnum: ""              , flamnum: ""                 , saonum: "SAO247605"   , ppmnum: "PPM350561"   , varname: "V* AX Gru"   , hipnum: "HIP112750"   , starname: ""                , alphah: 22.0 , alpham: 50.0 , alphas:  0.96 , plusmin:  -1 , deltag:  55.0 , deltam: 14.0 , deltas:  2.8  , orig: "iras"	   , spectype: "M3III"       , parallax:     1.68  , parerr:	 0.83  , promot: " PROMOT      0  -0.03" , vmag:   7.11  , hmag:   2.31  , irastwelvemu:     5.54  , qual:   3  , ftwelve:    0.00  , ones:  0.0  , diam:   2.15  , errdiam:  0.11  , simrem: "Variable Star	   " , hvartype: "U"	  , multflag: ""  , compid: ""      , theta:	 0 , rho:   0.00 , compmagdiff: 0.00 , notes: ""  , hdnotes: "" , hdmoent: ""  , hdmcoment: "" },$ 
{ name: "HD216386"       , baynum: "lam Aqr"       , hrnum: "HR8698"        , flamnum: "FL 73 Aqr"        , saonum: "SAO146362"   , ppmnum: "PPM206868"   , varname: "V* lam Aqr"  , hipnum: "HIP112961"   , starname: ""                , alphah: 22.0 , alpham: 52.0 , alphas: 36.88 , plusmin:  -1 , deltag:   7.0 , deltam: 34.0 , deltas: 46.6  , orig: "msx"	   , spectype: "M2III"       , parallax:     8.33  , parerr:	 1.13  , promot: " PROMOT   0.01   0.04" , vmag:   3.77  , hmag:  -0.45  , irastwelvemu:     0.00  , qual:   0  , ftwelve:   64.84  , ones:  3.0  , diam:   6.71  , errdiam:  0.05  , simrem: "Variable Star	   " , hvartype: "U"	  , multflag: "V"  , compid: ""      , theta:	  0 , rho:   0.00 , compmagdiff: 0.00 , notes: ""  , hdnotes: "" , hdmoent: ""  , hdmcoment: "" },$ 
{ name: "HD217005"       , baynum: ""              , hrnum: ""              , flamnum: ""                 , saonum: "SAO191529"   , ppmnum: "PPM274431"   , varname: "V* TV PsA"   , hipnum: "HIP113386"   , starname: ""                , alphah: 22.0 , alpham: 57.0 , alphas:  48.5 , plusmin:  -1 , deltag:  26.0 , deltam: 10.0 , deltas:  0.0  , orig: "iras"	   , spectype: "M5III"       , parallax:     0.00  , parerr:	 0.00  , promot: " PROMOT   0.04  -0.01" , vmag:   9.01  , hmag:   2.43  , irastwelvemu:     6.77  , qual:   3  , ftwelve:    0.00  , ones:  0.0  , diam:   2.13  , errdiam:  0.07  , simrem: "Variable Star	   " , hvartype: "D"	  , multflag: "C"  , compid: "AB"      , theta:  343  , rho:  9.09    , compmagdiff:  1.58  , notes: ""  , hdnotes: "" , hdmoent: "Y" , hdmcoment: "" },$ 
{ name: "HD217364"       , baynum: "zet Gru"       , hrnum: "HR8747"        , flamnum: ""                 , saonum: "SAO247680"   , ppmnum: "PPM350708"   , varname: ""            , hipnum: "HIP113638"   , starname: ""                , alphah: 23.0 , alpham:  0.0 , alphas: 52.81 , plusmin:  -1 , deltag:  52.0 , deltam: 45.0 , deltas: 14.9  , orig: "iras"	   , spectype: "G9III"       , parallax:    28.99  , parerr:	 1.31  , promot: " PROMOT  -0.06  -0.01" , vmag:   4.13  , hmag:   1.85  , irastwelvemu:     6.14  , qual:   3  , ftwelve:    0.00  , ones:  0.0  , diam:   2.02  , errdiam:  0.04  , simrem: "Star	    " , hvartype: ""	  , multflag: "X"  , compid: ""      , theta:	  0 , rho:   0.00 , compmagdiff: 0.00 , notes: ""  , hdnotes: "" , hdmoent: ""  , hdmcoment: "" },$ 
{ name: "HD217902"       , baynum: "kap Gru"       , hrnum: "HR8774"        , flamnum: ""                 , saonum: "SAO247711"   , ppmnum: "PPM350761"   , varname: ""            , hipnum: "HIP113957"   , starname: ""                , alphah: 23.0 , alpham:  4.0 , alphas: 39.63 , plusmin:  -1 , deltag:  53.0 , deltam: 57.0 , deltas: 53.7  , orig: "iras"	   , spectype: "K5III"       , parallax:     8.36  , parerr:	 0.68  , promot: " PROMOT   0.06  -0.11" , vmag:   5.39  , hmag:   1.98  , irastwelvemu:     5.96  , qual:   3  , ftwelve:    0.00  , ones:  0.0  , diam:   2.18  , errdiam:   0.1  , simrem: "Star	    " , hvartype: ""	  , multflag: ""  , compid: ""      , theta:	 0 , rho:   0.00 , compmagdiff: 0.00 , notes: ""  , hdnotes: "" , hdmoent: ""  , hdmcoment: "" },$ 
{ name: "HD218594"       , baynum: "c02 Aqr"       , hrnum: "HR8812"        , flamnum: "FL 88 Aqr"        , saonum: "SAO191683"   , ppmnum: "PPM274643"   , varname: ""            , hipnum: "HIP114341"   , starname: ""                , alphah: 23.0 , alpham:  9.0 , alphas:  26.8 , plusmin:  -1 , deltag:  21.0 , deltam: 10.0 , deltas: 20.7  , orig: "msx"	   , spectype: "K1III"       , parallax:    13.96  , parerr:	 0.94  , promot: " PROMOT   0.05   0.04" , vmag:   3.66  , hmag:   1.05  , irastwelvemu:     0.00  , qual:   0  , ftwelve:   12.81  , ones:  3.1  , diam:    3.1  , errdiam:  0.07  , simrem: "Star	    " , hvartype: ""	  , multflag: ""  , compid: ""      , theta:	 0 , rho:   0.00 , compmagdiff: 0.00 , notes: ""  , hdnotes: "" , hdmoent: ""  , hdmcoment: "" },$ 
{ name: "HD218670"       , baynum: "iot Gru"       , hrnum: "HR8820"        , flamnum: ""                 , saonum: "SAO231468"   , ppmnum: "PPM329009"   , varname: ""            , hipnum: "HIP114421"   , starname: ""                , alphah: 23.0 , alpham: 10.0 , alphas: 21.54 , plusmin:  -1 , deltag:  45.0 , deltam: 14.0 , deltas: 48.2  , orig: "iras"	   , spectype: "K1III"       , parallax:    17.63  , parerr:	 0.92  , promot: " PROMOT   0.14  -0.02" , vmag:   3.89  , hmag:   1.78  , irastwelvemu:     6.44  , qual:   3  , ftwelve:    0.00  , ones:  0.0  , diam:   2.06  , errdiam:  0.07  , simrem: "Spectroscopic binary	  " , hvartype: "C"	 , multflag: "O"  , compid: ""      , theta:	 0 , rho:   0.00 , compmagdiff: 0.00 , notes: ""  , hdnotes: "" , hdmoent: ""  , hdmcoment: "Y" },$
{ name: "HD219449"       , baynum: "psi01 Aqr"     , hrnum: "HR8841"        , flamnum: "FL 91 Aqr"        , saonum: "SAO146598"   , ppmnum: "PPM207344"   , varname: ""            , hipnum: "HIP114855"   , starname: ""                , alphah: 23.0 , alpham: 15.0 , alphas: 53.49 , plusmin:  -1 , deltag:   9.0 , deltam:  5.0 , deltas: 15.8  , orig: "iras"	   , spectype: "K0III"       , parallax:    21.97  , parerr:	 0.89  , promot: " PROMOT   0.37  -0.01" , vmag:   4.21  , hmag:   1.86  , irastwelvemu:     5.93  , qual:   3  , ftwelve:    0.00  , ones:  0.0  , diam:   2.02  , errdiam:  0.07  , simrem: "High proper-motion Star     " , hvartype: "C"	  , multflag: ""  , compid: ""      , theta:	 0 , rho:   0.00 , compmagdiff: 0.00 , notes: ""  , hdnotes: "" , hdmoent: ""  , hdmcoment: "" },$   
{ name: "HD219615"       , baynum: "gam Psc"       , hrnum: "HR8852"        , flamnum: "FL 6 Psc"         , saonum: "SAO128085"   , ppmnum: "PPM173938"   , varname: ""            , hipnum: "HIP114971"   , starname: ""                , alphah: 23.0 , alpham: 17.0 , alphas:  9.94 , plusmin:  +1 , deltag:   3.0 , deltam: 16.0 , deltas: 56.2  , orig: "iras"	   , spectype: "G9III"       , parallax:    24.92  , parerr:	 0.89  , promot: " PROMOT   0.76   0.02" , vmag:   3.69  , hmag:   1.52  , irastwelvemu:      7.9  , qual:   3  , ftwelve:    0.00  , ones:  0.0  , diam:   2.24  , errdiam:  0.04  , simrem: "High proper-motion Star     " , hvartype: ""	 , multflag: ""  , compid: ""	   , theta:	0 , rho:   0.00 , compmagdiff: 0.00 , notes: ""  , hdnotes: "" , hdmoent: ""  , hdmcoment: "" },$   
{ name: "HD219784"       , baynum: "gam Scl"       , hrnum: "HR8863"        , flamnum: ""                 , saonum: "SAO214444"   , ppmnum: "PPM303593"   , varname: ""            , hipnum: "HIP115102"   , starname: ""                , alphah: 23.0 , alpham: 18.0 , alphas: 49.44 , plusmin:  -1 , deltag:  32.0 , deltam: 31.0 , deltas: 55.3  , orig: "iras"	   , spectype: "G8III"       , parallax:    18.24  , parerr:	  0.8  , promot: " PROMOT   0.02  -0.06" , vmag:   4.42  , hmag:   1.99  , irastwelvemu:     6.04  , qual:   3  , ftwelve:    0.00  , ones:  0.0  , diam:   2.04  , errdiam:  0.07  , simrem: "Star	    " , hvartype: "C"	   , multflag: ""  , compid: ""      , theta:	  0 , rho:   0.00 , compmagdiff: 0.00 , notes: ""  , hdnotes: "" , hdmoent: ""  , hdmcoment: "" },$   
{ name: "HD220009"       , baynum: "b Psc"         , hrnum: "HR8878"        , flamnum: "FL 7 Psc"         , saonum: "SAO128126"   , ppmnum: "PPM173998"   , varname: ""            , hipnum: "HIP115227"   , starname: ""                , alphah: 23.0 , alpham: 20.0 , alphas: 20.58 , plusmin:  +1 , deltag:   5.0 , deltam: 22.0 , deltas: 52.7  , orig: "iras"	   , spectype: "K2III"       , parallax:     9.56  , parerr:	 0.95  , promot: " PROMOT   0.08  -0.06" , vmag:   5.08  , hmag:   2.17  , irastwelvemu:      5.0  , qual:   3  , ftwelve:    0.00  , ones:  0.0  , diam:   1.81  , errdiam:  0.05  , simrem: "Star	    " , hvartype: ""	  , multflag: ""  , compid: ""      , theta:	 0 , rho:   0.00 , compmagdiff: 0.00 , notes: ""  , hdnotes: "" , hdmoent: ""  , hdmcoment: "" },$   
{ name: "HD220088"       , baynum: ""              , hrnum: "HR8882"        , flamnum: "FL 63 Peg"        , saonum: "SAO73187"    , ppmnum: "PPM88742"    , varname: ""            , hipnum: "HIP115271"   , starname: ""                , alphah: 23.0 , alpham: 20.0 , alphas: 49.56 , plusmin:  +1 , deltag:  30.0 , deltam: 24.0 , deltas: 53.7  , orig: "iras"	   , spectype: "M0III"       , parallax:     7.49  , parerr:	 0.67  , promot: " PROMOT   0.08  -0.06" , vmag:   5.59  , hmag:   2.03  , irastwelvemu:     5.48  , qual:   3  , ftwelve:    0.00  , ones:  0.0  , diam:   2.26  , errdiam:  0.14  , simrem: "Star	    " , hvartype: "M"	   , multflag: "G"  , compid: ""      , theta:     0 , rho:   0.00 , compmagdiff: 0.00 , notes: ""  , hdnotes: "" , hdmoent: ""  , hdmcoment: "" },$   
{ name: "HD220321"       , baynum: "b01 Aqr"       , hrnum: "HR8892"        , flamnum: "FL 98 Aqr"        , saonum: "SAO191858"   , ppmnum: "PPM274885"   , varname: ""            , hipnum: "HIP115438"   , starname: ""                , alphah: 23.0 , alpham: 22.0 , alphas: 58.23 , plusmin:  -1 , deltag:  20.0 , deltam:  6.0 , deltas:  2.1  , orig: "msx"	   , spectype: "K0III"       , parallax:    20.14  , parerr:	 0.72  , promot: " PROMOT  -0.12  -0.09" , vmag:   3.97  , hmag:   1.45  , irastwelvemu:     0.00  , qual:   0  , ftwelve:    8.79  , ones:  3.3  , diam:   2.38  , errdiam:  0.07  , simrem: "Star	    " , hvartype: ""	  , multflag: ""  , compid: ""      , theta:	 0 , rho:   0.00 , compmagdiff: 0.00 , notes: ""  , hdnotes: "" , hdmoent: ""  , hdmcoment: "" },$   
{ name: "HD220704"       , baynum: "b02 Aqr"       , hrnum: "HR8906"        , flamnum: "FL 99 Aqr"        , saonum: "SAO191900"   , ppmnum: "PPM274952"   , varname: ""            , hipnum: "HIP115669"   , starname: ""                , alphah: 23.0 , alpham: 26.0 , alphas:  2.79 , plusmin:  -1 , deltag:  20.0 , deltam: 38.0 , deltas: 31.2  , orig: "msx"	   , spectype: "K4III"       , parallax:    10.57  , parerr:	 0.72  , promot: " PROMOT  -0.05  -0.05" , vmag:   4.39  , hmag:   1.09  , irastwelvemu:     0.00  , qual:   0  , ftwelve:   13.34  , ones:  3.1  , diam:   3.44  , errdiam:  0.07  , simrem: "Variable Star	   " , hvartype: "M"	  , multflag: ""  , compid: ""      , theta:	 0 , rho:   0.00 , compmagdiff: 0.00 , notes: ""  , hdnotes: "" , hdmoent: ""  , hdmcoment: "" },$   
{ name: "HD223075"       , baynum: "TX Psc "       , hrnum: "HR9004"        , flamnum: "FL 19 Psc"        , saonum: "SAO128374"   , ppmnum: "PPM174411"   , varname: "V* TX Psc"   , hipnum: "HIP117245"   , starname: ""                , alphah: 23.0 , alpham: 46.0 , alphas: 23.52 , plusmin:  +1 , deltag:   3.0 , deltam: 29.0 , deltas: 12.5  , orig: "iras"	   , spectype: "CII..."      , parallax:     4.29  , parerr:	 0.93  , promot: " PROMOT  -0.03  -0.02" , vmag:   5.04  , hmag:  -0.39  , irastwelvemu:   114.67  , qual:   3  , ftwelve:    0.00  , ones:  0.0  , diam:    2.1  , errdiam:  0.14  , simrem: "Carbon Star	 " , hvartype: "U"	, multflag: ""  , compid: ""	  , theta:     0 , rho:   0.00 , compmagdiff: 0.00 , notes: "P" , hdnotes: "" , hdmoent: ""  , hdmcoment: "" },$   
{ name: "HD223800"       , baynum: ""              , hrnum: ""              , flamnum: ""                 , saonum: "SAO165936"   , ppmnum: "PPM242243"   , varname: "V* LW Aqr"   , hipnum: "HIP117747"   , starname: ""                , alphah: 23.0 , alpham: 52.0 , alphas: 47.56 , plusmin:  -1 , deltag:  12.0 , deltam:  1.0 , deltas:  0.9  , orig: "iras"	   , spectype: "M4III"       , parallax:     2.81  , parerr:	 0.99  , promot: " PROMOT  -0.02  -0.01" , vmag:   7.47  , hmag:   1.78  , irastwelvemu:     9.65  , qual:   3  , ftwelve:    0.00  , ones:  0.0  , diam:   2.85  , errdiam:  0.07  , simrem: "Variable Star of irregular type   " , hvartype: ""      , multflag: ""  , compid: ""	 , theta:     0 , rho:   0.00 , compmagdiff: 0.00 , notes: ""  , hdnotes: "" , hdmoent: ""  , hdmcoment: "" }$   
          ]

  hdmcom = [ $
{ name: "HD1632"     , type: "F" , qual: "A" , notes: ""  , nsys:  1, ncomp:  2, nparm:   9, ncorr:  1, seq:  2, compid: "B" , hpmag:  8.33, theta:  288.30, rho:  1.81, dtheta:   99.9, drho:  99.9},$        
{ name: "HD1632"     , type: "F" , qual: "A" , notes: ""  , nsys:  1, ncomp:  2, nparm:   9, ncorr:  1, seq:  1, compid: "A" , hpmag:  7.32, theta:	0.0, rho:   0.0, dtheta:   99.9, drho:  99.9},$        
{ name: "HD17709"    , type: "F" , qual: "A" , notes: ""  , nsys:  1, ncomp:  2, nparm:   9, ncorr:  1, seq:  1, compid: "B" , hpmag: 10.77, theta:	0.0, rho:   0.0, dtheta:   99.9, drho:  99.9},$        
{ name: "HD17709"    , type: "F" , qual: "A" , notes: ""  , nsys:  1, ncomp:  2, nparm:   9, ncorr:  1, seq:  2, compid: "A" , hpmag: 11.21, theta:  310.00, rho:  0.21, dtheta:   99.9, drho:  99.9},$        
{ name: "HD21754"    , type: "F" , qual: "A" , notes: ""  , nsys:  1, ncomp:  2, nparm:   9, ncorr:  1, seq:  2, compid: "B" , hpmag: 11.12, theta:  154.00, rho:  0.32, dtheta:   99.9, drho:  99.9},$        
{ name: "HD21754"    , type: "F" , qual: "A" , notes: ""  , nsys:  1, ncomp:  2, nparm:   9, ncorr:  1, seq:  1, compid: "A" , hpmag:  8.50, theta:	0.0, rho:   0.0, dtheta:   99.9, drho:  99.9},$        
{ name: "HD29503"    , type: "L" , qual: "A" , notes: ""  , nsys:  1, ncomp:  2, nparm:  11, ncorr:  1, seq:  1, compid: "A" , hpmag:  4.10, theta:	0.0, rho:   0.0, dtheta:   99.9, drho:  99.9},$        
{ name: "HD29503"    , type: "L" , qual: "A" , notes: ""  , nsys:  1, ncomp:  2, nparm:  11, ncorr:  1, seq:  2, compid: "B" , hpmag:  6.99, theta:  343.30, rho:  0.81, dtheta:   1.70, drho:  0.03},$        
{ name: "HD32831"    , type: "F" , qual: "A" , notes: ""  , nsys:  1, ncomp:  2, nparm:   9, ncorr:  1, seq:  1, compid: "A" , hpmag:  4.74, theta:	0.0, rho:   0.0, dtheta:   99.9, drho:  99.9},$        
{ name: "HD32831"    , type: "F" , qual: "A" , notes: ""  , nsys:  1, ncomp:  2, nparm:   9, ncorr:  1, seq:  2, compid: "B" , hpmag:  8.48, theta:  306.30, rho:  3.15, dtheta:   99.9, drho:  99.9},$        
{ name: "HD33856"    , type: "F" , qual: "A" , notes: ""  , nsys:  1, ncomp:  2, nparm:   9, ncorr:  1, seq:  1, compid: "A" , hpmag:  4.67, theta:	0.0, rho:   0.0, dtheta:   99.9, drho:  99.9},$        
{ name: "HD33856"    , type: "F" , qual: "A" , notes: ""  , nsys:  1, ncomp:  2, nparm:   9, ncorr:  1, seq:  2, compid: "B" , hpmag:  8.50, theta:   63.40, rho:  6.91, dtheta:   99.9, drho:  99.9},$        
{ name: "HD42995"    , type: "L" , qual: "B" , notes: "W" , nsys:  1, ncomp:  2, nparm:  11, ncorr:  1, seq:  1, compid: "A" , hpmag:  3.38, theta:	0.0, rho:   0.0, dtheta:   99.9, drho:  99.9},$        
{ name: "HD42995"    , type: "L" , qual: "B" , notes: "W" , nsys:  1, ncomp:  2, nparm:  11, ncorr:  1, seq:  2, compid: "B" , hpmag:  6.07, theta:  260.70, rho:  1.70, dtheta:   0.90, drho: -0.05},$        
{ name: "HD55865"    , type: "I" , qual: "A" , notes: ""  , nsys:  1, ncomp:  2, nparm:  12, ncorr:  1, seq:  1, compid: "A" , hpmag:  3.93, theta:	0.0, rho:   0.0, dtheta:   99.9, drho:  99.9},$        
{ name: "HD55865"    , type: "I" , qual: "A" , notes: ""  , nsys:  1, ncomp:  2, nparm:  12, ncorr:  1, seq:  2, compid: "B" , hpmag:  5.78, theta:  298.22, rho: 14.11, dtheta:  -0.03, drho:  0.00},$        
{ name: "HD62345"    , type: "F" , qual: "D" , notes: "D" , nsys:  1, ncomp:  2, nparm:   9, ncorr:  1, seq:  2, compid: "B" , hpmag: 12.63, theta:  265.00, rho:  1.44, dtheta:   99.9, drho:  99.9},$        
{ name: "HD62345"    , type: "F" , qual: "D" , notes: "D" , nsys:  1, ncomp:  2, nparm:   9, ncorr:  1, seq:  1, compid: "A" , hpmag:  8.64, theta:	0.0, rho:   0.0, dtheta:   99.9, drho:  99.9},$        
{ name: "HD74956"    , type: "L" , qual: "A" , notes: ""  , nsys:  1, ncomp:  2, nparm:  11, ncorr:  1, seq:  1, compid: "A" , hpmag:  1.99, theta:	0.0, rho:   0.0, dtheta:   99.9, drho:  99.9},$        
{ name: "HD74956"    , type: "L" , qual: "A" , notes: ""  , nsys:  1, ncomp:  2, nparm:  11, ncorr:  1, seq:  2, compid: "B" , hpmag:  5.57, theta:    5.00, rho:  0.74, dtheta:  -3.00, drho:  0.05},$        
{ name: "HD74739"    , type: "I" , qual: "B" , notes: ""  , nsys:  1, ncomp:  2, nparm:  12, ncorr:  1, seq:  1, compid: "A" , hpmag:  4.20, theta:	0.0, rho:   0.0, dtheta:   99.9, drho:  99.9},$        
{ name: "HD74739"    , type: "I" , qual: "B" , notes: ""  , nsys:  1, ncomp:  2, nparm:  12, ncorr:  1, seq:  2, compid: "B" , hpmag:  6.59, theta:  307.55, rho: 30.48, dtheta:   0.00, drho:  0.00},$        
{ name: "HD74874"    , type: "L" , qual: "B" , notes: "W" , nsys:  1, ncomp:  2, nparm:  11, ncorr:  1, seq:  2, compid: "C" , hpmag:  6.67, theta:  291.40, rho:  2.87, dtheta:   0.80, drho:  0.05},$        
{ name: "HD74874"    , type: "L" , qual: "B" , notes: "W" , nsys:  1, ncomp:  2, nparm:  11, ncorr:  1, seq:  1, compid: "A" , hpmag:  3.56, theta:	0.0, rho:   0.0, dtheta:   99.9, drho:  99.9},$        
{ name: "HD89484"    , type: "L" , qual: "A" , notes: "W" , nsys:  1, ncomp:  2, nparm:  11, ncorr:  1, seq:  2, compid: "B" , hpmag:  3.64, theta:  124.38, rho:  4.58, dtheta:   0.11, drho:  0.00},$        
{ name: "HD89484"    , type: "L" , qual: "A" , notes: "W" , nsys:  1, ncomp:  2, nparm:  11, ncorr:  1, seq:  1, compid: "A" , hpmag:  2.49, theta:	0.0, rho:   0.0, dtheta:   99.9, drho:  99.9},$        
{ name: "HD91942"    , type: "F" , qual: "A" , notes: ""  , nsys:  1, ncomp:  2, nparm:   9, ncorr:  1, seq:  1, compid: "A" , hpmag:  7.07, theta:	0.0, rho:   0.0, dtheta:   99.9, drho:  99.9},$        
{ name: "HD91942"    , type: "F" , qual: "A" , notes: ""  , nsys:  1, ncomp:  2, nparm:   9, ncorr:  1, seq:  2, compid: "B" , hpmag:  9.95, theta:  238.20, rho:  5.09, dtheta:   99.9, drho:  99.9},$        
{ name: "HD92397"    , type: "I" , qual: "A" , notes: ""  , nsys:  1, ncomp:  2, nparm:  12, ncorr:  1, seq:  1, compid: "A" , hpmag:  4.85, theta:	0.0, rho:   0.0, dtheta:   99.9, drho:  99.9},$        
{ name: "HD92397"    , type: "I" , qual: "A" , notes: ""  , nsys:  1, ncomp:  2, nparm:  12, ncorr:  1, seq:  2, compid: "B" , hpmag:  7.67, theta:   21.10, rho: 14.55, dtheta:  -0.10, drho:  0.00},$        
{ name: "HD92436"    , type: "I" , qual: "C" , notes: ""  , nsys:  1, ncomp:  2, nparm:  12, ncorr:  1, seq:  1, compid: "A" , hpmag:  6.04, theta:	0.0, rho:   0.0, dtheta:   99.9, drho:  99.9},$        
{ name: "HD92436"    , type: "I" , qual: "C" , notes: ""  , nsys:  1, ncomp:  2, nparm:  12, ncorr:  1, seq:  2, compid: "B" , hpmag:  8.61, theta:   79.62, rho: 25.53, dtheta:   0.07, drho:  0.04},$        
{ name: "HD97068"    , type: "F" , qual: "A" , notes: ""  , nsys:  1, ncomp:  2, nparm:   9, ncorr:  1, seq:  2, compid: "B" , hpmag: 10.90, theta:   40.00, rho:  0.63, dtheta:   99.9, drho:  99.9},$        
{ name: "HD97068"    , type: "F" , qual: "A" , notes: ""  , nsys:  1, ncomp:  2, nparm:   9, ncorr:  1, seq:  1, compid: "A" , hpmag:  8.14, theta:	0.0, rho:   0.0, dtheta:   99.9, drho:  99.9},$        
{ name: "HD281813"   , type: "F" , qual: "B" , notes: ""  , nsys:  1, ncomp:  2, nparm:   9, ncorr:  1, seq:  1, compid: "A" , hpmag:  8.37, theta:	0.0, rho:   0.0, dtheta:   99.9, drho:  99.9},$        
{ name: "HD281813"   , type: "F" , qual: "B" , notes: ""  , nsys:  1, ncomp:  2, nparm:   9, ncorr:  1, seq:  2, compid: "B" , hpmag:  8.92, theta:  350.00, rho:  0.11, dtheta:   99.9, drho:  99.9},$        
{ name: "HD101104"   , type: "F" , qual: "A" , notes: ""  , nsys:  1, ncomp:  2, nparm:   9, ncorr:  1, seq:  1, compid: "A" , hpmag:  8.13, theta:	0.0, rho:   0.0, dtheta:   99.9, drho:  99.9},$        
{ name: "HD101104"   , type: "F" , qual: "A" , notes: ""  , nsys:  1, ncomp:  2, nparm:   9, ncorr:  1, seq:  2, compid: "B" , hpmag:  9.13, theta:    3.90, rho:  1.90, dtheta:   99.9, drho:  99.9},$        
{ name: "HD110380"   , type: "L" , qual: "C" , notes: ""  , nsys:  1, ncomp:  2, nparm:  11, ncorr:  1, seq:  2, compid: "B" , hpmag:  3.60, theta:  284.45, rho:  2.70, dtheta:  -1.56, drho: -0.12},$        
{ name: "HD110380"   , type: "L" , qual: "C" , notes: ""  , nsys:  1, ncomp:  2, nparm:  11, ncorr:  1, seq:  1, compid: "A" , hpmag:  3.55, theta:	0.0, rho:   0.0, dtheta:   99.9, drho:  99.9},$        
{ name: "HD112985"   , type: "F" , qual: "A" , notes: ""  , nsys:  1, ncomp:  2, nparm:   9, ncorr:  1, seq:  2, compid: "B" , hpmag:  8.86, theta:  163.00, rho:  0.56, dtheta:   99.9, drho:  99.9},$        
{ name: "HD112985"   , type: "F" , qual: "A" , notes: ""  , nsys:  1, ncomp:  2, nparm:   9, ncorr:  1, seq:  1, compid: "A" , hpmag:  6.02, theta:	0.0, rho:   0.0, dtheta:   99.9, drho:  99.9},$        
{ name: "HD117440"   , type: "F" , qual: "A" , notes: ""  , nsys:  1, ncomp:  2, nparm:   9, ncorr:  1, seq:  1, compid: "A" , hpmag:  4.64, theta:	0.0, rho:   0.0, dtheta:   99.9, drho:  99.9},$        
{ name: "HD117440"   , type: "F" , qual: "A" , notes: ""  , nsys:  1, ncomp:  2, nparm:   9, ncorr:  1, seq:  2, compid: "B" , hpmag:  5.03, theta:   98.00, rho:  0.22, dtheta:   99.9, drho:  99.9},$        
{ name: "HD122451"   , type: "F" , qual: "A" , notes: ""  , nsys:  1, ncomp:  2, nparm:   9, ncorr:  1, seq:  1, compid: "A" , hpmag:  0.58, theta:	0.0, rho:   0.0, dtheta:   99.9, drho:  99.9},$        
{ name: "HD122451"   , type: "F" , qual: "A" , notes: ""  , nsys:  1, ncomp:  2, nparm:   9, ncorr:  1, seq:  2, compid: "B" , hpmag:  3.95, theta:  234.00, rho:  0.87, dtheta:   99.9, drho:  99.9},$        
{ name: "HD123123"   , type: "F" , qual: "A" , notes: ""  , nsys:  1, ncomp:  2, nparm:   9, ncorr:  1, seq:  2, compid: "B" , hpmag:  8.23, theta:  131.00, rho:  0.26, dtheta:   99.9, drho:  99.9},$        
{ name: "HD123123"   , type: "F" , qual: "A" , notes: ""  , nsys:  1, ncomp:  2, nparm:   9, ncorr:  1, seq:  1, compid: "A" , hpmag:  8.14, theta:	0.0, rho:   0.0, dtheta:   99.9, drho:  99.9},$        
{ name: "HD124897"   , type: "F" , qual: "A" , notes: ""  , nsys:  1, ncomp:  2, nparm:   9, ncorr:  1, seq:  2, compid: "B" , hpmag:  3.49, theta:  198.00, rho:  0.26, dtheta:   99.9, drho:  99.9},$        
{ name: "HD124897"   , type: "F" , qual: "A" , notes: ""  , nsys:  1, ncomp:  2, nparm:   9, ncorr:  1, seq:  1, compid: "A" , hpmag:  0.16, theta:	0.0, rho:   0.0, dtheta:   99.9, drho:  99.9},$        
{ name: "HD129989"   , type: "F" , qual: "A" , notes: ""  , nsys:  1, ncomp:  2, nparm:   9, ncorr:  1, seq:  1, compid: "A" , hpmag:  2.65, theta:	0.0, rho:   0.0, dtheta:   99.9, drho:  99.9},$        
{ name: "HD129989"   , type: "F" , qual: "A" , notes: ""  , nsys:  1, ncomp:  2, nparm:   9, ncorr:  1, seq:  2, compid: "B" , hpmag:  4.85, theta:  341.00, rho:  2.87, dtheta:   99.9, drho:  99.9},$        
{ name: "HD134505"   , type: "F" , qual: "A" , notes: ""  , nsys:  1, ncomp:  2, nparm:   9, ncorr:  1, seq:  2, compid: "B" , hpmag:  8.90, theta:  215.60, rho:  2.11, dtheta:   99.9, drho:  99.9},$        
{ name: "HD134505"   , type: "F" , qual: "A" , notes: ""  , nsys:  1, ncomp:  2, nparm:   9, ncorr:  1, seq:  1, compid: "A" , hpmag:  7.67, theta:	0.0, rho:   0.0, dtheta:   99.9, drho:  99.9},$        
{ name: "HD146003"   , type: "L" , qual: "A" , notes: ""  , nsys:  1, ncomp:  2, nparm:  11, ncorr:  1, seq:  2, compid: "B" , hpmag:  8.47, theta:  225.00, rho:  0.52, dtheta:   2.00, drho:  0.00},$        
{ name: "HD146003"   , type: "L" , qual: "A" , notes: ""  , nsys:  1, ncomp:  2, nparm:  11, ncorr:  1, seq:  1, compid: "A" , hpmag:  6.75, theta:	0.0, rho:   0.0, dtheta:   99.9, drho:  99.9},$        
{ name: "HD150680"   , type: "L" , qual: "A" , notes: ""  , nsys:  1, ncomp:  2, nparm:  11, ncorr:  1, seq:  1, compid: "A" , hpmag:  3.02, theta:	0.0, rho:   0.0, dtheta:   99.9, drho:  99.9},$        
{ name: "HD150680"   , type: "L" , qual: "A" , notes: ""  , nsys:  1, ncomp:  2, nparm:  11, ncorr:  1, seq:  2, compid: "B" , hpmag:  5.71, theta:   78.10, rho:  1.55, dtheta:  -4.20, drho:  0.00},$        
{ name: "HD153162"   , type: "F" , qual: "B" , notes: ""  , nsys:  1, ncomp:  2, nparm:   9, ncorr:  1, seq:  1, compid: "A" , hpmag:  6.43, theta:	0.0, rho:   0.0, dtheta:   99.9, drho:  99.9},$        
{ name: "HD153162"   , type: "F" , qual: "B" , notes: ""  , nsys:  1, ncomp:  2, nparm:   9, ncorr:  1, seq:  2, compid: "B" , hpmag:  9.94, theta:  131.00, rho:  2.27, dtheta:   99.9, drho:  99.9},$        
{ name: "HD159532"   , type: "F" , qual: "B" , notes: ""  , nsys:  1, ncomp:  2, nparm:   9, ncorr:  1, seq:  1, compid: "A" , hpmag:  1.97, theta:	0.0, rho:   0.0, dtheta:   99.9, drho:  99.9},$        
{ name: "HD159532"   , type: "F" , qual: "B" , notes: ""  , nsys:  1, ncomp:  2, nparm:   9, ncorr:  1, seq:  2, compid: "B" , hpmag:  5.36, theta:  314.70, rho:  6.47, dtheta:   99.9, drho:  99.9},$        
{ name: "HD163755"   , type: "F" , qual: "A" , notes: ""  , nsys:  1, ncomp:  2, nparm:   9, ncorr:  1, seq:  2, compid: "B" , hpmag:  7.11, theta:  104.60, rho:  5.49, dtheta:   99.9, drho:  99.9},$        
{ name: "HD163755"   , type: "F" , qual: "A" , notes: ""  , nsys:  1, ncomp:  2, nparm:   9, ncorr:  1, seq:  1, compid: "A" , hpmag:  5.26, theta:	0.0, rho:   0.0, dtheta:   99.9, drho:  99.9},$        
{ name: "HD169420"   , type: "F" , qual: "A" , notes: ""  , nsys:  1, ncomp:  2, nparm:   9, ncorr:  1, seq:  1, compid: "A" , hpmag:  5.05, theta:	0.0, rho:   0.0, dtheta:   99.9, drho:  99.9},$        
{ name: "HD169420"   , type: "F" , qual: "A" , notes: ""  , nsys:  1, ncomp:  2, nparm:   9, ncorr:  1, seq:  2, compid: "B" , hpmag:  7.47, theta:  283.80, rho:  1.66, dtheta:   99.9, drho:  99.9},$        
{ name: "HD172768"   , type: "F" , qual: "D" , notes: "D" , nsys:  1, ncomp:  2, nparm:   9, ncorr:  1, seq:  2, compid: "B" , hpmag:  7.98, theta:  125.00, rho:  0.13, dtheta:   99.9, drho:  99.9},$        
{ name: "HD172768"   , type: "F" , qual: "D" , notes: "D" , nsys:  1, ncomp:  2, nparm:   9, ncorr:  1, seq:  1, compid: "A" , hpmag:  7.44, theta:	0.0, rho:   0.0, dtheta:   99.9, drho:  99.9},$        
{ name: "HD183912"   , type: "L" , qual: "A" , notes: ""  , nsys:  1, ncomp:  2, nparm:  11, ncorr:  1, seq:  1, compid: "A" , hpmag:  3.36, theta:	0.0, rho:   0.0, dtheta:   99.9, drho:  99.9},$        
{ name: "HD183912"   , type: "L" , qual: "A" , notes: ""  , nsys:  1, ncomp:  2, nparm:  11, ncorr:  1, seq:  2, compid: "C" , hpmag:  5.48, theta:  152.20, rho:  0.39, dtheta:  -2.40, drho: -0.01},$        
{ name: "HD187076"   , type: "F" , qual: "A" , notes: ""  , nsys:  1, ncomp:  2, nparm:   9, ncorr:  1, seq:  2, compid: "B" , hpmag:  4.95, theta:   62.00, rho:  0.11, dtheta:   99.9, drho:  99.9},$        
{ name: "HD187076"   , type: "F" , qual: "A" , notes: ""  , nsys:  1, ncomp:  2, nparm:   9, ncorr:  1, seq:  1, compid: "A" , hpmag:  4.32, theta:	0.0, rho:   0.0, dtheta:   99.9, drho:  99.9},$        
{ name: "HD192876"   , type: "F" , qual: "B" , notes: ""  , nsys:  1, ncomp:  2, nparm:   9, ncorr:  1, seq:  1, compid: "A" , hpmag:  4.44, theta:	0.0, rho:   0.0, dtheta:   99.9, drho:  99.9},$        
{ name: "HD192876"   , type: "F" , qual: "B" , notes: ""  , nsys:  1, ncomp:  2, nparm:   9, ncorr:  1, seq:  2, compid: "E" , hpmag:  8.60, theta:  355.00, rho:  0.65, dtheta:   99.9, drho:  99.9},$        
{ name: "HD192947"   , type: "F" , qual: "B" , notes: ""  , nsys:  1, ncomp:  2, nparm:   9, ncorr:  1, seq:  1, compid: "A" , hpmag:  4.44, theta:	0.0, rho:   0.0, dtheta:   99.9, drho:  99.9},$        
{ name: "HD192947"   , type: "F" , qual: "B" , notes: ""  , nsys:  1, ncomp:  2, nparm:   9, ncorr:  1, seq:  2, compid: "E" , hpmag:  8.60, theta:  355.00, rho:  0.65, dtheta:   99.9, drho:  99.9},$        
{ name: "HD193495"   , type: "F" , qual: "A" , notes: ""  , nsys:  1, ncomp:  2, nparm:   9, ncorr:  1, seq:  2, compid: "C" , hpmag:  9.14, theta:   75.00, rho:  0.68, dtheta:   99.9, drho:  99.9},$        
{ name: "HD193495"   , type: "F" , qual: "A" , notes: ""  , nsys:  1, ncomp:  2, nparm:   9, ncorr:  1, seq:  1, compid: "B" , hpmag:  6.16, theta:	0.0, rho:   0.0, dtheta:   99.9, drho:  99.9},$        
{ name: "HD197964"   , type: "I" , qual: "A" , notes: ""  , nsys:  1, ncomp:  2, nparm:  12, ncorr:  1, seq:  1, compid: "A" , hpmag:  4.44, theta:	0.0, rho:   0.0, dtheta:   99.9, drho:  99.9},$        
{ name: "HD197964"   , type: "I" , qual: "A" , notes: ""  , nsys:  1, ncomp:  2, nparm:  12, ncorr:  1, seq:  2, compid: "B" , hpmag:  5.25, theta:  266.72, rho:  9.39, dtheta:  -0.04, drho: -0.02},$        
{ name: "HD217005"   , type: "F" , qual: "A" , notes: ""  , nsys:  1, ncomp:  2, nparm:   9, ncorr:  1, seq:  1, compid: "A" , hpmag:  7.74, theta:	0.0, rho:   0.0, dtheta:   99.9, drho:  99.9},$        
{ name: "HD217005"   , type: "F" , qual: "A" , notes: ""  , nsys:  1, ncomp:  2, nparm:   9, ncorr:  1, seq:  2, compid: "B" , hpmag:  9.32, theta:  343.26, rho:  9.09, dtheta:   99.9, drho:  99.9}$ 
	]

  hdmo = [ $
{ name: "HD9053"   , period:	 193.79, time:     8446.30, axis:      4.91, ecc:  0.00, w:     0.00, i:    50.34, omega:   25.33},$	    
{ name: "HD21754"  , period:	 960.00, time:     7546.57, axis:      4.25, ecc:  0.40, w:   326.32, i:    36.95, omega:  207.61},$	    
{ name: "HD23817"  , period:	1911.50, time:     8872.48, axis:     27.10, ecc:  0.21, w:    13.80, i:    82.85, omega:   22.39},$	    
{ name: "HD34334"  , period:	 434.80, time:     8348.12, axis:      7.24, ecc:  0.10, w:    40.00, i:    52.93, omega:   56.20},$	    
{ name: "HD48915"  , period:   18295.40, time:   -27123.70, axis:   2490.40, ecc:  0.59, w:   327.27, i:   136.53, omega:   44.86},$	    
{ name: "HD49293"  , period:	1760.90, time:     1942.50, axis:      6.63, ecc:  0.40, w:   172.00, i:    96.25, omega:   47.63},$	    
{ name: "HD61421"  , period:   14748.00, time:     -196.00, axis:   1179.00, ecc:  0.36, w:    88.80, i:    31.91, omega:  284.80},$	    
{ name: "HD69142"  , period:	 930.00, time:     8559.22, axis:     10.86, ecc:  0.40, w:   140.00, i:   136.31, omega:  250.97},$	    
{ name: "HD88284"  , period:	1585.80, time:     8664.39, axis:     16.79, ecc:  0.14, w:   238.90, i:    79.49, omega:  249.62},$	    
{ name: "HD112985" , period:	 422.03, time:     7947.67, axis:     11.67, ecc:  0.49, w:   316.39, i:   120.07, omega:   59.27},$	    
{ name: "HD121370" , period:	 494.17, time:     8398.65, axis:     35.41, ecc:  0.26, w:   326.33, i:   116.57, omega:   74.53},$	    
{ name: "HD148856" , period:	 410.58, time:     8393.06, axis:     11.00, ecc:  0.55, w:    24.61, i:    46.38, omega:   17.81},$	    
{ name: "HD173764" , period:	 834.00, time:   -17519.10, axis:      5.12, ecc:  0.35, w:    33.90, i:   116.20, omega:  114.21},$	    
{ name: "HD176411" , period:	1270.60, time:     1718.50, axis:     13.69, ecc:  0.27, w:    82.00, i:    87.52, omega:   59.67},$	    
{ name: "HD177716" , period:	  69.28, time:     8394.11, axis:      8.88, ecc:  0.00, w:     0.00, i:    62.53, omega:  128.10},$	    
{ name: "HD193495" , period:	1374.23, time:   -18477.67, axis:     28.75, ecc:  0.43, w:   120.10, i:    84.00, omega:  212.79},$	    
{ name: "HD211416" , period:	4198.00, time:     7862.93, axis:     32.34, ecc:  0.38, w:    76.00, i:   113.00, omega:  262.00},$	    
{ name: "HD215182" , period:	 818.00, time:     7988.11, axis:     13.60, ecc:  0.15, w:     5.61, i:    70.58, omega:  203.61},$	    
{ name: "HD218670" , period:	 409.61, time:   -23884.43, axis:      6.22, ecc:  0.66, w:   240.76, i:   122.82, omega:  127.59}$
	]

   bright = [ $
{ hr: "HR18"    , name:    "HD402"  , multiple:  ""  , ads:         ""  , adscomp:  ""  , dmag: 99.9 ,  sep: 9999.9 ,  multid:     "" ,  multcnt:  0 ,  flag: "*" },$
{ hr: "HR25"    , name:    "HD496"  , multiple:  ""  , ads:         ""  , adscomp:  ""  , dmag: 99.9 ,  sep: 9999.9 ,  multid:     "" ,  multcnt:  0 ,  flag: ""  },$
{ hr: "HR46"    , name:   "HD1014"  , multiple:  ""  , ads:   "ADS180"  , adscomp:  ""  , dmag:  6.0 ,  sep:    3.0 ,  multid:     "" ,  multcnt:  0 ,  flag: "*" },$
{ hr: "HR48"    , name:   "HD1038"  , multiple:  ""  , ads:         ""  , adscomp:  ""  , dmag: 99.9 ,  sep: 9999.9 ,  multid:     "" ,  multcnt:  0 ,  flag: "*" },$
{ hr: "HR74"    , name:   "HD1522"  , multiple: "W"  , ads:         ""  , adscomp:  ""  , dmag:  4.8 ,  sep:  108.8 ,  multid: "AC"   ,  multcnt:  3 ,  flag: "*" },$
{ hr: "HR79"    , name:   "HD1632"  , multiple:  ""  , ads:         ""  , adscomp:  ""  , dmag: 99.9 ,  sep: 9999.9 ,  multid:     "" ,  multcnt:  0 ,  flag: ""  },$
{ hr: "HR98"    , name:   "HD2151"  , multiple:  ""  , ads:         ""  , adscomp:  ""  , dmag: 99.9 ,  sep: 9999.9 ,  multid:     "" ,  multcnt:  0 ,  flag: "*" },$
{ hr: "HR165"   , name:   "HD3627"  , multiple:  ""  , ads:   "ADS548"  , adscomp:  ""  , dmag:  8.2 ,  sep:   28.7 ,  multid: "AB"   ,  multcnt:  3 ,  flag: "*" },$
{ hr: "HR188"   , name:   "HD4128"  , multiple:  ""  , ads:         ""  , adscomp:  ""  , dmag: 99.9 ,  sep: 9999.9 ,  multid:     "" ,  multcnt:  0 ,  flag: "*" },$
{ hr: "HR215"   , name:   "HD4502"  , multiple: "W"  , ads:         ""  , adscomp:  ""  , dmag:  5.6 ,  sep:  162.7 ,  multid: "AD"   ,  multcnt:  4 ,  flag: "*" },$
{ hr: "HR248"   , name:   "HD5112"  , multiple:  ""  , ads:         ""  , adscomp:  ""  , dmag: 99.9 ,  sep: 9999.9 ,  multid:     "" ,  multcnt:  0 ,  flag: ""  },$
{ hr: "HR267"   , name:   "HD5437"  , multiple:  ""  , ads:         ""  , adscomp:  ""  , dmag: 99.9 ,  sep: 9999.9 ,  multid:     "" ,  multcnt:  0 ,  flag: ""  },$
{ hr: "HR304"   , name:   "HD6311"  , multiple:  ""  , ads:         ""  , adscomp:  ""  , dmag: 99.9 ,  sep: 9999.9 ,  multid:     "" ,  multcnt:  0 ,  flag: "*" },$
{ hr: "HR322"   , name:   "HD6595"  , multiple: "W"  , ads:         ""  , adscomp:  ""  , dmag:  0.2 ,  sep:    1.0 ,  multid: "AB"   ,  multcnt:  3 ,  flag: "*" },$
{ hr: "HR334"   , name:   "HD6805"  , multiple: "W"  , ads:         ""  , adscomp:  ""  , dmag:  6.7 ,  sep:  233.5 ,  multid:     "" ,  multcnt:  0 ,  flag: "*" },$
{ hr: "HR400"   , name:   "HD8498"  , multiple:  ""  , ads:         ""  , adscomp:  ""  , dmag: 99.9 ,  sep: 9999.9 ,  multid:     "" ,  multcnt:  0 ,  flag: "*" },$
{ hr: "HR429"   , name:   "HD9053"  , multiple:  ""  , ads:         ""  , adscomp:  ""  , dmag: 99.9 ,  sep: 9999.9 ,  multid:     "" ,  multcnt:  0 ,  flag: "*" },$
{ hr: "HR434"   , name:   "HD9138"  , multiple: "W"  , ads:         ""  , adscomp:  ""  , dmag:  5.6 ,  sep:  182.5 ,  multid: "AB"   ,  multcnt:  3 ,  flag: "*" },$
{ hr: "HR440"   , name:   "HD9362"  , multiple:  ""  , ads:         ""  , adscomp:  ""  , dmag: 99.9 ,  sep: 9999.9 ,  multid:     "" ,  multcnt:  0 ,  flag: ""  },$
{ hr: "HR468"   , name:  "HD10052"  , multiple:  ""  , ads:         ""  , adscomp:  ""  , dmag: 99.9 ,  sep: 9999.9 ,  multid:     "" ,  multcnt:  0 ,  flag: ""  },$
{ hr: "HR472"   , name:  "HD10144"  , multiple:  ""  , ads:         ""  , adscomp:  ""  , dmag: 99.9 ,  sep: 9999.9 ,  multid:     "" ,  multcnt:  0 ,  flag: "*" },$
{ hr: "HR489"   , name:  "HD10380"  , multiple:  ""  , ads:         ""  , adscomp:  ""  , dmag: 99.9 ,  sep: 9999.9 ,  multid:     "" ,  multcnt:  0 ,  flag: ""  },$
{ hr: "HR500"   , name:  "HD10550"  , multiple:  ""  , ads:         ""  , adscomp:  ""  , dmag: 99.9 ,  sep: 9999.9 ,  multid:     "" ,  multcnt:  0 ,  flag: ""  },$
{ hr: "HR509"   , name:  "HD10700"  , multiple: "W"  , ads:         ""  , adscomp:  ""  , dmag:  9.5 ,  sep:   89.8 ,  multid:     "" ,  multcnt:  0 ,  flag: ""  },$
{ hr: "HR513"   , name:  "HD10824"  , multiple:  ""  , ads:         ""  , adscomp:  ""  , dmag: 99.9 ,  sep: 9999.9 ,  multid:     "" ,  multcnt:  0 ,  flag: ""  },$
{ hr: "HR539"   , name:  "HD11353"  , multiple: "W"  , ads:         ""  , adscomp:  ""  , dmag:  6.2 ,  sep:  187.0 ,  multid:     "" ,  multcnt:  0 ,  flag: "*" },$
{ hr: "HR566"   , name:  "HD11937"  , multiple: "W"  , ads:         ""  , adscomp:  ""  , dmag:  6.5 ,  sep:    4.8 ,  multid:     "" ,  multcnt:  0 ,  flag: "*" },$
{ hr: "HR602"   , name:  "HD12524"  , multiple:  ""  , ads:         ""  , adscomp:  ""  , dmag: 99.9 ,  sep: 9999.9 ,  multid:     "" ,  multcnt:  0 ,  flag: ""  },$
{ hr: "HR631"   , name:  "HD13325"  , multiple:  ""  , ads:         ""  , adscomp:  ""  , dmag: 99.9 ,  sep: 9999.9 ,  multid:     "" ,  multcnt:  0 ,  flag: ""  },$
{ hr: "HR648"   , name:  "HD13596"  , multiple:  ""  , ads:         ""  , adscomp:  ""  , dmag: 99.9 ,  sep: 9999.9 ,  multid:     "" ,  multcnt:  0 ,  flag: "*" },$
{ hr: "HR794"   , name:  "HD16815"  , multiple:  ""  , ads:         ""  , adscomp:  ""  , dmag: 99.9 ,  sep: 9999.9 ,  multid:     "" ,  multcnt:  0 ,  flag: ""  },$
{ hr: "HR843"   , name:  "HD17709"  , multiple: "A"  , ads:         ""  , adscomp:  ""  , dmag: 99.9 ,  sep: 9999.9 ,  multid:     "" ,  multcnt:  0 ,  flag: "*" },$
{ hr: "HR874"   , name:  "HD18322"  , multiple:  ""  , ads:         ""  , adscomp:  ""  , dmag: 99.9 ,  sep: 9999.9 ,  multid:     "" ,  multcnt:  0 ,  flag: "*" },$
{ hr: "HR902"   , name:  "HD18700"  , multiple:  ""  , ads:         ""  , adscomp:  ""  , dmag: 99.9 ,  sep: 9999.9 ,  multid:     "" ,  multcnt:  0 ,  flag: ""  },$
{ hr: "HR911"   , name:  "HD18884"  , multiple:  ""  , ads:         ""  , adscomp:  ""  , dmag: 99.9 ,  sep: 9999.9 ,  multid:     "" ,  multcnt:  0 ,  flag: "*" },$
{ hr: "HR1003"  , name:  "HD20720"  , multiple:  ""  , ads:  "ADS2472"  , adscomp:  ""  , dmag:  6.2 ,  sep:    5.5 ,  multid: "AB"   ,  multcnt:  6 ,  flag: "*" },$
{ hr: "HR 999"  , name:  "HD20644"  , multiple:  ""  , ads:         ""  , adscomp:  ""  , dmag: 99.9 ,  sep: 9999.9 ,  multid:     "" ,  multcnt:  0 ,  flag: ""  },$
{ hr: "HR1030"  , name:  "HD21120"  , multiple:  ""  , ads:         ""  , adscomp:  ""  , dmag: 99.9 ,  sep: 9999.9 ,  multid:     "" ,  multcnt:  0 ,  flag: "*" },$
{ hr: "HR1066"  , name:  "HD21754"  , multiple:  ""  , ads:         ""  , adscomp:  ""  , dmag:  2.0 ,  sep:    0.0 ,  multid:     "" ,  multcnt:  0 ,  flag: "*" },$
{ hr: "HR1143"  , name:  "HD23319"  , multiple: "W"  , ads:         ""  , adscomp:  ""  , dmag:  7.6 ,  sep:    5.4 ,  multid:     "" ,  multcnt:  0 ,  flag: ""  },$
{ hr: "HR1136"  , name:  "HD23249"  , multiple:  ""  , ads:         ""  , adscomp:  ""  , dmag: 99.9 ,  sep: 9999.9 ,  multid:     "" ,  multcnt:  0 ,  flag: "*" },$
{ hr: "HR1175"  , name:  "HD23817"  , multiple: "W"  , ads:         ""  , adscomp:  ""  , dmag:  4.2 ,  sep: 1480.0 ,  multid:     "" ,  multcnt:  0 ,  flag: "*" },$
{ hr: "HR1250"  , name:  "HD25470"  , multiple:  ""  , ads:         ""  , adscomp:  ""  , dmag: 99.9 ,  sep: 9999.9 ,  multid:     "" ,  multcnt:  0 ,  flag: "*" },$
{ hr: "HR1256"  , name:  "HD25604"  , multiple: "W"  , ads:         ""  , adscomp:  ""  , dmag:  5.0 ,  sep:  137.2 ,  multid:     "" ,  multcnt:  0 ,  flag: "*" },$
{ hr: "HR1262"  , name:  "HD25680"  , multiple: "W"  , ads:         ""  , adscomp:  ""  , dmag:  2.7 ,  sep:  170.1 ,  multid: "AB"   ,  multcnt:  3 ,  flag: "*" },$
{ hr: "HR1326"  , name:  "HD26967"  , multiple:  ""  , ads:         ""  , adscomp:  ""  , dmag: 99.9 ,  sep: 9999.9 ,  multid:     "" ,  multcnt:  0 ,  flag: "*" },$
{ hr: "HR1336"  , name:  "HD27256"  , multiple: "W"  , ads:         ""  , adscomp:  ""  , dmag:  8.6 ,  sep:   48.5 ,  multid:     "" ,  multcnt:  0 ,  flag: ""  },$
{ hr: "HR1373"  , name:  "HD27697"  , multiple: "W"  , ads:         ""  , adscomp:  ""  , dmag:  8.7 ,  sep:  109.6 ,  multid: "AB"   ,  multcnt:  3 ,  flag: "*" },$
{ hr: "HR1411"  , name:  "HD28307"  , multiple: "W"  , ads:         ""  , adscomp:  ""  , dmag:  0.4 ,  sep:  337.4 ,  multid: "AB"   ,  multcnt:  4 ,  flag: "*" },$
{ hr: "HR1412"  , name:  "HD28319"  , multiple: "W"  , ads:         ""  , adscomp:  ""  , dmag:  0.4 ,  sep:  337.4 ,  multid: "AB"   ,  multcnt:  4 ,  flag: "*" },$
{ hr: "HR1437"  , name:  "HD28749"  , multiple:  ""  , ads:         ""  , adscomp:  ""  , dmag: 99.9 ,  sep: 9999.9 ,  multid:     "" ,  multcnt:  0 ,  flag: ""  },$
{ hr: "HR1452"  , name:  "HD29065"  , multiple:  ""  , ads:         ""  , adscomp:  ""  , dmag: 99.9 ,  sep: 9999.9 ,  multid:     "" ,  multcnt:  0 ,  flag: ""  },$
{ hr: "HR1457"  , name:  "HD29139"  , multiple:  ""  , ads:  "ADS3321"  , adscomp:  ""  , dmag:  9.8 ,  sep:  121.7 ,  multid: "AC"   ,  multcnt:  6 ,  flag: "*" },$
{ hr: "HR1481"  , name:  "HD29503"  , multiple: "W"  , ads:         ""  , adscomp:  ""  , dmag:  3.4 ,  sep:    0.8 ,  multid:     "" ,  multcnt:  0 ,  flag: "*" },$
{ hr: "HR1580"  , name:  "HD31421"  , multiple:  ""  , ads:  "ADS3540"  , adscomp:  ""  , dmag:  7.5 ,  sep:  100.4 ,  multid: "AC"   ,  multcnt:  3 ,  flag: "*" },$
{ hr: "HR1577"  , name:  "HD31398"  , multiple:  ""  , ads:         ""  , adscomp:  ""  , dmag: 99.9 ,  sep: 9999.9 ,  multid:     "" ,  multcnt:  0 ,  flag: "*" },$
{ hr: "HR1601"  , name:  "HD31767"  , multiple:  ""  , ads:         ""  , adscomp:  ""  , dmag: 99.9 ,  sep: 9999.9 ,  multid:     "" ,  multcnt:  0 ,  flag: ""  },$
{ hr: "HR1652"  , name:  "HD32831"  , multiple: "W"  , ads:         ""  , adscomp:  ""  , dmag:  4.1 ,  sep:    3.0 ,  multid:     "" ,  multcnt:  0 ,  flag: "*" },$
{ hr: "HR1663"  , name:  "HD33042"  , multiple:  ""  , ads:         ""  , adscomp:  ""  , dmag: 99.9 ,  sep: 9999.9 ,  multid:     "" ,  multcnt:  0 ,  flag: "*" },$
{ hr: "HR1695"  , name:  "HD33684"  , multiple:  ""  , ads:         ""  , adscomp:  ""  , dmag: 99.9 ,  sep: 9999.9 ,  multid:     "" ,  multcnt:  0 ,  flag: "*" },$
{ hr: "HR1698"  , name:  "HD33856"  , multiple:  ""  , ads:  "ADS3797"  , adscomp:  ""  , dmag:  3.9 ,  sep:    6.9 ,  multid: "AB"   ,  multcnt:  3 ,  flag: "*" },$
{ hr: "HR1726"  , name:  "HD34334"  , multiple:  ""  , ads:  "ADS3872"  , adscomp:  ""  , dmag:  5.8 ,  sep:    4.2 ,  multid:     "" ,  multcnt:  0 ,  flag: "*" },$
{ hr: "HR1784"  , name:  "HD35369"  , multiple:  ""  , ads:         ""  , adscomp:  ""  , dmag: 99.9 ,  sep: 9999.9 ,  multid:     "" ,  multcnt:  0 ,  flag: ""  },$
{ hr: "HR1799"  , name:  "HD35536"  , multiple:  ""  , ads:         ""  , adscomp:  ""  , dmag: 99.9 ,  sep: 9999.9 ,  multid:     "" ,  multcnt:  0 ,  flag: ""  },$
{ hr: "HR1805"  , name:  "HD35620"  , multiple: "W"  , ads:         ""  , adscomp:  ""  , dmag:  3.2 ,  sep:  206.8 ,  multid: "AD"   ,  multcnt:  4 ,  flag: "*" },$
{ hr: "HR1829"  , name:  "HD36079"  , multiple:  ""  , ads:  "ADS4066"  , adscomp:  ""  , dmag:  4.5 ,  sep:    2.6 ,  multid: "AB"   ,  multcnt:  5 ,  flag: "*" },$
{ hr: "HR1862"  , name:  "HD36597"  , multiple:  ""  , ads:         ""  , adscomp:  ""  , dmag: 99.9 ,  sep: 9999.9 ,  multid:     "" ,  multcnt:  0 ,  flag: ""  },$
{ hr: "HR1865"  , name:  "HD36673"  , multiple:  ""  , ads:  "ADS4146"  , adscomp:  ""  , dmag:  8.5 ,  sep:   35.8 ,  multid: "AB"   ,  multcnt:  3 ,  flag: "*" },$
{ hr: "HR1922"  , name:  "HD37350"  , multiple:  ""  , ads:         ""  , adscomp:  ""  , dmag: 99.9 ,  sep: 9999.9 ,  multid:     "" ,  multcnt:  0 ,  flag: "*" },$
{ hr: "HR1907"  , name:  "HD37160"  , multiple:  ""  , ads:         ""  , adscomp:  ""  , dmag: 99.9 ,  sep: 9999.9 ,  multid:     "" ,  multcnt:  0 ,  flag: "*" },$
{ hr: "HR2040"  , name:  "HD39425"  , multiple:  ""  , ads:         ""  , adscomp:  ""  , dmag: 99.9 ,  sep: 9999.9 ,  multid:     "" ,  multcnt:  0 ,  flag: "*" },$
{ hr: "HR2018"  , name:  "HD39045"  , multiple:  ""  , ads:  "ADS4443"  , adscomp:  ""  , dmag:  5.9 ,  sep:   15.2 ,  multid:     "" ,  multcnt:  0 ,  flag: "*" },$
{ hr: "HR2037"  , name:  "HD39400"  , multiple:  ""  , ads:  "ADS4467"  , adscomp:  ""  , dmag:  8.4 ,  sep:   43.4 ,  multid:     "" ,  multcnt:  0 ,  flag: ""  },$
{ hr: "HR2120"  , name:  "HD40808"  , multiple:  ""  , ads:         ""  , adscomp:  ""  , dmag: 99.9 ,  sep: 9999.9 ,  multid:     "" ,  multcnt:  0 ,  flag: ""  },$
{ hr: "HR2113"  , name:  "HD40657"  , multiple:  ""  , ads:         ""  , adscomp:  ""  , dmag: 99.9 ,  sep: 9999.9 ,  multid:     "" ,  multcnt:  0 ,  flag: ""  },$
{ hr: "HR2168"  , name:  "HD42042"  , multiple:  ""  , ads:         ""  , adscomp:  ""  , dmag: 99.9 ,  sep: 9999.9 ,  multid:     "" ,  multcnt:  0 ,  flag: ""  },$
{ hr: "HR2216"  , name:  "HD42995"  , multiple:  ""  , ads:  "ADS4841"  , adscomp:  ""  , dmag:  2.0 ,  sep:    0.0 ,  multid:  "O"   ,  multcnt:  3 ,  flag: "*" },$
{ hr: "HR2219"  , name:  "HD43039"  , multiple:  ""  , ads:         ""  , adscomp:  ""  , dmag: 99.9 ,  sep: 9999.9 ,  multid:     "" ,  multcnt:  0 ,  flag: ""  },$
{ hr: "HR2269"  , name:  "HD44033"  , multiple:  ""  , ads:         ""  , adscomp:  ""  , dmag: 99.9 ,  sep: 9999.9 ,  multid:     "" ,  multcnt:  0 ,  flag: "*" },$
{ hr: "HR2352"  , name:  "HD45669"  , multiple:  ""  , ads:         ""  , adscomp:  ""  , dmag: 99.9 ,  sep: 9999.9 ,  multid:     "" ,  multcnt:  0 ,  flag: ""  },$
{ hr: "HR2286"  , name:  "HD44478"  , multiple:  ""  , ads:  "ADS4990"  , adscomp:  ""  , dmag:  8.1 ,  sep:  121.7 ,  multid: "AxBC" ,  multcnt:  3 ,  flag: "*" },$
{ hr: "HR2326"  , name:  "HD45348"  , multiple:  ""  , ads:         ""  , adscomp:  ""  , dmag: 99.9 ,  sep: 9999.9 ,  multid:     "" ,  multcnt:  0 ,  flag: "*" },$
{ hr: "HR2355"  , name:  "HD45724"  , multiple: "W"  , ads:         ""  , adscomp:  ""  , dmag:  4.0 ,  sep:   19.3 ,  multid:     "" ,  multcnt:  0 ,  flag: ""  },$
{ hr: "HR2429"  , name:  "HD47205"  , multiple:  ""  , ads:         ""  , adscomp:  ""  , dmag: 99.9 ,  sep: 9999.9 ,  multid:     "" ,  multcnt:  0 ,  flag: ""  },$
{ hr: "HR2458"  , name:  "HD47886"  , multiple:  ""  , ads:         ""  , adscomp:  ""  , dmag: 99.9 ,  sep: 9999.9 ,  multid:     "" ,  multcnt:  0 ,  flag: ""  },$
{ hr: "HR2469"  , name:  "HD48217"  , multiple:  ""  , ads:         ""  , adscomp:  ""  , dmag: 99.9 ,  sep: 9999.9 ,  multid:     "" ,  multcnt:  0 ,  flag: "*" },$
{ hr: "HR2473"  , name:  "HD48329"  , multiple:  ""  , ads:  "ADS5381"  , adscomp:  ""  , dmag:  6.0 ,  sep:  110.3 ,  multid:     "" ,  multcnt:  0 ,  flag: "*" },$
{ hr: "HR2478"  , name:  "HD48433"  , multiple:  ""  , ads:  "ADS5387"  , adscomp:  ""  , dmag:  8.4 ,  sep:   27.2 ,  multid:     "" ,  multcnt:  0 ,  flag: "*" },$
{ hr: "HR2491"  , name:  "HD48915"  , multiple:  ""  , ads:  "ADS5423"  , adscomp:  ""  , dmag: 10.3 ,  sep:   11.2 ,  multid: "AB"   ,  multcnt:  4 ,  flag: "*" },$
{ hr: "HR2503"  , name:  "HD49161"  , multiple:  ""  , ads:         ""  , adscomp:  ""  , dmag: 99.9 ,  sep: 9999.9 ,  multid:     "" ,  multcnt:  0 ,  flag: ""  },$
{ hr: "HR2506"  , name:  "HD49293"  , multiple:  ""  , ads:         ""  , adscomp:  ""  , dmag: 99.9 ,  sep: 9999.9 ,  multid:     "" ,  multcnt:  0 ,  flag: "*" },$
{ hr: "HR2574"  , name:  "HD50778"  , multiple:  ""  , ads:         ""  , adscomp:  ""  , dmag: 99.9 ,  sep: 9999.9 ,  multid:     "" ,  multcnt:  0 ,  flag: "*" },$
{ hr: "HR2608"  , name:  "HD51799"  , multiple:  ""  , ads:         ""  , adscomp:  ""  , dmag: 99.9 ,  sep: 9999.9 ,  multid:     "" ,  multcnt:  0 ,  flag: ""  },$
{ hr: "HR2652"  , name:  "HD53047"  , multiple:  ""  , ads:         ""  , adscomp:  ""  , dmag: 99.9 ,  sep: 9999.9 ,  multid:     "" ,  multcnt:  0 ,  flag: "*" },$
{ hr: "HR2639"  , name:  "HD52666"  , multiple:  ""  , ads:         ""  , adscomp:  ""  , dmag: 99.9 ,  sep: 9999.9 ,  multid:     "" ,  multcnt:  0 ,  flag: ""  },$
{ hr: "HR2693"  , name:  "HD54605"  , multiple:  ""  , ads:         ""  , adscomp:  ""  , dmag: 99.9 ,  sep: 9999.9 ,  multid:     "" ,  multcnt:  0 ,  flag: "*" },$
{ hr: "HR2736"  , name:  "HD55865"  , multiple: "W"  , ads:         ""  , adscomp: "A"  , dmag:  1.9 ,  sep:   13.6 ,  multid:     "" ,  multcnt:  0 ,  flag: "*" },$
{ hr: "HR2735"  , name:  "HD55864"  , multiple: "W"  , ads:         ""  , adscomp: "B"  , dmag:  1.9 ,  sep:   13.6 ,  multid:     "" ,  multcnt:  0 ,  flag: "*" },$
{ hr: "HR2697"  , name:  "HD54719"  , multiple:  ""  , ads:  "ADS5846"  , adscomp:  ""  , dmag:  6.5 ,  sep:    1.9 ,  multid: "AB"   ,  multcnt:  3 ,  flag: "*" },$
{ hr: "HR2821"  , name:  "HD58207"  , multiple:  ""  , ads:         ""  , adscomp:  ""  , dmag: 99.9 ,  sep: 9999.9 ,  multid:     "" ,  multcnt:  0 ,  flag: "*" },$
{ hr: "HR2854"  , name:  "HD58972"  , multiple:  ""  , ads:  "ADS6100"  , adscomp:  ""  , dmag:  5.9 ,  sep:  130.0 ,  multid: "AD"   ,  multcnt:  4 ,  flag: "*" },$
{ hr: "HR2867"  , name:  "HD59381"  , multiple:  ""  , ads:         ""  , adscomp:  ""  , dmag: 99.9 ,  sep: 9999.9 ,  multid:     "" ,  multcnt:  0 ,  flag: ""  },$
{ hr: "HR2905"  , name:  "HD60522"  , multiple: "W"  , ads:         ""  , adscomp:  ""  , dmag:  9.0 ,  sep:   46.1 ,  multid:     "" ,  multcnt:  0 ,  flag: "*" },$
{ hr: "HR2943"  , name:  "HD61421"  , multiple:  ""  , ads:  "ADS6251"  , adscomp:  ""  , dmag: 10.4 ,  sep:    4.6 ,  multid: "AC"   ,  multcnt:  5 ,  flag: "*" },$
{ hr: "HR2959"  , name:  "HD61772"  , multiple:  ""  , ads:         ""  , adscomp:  ""  , dmag: 99.9 ,  sep: 9999.9 ,  multid:     "" ,  multcnt:  0 ,  flag: ""  },$
{ hr: "HR2970"  , name:  "HD61935"  , multiple:  ""  , ads:         ""  , adscomp:  ""  , dmag: 99.9 ,  sep: 9999.9 ,  multid:     "" ,  multcnt:  0 ,  flag: "*" },$
{ hr: "HR2976"  , name:  "HD62082"  , multiple:  ""  , ads:         ""  , adscomp:  ""  , dmag: 99.9 ,  sep: 9999.9 ,  multid:     "" ,  multcnt:  0 ,  flag: ""  },$
{ hr: "HR3024"  , name:  "HD63295"  , multiple: "W"  , ads:         ""  , adscomp:  ""  , dmag:  5.8 ,  sep:   16.7 ,  multid:     "" ,  multcnt:  0 ,  flag: ""  },$
{ hr: "HR2973"  , name:  "HD62044"  , multiple: "W"  , ads:         ""  , adscomp:  ""  , dmag:  6.5 ,  sep:  182.2 ,  multid:     "" ,  multcnt:  0 ,  flag: "*" },$
{ hr: "HR2993"  , name:  "HD62576"  , multiple:  ""  , ads:  "ADS6324"  , adscomp:  ""  , dmag:  8.9 ,  sep:   26.2 ,  multid:     "" ,  multcnt:  0 ,  flag: ""  },$
{ hr: "HR2983"  , name:  "HD62285"  , multiple:  ""  , ads:         ""  , adscomp:  ""  , dmag: 99.9 ,  sep: 9999.9 ,  multid:     "" ,  multcnt:  0 ,  flag: ""  },$
{ hr: "HR2985"  , name:  "HD62345"  , multiple:  ""  , ads:  "ADS6321"  , adscomp:  ""  , dmag:  5.8 ,  sep:    7.1 ,  multid:     "" ,  multcnt:  0 ,  flag: "*" },$
{ hr: "HR2990"  , name:  "HD62509"  , multiple:  ""  , ads:  "ADS6335"  , adscomp:  ""  , dmag: 10.2 ,  sep:  201.1 ,  multid: "AC"   ,  multcnt:  7 ,  flag: "*" },$
{ hr: "HR3003"  , name:  "HD62721"  , multiple: "D"  , ads:         ""  , adscomp:  ""  , dmag:  0.0 ,  sep:    0.1 ,  multid:     "" ,  multcnt:  0 ,  flag: "*" },$
{ hr: "HR3013"  , name:  "HD62898"  , multiple:  ""  , ads:  "ADS6364"  , adscomp:  ""  , dmag:  5.2 ,  sep:   21.0 ,  multid: "AB"   ,  multcnt:  3 ,  flag: "*" },$
{ hr: "HR3041"  , name:  "HD63640"  , multiple:  ""  , ads:         ""  , adscomp:  ""  , dmag: 99.9 ,  sep: 9999.9 ,  multid:     "" ,  multcnt:  0 ,  flag: "*" },$
{ hr: "HR3045"  , name:  "HD63700"  , multiple:  ""  , ads:  "ADS6393"  , adscomp:  ""  , dmag:  9.5 ,  sep:    5.1 ,  multid:     "" ,  multcnt:  0 ,  flag: "*" },$
{ hr: "HR3043"  , name:  "HD63660"  , multiple:  ""  , ads:         ""  , adscomp:  ""  , dmag: 99.9 ,  sep: 9999.9 ,  multid:     "" ,  multcnt:  0 ,  flag: ""  },$
{ hr: "HR3052"  , name:  "HD63852"  , multiple:  ""  , ads:         ""  , adscomp:  ""  , dmag: 99.9 ,  sep: 9999.9 ,  multid:     "" ,  multcnt:  0 ,  flag: ""  },$
{ hr: "HR3080"  , name:  "HD64440"  , multiple:  ""  , ads:         ""  , adscomp:  ""  , dmag: 99.9 ,  sep: 9999.9 ,  multid:     "" ,  multcnt:  0 ,  flag: "*" },$
{ hr: "HR3099"  , name:  "HD65183"  , multiple:  ""  , ads:         ""  , adscomp:  ""  , dmag: 99.9 ,  sep: 9999.9 ,  multid:     "" ,  multcnt:  0 ,  flag: "*" },$
{ hr: "HR3141"  , name:  "HD65953"  , multiple:  ""  , ads:         ""  , adscomp:  ""  , dmag: 99.9 ,  sep: 9999.9 ,  multid:     "" ,  multcnt:  0 ,  flag: "*" },$
{ hr: "HR3155"  , name:  "HD66435"  , multiple:  ""  , ads:         ""  , adscomp:  ""  , dmag: 99.9 ,  sep: 9999.9 ,  multid:     "" ,  multcnt:  0 ,  flag: "*" },$
{ hr: "HR3145"  , name:  "HD66141"  , multiple: "W"  , ads:         ""  , adscomp:  ""  , dmag:  4.7 ,  sep:  241.4 ,  multid:     "" ,  multcnt:  0 ,  flag: ""  },$
{ hr: "HR3187"  , name:  "HD67582"  , multiple:  ""  , ads:         ""  , adscomp:  ""  , dmag: 99.9 ,  sep: 9999.9 ,  multid:     "" ,  multcnt:  0 ,  flag: "*" },$
{ hr: "HR3185"  , name:  "HD67523"  , multiple: "W"  , ads:         ""  , adscomp:  ""  , dmag: 10.9 ,  sep:   29.6 ,  multid:     "" ,  multcnt:  0 ,  flag: "*" },$
{ hr: "HR3225"  , name:  "HD68553"  , multiple:  ""  , ads:         ""  , adscomp:  ""  , dmag: 99.9 ,  sep: 9999.9 ,  multid:     "" ,  multcnt:  0 ,  flag: "*" },$
{ hr: "HR3247"  , name:  "HD69194"  , multiple:  ""  , ads:         ""  , adscomp:  ""  , dmag: 99.9 ,  sep: 9999.9 ,  multid:     "" ,  multcnt:  0 ,  flag: "*" },$
{ hr: "HR3243"  , name:  "HD69142"  , multiple: "W"  , ads:         ""  , adscomp:  ""  , dmag:  5.1 ,  sep:   51.1 ,  multid:     "" ,  multcnt:  0 ,  flag: "*" },$
{ hr: "HR3340"  , name:  "HD71701"  , multiple: "W"  , ads:         ""  , adscomp:  ""  , dmag:  7.7 ,  sep:   31.0 ,  multid:     "" ,  multcnt:  0 ,  flag: ""  },$
{ hr: "HR3282"  , name:  "HD70555"  , multiple:  ""  , ads:         ""  , adscomp:  ""  , dmag: 99.9 ,  sep: 9999.9 ,  multid:     "" ,  multcnt:  0 ,  flag: ""  },$
{ hr: "HR3296"  , name:  "HD70946"  , multiple:  ""  , ads:         ""  , adscomp:  ""  , dmag: 99.9 ,  sep: 9999.9 ,  multid:     "" ,  multcnt:  0 ,  flag: "*" },$
{ hr: "HR3319"  , name:  "HD71250"  , multiple:  ""  , ads:         ""  , adscomp:  ""  , dmag: 99.9 ,  sep: 9999.9 ,  multid:     "" ,  multcnt:  0 ,  flag: "*" },$
{ hr: "HR3357"  , name:  "HD72094"  , multiple: "W"  , ads:         ""  , adscomp:  ""  , dmag:  0.0 ,  sep:    0.3 ,  multid:  "O"   ,  multcnt:  3 ,  flag: "*" },$
{ hr: "HR3431"  , name:  "HD73840"  , multiple:  ""  , ads:         ""  , adscomp:  ""  , dmag: 99.9 ,  sep: 9999.9 ,  multid:     "" ,  multcnt:  0 ,  flag: "*" },$
{ hr: "HR3438"  , name:  "HD74006"  , multiple: "W"  , ads:         ""  , adscomp:  ""  , dmag:  8.5 ,  sep:   12.6 ,  multid:     "" ,  multcnt:  0 ,  flag: ""  },$
{ hr: "HR3444"  , name:  "HD74167"  , multiple:  ""  , ads:         ""  , adscomp:  ""  , dmag: 99.9 ,  sep: 9999.9 ,  multid:     "" ,  multcnt:  0 ,  flag: ""  },$
{ hr: "HR3445"  , name:  "HD74180"  , multiple: "W"  , ads:         ""  , adscomp:  ""  , dmag:  6.9 ,  sep:   37.5 ,  multid:     "" ,  multcnt:  0 ,  flag: "*" },$
{ hr: "HR3477"  , name:  "HD74772"  , multiple: "W"  , ads:         ""  , adscomp:  ""  , dmag:  7.1 ,  sep:   45.3 ,  multid:     "" ,  multcnt:  0 ,  flag: "*" },$
{ hr: "HR3461"  , name:  "HD74442"  , multiple:  ""  , ads:  "ADS6967"  , adscomp:  ""  , dmag:  7.5 ,  sep:   38.4 ,  multid:     "" ,  multcnt:  0 ,  flag: "*" },$
{ hr: "HR3485"  , name:  "HD74956"  , multiple: "W"  , ads:         ""  , adscomp:  ""  , dmag:  3.0 ,  sep:    2.2 ,  multid: "AB"   ,  multcnt:  4 ,  flag: "*" },$
{ hr: "HR3475"  , name:  "HD74739"  , multiple:  ""  , ads:  "ADS6988"  , adscomp: "A"  , dmag:  2.5 ,  sep:   30.4 ,  multid:     "" ,  multcnt:  0 ,  flag: "*" },$
{ hr: "HR3474"  , name:  "HD74738"  , multiple:  ""  , ads:  "ADS6988"  , adscomp: "B"  , dmag:  2.5 ,  sep:   30.4 ,  multid:     "" ,  multcnt:  0 ,  flag: "*" },$
{ hr: "HR3482"  , name:  "HD74874"  , multiple:  ""  , ads:  "ADS6993"  , adscomp:  ""  , dmag:  0.9 ,  sep:    0.2 ,  multid: "AB"   ,  multcnt:  6 ,  flag: "*" },$
{ hr: "HR3547"  , name:  "HD76294"  , multiple:  ""  , ads:         ""  , adscomp:  ""  , dmag: 99.9 ,  sep: 9999.9 ,  multid:     "" ,  multcnt:  0 ,  flag: ""  },$
{ hr: "HR3614"  , name:  "HD78004"  , multiple:  ""  , ads:         ""  , adscomp:  ""  , dmag: 99.9 ,  sep: 9999.9 ,  multid:     "" ,  multcnt:  0 ,  flag: ""  },$
{ hr: "HR3685"  , name:  "HD80007"  , multiple:  ""  , ads:         ""  , adscomp:  ""  , dmag: 99.9 ,  sep: 9999.9 ,  multid:     "" ,  multcnt:  0 ,  flag: "*" },$
{ hr: "HR3692"  , name:  "HD80108"  , multiple:  ""  , ads:         ""  , adscomp:  ""  , dmag: 99.9 ,  sep: 9999.9 ,  multid:     "" ,  multcnt:  0 ,  flag: "*" },$
{ hr: "HR3699"  , name:  "HD80404"  , multiple:  ""  , ads:         ""  , adscomp:  ""  , dmag: 99.9 ,  sep: 9999.9 ,  multid:     "" ,  multcnt:  0 ,  flag: "*" },$
{ hr: "HR3705"  , name:  "HD80493"  , multiple:  ""  , ads:         ""  , adscomp:  ""  , dmag: 99.9 ,  sep: 9999.9 ,  multid:     "" ,  multcnt:  0 ,  flag: "*" },$
{ hr: "HR3726"  , name:  "HD81034"  , multiple:  ""  , ads:         ""  , adscomp:  ""  , dmag: 99.9 ,  sep: 9999.9 ,  multid:     "" ,  multcnt:  0 ,  flag: ""  },$
{ hr: "HR3731"  , name:  "HD81146"  , multiple:  ""  , ads:  "ADS7351"  , adscomp:  ""  , dmag:  5.1 ,  sep:    2.5 ,  multid: "AB"   ,  multcnt:  3 ,  flag: "*" },$
{ hr: "HR3738"  , name:  "HD81420"  , multiple:  ""  , ads:         ""  , adscomp:  ""  , dmag: 99.9 ,  sep: 9999.9 ,  multid:     "" ,  multcnt:  0 ,  flag: "*" },$
{ hr: "HR3748"  , name:  "HD81797"  , multiple: "W"  , ads:         ""  , adscomp:  ""  , dmag:  7.5 ,  sep:  283.1 ,  multid: "AB"   ,  multcnt:  3 ,  flag: "*" },$
{ hr: "HR3765"  , name:  "HD82150"  , multiple:  ""  , ads:         ""  , adscomp:  ""  , dmag: 99.9 ,  sep: 9999.9 ,  multid:     "" ,  multcnt:  0 ,  flag: ""  },$
{ hr: "HR3773"  , name:  "HD82308"  , multiple:  ""  , ads:         ""  , adscomp:  ""  , dmag: 99.9 ,  sep: 9999.9 ,  multid:     "" ,  multcnt:  0 ,  flag: "*" },$
{ hr: "HR3779"  , name:  "HD82381"  , multiple:  ""  , ads:  "ADS7416"  , adscomp:  ""  , dmag:  4.4 ,  sep:   37.3 ,  multid:     "" ,  multcnt:  0 ,  flag: "*" },$
{ hr: "HR3834"  , name:  "HD83425"  , multiple:  ""  , ads:         ""  , adscomp:  ""  , dmag: 99.9 ,  sep: 9999.9 ,  multid:     "" ,  multcnt:  0 ,  flag: "*" },$
{ hr: "HR3845"  , name:  "HD83618"  , multiple:  ""  , ads:         ""  , adscomp:  ""  , dmag: 99.9 ,  sep: 9999.9 ,  multid:     "" ,  multcnt:  0 ,  flag: "*" },$
{ hr: "HR3884"  , name:  "HD84810"  , multiple:  ""  , ads:         ""  , adscomp:  ""  , dmag: 99.9 ,  sep: 9999.9 ,  multid:     "" ,  multcnt:  0 ,  flag: "*" },$
{ hr: "HR3873"  , name:  "HD84441"  , multiple:  ""  , ads:         ""  , adscomp:  ""  , dmag: 99.9 ,  sep: 9999.9 ,  multid:     "" ,  multcnt:  0 ,  flag: "*" },$
{ hr: "HR3912"  , name:  "HD85622"  , multiple:  ""  , ads:         ""  , adscomp:  ""  , dmag: 99.9 ,  sep: 9999.9 ,  multid:     "" ,  multcnt:  0 ,  flag: "*" },$
{ hr: "HR3905"  , name:  "HD85503"  , multiple:  ""  , ads:         ""  , adscomp:  ""  , dmag: 99.9 ,  sep: 9999.9 ,  multid:     "" ,  multcnt:  0 ,  flag: "*" },$
{ hr: "HR3915"  , name:  "HD85709"  , multiple:  ""  , ads:         ""  , adscomp:  ""  , dmag: 99.9 ,  sep: 9999.9 ,  multid:     "" ,  multcnt:  0 ,  flag: ""  },$
{ hr: "HR3923"  , name:  "HD85951"  , multiple:  ""  , ads:         ""  , adscomp:  ""  , dmag: 99.9 ,  sep: 9999.9 ,  multid:     "" ,  multcnt:  0 ,  flag: ""  },$
{ hr: "HR3980"  , name:  "HD87837"  , multiple:  ""  , ads:  "ADS7649"  , adscomp:  ""  , dmag:  7.7 ,  sep:    7.9 ,  multid:     "" ,  multcnt:  0 ,  flag: "*" },$
{ hr: "HR3982"  , name:  "HD87901"  , multiple:  ""  , ads:  "ADS7654"  , adscomp: "A"  , dmag:  6.8 ,  sep:  177.6 ,  multid: "AB"   ,  multcnt:  4 ,  flag: "*" },$
{ hr: "HR3994"  , name:  "HD88284"  , multiple:  ""  , ads:  "ADS7671"  , adscomp:  ""  , dmag:  7.7 ,  sep:  112.2 ,  multid: "AC"   ,  multcnt:  3 ,  flag: "*" },$
{ hr: "HR4007"  , name:  "HD88647"  , multiple:  ""  , ads:         ""  , adscomp:  ""  , dmag: 99.9 ,  sep: 9999.9 ,  multid:     "" ,  multcnt:  0 ,  flag: "*" },$
{ hr: "HR4035"  , name:  "HD89056"  , multiple:  ""  , ads:         ""  , adscomp:  ""  , dmag: 99.9 ,  sep: 9999.9 ,  multid:     "" ,  multcnt:  0 ,  flag: ""  },$
{ hr: "HR4050"  , name:  "HD89388"  , multiple: "W"  , ads:         ""  , adscomp:  ""  , dmag:  9.2 ,  sep:   16.4 ,  multid: "AB"   ,  multcnt:  3 ,  flag: "*" },$
{ hr: "HR4049"  , name:  "HD89353"  , multiple:  ""  , ads:         ""  , adscomp:  ""  , dmag: 99.9 ,  sep: 9999.9 ,  multid:     "" ,  multcnt:  0 ,  flag: "*" },$
{ hr: "HR4063"  , name:  "HD89682"  , multiple:  ""  , ads:         ""  , adscomp:  ""  , dmag: 99.9 ,  sep: 9999.9 ,  multid:     "" ,  multcnt:  0 ,  flag: "*" },$
{ hr: "HR4057"  , name:  "HD89484"  , multiple:  ""  , ads:  "ADS7724"  , adscomp: "A"  , dmag:  1.2 ,  sep:    4.5 ,  multid: "AB"   ,  multcnt:  4 ,  flag: "*" },$
{ hr: "HR4058"  , name:  "HD89485"  , multiple:  ""  , ads:  "ADS7724"  , adscomp: "B"  , dmag:  1.2 ,  sep:    4.5 ,  multid: "AB"   ,  multcnt:  4 ,  flag: "*" },$
{ hr: "HR4092"  , name:  "HD90362"  , multiple:  ""  , ads:         ""  , adscomp:  ""  , dmag: 99.9 ,  sep: 9999.9 ,  multid:     "" ,  multcnt:  0 ,  flag: ""  },$
{ hr: "HR4094"  , name:  "HD90432"  , multiple:  ""  , ads:         ""  , adscomp:  ""  , dmag: 99.9 ,  sep: 9999.9 ,  multid:     "" ,  multcnt:  0 ,  flag: ""  },$
{ hr: "HR4104"  , name:  "HD90610"  , multiple:  ""  , ads:         ""  , adscomp:  ""  , dmag: 99.9 ,  sep: 9999.9 ,  multid:     "" ,  multcnt:  0 ,  flag: "*" },$
{ hr: "HR4145"  , name:  "HD91550"  , multiple:  ""  , ads:  "ADS7834"  , adscomp:  ""  , dmag:  8.7 ,  sep:   19.1 ,  multid:     "" ,  multcnt:  0 ,  flag: ""  },$
{ hr: "HR4159"  , name:  "HD91942"  , multiple:  ""  , ads:         ""  , adscomp:  ""  , dmag: 99.9 ,  sep: 9999.9 ,  multid:     "" ,  multcnt:  0 ,  flag: ""  },$
{ hr: "HR4162"  , name:  "HD92036"  , multiple:  ""  , ads:         ""  , adscomp:  ""  , dmag: 99.9 ,  sep: 9999.9 ,  multid:     "" ,  multcnt:  0 ,  flag: ""  },$
{ hr: "HR4177"  , name:  "HD92397"  , multiple: "W"  , ads:         ""  , adscomp:  ""  , dmag:  3.4 ,  sep:   14.6 ,  multid:     "" ,  multcnt:  0 ,  flag: "*" },$
{ hr: "HR4179"  , name:  "HD92436"  , multiple: "W"  , ads:         ""  , adscomp:  ""  , dmag:  2.7 ,  sep:   23.5 ,  multid:     "" ,  multcnt:  0 ,  flag: "*" },$
{ hr: "HR4200"  , name:  "HD93070"  , multiple:  ""  , ads:         ""  , adscomp:  ""  , dmag: 99.9 ,  sep: 9999.9 ,  multid:     "" ,  multcnt:  0 ,  flag: "*" },$
{ hr: "HR4224"  , name:  "HD93655"  , multiple:  ""  , ads:         ""  , adscomp:  ""  , dmag: 99.9 ,  sep: 9999.9 ,  multid:     "" ,  multcnt:  0 ,  flag: ""  },$
{ hr: "HR4232"  , name:  "HD93813"  , multiple:  ""  , ads:         ""  , adscomp:  ""  , dmag: 99.9 ,  sep: 9999.9 ,  multid:     "" ,  multcnt:  0 ,  flag: ""  },$
{ hr: "HR4247"  , name:  "HD94264"  , multiple:  ""  , ads:         ""  , adscomp:  ""  , dmag: 99.9 ,  sep: 9999.9 ,  multid:     "" ,  multcnt:  0 ,  flag: "*" },$
{ hr: "HR4257"  , name:  "HD94510"  , multiple: "W"  , ads:         ""  , adscomp:  ""  , dmag:  2.7 ,  sep:  153.9 ,  multid: "AB"   ,  multcnt:  3 ,  flag: "*" },$
{ hr: "HR4266"  , name:  "HD94683"  , multiple: "W"  , ads:         ""  , adscomp:  ""  , dmag:  5.0 ,  sep:    7.1 ,  multid:     "" ,  multcnt:  0 ,  flag: ""  },$
{ hr: "HR4287"  , name:  "HD95272"  , multiple:  ""  , ads:         ""  , adscomp:  ""  , dmag: 99.9 ,  sep: 9999.9 ,  multid:     "" ,  multcnt:  0 ,  flag: "*" },$
{ hr: "HR4299"  , name:  "HD95578"  , multiple:  ""  , ads:         ""  , adscomp:  ""  , dmag: 99.9 ,  sep: 9999.9 ,  multid:     "" ,  multcnt:  0 ,  flag: ""  },$
{ hr: "HR4337"  , name:  "HD96918"  , multiple:  ""  , ads:         ""  , adscomp:  ""  , dmag: 99.9 ,  sep: 9999.9 ,  multid:     "" ,  multcnt:  0 ,  flag: "*" },$
{ hr: "HR4342"  , name:  "HD97271"  , multiple:  ""  , ads:         ""  , adscomp:  ""  , dmag: 99.9 ,  sep: 9999.9 ,  multid:     "" ,  multcnt:  0 ,  flag: ""  },$
{ hr: "HR4354"  , name:  "HD97576"  , multiple:  ""  , ads:         ""  , adscomp:  ""  , dmag: 99.9 ,  sep: 9999.9 ,  multid:     "" ,  multcnt:  0 ,  flag: ""  },$
{ hr: "HR4362"  , name:  "HD97778"  , multiple:  ""  , ads:         ""  , adscomp:  ""  , dmag: 99.9 ,  sep: 9999.9 ,  multid:     "" ,  multcnt:  0 ,  flag: "*" },$
{ hr: "HR4379"  , name:  "HD98292"  , multiple: "W"  , ads:         ""  , adscomp:  ""  , dmag:  7.5 ,  sep:   34.7 ,  multid:     "" ,  multcnt:  0 ,  flag: "*" },$
{ hr: "HR4377"  , name:  "HD98262"  , multiple:  ""  , ads:  "ADS8123"  , adscomp:  ""  , dmag:  6.0 ,  sep:    7.2 ,  multid:     "" ,  multcnt:  0 ,  flag: "*" },$
{ hr: "HR4382"  , name:  "HD98430"  , multiple:  ""  , ads:         ""  , adscomp:  ""  , dmag: 99.9 ,  sep: 9999.9 ,  multid:     "" ,  multcnt:  0 ,  flag: ""  },$
{ hr: "HR4402"  , name:  "HD99167"  , multiple:  ""  , ads:         ""  , adscomp:  ""  , dmag: 99.9 ,  sep: 9999.9 ,  multid:     "" ,  multcnt:  0 ,  flag: ""  },$
{ hr: "HR9084"  , name: "HD224889"  , multiple:  ""  , ads:         ""  , adscomp:  ""  , dmag: 99.9 ,  sep: 9999.9 ,  multid:     "" ,  multcnt:  0 ,  flag: ""  },$
{ hr: "HR9089"  , name: "HD224935"  , multiple:  ""  , ads:         ""  , adscomp:  ""  , dmag: 99.9 ,  sep: 9999.9 ,  multid:     "" ,  multcnt:  0 ,  flag: "*" },$
{ hr: "HR4450"  , name: "HD100407"  , multiple: "W"  , ads:         ""  , adscomp:  ""  , dmag:  7.0 ,  sep:   68.2 ,  multid:     "" ,  multcnt:  0 ,  flag: "*" },$
{ hr: "HR4471"  , name: "HD100920"  , multiple: "D"  , ads:         ""  , adscomp:  ""  , dmag:  4.5 ,  sep:    0.1 ,  multid:     "" ,  multcnt:  0 ,  flag: "*" },$
{ hr: "HR4503"  , name: "HD101666"  , multiple: "W"  , ads:         ""  , adscomp:  ""  , dmag:  3.1 ,  sep:   67.0 ,  multid: "AC"   ,  multcnt:  4 ,  flag: "*" },$
{ hr: "HR4526"  , name: "HD102461"  , multiple:  ""  , ads:         ""  , adscomp:  ""  , dmag: 99.9 ,  sep: 9999.9 ,  multid:     "" ,  multcnt:  0 ,  flag: "*" },$
{ hr: "HR4538"  , name: "HD102839"  , multiple:  ""  , ads:         ""  , adscomp:  ""  , dmag: 99.9 ,  sep: 9999.9 ,  multid:     "" ,  multcnt:  0 ,  flag: ""  },$
{ hr: "HR4546"  , name: "HD102964"  , multiple:  ""  , ads:         ""  , adscomp:  ""  , dmag: 99.9 ,  sep: 9999.9 ,  multid:     "" ,  multcnt:  0 ,  flag: ""  },$
{ hr: "HR4564"  , name: "HD103578"  , multiple: "W"  , ads:         ""  , adscomp:  ""  , dmag: 99.9 ,  sep:   90.0 ,  multid:     "" ,  multcnt:  0 ,  flag: "*" },$
{ hr: "HR4607"  , name: "HD104933"  , multiple:  ""  , ads:         ""  , adscomp:  ""  , dmag: 99.9 ,  sep: 9999.9 ,  multid:     "" ,  multcnt:  0 ,  flag: ""  },$
{ hr: "HR4700"  , name: "HD107446"  , multiple:  ""  , ads:         ""  , adscomp:  ""  , dmag: 99.9 ,  sep: 9999.9 ,  multid:     "" ,  multcnt:  0 ,  flag: "*" },$
{ hr: "HR4737"  , name: "HD108381"  , multiple:  ""  , ads:         ""  , adscomp:  ""  , dmag: 99.9 ,  sep: 9999.9 ,  multid:     "" ,  multcnt:  0 ,  flag: "*" },$
{ hr: "HR4755"  , name: "HD108759"  , multiple:  ""  , ads:         ""  , adscomp:  ""  , dmag: 99.9 ,  sep: 9999.9 ,  multid:     "" ,  multcnt:  0 ,  flag: ""  },$
{ hr: "HR4759"  , name: "HD108821"  , multiple:  ""  , ads:         ""  , adscomp:  ""  , dmag: 99.9 ,  sep: 9999.9 ,  multid:     "" ,  multcnt:  0 ,  flag: ""  },$
{ hr: "HR4786"  , name: "HD109379"  , multiple:  ""  , ads:         ""  , adscomp:  ""  , dmag: 99.9 ,  sep: 9999.9 ,  multid:     "" ,  multcnt:  0 ,  flag: "*" },$
{ hr: "HR4825"  , name: "HD110379"  , multiple:  ""  , ads:  "ADS8630"  , adscomp: "A"  , dmag:  0.1 ,  sep:    4.1 ,  multid: "AB"   ,  multcnt:  4 ,  flag: "*" },$
{ hr: "HR4826"  , name: "HD110380"  , multiple:  ""  , ads:  "ADS8630"  , adscomp: "B"  , dmag:  0.1 ,  sep:    4.1 ,  multid: "AB"   ,  multcnt:  4 ,  flag: "*" },$
{ hr: "HR4902"  , name: "HD112142"  , multiple: "D"  , ads:         ""  , adscomp:  ""  , dmag:  3.3 ,  sep:    0.0 ,  multid:     "" ,  multcnt:  0 ,  flag: "*" },$
{ hr: "HR4906"  , name: "HD112213"  , multiple:  ""  , ads:         ""  , adscomp:  ""  , dmag: 99.9 ,  sep: 9999.9 ,  multid:     "" ,  multcnt:  0 ,  flag: ""  },$
{ hr: "HR4923"  , name: "HD112985"  , multiple:  ""  , ads:         ""  , adscomp:  ""  , dmag: 99.9 ,  sep: 9999.9 ,  multid:     "" ,  multcnt:  0 ,  flag: "*" },$
{ hr: "HR4930"  , name: "HD113120"  , multiple:  ""  , ads:         ""  , adscomp:  ""  , dmag: 99.9 ,  sep: 9999.9 ,  multid:     "" ,  multcnt:  0 ,  flag: "*" },$
{ hr: "HR4954"  , name: "HD113996"  , multiple:  ""  , ads:         ""  , adscomp:  ""  , dmag: 99.9 ,  sep: 9999.9 ,  multid:     "" ,  multcnt:  0 ,  flag: ""  },$
{ hr: "HR5002"  , name: "HD115211"  , multiple:  ""  , ads:         ""  , adscomp:  ""  , dmag: 99.9 ,  sep: 9999.9 ,  multid:     "" ,  multcnt:  0 ,  flag: "*" },$
{ hr: "HR5015"  , name: "HD115521"  , multiple:  ""  , ads:         ""  , adscomp:  ""  , dmag: 99.9 ,  sep: 9999.9 ,  multid:     "" ,  multcnt:  0 ,  flag: "*" },$
{ hr: "HR5020"  , name: "HD115659"  , multiple: "W"  , ads:         ""  , adscomp:  ""  , dmag:  6.7 ,  sep:  138.4 ,  multid:     "" ,  multcnt:  0 ,  flag: "*" },$
{ hr: "HR5056"  , name: "HD116658"  , multiple: "W"  , ads:         ""  , adscomp:  ""  , dmag:  1.5 ,  sep:    0.0 ,  multid:  "O"   ,  multcnt:  5 ,  flag: "*" },$
{ hr: "HR5064"  , name: "HD116870"  , multiple:  ""  , ads:         ""  , adscomp:  ""  , dmag: 99.9 ,  sep: 9999.9 ,  multid:     "" ,  multcnt:  0 ,  flag: "*" },$
{ hr: "HR5089"  , name: "HD117440"  , multiple: "W"  , ads:         ""  , adscomp:  ""  , dmag:  0.1 ,  sep:    0.2 ,  multid:     "" ,  multcnt:  0 ,  flag: "*" },$
{ hr: "HR5123"  , name: "HD118508"  , multiple:  ""  , ads:         ""  , adscomp:  ""  , dmag: 99.9 ,  sep: 9999.9 ,  multid:     "" ,  multcnt:  0 ,  flag: ""  },$
{ hr: "HR5192"  , name: "HD120323"  , multiple:  ""  , ads:         ""  , adscomp:  ""  , dmag: 99.9 ,  sep: 9999.9 ,  multid:     "" ,  multcnt:  0 ,  flag: "*" },$
{ hr: "HR5200"  , name: "HD120477"  , multiple:  ""  , ads:         ""  , adscomp:  ""  , dmag: 99.9 ,  sep: 9999.9 ,  multid:     "" ,  multcnt:  0 ,  flag: "*" },$
{ hr: "HR5201"  , name: "HD120539"  , multiple:  ""  , ads:         ""  , adscomp:  ""  , dmag: 99.9 ,  sep: 9999.9 ,  multid:     "" ,  multcnt:  0 ,  flag: ""  },$
{ hr: "HR5194"  , name: "HD120404"  , multiple:  ""  , ads:         ""  , adscomp:  ""  , dmag: 99.9 ,  sep: 9999.9 ,  multid:     "" ,  multcnt:  0 ,  flag: ""  },$
{ hr: "HR5219"  , name: "HD120933"  , multiple:  ""  , ads:         ""  , adscomp:  ""  , dmag: 99.9 ,  sep: 9999.9 ,  multid:     "" ,  multcnt:  0 ,  flag: "*" },$
{ hr: "HR5235"  , name: "HD121370"  , multiple: "W"  , ads:         ""  , adscomp:  ""  , dmag:  6.0 ,  sep:  112.6 ,  multid:     "" ,  multcnt:  0 ,  flag: "*" },$
{ hr: "HR5267"  , name: "HD122451"  , multiple: "W"  , ads:         ""  , adscomp:  ""  , dmag:  3.2 ,  sep:    1.3 ,  multid:     "" ,  multcnt:  0 ,  flag: "*" },$
{ hr: "HR5287"  , name: "HD123123"  , multiple:  ""  , ads:         ""  , adscomp:  ""  , dmag: 99.9 ,  sep: 9999.9 ,  multid:     "" ,  multcnt:  0 ,  flag: ""  },$
{ hr: "HR5288"  , name: "HD123139"  , multiple: "W"  , ads:         ""  , adscomp:  ""  , dmag: 12.0 ,  sep:   69.9 ,  multid:     "" ,  multcnt:  0 ,  flag: "*" },$
{ hr: "HR5315"  , name: "HD124294"  , multiple:  ""  , ads:         ""  , adscomp:  ""  , dmag: 99.9 ,  sep: 9999.9 ,  multid:     "" ,  multcnt:  0 ,  flag: "*" },$
{ hr: "HR5340"  , name: "HD124897"  , multiple:  ""  , ads:         ""  , adscomp:  ""  , dmag: 99.9 ,  sep: 9999.9 ,  multid:     "" ,  multcnt:  0 ,  flag: "*" },$
{ hr: "HR5352"  , name: "HD125180"  , multiple:  ""  , ads:         ""  , adscomp:  ""  , dmag: 99.9 ,  sep: 9999.9 ,  multid:     "" ,  multcnt:  0 ,  flag: ""  },$
{ hr: "HR5339"  , name: "HD124882"  , multiple:  ""  , ads:         ""  , adscomp:  ""  , dmag: 99.9 ,  sep: 9999.9 ,  multid:     "" ,  multcnt:  0 ,  flag: ""  },$
{ hr: "HR5410"  , name: "HD126927"  , multiple:  ""  , ads:         ""  , adscomp:  ""  , dmag: 99.9 ,  sep: 9999.9 ,  multid:     "" ,  multcnt:  0 ,  flag: ""  },$
{ hr: "HR5429"  , name: "HD127665"  , multiple:  ""  , ads:  "ADS9296"  , adscomp:  ""  , dmag:  8.2 ,  sep:   42.2 ,  multid:     "" ,  multcnt:  0 ,  flag: ""  },$
{ hr: "HR5485"  , name: "HD129456"  , multiple:  ""  , ads:         ""  , adscomp:  ""  , dmag: 99.9 ,  sep: 9999.9 ,  multid:     "" ,  multcnt:  0 ,  flag: "*" },$
{ hr: "HR5506"  , name: "HD129989"  , multiple:  ""  , ads:  "ADS9372"  , adscomp: "A"  , dmag:  2.6 ,  sep:    2.8 ,  multid: "AB"   ,  multcnt:  3 ,  flag: "*" },$
{ hr: "HR5505"  , name: "HD129988"  , multiple:  ""  , ads:  "ADS9372"  , adscomp: "B"  , dmag:  2.6 ,  sep:    2.8 ,  multid: "AB"   ,  multcnt:  3 ,  flag: "*" },$
{ hr: "HR5496"  , name: "HD129902"  , multiple:  ""  , ads:         ""  , adscomp:  ""  , dmag: 99.9 ,  sep: 9999.9 ,  multid:     "" ,  multcnt:  0 ,  flag: "*" },$
{ hr: "HR5526"  , name: "HD130694"  , multiple:  ""  , ads:         ""  , adscomp:  ""  , dmag: 99.9 ,  sep: 9999.9 ,  multid:     "" ,  multcnt:  0 ,  flag: "*" },$
{ hr: "HR5540"  , name: "HD131109"  , multiple:  ""  , ads:         ""  , adscomp:  ""  , dmag: 99.9 ,  sep: 9999.9 ,  multid:     "" ,  multcnt:  0 ,  flag: "*" },$
{ hr: "HR5600"  , name: "HD133124"  , multiple:  ""  , ads:         ""  , adscomp:  ""  , dmag: 99.9 ,  sep: 9999.9 ,  multid:     "" ,  multcnt:  0 ,  flag: ""  },$
{ hr: "HR5601"  , name: "HD133165"  , multiple:  ""  , ads:         ""  , adscomp:  ""  , dmag: 99.9 ,  sep: 9999.9 ,  multid:     "" ,  multcnt:  0 ,  flag: ""  },$
{ hr: "HR5603"  , name: "HD133216"  , multiple:  ""  , ads:         ""  , adscomp:  ""  , dmag: 99.9 ,  sep: 9999.9 ,  multid:     "" ,  multcnt:  0 ,  flag: "*" },$
{ hr: "HR5616"  , name: "HD133582"  , multiple:  ""  , ads:         ""  , adscomp:  ""  , dmag: 99.9 ,  sep: 9999.9 ,  multid:     "" ,  multcnt:  0 ,  flag: ""  },$
{ hr: "HR5622"  , name: "HD133774"  , multiple:  ""  , ads:         ""  , adscomp:  ""  , dmag: 99.9 ,  sep: 9999.9 ,  multid:     "" ,  multcnt:  0 ,  flag: ""  },$
{ hr: "HR5649"  , name: "HD134505"  , multiple: "W"  , ads:         ""  , adscomp:  ""  , dmag:  3.6 ,  sep:   71.9 ,  multid:     "" ,  multcnt:  0 ,  flag: "*" },$
{ hr: "HR5645"  , name: "HD134468"  , multiple:  ""  , ads:         ""  , adscomp:  ""  , dmag: 99.9 ,  sep: 9999.9 ,  multid:     "" ,  multcnt:  0 ,  flag: ""  },$
{ hr: "HR5666"  , name: "HD135291"  , multiple:  ""  , ads:         ""  , adscomp:  ""  , dmag: 99.9 ,  sep: 9999.9 ,  multid:     "" ,  multcnt:  0 ,  flag: ""  },$
{ hr: "HR5686"  , name: "HD135758"  , multiple:  ""  , ads:         ""  , adscomp:  ""  , dmag: 99.9 ,  sep: 9999.9 ,  multid:     "" ,  multcnt:  0 ,  flag: "*" },$
{ hr: "HR5725"  , name: "HD137066"  , multiple:  ""  , ads:         ""  , adscomp:  ""  , dmag: 99.9 ,  sep: 9999.9 ,  multid:     "" ,  multcnt:  0 ,  flag: ""  },$
{ hr: "HR5787"  , name: "HD138905"  , multiple:  ""  , ads:  "ADS9704"  , adscomp:  ""  , dmag:  0.2 ,  sep:    0.1 ,  multid: "AP"   ,  multcnt:  3 ,  flag: "*" },$
{ hr: "HR5784"  , name: "HD138816"  , multiple:  ""  , ads:         ""  , adscomp:  ""  , dmag: 99.9 ,  sep: 9999.9 ,  multid:     "" ,  multcnt:  0 ,  flag: ""  },$
{ hr: "HR5771"  , name: "HD138538"  , multiple: "W"  , ads:         ""  , adscomp:  ""  , dmag:  5.4 ,  sep:   83.2 ,  multid:     "" ,  multcnt:  0 ,  flag: "*" },$
{ hr: "HR5797"  , name: "HD139127"  , multiple: "W"  , ads:         ""  , adscomp:  ""  , dmag:  6.7 ,  sep:   11.8 ,  multid:     "" ,  multcnt:  0 ,  flag: "*" },$
{ hr: "HR5838"  , name: "HD139997"  , multiple: "W"  , ads:         ""  , adscomp:  ""  , dmag:  5.0 ,  sep:  172.0 ,  multid:     "" ,  multcnt:  0 ,  flag: ""  },$
{ hr: "HR5854"  , name: "HD140573"  , multiple:  ""  , ads:  "ADS9765"  , adscomp:  ""  , dmag:  8.3 ,  sep:   58.2 ,  multid: "AB"   ,  multcnt:  3 ,  flag: "*" },$
{ hr: "HR5899"  , name: "HD141992"  , multiple:  ""  , ads:         ""  , adscomp:  ""  , dmag: 99.9 ,  sep: 9999.9 ,  multid:     "" ,  multcnt:  0 ,  flag: ""  },$
{ hr: "HR5908"  , name: "HD142198"  , multiple:  ""  , ads:         ""  , adscomp:  ""  , dmag: 99.9 ,  sep: 9999.9 ,  multid:     "" ,  multcnt:  0 ,  flag: ""  },$
{ hr: "HR6048"  , name: "HD145897"  , multiple:  ""  , ads:         ""  , adscomp:  ""  , dmag: 99.9 ,  sep: 9999.9 ,  multid:     "" ,  multcnt:  0 ,  flag: "*" },$
{ hr: "HR6030"  , name: "HD145544"  , multiple: "W"  , ads:         ""  , adscomp:  ""  , dmag:  8.0 ,  sep:   30.0 ,  multid:     "" ,  multcnt:  0 ,  flag: ""  },$
{ hr: "HR6055"  , name: "HD146003"  , multiple:  ""  , ads:         ""  , adscomp:  ""  , dmag: 99.9 ,  sep: 9999.9 ,  multid:     "" ,  multcnt:  0 ,  flag: "*" },$
{ hr: "HR6075"  , name: "HD146791"  , multiple: "W"  , ads:         ""  , adscomp:  ""  , dmag:  9.1 ,  sep:  110.6 ,  multid:     "" ,  multcnt:  0 ,  flag: "*" },$
{ hr: "HR6072"  , name: "HD146686"  , multiple: "W"  , ads:         ""  , adscomp:  ""  , dmag:  6.0 ,  sep:   44.9 ,  multid:     "" ,  multcnt:  0 ,  flag: "*" },$
{ hr: "HR6081"  , name: "HD147084"  , multiple:  ""  , ads:         ""  , adscomp:  ""  , dmag: 99.9 ,  sep: 9999.9 ,  multid:     "" ,  multcnt:  0 ,  flag: "*" },$
{ hr: "HR6107"  , name: "HD147749"  , multiple: "W"  , ads:         ""  , adscomp:  ""  , dmag:  0.1 ,  sep:  364.4 ,  multid: "AB"   ,  multcnt:  4 ,  flag: ""  },$
{ hr: "HR6108"  , name: "HD147767"  , multiple:  ""  , ads:         ""  , adscomp:  ""  , dmag: 99.9 ,  sep: 9999.9 ,  multid:     "" ,  multcnt:  0 ,  flag: ""  },$
{ hr: "HR6108"  , name: "HD147767"  , multiple:  ""  , ads:         ""  , adscomp:  ""  , dmag: 99.9 ,  sep: 9999.9 ,  multid:     "" ,  multcnt:  0 ,  flag: ""  },$
{ hr: "HR6107"  , name: "HD147749"  , multiple: "W"  , ads:         ""  , adscomp:  ""  , dmag:  0.1 ,  sep:  364.4 ,  multid: "AB"   ,  multcnt:  4 ,  flag: ""  },$
{ hr: "HR6136"  , name: "HD148513"  , multiple:  ""  , ads:         ""  , adscomp:  ""  , dmag: 99.9 ,  sep: 9999.9 ,  multid:     "" ,  multcnt:  0 ,  flag: "*" },$
{ hr: "HR6134"  , name: "HD148478"  , multiple:  ""  , ads: "ADS10074"  , adscomp:  ""  , dmag:  4.2 ,  sep:    2.9 ,  multid:     "" ,  multcnt:  0 ,  flag: "*" },$
{ hr: "HR6148"  , name: "HD148856"  , multiple: "W"  , ads:         ""  , adscomp:  ""  , dmag:  7.3 ,  sep:  256.2 ,  multid:     "" ,  multcnt:  0 ,  flag: "*" },$
{ hr: "HR6212"  , name: "HD150680"  , multiple:  ""  , ads: "ADS10157"  , adscomp:  ""  , dmag:  2.6 ,  sep:    1.1 ,  multid:     "" ,  multcnt:  0 ,  flag: "*" },$
{ hr: "HR6163"  , name: "HD149324"  , multiple: "W"  , ads:         ""  , adscomp:  ""  , dmag:  7.8 ,  sep:   51.1 ,  multid:     "" ,  multcnt:  0 ,  flag: "*" },$
{ hr: "HR6227"  , name: "HD151203"  , multiple:  ""  , ads:         ""  , adscomp:  ""  , dmag: 99.9 ,  sep: 9999.9 ,  multid:     "" ,  multcnt:  0 ,  flag: ""  },$
{ hr: "HR6228"  , name: "HD151217"  , multiple: "W"  , ads:         ""  , adscomp:  ""  , dmag:  3.9 ,  sep:   82.5 ,  multid: "AB"   ,  multcnt:  3 ,  flag: ""  },$
{ hr: "HR6217"  , name: "HD150798"  , multiple:  ""  , ads:         ""  , adscomp:  ""  , dmag: 99.9 ,  sep: 9999.9 ,  multid:     "" ,  multcnt:  0 ,  flag: ""  },$
{ hr: "HR6229"  , name: "HD151249"  , multiple: "W"  , ads:         ""  , adscomp:  ""  , dmag:  9.5 ,  sep:   23.6 ,  multid:     "" ,  multcnt:  0 ,  flag: ""  },$
{ hr: "HR6258"  , name: "HD152173"  , multiple:  ""  , ads:         ""  , adscomp:  ""  , dmag: 99.9 ,  sep: 9999.9 ,  multid:     "" ,  multcnt:  0 ,  flag: ""  },$
{ hr: "HR6257"  , name: "HD152161"  , multiple:  ""  , ads:         ""  , adscomp:  ""  , dmag: 99.9 ,  sep: 9999.9 ,  multid:     "" ,  multcnt:  0 ,  flag: "*" },$
{ hr: "HR6271"  , name: "HD152334"  , multiple:  ""  , ads:         ""  , adscomp:  ""  , dmag: 99.9 ,  sep: 9999.9 ,  multid:     "" ,  multcnt:  0 ,  flag: "*" },$
{ hr: "HR6262"  , name: "HD152236"  , multiple:  ""  , ads:         ""  , adscomp:  ""  , dmag: 99.9 ,  sep: 9999.9 ,  multid:     "" ,  multcnt:  0 ,  flag: "*" },$
{ hr: "HR6266"  , name: "HD152293"  , multiple:  ""  , ads:         ""  , adscomp:  ""  , dmag: 99.9 ,  sep: 9999.9 ,  multid:     "" ,  multcnt:  0 ,  flag: "*" },$
{ hr: "HR6288"  , name: "HD152820"  , multiple:  ""  , ads:         ""  , adscomp:  ""  , dmag: 99.9 ,  sep: 9999.9 ,  multid:     "" ,  multcnt:  0 ,  flag: ""  },$
{ hr: "HR6299"  , name: "HD153210"  , multiple:  ""  , ads:         ""  , adscomp:  ""  , dmag: 99.9 ,  sep: 9999.9 ,  multid:     "" ,  multcnt:  0 ,  flag: "*" },$
{ hr: "HR6285"  , name: "HD152786"  , multiple:  ""  , ads:         ""  , adscomp:  ""  , dmag: 99.9 ,  sep: 9999.9 ,  multid:     "" ,  multcnt:  0 ,  flag: ""  },$
{ hr: "HR6295"  , name: "HD152980"  , multiple:  ""  , ads:         ""  , adscomp:  ""  , dmag: 99.9 ,  sep: 9999.9 ,  multid:     "" ,  multcnt:  0 ,  flag: ""  },$
{ hr: "HR6393"  , name: "HD155644"  , multiple: "W"  , ads:         ""  , adscomp:  ""  , dmag:  8.7 ,  sep:   30.3 ,  multid:     "" ,  multcnt:  0 ,  flag: ""  },$
{ hr: "HR6433"  , name: "HD156681"  , multiple:  ""  , ads:         ""  , adscomp:  ""  , dmag: 99.9 ,  sep: 9999.9 ,  multid:     "" ,  multcnt:  0 ,  flag: ""  },$
{ hr: "HR6417"  , name: "HD156277"  , multiple:  ""  , ads:         ""  , adscomp:  ""  , dmag: 99.9 ,  sep: 9999.9 ,  multid:     "" ,  multcnt:  0 ,  flag: ""  },$
{ hr: "HR6459"  , name: "HD157236"  , multiple:  ""  , ads:         ""  , adscomp:  ""  , dmag: 99.9 ,  sep: 9999.9 ,  multid:     "" ,  multcnt:  0 ,  flag: ""  },$
{ hr: "HR6526"  , name: "HD158899"  , multiple:  ""  , ads:         ""  , adscomp:  ""  , dmag: 99.9 ,  sep: 9999.9 ,  multid:     "" ,  multcnt:  0 ,  flag: "*" },$
{ hr: "HR6556"  , name: "HD159561"  , multiple: "A"  , ads:         ""  , adscomp:  ""  , dmag: 99.9 ,  sep:    0.1 ,  multid:     "" ,  multcnt:  0 ,  flag: "*" },$
{ hr: "HR6546"  , name: "HD159433"  , multiple:  ""  , ads:         ""  , adscomp:  ""  , dmag: 99.9 ,  sep: 9999.9 ,  multid:     "" ,  multcnt:  0 ,  flag: ""  },$
{ hr: "HR6553"  , name: "HD159532"  , multiple:  ""  , ads:         ""  , adscomp:  ""  , dmag: 99.9 ,  sep: 9999.9 ,  multid:     "" ,  multcnt:  0 ,  flag: "*" },$
{ hr: "HR6584"  , name: "HD160677"  , multiple:  ""  , ads:         ""  , adscomp:  ""  , dmag: 99.9 ,  sep: 9999.9 ,  multid:     "" ,  multcnt:  0 ,  flag: ""  },$
{ hr: "HR6583"  , name: "HD160668"  , multiple:  ""  , ads:         ""  , adscomp:  ""  , dmag: 99.9 ,  sep: 9999.9 ,  multid:     "" ,  multcnt:  0 ,  flag: ""  },$
{ hr: "HR6587"  , name: "HD160748"  , multiple:  ""  , ads:         ""  , adscomp:  ""  , dmag: 99.9 ,  sep: 9999.9 ,  multid:     "" ,  multcnt:  0 ,  flag: ""  },$
{ hr: "HR6603"  , name: "HD161096"  , multiple:  ""  , ads:         ""  , adscomp:  ""  , dmag: 99.9 ,  sep: 9999.9 ,  multid:     "" ,  multcnt:  0 ,  flag: "*" },$
{ hr: "HR6582"  , name: "HD160635"  , multiple:  ""  , ads:         ""  , adscomp:  ""  , dmag: 99.9 ,  sep: 9999.9 ,  multid:     "" ,  multcnt:  0 ,  flag: ""  },$
{ hr: "HR6623"  , name: "HD161797"  , multiple:  ""  , ads: "ADS10786"  , adscomp:  ""  , dmag:  6.4 ,  sep:   33.8 ,  multid: "AxBC" ,  multcnt:  4 ,  flag: "*" },$
{ hr: "HR6630"  , name: "HD161892"  , multiple: "W"  , ads:         ""  , adscomp:  ""  , dmag: 11.5 ,  sep:   41.7 ,  multid: "AC"   ,  multcnt:  3 ,  flag: ""  },$
{ hr: "HR6703"  , name: "HD163993"  , multiple:  ""  , ads:         ""  , adscomp:  ""  , dmag: 99.9 ,  sep: 9999.9 ,  multid:     "" ,  multcnt:  0 ,  flag: ""  },$
{ hr: "HR6682"  , name: "HD163376"  , multiple:  ""  , ads:         ""  , adscomp:  ""  , dmag: 99.9 ,  sep: 9999.9 ,  multid:     "" ,  multcnt:  0 ,  flag: ""  },$
{ hr: "HR6698"  , name: "HD163917"  , multiple:  ""  , ads:         ""  , adscomp:  ""  , dmag: 99.9 ,  sep: 9999.9 ,  multid:     "" ,  multcnt:  0 ,  flag: ""  },$
{ hr: "HR6694"  , name: "HD163756"  , multiple: "W"  , ads:         ""  , adscomp: "B"  , dmag:  1.8 ,  sep:    5.5 ,  multid: "AB"   ,  multcnt:  3 ,  flag: "*" },$
{ hr: "HR6693"  , name: "HD163755"  , multiple: "W"  , ads:         ""  , adscomp: "A"  , dmag:  1.8 ,  sep:    5.5 ,  multid: "AB"   ,  multcnt:  3 ,  flag: "*" },$
{ hr: "HR6706"  , name: "HD164064"  , multiple:  ""  , ads:         ""  , adscomp:  ""  , dmag: 99.9 ,  sep: 9999.9 ,  multid:     "" ,  multcnt:  0 ,  flag: "*" },$
{ hr: "HR6713"  , name: "HD164349"  , multiple:  ""  , ads:         ""  , adscomp:  ""  , dmag: 99.9 ,  sep: 9999.9 ,  multid:     "" ,  multcnt:  0 ,  flag: "*" },$
{ hr: "HR6715"  , name: "HD164358"  , multiple:  ""  , ads:         ""  , adscomp:  ""  , dmag: 99.9 ,  sep: 9999.9 ,  multid:     "" ,  multcnt:  0 ,  flag: ""  },$
{ hr: "HR6746"  , name: "HD165135"  , multiple:  ""  , ads:         ""  , adscomp:  ""  , dmag: 99.9 ,  sep: 9999.9 ,  multid:     "" ,  multcnt:  0 ,  flag: "*" },$
{ hr: "HR6816"  , name: "HD167036"  , multiple:  ""  , ads:         ""  , adscomp:  ""  , dmag: 99.9 ,  sep: 9999.9 ,  multid:     "" ,  multcnt:  0 ,  flag: "*" },$
{ hr: "HR6832"  , name: "HD167618"  , multiple: "W"  , ads:         ""  , adscomp:  ""  , dmag:  4.9 ,  sep:    3.5 ,  multid: "AB"   ,  multcnt:  4 ,  flag: "*" },$
{ hr: "HR6860"  , name: "HD168532"  , multiple:  ""  , ads:         ""  , adscomp:  ""  , dmag: 99.9 ,  sep: 9999.9 ,  multid:     "" ,  multcnt:  0 ,  flag: "*" },$
{ hr: "HR6858"  , name: "HD168415"  , multiple:  ""  , ads:         ""  , adscomp:  ""  , dmag: 99.9 ,  sep: 9999.9 ,  multid:     "" ,  multcnt:  0 ,  flag: ""  },$
{ hr: "HR6859"  , name: "HD168454"  , multiple:  ""  , ads: "ADS11264"  , adscomp:  ""  , dmag: 10.2 ,  sep:   58.1 ,  multid: "AD"   ,  multcnt:  4 ,  flag: "*" },$
{ hr: "HR6869"  , name: "HD168723"  , multiple: "W"  , ads:         ""  , adscomp:  ""  , dmag:  8.7 ,  sep:  179.7 ,  multid:     "" ,  multcnt:  0 ,  flag: "*" },$
{ hr: "HR6862"  , name: "HD168592"  , multiple:  ""  , ads:         ""  , adscomp:  ""  , dmag: 99.9 ,  sep: 9999.9 ,  multid:     "" ,  multcnt:  0 ,  flag: ""  },$
{ hr: "HR6855"  , name: "HD168339"  , multiple: "W"  , ads:         ""  , adscomp:  ""  , dmag:  4.6 ,  sep:    3.5 ,  multid: "AB"   ,  multcnt:  3 ,  flag: "*" },$
{ hr: "HR6895"  , name: "HD169414"  , multiple: "W"  , ads:         ""  , adscomp:  ""  , dmag:  6.5 ,  sep:  221.8 ,  multid:     "" ,  multcnt:  0 ,  flag: ""  },$
{ hr: "HR6879"  , name: "HD169022"  , multiple: "W"  , ads:         ""  , adscomp:  ""  , dmag: 12.3 ,  sep:   36.1 ,  multid:     "" ,  multcnt:  0 ,  flag: "*" },$
{ hr: "HR6896"  , name: "HD169420"  , multiple:  ""  , ads: "ADS11325"  , adscomp:  ""  , dmag:  3.6 ,  sep:    1.7 ,  multid:     "" ,  multcnt:  0 ,  flag: "*" },$
{ hr: "HR6913"  , name: "HD169916"  , multiple:  ""  , ads:         ""  , adscomp:  ""  , dmag: 99.9 ,  sep: 9999.9 ,  multid:     "" ,  multcnt:  0 ,  flag: "*" },$
{ hr: "HR6905"  , name: "HD169767"  , multiple:  ""  , ads:         ""  , adscomp:  ""  , dmag: 99.9 ,  sep: 9999.9 ,  multid:     "" ,  multcnt:  0 ,  flag: "*" },$
{ hr: "HR6959"  , name: "HD170975"  , multiple:  ""  , ads:         ""  , adscomp:  ""  , dmag: 99.9 ,  sep: 9999.9 ,  multid:     "" ,  multcnt:  0 ,  flag: ""  },$
{ hr: "HR6961"  , name: "HD171115"  , multiple:  ""  , ads:         ""  , adscomp:  ""  , dmag: 99.9 ,  sep: 9999.9 ,  multid:     "" ,  multcnt:  0 ,  flag: ""  },$
{ hr: "HR6973"  , name: "HD171443"  , multiple:  ""  , ads:         ""  , adscomp:  ""  , dmag: 99.9 ,  sep: 9999.9 ,  multid:     "" ,  multcnt:  0 ,  flag: "*" },$
{ hr: "HR6991"  , name: "HD171967"  , multiple:  ""  , ads:         ""  , adscomp:  ""  , dmag: 99.9 ,  sep: 9999.9 ,  multid:     "" ,  multcnt:  0 ,  flag: ""  },$
{ hr: "HR6982"  , name: "HD171759"  , multiple: "W"  , ads:         ""  , adscomp:  ""  , dmag:  7.9 ,  sep:   55.6 ,  multid:     "" ,  multcnt:  0 ,  flag: "*" },$
{ hr: "HR7046"  , name: "HD173460"  , multiple:  ""  , ads: "ADS11652"  , adscomp:  ""  , dmag:  7.7 ,  sep:   13.7 ,  multid:     "" ,  multcnt:  0 ,  flag: ""  },$
{ hr: "HR7063"  , name: "HD173764"  , multiple:  ""  , ads:         ""  , adscomp:  ""  , dmag: 99.9 ,  sep: 9999.9 ,  multid:     "" ,  multcnt:  0 ,  flag: "*" },$
{ hr: "HR7078"  , name: "HD174116"  , multiple:  ""  , ads: "ADS11713"  , adscomp:  ""  , dmag:  8.6 ,  sep:   16.6 ,  multid:     "" ,  multcnt:  0 ,  flag: ""  },$
{ hr: "HR7116"  , name: "HD174974"  , multiple:  ""  , ads: "ADS11794"  , adscomp:  ""  , dmag:  5.8 ,  sep:    2.5 ,  multid: "AB"   ,  multcnt:  3 ,  flag: "*" },$
{ hr: "HR7150"  , name: "HD175775"  , multiple:  ""  , ads:         ""  , adscomp:  ""  , dmag: 99.9 ,  sep: 9999.9 ,  multid:     "" ,  multcnt:  0 ,  flag: "*" },$
{ hr: "HR7127"  , name: "HD175329"  , multiple:  ""  , ads:         ""  , adscomp:  ""  , dmag: 99.9 ,  sep: 9999.9 ,  multid:     "" ,  multcnt:  0 ,  flag: ""  },$
{ hr: "HR7176"  , name: "HD176411"  , multiple: "W"  , ads:         ""  , adscomp:  ""  , dmag:  5.9 ,  sep:  131.1 ,  multid: "AB"   ,  multcnt:  3 ,  flag: "*" },$
{ hr: "HR7183"  , name: "HD176541"  , multiple:  ""  , ads:         ""  , adscomp:  ""  , dmag: 99.9 ,  sep: 9999.9 ,  multid:     "" ,  multcnt:  0 ,  flag: ""  },$
{ hr: "HR7192"  , name: "HD176670"  , multiple:  ""  , ads:         ""  , adscomp:  ""  , dmag: 99.9 ,  sep: 9999.9 ,  multid:     "" ,  multcnt:  0 ,  flag: ""  },$
{ hr: "HR7193"  , name: "HD176678"  , multiple:  ""  , ads:         ""  , adscomp:  ""  , dmag: 99.9 ,  sep: 9999.9 ,  multid:     "" ,  multcnt:  0 ,  flag: ""  },$
{ hr: "HR7217"  , name: "HD177241"  , multiple:  ""  , ads: "ADS11996"  , adscomp:  ""  , dmag:  9.9 ,  sep:   35.7 ,  multid:     "" ,  multcnt:  0 ,  flag: ""  },$
{ hr: "HR7234"  , name: "HD177716"  , multiple:  ""  , ads:         ""  , adscomp:  ""  , dmag: 99.9 ,  sep: 9999.9 ,  multid:     "" ,  multcnt:  0 ,  flag: "*" },$
{ hr: "HR7264"  , name: "HD178524"  , multiple: "W"  , ads:         ""  , adscomp:  ""  , dmag:  0.0 ,  sep:    0.1 ,  multid: "AB"   ,  multcnt:  3 ,  flag: "*" },$
{ hr: "HR7259"  , name: "HD178345"  , multiple:  ""  , ads:         ""  , adscomp:  ""  , dmag: 99.9 ,  sep: 9999.9 ,  multid:     "" ,  multcnt:  0 ,  flag: ""  },$
{ hr: "HR7350"  , name: "HD181925"  , multiple:  ""  , ads:         ""  , adscomp:  ""  , dmag: 99.9 ,  sep: 9999.9 ,  multid:     "" ,  multcnt:  0 ,  flag: ""  },$
{ hr: "HR7405"  , name: "HD183439"  , multiple: "W"  , ads:         ""  , adscomp:  ""  , dmag:  1.4 ,  sep:  413.7 ,  multid:     "" ,  multcnt:  0 ,  flag: "*" },$
{ hr: "HR7406"  , name: "HD183491"  , multiple:  ""  , ads:         ""  , adscomp:  ""  , dmag: 99.9 ,  sep: 9999.9 ,  multid:     "" ,  multcnt:  0 ,  flag: ""  },$
{ hr: "HR7417"  , name: "HD183912"  , multiple:  ""  , ads: "ADS12540"  , adscomp: "A"  , dmag:  2.0 ,  sep:   34.7 ,  multid: "AB"   ,  multcnt:  3 ,  flag: "*" },$
{ hr: "HR7418"  , name: "HD183914"  , multiple:  ""  , ads: "ADS12540"  , adscomp: "B"  , dmag:  2.0 ,  sep:   34.7 ,  multid: "AB"   ,  multcnt:  3 ,  flag: "*" },$
{ hr: "HR7429"  , name: "HD184406"  , multiple:  ""  , ads: "ADS12607"  , adscomp:  ""  , dmag:  5.0 ,  sep:  177.5 ,  multid: "AE"   ,  multcnt:  6 ,  flag: "*" },$
{ hr: "HR7475"  , name: "HD185622"  , multiple:  ""  , ads: "ADS12750"  , adscomp:  ""  , dmag:  2.7 ,  sep:   31.8 ,  multid:     "" ,  multcnt:  0 ,  flag: "*" },$
{ hr: "HR7536"  , name: "HD187076"  , multiple: "W"  , ads:         ""  , adscomp:  ""  , dmag: 99.9 ,  sep: 9999.9 ,  multid:     "" ,  multcnt:  0 ,  flag: "*" },$
{ hr: "HR7537"  , name: "HD187086"  , multiple:  ""  , ads:         ""  , adscomp:  ""  , dmag: 99.9 ,  sep: 9999.9 ,  multid:     "" ,  multcnt:  0 ,  flag: "*" },$
{ hr: "HR7557"  , name: "HD187642"  , multiple:  ""  , ads: "ADS13009"  , adscomp:  ""  , dmag:  8.6 ,  sep:  165.2 ,  multid: "AB"   ,  multcnt:  3 ,  flag: "*" },$
{ hr: "HR7570"  , name: "HD187929"  , multiple:  ""  , ads:         ""  , adscomp:  ""  , dmag: 99.9 ,  sep: 9999.9 ,  multid:     "" ,  multcnt:  0 ,  flag: "*" },$
{ hr: "HR7602"  , name: "HD188512"  , multiple:  ""  , ads: "ADS13110"  , adscomp:  ""  , dmag:  7.7 ,  sep:  175.0 ,  multid: "AC"   ,  multcnt:  3 ,  flag: "*" },$
{ hr: "HR7615"  , name: "HD188947"  , multiple:  ""  , ads: "ADS13149"  , adscomp:  ""  , dmag:  7.7 ,  sep:   46.0 ,  multid: "AC"   ,  multcnt:  5 ,  flag: "*" },$
{ hr: "HR7604"  , name: "HD188603"  , multiple:  ""  , ads:         ""  , adscomp:  ""  , dmag: 99.9 ,  sep: 9999.9 ,  multid:     "" ,  multcnt:  0 ,  flag: "*" },$
{ hr: "HR7635"  , name: "HD189319"  , multiple:  ""  , ads:         ""  , adscomp:  ""  , dmag: 99.9 ,  sep: 9999.9 ,  multid:     "" ,  multcnt:  0 ,  flag: "*" },$
{ hr: "HR7645"  , name: "HD189577"  , multiple:  ""  , ads: "ADS13230"  , adscomp:  ""  , dmag:  7.5 ,  sep:   28.5 ,  multid:     "" ,  multcnt:  0 ,  flag: "*" },$
{ hr: "HR7627"  , name: "HD189140"  , multiple:  ""  , ads:         ""  , adscomp:  ""  , dmag: 99.9 ,  sep: 9999.9 ,  multid:     "" ,  multcnt:  0 ,  flag: ""  },$
{ hr: "HR7665"  , name: "HD190248"  , multiple:  ""  , ads:         ""  , adscomp:  ""  , dmag: 99.9 ,  sep: 9999.9 ,  multid:     "" ,  multcnt:  0 ,  flag: "*" },$
{ hr: "HR7747"  , name: "HD192876"  , multiple:  ""  , ads: "ADS13632"  , adscomp:  ""  , dmag:  0.4 ,  sep:  377.7 ,  multid:  "*"   ,  multcnt:  9 ,  flag: "*" },$
{ hr: "HR7754"  , name: "HD192947"  , multiple:  ""  , ads: "ADS13645"  , adscomp:  ""  , dmag:  0.4 ,  sep:  377.7 ,  multid:  "*"   ,  multcnt:  9 ,  flag: "*" },$
{ hr: "HR7754"  , name: "HD192947"  , multiple:  ""  , ads: "ADS13645"  , adscomp:  ""  , dmag:  0.4 ,  sep:  377.7 ,  multid:  "*"   ,  multcnt:  9 ,  flag: "*" },$
{ hr: "HR7747"  , name: "HD192876"  , multiple:  ""  , ads: "ADS13632"  , adscomp:  ""  , dmag:  0.4 ,  sep:  377.7 ,  multid:  "*"   ,  multcnt:  9 ,  flag: "*" },$
{ hr: "HR7776"  , name: "HD193495"  , multiple: "W"  , ads:         ""  , adscomp:  ""  , dmag:  0.3 ,  sep:    0.0 ,  multid:  "*"   ,  multcnt:  8 ,  flag: "*" },$
{ hr: "HR7775"  , name: "HD193452"  , multiple:  ""  , ads: "ADS13717"  , adscomp:  ""  , dmag:  0.3 ,  sep:    0.0 ,  multid:  "*"   ,  multcnt:  8 ,  flag: "*" },$
{ hr: "HR7806"  , name: "HD194317"  , multiple:  ""  , ads:         ""  , adscomp:  ""  , dmag: 99.9 ,  sep: 9999.9 ,  multid:     "" ,  multcnt:  0 ,  flag: "*" },$
{ hr: "HR7873"  , name: "HD196321"  , multiple:  ""  , ads:         ""  , adscomp:  ""  , dmag: 99.9 ,  sep: 9999.9 ,  multid:     "" ,  multcnt:  0 ,  flag: ""  },$
{ hr: "HR7869"  , name: "HD196171"  , multiple: "W"  , ads:         ""  , adscomp:  ""  , dmag:  8.8 ,  sep:   66.0 ,  multid: "AB"   ,  multcnt:  3 ,  flag: ""  },$
{ hr: "HR7900"  , name: "HD196777"  , multiple:  ""  , ads:         ""  , adscomp:  ""  , dmag: 99.9 ,  sep: 9999.9 ,  multid:     "" ,  multcnt:  0 ,  flag: "*" },$
{ hr: "HR7909"  , name: "HD196917"  , multiple:  ""  , ads:         ""  , adscomp:  ""  , dmag: 99.9 ,  sep: 9999.9 ,  multid:     "" ,  multcnt:  0 ,  flag: ""  },$
{ hr: "HR7949"  , name: "HD197989"  , multiple:  ""  , ads: "ADS14274"  , adscomp:  ""  , dmag:  9.3 ,  sep:   54.9 ,  multid: "AB"   ,  multcnt:  3 ,  flag: "*" },$
{ hr: "HR7948"  , name: "HD197964"  , multiple:  ""  , ads: "ADS14279"  , adscomp: "A"  , dmag:  1.0 ,  sep:    9.8 ,  multid:     "" ,  multcnt:  0 ,  flag: "*" },$
{ hr: "HR7947"  , name: "HD197963"  , multiple:  ""  , ads: "ADS14279"  , adscomp: "B"  , dmag:  1.0 ,  sep:    9.8 ,  multid:     "" ,  multcnt:  0 ,  flag: "*" },$
{ hr: "HR7952"  , name: "HD198048"  , multiple:  ""  , ads:         ""  , adscomp:  ""  , dmag: 99.9 ,  sep: 9999.9 ,  multid:     "" ,  multcnt:  0 ,  flag: ""  },$
{ hr: "HR7986"  , name: "HD198700"  , multiple: "W"  , ads:         ""  , adscomp:  ""  , dmag:  8.8 ,  sep:   17.3 ,  multid:     "" ,  multcnt:  0 ,  flag: ""  },$
{ hr: "HR8128"  , name: "HD202369"  , multiple:  ""  , ads:         ""  , adscomp:  ""  , dmag: 99.9 ,  sep: 9999.9 ,  multid:     "" ,  multcnt:  0 ,  flag: "*" },$
{ hr: "HR8173"  , name: "HD203504"  , multiple:  ""  , ads: "ADS14909"  , adscomp:  ""  , dmag:  4.9 ,  sep:   36.2 ,  multid: "AB"   ,  multcnt:  3 ,  flag: "*" },$
{ hr: "HR8204"  , name: "HD204075"  , multiple:  ""  , ads: "ADS14971"  , adscomp:  ""  , dmag:  8.6 ,  sep:   21.3 ,  multid:     "" ,  multcnt:  0 ,  flag: "*" },$
{ hr: "HR8225"  , name: "HD204724"  , multiple:  ""  , ads: "ADS15027"  , adscomp:  ""  , dmag:  8.1 ,  sep:   29.8 ,  multid:     "" ,  multcnt:  0 ,  flag: ""  },$
{ hr: "HR8232"  , name: "HD204867"  , multiple:  ""  , ads: "ADS15050"  , adscomp:  ""  , dmag:  7.9 ,  sep:   35.5 ,  multid: "AB"   ,  multcnt:  3 ,  flag: "*" },$
{ hr: "HR8254"  , name: "HD205478"  , multiple: "A"  , ads:         ""  , adscomp:  ""  , dmag: 99.9 ,  sep:    0.1 ,  multid:  "*"   ,  multcnt:  0 ,  flag: "*" },$
{ hr: "HR8308"  , name: "HD206778"  , multiple:  ""  , ads: "ADS15268"  , adscomp:  ""  , dmag:  6.1 ,  sep:  142.5 ,  multid: "AC"   ,  multcnt:  3 ,  flag: "*" },$
{ hr: "HR8313"  , name: "HD206859"  , multiple:  ""  , ads:         ""  , adscomp:  ""  , dmag: 99.9 ,  sep: 9999.9 ,  multid:     "" ,  multcnt:  0 ,  flag: ""  },$
{ hr: "HR8350"  , name: "HD207932"  , multiple:  ""  , ads:         ""  , adscomp:  ""  , dmag: 99.9 ,  sep: 9999.9 ,  multid:     "" ,  multcnt:  0 ,  flag: "*" },$
{ hr: "HR8414"  , name: "HD209750"  , multiple: "W"  , ads:         ""  , adscomp:  ""  , dmag:  9.0 ,  sep:  113.0 ,  multid:     "" ,  multcnt:  0 ,  flag: "*" },$
{ hr: "HR8436"  , name: "HD210090"  , multiple:  ""  , ads:         ""  , adscomp:  ""  , dmag: 99.9 ,  sep: 9999.9 ,  multid:     "" ,  multcnt:  0 ,  flag: "*" },$
{ hr: "HR8458"  , name: "HD210502"  , multiple:  ""  , ads:         ""  , adscomp:  ""  , dmag: 99.9 ,  sep: 9999.9 ,  multid:     "" ,  multcnt:  0 ,  flag: ""  },$
{ hr: "HR8502"  , name: "HD211416"  , multiple: "A"  , ads:         ""  , adscomp:  ""  , dmag: 99.9 ,  sep:    0.1 ,  multid:     "" ,  multcnt:  0 ,  flag: "*" },$
{ hr: "HR8562"  , name: "HD213119"  , multiple:  ""  , ads:         ""  , adscomp:  ""  , dmag: 99.9 ,  sep: 9999.9 ,  multid:     "" ,  multcnt:  0 ,  flag: ""  },$
{ hr: "HR8556"  , name: "HD213009"  , multiple: "W"  , ads:         ""  , adscomp:  ""  , dmag:  8.8 ,  sep:    5.6 ,  multid:     "" ,  multcnt:  0 ,  flag: ""  },$
{ hr: "HR8650"  , name: "HD215182"  , multiple:  ""  , ads: "ADS16211"  , adscomp:  ""  , dmag:  5.1 ,  sep:   90.4 ,  multid: "AxBC" ,  multcnt:  6 ,  flag: "*" },$
{ hr: "HR8655"  , name: "HD215369"  , multiple: "W"  , ads:         ""  , adscomp:  ""  , dmag:  6.6 ,  sep:   24.4 ,  multid:     "" ,  multcnt:  0 ,  flag: ""  },$
{ hr: "HR8667"  , name: "HD215665"  , multiple:  ""  , ads:         ""  , adscomp:  ""  , dmag: 99.9 ,  sep: 9999.9 ,  multid:     "" ,  multcnt:  0 ,  flag: "*" },$
{ hr: "HR8684"  , name: "HD216131"  , multiple:  ""  , ads:         ""  , adscomp:  ""  , dmag: 99.9 ,  sep: 9999.9 ,  multid:     "" ,  multcnt:  0 ,  flag: ""  },$
{ hr: "HR8679"  , name: "HD216032"  , multiple: "W"  , ads:         ""  , adscomp:  ""  , dmag:  4.5 ,  sep:  132.5 ,  multid:     "" ,  multcnt:  0 ,  flag: "*" },$
{ hr: "HR8698"  , name: "HD216386"  , multiple:  ""  , ads:         ""  , adscomp:  ""  , dmag: 99.9 ,  sep: 9999.9 ,  multid:     "" ,  multcnt:  0 ,  flag: "*" },$
{ hr: "HR8747"  , name: "HD217364"  , multiple:  ""  , ads:         ""  , adscomp:  ""  , dmag: 99.9 ,  sep: 9999.9 ,  multid:     "" ,  multcnt:  0 ,  flag: ""  },$
{ hr: "HR8774"  , name: "HD217902"  , multiple:  ""  , ads:         ""  , adscomp:  ""  , dmag: 99.9 ,  sep: 9999.9 ,  multid:     "" ,  multcnt:  0 ,  flag: "*" },$
{ hr: "HR8812"  , name: "HD218594"  , multiple:  ""  , ads:         ""  , adscomp:  ""  , dmag: 99.9 ,  sep: 9999.9 ,  multid:     "" ,  multcnt:  0 ,  flag: ""  },$
{ hr: "HR8820"  , name: "HD218670"  , multiple:  ""  , ads:         ""  , adscomp:  ""  , dmag: 99.9 ,  sep: 9999.9 ,  multid:     "" ,  multcnt:  0 ,  flag: "*" },$
{ hr: "HR8841"  , name: "HD219449"  , multiple:  ""  , ads: "ADS16633"  , adscomp: "A"  , dmag:  4.8 ,  sep:   49.2 ,  multid: "AB"   ,  multcnt:  5 ,  flag: "*" },$
{ hr: "HR8852"  , name: "HD219615"  , multiple:  ""  , ads:         ""  , adscomp:  ""  , dmag: 99.9 ,  sep: 9999.9 ,  multid:     "" ,  multcnt:  0 ,  flag: "*" },$
{ hr: "HR8863"  , name: "HD219784"  , multiple:  ""  , ads:         ""  , adscomp:  ""  , dmag: 99.9 ,  sep: 9999.9 ,  multid:     "" ,  multcnt:  0 ,  flag: ""  },$
{ hr: "HR8878"  , name: "HD220009"  , multiple:  ""  , ads:         ""  , adscomp:  ""  , dmag: 99.9 ,  sep: 9999.9 ,  multid:     "" ,  multcnt:  0 ,  flag: ""  },$
{ hr: "HR8882"  , name: "HD220088"  , multiple:  ""  , ads:         ""  , adscomp:  ""  , dmag: 99.9 ,  sep: 9999.9 ,  multid:     "" ,  multcnt:  0 ,  flag: ""  },$
{ hr: "HR8892"  , name: "HD220321"  , multiple:  ""  , ads:         ""  , adscomp:  ""  , dmag: 99.9 ,  sep: 9999.9 ,  multid:     "" ,  multcnt:  0 ,  flag: ""  },$
{ hr: "HR8906"  , name: "HD220704"  , multiple:  ""  , ads:         ""  , adscomp:  ""  , dmag: 99.9 ,  sep: 9999.9 ,  multid:     "" ,  multcnt:  0 ,  flag: "*" },$
{ hr: "HR9004"  , name: "HD223075"  , multiple:  ""  , ads:         ""  , adscomp:  ""  , dmag: 99.9 ,  sep: 9999.9 ,  multid:     "" ,  multcnt:  0 ,  flag: "*" }$
	]

   brightrem = [ $
{ hr:   "HR18" , count:  1 ,  cat: "VAR" ,  remark: " Amp. 0.07V." },$
{ hr:   "HR46" , count:  1 ,  cat: "D"   ,  remark: " CPM." },$
{ hr:   "HR46" , count:  1 ,  cat: "G"   ,  remark: " Hyades group." },$
{ hr:   "HR46" , count:  1 ,  cat: "VAR" ,  remark: " Lb? 5.06 - 5.16V." },$
{ hr:   "HR48" , count:  1 ,  cat: "G"   ,  remark: " Wolf 630 group." },$
{ hr:   "HR48" , count:  1 ,  cat: "S"   ,  remark: " Ultraviolet FeII emission." },$
{ hr:   "HR48" , count:  1 ,  cat: "VAR" ,  remark: " Lb 4.26 - 4.46V." },$
{ hr:   "HR74" , count:  1 ,  cat: "D"   ,  remark: " Component B, 12.87v at 63, optical." },$
{ hr:   "HR74" , count:  1 ,  cat: "N"   ,  remark: " Deneb Kaitos Shemali; Deneb Kaitos Al Shamaliyy." },$
{ hr:   "HR74" , count:  1 ,  cat: "VAR" ,  remark: " 3.46 - 3.56V." },$
{ hr:   "HR98" , count:  1 ,  cat: "G"   ,  remark: " Zeta Her group." },$
{ hr:   "HR98" , count:  1 ,  cat: "S"   ,  remark: " Lithium/calcium ratio = 10 times solar value." },$
{ hr:   "HR98" , count:  1 ,  cat: "VAR" ,  remark: " 2.75 - 2.81V." },$
{ hr:  "HR165" , count:  1 ,  cat: "D"   ,  remark: " AB CPM.  Component C, 15.2v at 48 optical." },$
{ hr:  "HR165" , count:  1 ,  cat: "SB"  ,  remark: " ADS 548A, 15,000d, K 4.0k/s, V0 -8.5k/s, asini 785.  Unresolved by speckle interferometry 1983.93." },$
{ hr:  "HR188" , count:  1 ,  cat: "N"   ,  remark: " DIPHDA; Deneb Kaitos; Difda; Difda al Thani; Rana Secunda, the Second Frog (the First Frog is Fomalhaut = HR 8728)." },$
{ hr:  "HR188" , count:  1 ,  cat: "VAR" ,  remark: " 1.96 - 2.11V." },$
{ hr:  "HR215" , count:  1 ,  cat: "D"   ,  remark: " AB CPM.  Companions probably optical." },$
{ hr:  "HR215" , count:  1 ,  cat: "S"   ,  remark: " CaII emission." },$
{ hr:  "HR215" , count:  1 ,  cat: "SB"  ,  remark: " Component A of visual system, 17.7692d, K 26.3k/s, V0 -23.7k/s, asini 6.43.  Possible X-ray source 3U0032+24." },$
{ hr:  "HR215" , count:  1 ,  cat: "VAR" ,  remark: " Component A of visual system, EB 3.92 - 4.14V, 17.7695d." },$
{ hr:  "HR304" , count:  1 ,  cat: "VAR" ,  remark: " Amp. 0.10V." },$
{ hr:  "HR322" , count:  1 ,  cat: "D"   ,  remark: " Mag. and color blend of close pair 4.2, 4.2v.  C, 11.5v at 57." },$
{ hr:  "HR322" , count:  1 ,  cat: "DYN" ,  remark: " 0.013." },$
{ hr:  "HR334" , count:  1 ,  cat: "N"   ,  remark: " Dheneb; Deneb; Deneb Algenubi." },$
{ hr:  "HR400" , count:  1 ,  cat: "G"   ,  remark: " Wolf 630 group." },$
{ hr:  "HR429" , count:  1 ,  cat: "SB"  ,  remark: " 193.85d, K 16.0k/s, V0 +26.0k/s, asini 42.6." },$
{ hr:  "HR429" , count:  1 ,  cat: "VAR" ,  remark: " 3.39 - 3.49V." },$
{ hr:  "HR434" , count:  1 ,  cat: "R"   ,  remark: " Diam. 0.0030." },$
{ hr:  "HR472" , count:  1 ,  cat: "G"   ,  remark: " Member of Pleiades group." },$
{ hr:  "HR472" , count:  1 ,  cat: "N"   ,  remark: " ACHERNAR." },$
{ hr:  "HR472" , count:  1 ,  cat: "R"   ,  remark: " Diam. = 0.00185 - 0.00192." },$
{ hr:  "HR472" , count:  1 ,  cat: "RV"  ,  remark: " Period in RV and light (1.26d) seems best explained by rotation.  Weak but significant variations in strength of" },$
{ hr:  "HR472" , count:  2 ,  cat: "RV"  ,  remark: " MgII 4481.  RV of H gamma and HeI 4471 consistent with period, amp. 30k/s.  Variable light amp. 0.02V." },$
{ hr:  "HR472" , count:  1 ,  cat: "S"   ,  remark: " Lyman alpha and Lyman beta observed from COPERNICUS.  H alpha and H beta var. emission and possible high-velocity mass" },$
{ hr:  "HR472" , count:  2 ,  cat: "S"   ,  remark: " loss.  Expanding circumstellar shell." },$
{ hr:  "HR472" , count:  1 ,  cat: "VAR" ,  remark: " EB or Ell, amp. 0.02V.  H alpha var. emission and possible high-velocity mass loss.  Expanding circumstellar shell." },$
{ hr:  "HR539" , count:  1 ,  cat: "D"   ,  remark: " Second visual component optical." },$
{ hr:  "HR539" , count:  1 ,  cat: "N"   ,  remark: " Baten Kaitos." },$
{ hr:  "HR539" , count:  1 ,  cat: "SB"  ,  remark: " Component A of visual double.  1652d, K 3.3k/s, V0 +9.2k/s, asini 60.5. Unresolved by speckle interferometry." },$
{ hr:  "HR566" , count:  1 ,  cat: "D"   ,  remark: " CPM." },$
{ hr:  "HR648" , count:  1 ,  cat: "G"   ,  remark: " Zeta Her group." },$
{ hr:  "HR843" , count:  1 ,  cat: "S"   ,  remark: " Also classified K7III." },$
{ hr:  "HR874" , count:  1 ,  cat: "G"   ,  remark: " Wolf 630 group." },$
{ hr:  "HR874" , count:  1 ,  cat: "N"   ,  remark: " Azha." },$
{ hr:  "HR911" , count:  1 ,  cat: "N"   ,  remark: " MENKAR; Mekab; Menkab; Monkar." },$
{ hr:  "HR911" , count:  1 ,  cat: "S"   ,  remark: " Ultraviolet FeII emission." },$
{ hr:  "HR911" , count:  1 ,  cat: "VAR" ,  remark: " Lb? 2.45 - 2.54V.  Spectrum var." },$
{ hr: "HR1003" , count:  1 ,  cat: "D"   ,  remark: " AB binary, B is K0V.  C, 11v at 40 optical." },$
{ hr: "HR1003" , count:  1 ,  cat: "DYN" ,  remark: " 0.010." },$
{ hr: "HR1003" , count:  1 ,  cat: "G"   ,  remark: " Hyades group." },$
{ hr: "HR1003" , count:  1 ,  cat: "S"   ,  remark: " Ultraviolet FeII emission." },$
{ hr: "HR1003" , count:  1 ,  cat: "VAR" ,  remark: " Lb? 3.57 - 3.72V." },$
{ hr: "HR1030" , count:  1 ,  cat: "SB"  ,  remark: " 1654.9d, K 4.4k/s, V0 -20.1k/s, asini 96.7.  Unresolved by speckle interferometry." },$
{ hr: "HR1066" , count:  1 ,  cat: "SB"  ,  remark: " 4.5, 6.5v, sep. 0.011, 960.0d, K 8.3k/s, V0 +14.2k/s, asini 100.  Unresolved by speckle interferometry 1980.94 and" },$
{ hr: "HR1066" , count:  2 ,  cat: "SB"  ,  remark: " 1981.68." },$
{ hr: "HR1136" , count:  1 ,  cat: "N"   ,  remark: " Rana in Becvar. But see HR 188." },$
{ hr: "HR1136" , count:  1 ,  cat: "S"   ,  remark: " CaII H and K emission." },$
{ hr: "HR1136" , count:  1 ,  cat: "VAR" ,  remark: " RS:, 3.51 - 3.56V, about 10d." },$
{ hr: "HR1175" , count:  1 ,  cat: "SB"  ,  remark: " 1911.5d, K 5.2k/s, V0 +51.1k/s, asini 134.  Unresolved by speckle interferometry 1978.96." },$
{ hr: "HR1250" , count:  1 ,  cat: "G"   ,  remark: " Member of the local association (Pleiades group)." },$
{ hr: "HR1250" , count:  1 ,  cat: "VAR" ,  remark: " Lb?, amp. 0.07V." },$
{ hr: "HR1256" , count:  1 ,  cat: "G"   ,  remark: " Hyades?" },$
{ hr: "HR1262" , count:  1 ,  cat: "G"   ,  remark: " Hyades?" },$
{ hr: "HR1326" , count:  1 ,  cat: "G"   ,  remark: " Wolf 630 group." },$
{ hr: "HR1373" , count:  1 ,  cat: "G"   ,  remark: " In Taurus cluster; Mel 25 #41; the Hyades." },$
{ hr: "HR1373" , count:  1 ,  cat: "N"   ,  remark: " Hyadum II." },$
{ hr: "HR1373" , count:  1 ,  cat: "SB"  ,  remark: " 529.8d, K 3.0k/s, V0 +39.5k/s, asini 19.8.  D. W. Dunham indicates 3.9, 13.0v, sep. 0.04." },$
{ hr: "HR1373" , count:  1 ,  cat: "VAR" ,  remark: " Amp. 0.1V." },$
{ hr: "HR1411" , count:  1 ,  cat: "C"   ,  remark: " Color excess E(B-V) = +0.09." },$
{ hr: "HR1411" , count:  1 ,  cat: "D"   ,  remark: " CPM with HR 1412.  Not clear if there are one or two occultation companions: mag. diff 3.8v, sep. 0.082, another" },$
{ hr: "HR1411" , count:  2 ,  cat: "D"   ,  remark: " possible mag. diff 8v, sep. 0.2." },$
{ hr: "HR1411" , count:  1 ,  cat: "G"   ,  remark: " In Hyades cluster; Mel 25 #71." },$
{ hr: "HR1411" , count:  1 ,  cat: "R"   ,  remark: " Diam. 0.0026." },$
{ hr: "HR1411" , count:  1 ,  cat: "SB"  ,  remark: " 6000 or 3000d.  Unresolved by speckle interferometry 1983.93." },$
{ hr: "HR1412" , count:  1 ,  cat: "D"   ,  remark: " CPM with HR 1411.  Close occultation binary, 3.5, 5.8v, sep. 0.005." },$
{ hr: "HR1412" , count:  1 ,  cat: "G"   ,  remark: " Member of Hyades cluster; Mel 25 #72." },$
{ hr: "HR1412" , count:  1 ,  cat: "SB"  ,  remark: " Sep. 0.005, 140.728d, K 31.0k/s, V0 +39.6k/s, asini 39.7, e 0.75." },$
{ hr: "HR1412" , count:  1 ,  cat: "VAR" ,  remark: " Delta Sct, amp. 0.03V (variable), 0.080d.  Possibly also eclipsing." },$
{ hr: "HR1457" , count:  1 ,  cat: "D"   ,  remark: " AB binary.  B is 13.5v, dM2 at 31.  CD, 122 from A is 11.2, 13.6v sep. 2 also binary but independent of AB." },$
{ hr: "HR1457" , count:  1 ,  cat: "DYN" ,  remark: " 0.048." },$
{ hr: "HR1457" , count:  1 ,  cat: "G"   ,  remark: " Hyades group." },$
{ hr: "HR1457" , count:  1 ,  cat: "N"   ,  remark: " ALDEBARAN; Cor Tauri; Parilicium." },$
{ hr: "HR1457" , count:  1 ,  cat: "R"   ,  remark: " Diam.  Two determinations, 0.022 and 0.0237." },$
{ hr: "HR1457" , count:  1 ,  cat: "S"   ,  remark: " IR emission envelope diam. 10. MgII emissions indicate a cooler shell surrounding the supergiant." },$
{ hr: "HR1457" , count:  1 ,  cat: "VAR" ,  remark: " Lb 0.75 - 0.95V.  Var. H and K emission." },$
{ hr: "HR1481" , count:  1 ,  cat: "N"   ,  remark: " Sceptrum." },$
{ hr: "HR1580" , count:  1 ,  cat: "D"   ,  remark: " Optical group." },$
{ hr: "HR1580" , count:  1 ,  cat: "G"   ,  remark: " Hyades?" },$
{ hr: "HR1580" , count:  1 ,  cat: "S"   ,  remark: " Also classified K2IIIbCN-1." },$
{ hr: "HR1577" , count:  1 ,  cat: "N"   ,  remark: " Hassaleh in Becvar." },$
{ hr: "HR1577" , count:  1 ,  cat: "VAR" ,  remark: " 4.0 - 4.15p." },$
{ hr: "HR1652" , count:  1 ,  cat: "DYN" ,  remark: " 0.005." },$
{ hr: "HR1652" , count:  1 ,  cat: "VAR" ,  remark: " Secondary probably variable." },$
{ hr: "HR1663" , count:  1 ,  cat: "VAR" ,  remark: " 6.73 - 6.82p." },$
{ hr: "HR1695" , count:  1 ,  cat: "VAR" ,  remark: " SRb, amp. 0.12:V, 40d." },$
{ hr: "HR1698" , count:  1 ,  cat: "D"   ,  remark: " AB fixed.  B, 8.4v, F7V at 7; C, 11.8 at 182." },$
{ hr: "HR1698" , count:  1 ,  cat: "DYN" ,  remark: " 0.001." },$
{ hr: "HR1698" , count:  1 ,  cat: "S"   ,  remark: " Also classified K0.5III." },$
{ hr: "HR1698" , count:  1 ,  cat: "SB"  ,  remark: " ADS 3797A, 1031.40d, K 8.7k/s, V0 +40.5k/s, asini 123.  Unresolved by speckle interferometry." },$
{ hr: "HR1726" , count:  1 ,  cat: "D"   ,  remark: " CPM." },$
{ hr: "HR1726" , count:  1 ,  cat: "S"   ,  remark: " Also classified K2.5IIIb CN-0.5." },$
{ hr: "HR1726" , count:  1 ,  cat: "SB"  ,  remark: " ADS 3872A, 434.8d, K 14.8k/s, V0 -27.5k/s, asini 88.0." },$
{ hr: "HR1726" , count:  1 ,  cat: "VAR" ,  remark: " ADS 3872A, E?" },$
{ hr: "HR1805" , count:  1 ,  cat: "G"   ,  remark: " Hyades group." },$
{ hr: "HR1829" , count:  1 ,  cat: "D"   ,  remark: " AB binary; C, 12.0v at 64; D, 10.5 at 206; E, 10.5 at 241." },$
{ hr: "HR1829" , count:  1 ,  cat: "DYN" ,  remark: " 0.029." },$
{ hr: "HR1829" , count:  1 ,  cat: "N"   ,  remark: " NIHAL; Nibal." },$
{ hr: "HR1829" , count:  1 ,  cat: "VAR" ,  remark: " ADS 4066B, 7.0 - 11.0v." },$
{ hr: "HR1865" , count:  1 ,  cat: "C"   ,  remark: " U-B values scatter from +0.07 to +0.386." },$
{ hr: "HR1865" , count:  1 ,  cat: "N"   ,  remark: " ARNEB." },$
{ hr: "HR1865" , count:  1 ,  cat: "S"   ,  remark: " Probable magnetic star." },$
{ hr: "HR1922" , count:  1 ,  cat: "RV"  ,  remark: " Same period, originally considered SB in 1924; later identified as pulsating." },$
{ hr: "HR1922" , count:  1 ,  cat: "S"   ,  remark: " Also classified F4-G4Ia-II." },$
{ hr: "HR1922" , count:  1 ,  cat: "VAR" ,  remark: " CDelta 3.46 - 4.08V, 9.84200d.  Period varies." },$
{ hr: "HR1907" , count:  1 ,  cat: "G"   ,  remark: " Sigma Pup group." },$
{ hr: "HR2040" , count:  1 ,  cat: "G"   ,  remark: " 61 Cyg group." },$
{ hr: "HR2040" , count:  1 ,  cat: "N"   ,  remark: " Wezn; Wazn." },$
{ hr: "HR2018" , count:  1 ,  cat: "M"   ,  remark: " High space velocity." },$
{ hr: "HR2018" , count:  1 ,  cat: "S"   ,  remark: " Spectrum may be variable." },$
{ hr: "HR2018" , count:  1 ,  cat: "VAR" ,  remark: " Amp. 0.10V." },$
{ hr: "HR2216" , count:  1 ,  cat: "D"   ,  remark: " AB, 473.7y, a = 1.08.  B is 8.8v at 1.4.  A is suspected occultation double, 3.4, 5.4v, sep.  0.03.  Masses A, 12.4;" },$
{ hr: "HR2216" , count:  2 ,  cat: "D"   ,  remark: " B, 5.5 solar.  The three components are surrounded by a gaseous envelope." },$
{ hr: "HR2216" , count:  1 ,  cat: "DYN" ,  remark: " 0.007." },$
{ hr: "HR2216" , count:  1 ,  cat: "N"   ,  remark: " Propus; Praepes; Tejat Prior." },$
{ hr: "HR2216" , count:  1 ,  cat: "SB"  ,  remark: " ADS 4841A 2983d, K 8.8k/s, V0 +17.6k/s, asini 306.  Unresolved by speckle interferometry 1982.17 and 1983.93." },$
{ hr: "HR2216" , count:  1 ,  cat: "VAR" ,  remark: " ADS 4841A, SRa + EA 3.15 - 3.9v, 232.9d.  Deepest min. satisfy SB period 2984d." },$
{ hr: "HR2269" , count:  1 ,  cat: "VAR" ,  remark: " Lc?, 5.68 - 5.81V." },$
{ hr: "HR2286" , count:  1 ,  cat: "G"   ,  remark: " Zeta Her group." },$
{ hr: "HR2286" , count:  1 ,  cat: "N"   ,  remark: " Tejat Posterior; Calx; Pish Pai." },$
{ hr: "HR2286" , count:  1 ,  cat: "R"   ,  remark: " Occultation diam. = 0.0118 - 0.0160." },$
{ hr: "HR2286" , count:  1 ,  cat: "S"   ,  remark: " Ultraviolet FeII emission." },$
{ hr: "HR2286" , count:  1 ,  cat: "VAR" ,  remark: " Lb 2.76 - 3.02V." },$
{ hr: "HR2326" , count:  1 ,  cat: "G"   ,  remark: " Red star Pleiades group." },$
{ hr: "HR2326" , count:  1 ,  cat: "N"   ,  remark: " CANOPUS; Suhel; Suhail." },$
{ hr: "HR2326" , count:  1 ,  cat: "R"   ,  remark: " Diam. = 0.0061 - 0.0066." },$
{ hr: "HR2326" , count:  1 ,  cat: "S"   ,  remark: " Probable magnetic star." },$
{ hr: "HR2469" , count:  1 ,  cat: "G"   ,  remark: " Wolf 630 group." },$
{ hr: "HR2473" , count:  1 ,  cat: "D"   ,  remark: " Companion 9.22V, +1.13(B-V), +0.91(U-B), K0III-IV." },$
{ hr: "HR2473" , count:  1 ,  cat: "G"   ,  remark: " Red star Pleiades group." },$
{ hr: "HR2473" , count:  1 ,  cat: "N"   ,  remark: " Mebsuta; Melucta; Meboula." },$
{ hr: "HR2473" , count:  1 ,  cat: "R"   ,  remark: " Occultation diam. = 0.0018 - 0.0056." },$
{ hr: "HR2473" , count:  1 ,  cat: "S"   ,  remark: " Strong He 10830 emission and absorption." },$
{ hr: "HR2478" , count:  1 ,  cat: "D"   ,  remark: " Optical." },$
{ hr: "HR2491" , count:  1 ,  cat: "C"   ,  remark: " Color excess E(B-V) = -0.03." },$
{ hr: "HR2491" , count:  1 ,  cat: "D"   ,  remark: " AB -1.46 A1V, 8.49 A1V, 50.090y, a = 7.500 or 49.94y, a = 7.62.  D, 14.0v at 32 from A.  C, companion to B at 1.4" },$
{ hr: "HR2491" , count:  2 ,  cat: "D"   ,  remark: " suspected but not confirmed.  B is first white dwarf ever discovered; predicted by Bessel (1844) on basis of orbital" },$
{ hr: "HR2491" , count:  3 ,  cat: "D"   ,  remark: " motion of Sirius, it was first seen by Alvan Clark in 1862, and its peculiar high temperature, small size and great" },$
{ hr: "HR2491" , count:  4 ,  cat: "D"   ,  remark: " density established by W. Adams in 1925." },$
{ hr: "HR2491" , count:  1 ,  cat: "DYN" ,  remark: " 0.376." },$
{ hr: "HR2491" , count:  1 ,  cat: "G"   ,  remark: " Sirius group; UMa stream." },$
{ hr: "HR2491" , count:  1 ,  cat: "M"   ,  remark: " Soft X-rays observed from Astronomical Netherlands Satellite (ANS).  Sirius B not unusual compared with other dA white" },$
{ hr: "HR2491" , count:  2 ,  cat: "M"   ,  remark: " dwarfs.  Effective temperature about 32000K." },$
{ hr: "HR2491" , count:  1 ,  cat: "N"   ,  remark: " SIRIUS; Canicula; Dog Star; Aschere." },$
{ hr: "HR2491" , count:  1 ,  cat: "R"   ,  remark: " Diam. = 0.00560 - 0.00589." },$
{ hr: "HR2491" , count:  1 ,  cat: "S"   ,  remark: " Cadmium discovered in spectra from COPERNICUS. Iron overabundant by a factor of 5 in comparison with Sun and titanium by" },$
{ hr: "HR2491" , count:  2 ,  cat: "S"   ,  remark: " a factor of 2.  Possibility that the atmosphere of Sirius A polluted by material ejected from Sirius B. Weak magnetic" },$
{ hr: "HR2491" , count:  3 ,  cat: "S"   ,  remark: " field.  Barium abundance greater than solar abundance by about 1.76.  Also classified A/A0/A1." },$
{ hr: "HR2491" , count:  1 ,  cat: "SB"  ,  remark: " 50.04y D, K 2.4k/s, V0 -7.6k/s, asini 487." },$
{ hr: "HR2506" , count:  1 ,  cat: "S"   ,  remark: " Also classified K0III Ba 0.1." },$
{ hr: "HR2574" , count:  1 ,  cat: "G"   ,  remark: " 61 Cyg group." },$
{ hr: "HR2652" , count:  1 ,  cat: "VAR" ,  remark: " Amp. 0.08V." },$
{ hr: "HR2693" , count:  1 ,  cat: "G"   ,  remark: " Member OB group near Omicron CMa; Collinder 121 (#31)." },$
{ hr: "HR2693" , count:  1 ,  cat: "N"   ,  remark: " Wezen; Alwazn; Wesen; Al Wazor." },$
{ hr: "HR2693" , count:  1 ,  cat: "R"   ,  remark: " Diam. = 0.00329 - 0.00360." },$
{ hr: "HR2736" , count:  1 ,  cat: "D"   ,  remark: " Binary with HR 2735.  Combined mag. and colors, 3.63V, +0.91(B-V), +0.60(U-B), +0.48(R-I)." },$
{ hr: "HR2736" , count:  1 ,  cat: "DYN" ,  remark: " 0.018." },$
{ hr: "HR2736" , count:  1 ,  cat: "VAR" ,  remark: " 3.56 - 3.62V, blend with 2735." },$
{ hr: "HR2735" , count:  1 ,  cat: "D"   ,  remark: " Binary with HR 2736." },$
{ hr: "HR2735" , count:  1 ,  cat: "DYN" ,  remark: " 0.018." },$
{ hr: "HR2735" , count:  1 ,  cat: "VAR" ,  remark: " Combined light with HR 2736 varies, but 2736 is probably the variable." },$
{ hr: "HR2697" , count:  1 ,  cat: "D"   ,  remark: " AB CPM." },$
{ hr: "HR2697" , count:  1 ,  cat: "VAR" ,  remark: " 4.3 - 4.36V." },$
{ hr: "HR2821" , count:  1 ,  cat: "N"   ,  remark: " Propus, a name more commonly applied to HR 2216." },$
{ hr: "HR2854" , count:  1 ,  cat: "SB"  ,  remark: " 389.0d, K 18.6k/s, V0 +46.8k/s, asini 94.6.  Unresolved by speckle interferometry." },$
{ hr: "HR2905" , count:  1 ,  cat: "G"   ,  remark: " Wolf 630 group." },$
{ hr: "HR2905" , count:  1 ,  cat: "S"   ,  remark: " Ultraviolet FeII emission." },$
{ hr: "HR2943" , count:  1 ,  cat: "D"   ,  remark: " AB .35 F5IV-V, 10.3, 40.65y, a = 4.548.  Binary nature first revealed in 1840 by variable proper motion; companion" },$
{ hr: "HR2943" , count:  2 ,  cat: "D"   ,  remark: " first seen in 1896. Component C, 11.7v at 122 optical." },$
{ hr: "HR2943" , count:  1 ,  cat: "DYN" ,  remark: " 0.277." },$
{ hr: "HR2943" , count:  1 ,  cat: "N"   ,  remark: " PROCYON; Elgomaisa; Algomeysa; Antecanis." },$
{ hr: "HR2943" , count:  1 ,  cat: "R"   ,  remark: " Diam. = 0.00510 - 0.00550." },$
{ hr: "HR2943" , count:  1 ,  cat: "S"   ,  remark: " Chromospheric He 10830 narrower than in later-type stars." },$
{ hr: "HR2943" , count:  1 ,  cat: "SB"  ,  remark: " 40.65y D, K 1.7k/s, V0 -4.1k/s, asini 324." },$
{ hr: "HR2943" , count:  1 ,  cat: "VAR" ,  remark: " Delta Sct?  A 0.09:d period originally attributed to the star beta CMi (HR 2845) may instead apply to Procyon, which" },$
{ hr: "HR2943" , count:  2 ,  cat: "VAR" ,  remark: " had been used as a comparison star." },$
{ hr: "HR2970" , count:  1 ,  cat: "N"   ,  remark: " In early catalogues called Gamma Mon; HR 2227 now called Gamma, was Alpha in BAC and numerous older" },$
{ hr: "HR2970" , count:  2 ,  cat: "N"   ,  remark: " catalogues." },$
{ hr: "HR2973" , count:  1 ,  cat: "G"   ,  remark: " Eta Cep group." },$
{ hr: "HR2973" , count:  1 ,  cat: "S"   ,  remark: " H alpha emission." },$
{ hr: "HR2973" , count:  1 ,  cat: "SB"  ,  remark: " 19.605d, K 34.2k/s, V0 +45.8k/s, asini 9.22.  Possible radio binary." },$
{ hr: "HR2973" , count:  1 ,  cat: "VAR" ,  remark: " RS 4.13 - 4.29V, 19.423d." },$
{ hr: "HR2985" , count:  1 ,  cat: "DYN" ,  remark: " 0.018." },$
{ hr: "HR2990" , count:  1 ,  cat: "D"   ,  remark: " All the visual companions optical." },$
{ hr: "HR2990" , count:  1 ,  cat: "N"   ,  remark: " POLLUX; Hercules." },$
{ hr: "HR2990" , count:  1 ,  cat: "S"   ,  remark: " Emission line discovered by COPERNICUS at 1218.4 may be OV probably formed in a corona. Balloon-borne spectrometer" },$
{ hr: "HR2990" , count:  2 ,  cat: "S"   ,  remark: " revealed pronounced emission of MgII." },$
{ hr: "HR2990" , count:  1 ,  cat: "VAR" ,  remark: " NSV 3712 is component A, 1.10 - 1.17V, while component E is NSV 3716, 10.5v." },$
{ hr: "HR3003" , count:  1 ,  cat: "D"   ,  remark: " D. W. Dunham gives 5.8, 5.8v, sep. 0.1." },$
{ hr: "HR3003" , count:  1 ,  cat: "G"   ,  remark: " 61 Cyg group." },$
{ hr: "HR3003" , count:  1 ,  cat: "S"   ,  remark: " Also classified K5III." },$
{ hr: "HR3013" , count:  1 ,  cat: "D"   ,  remark: " C optical. Some disagreement as to which of B and C is the brighter." },$
{ hr: "HR3041" , count:  1 ,  cat: "VAR" ,  remark: " Cst 6.14V." },$
{ hr: "HR3045" , count:  1 ,  cat: "N"   ,  remark: " Azmidiske; Asmidiske, a name more properly applied to HR 3699 according to Allen." },$
{ hr: "HR3045" , count:  1 ,  cat: "S"   ,  remark: " Also classified G3Ib." },$
{ hr: "HR3080" , count:  1 ,  cat: "N"   ,  remark: " a Puppis, often misnamed alpha." },$
{ hr: "HR3080" , count:  1 ,  cat: "SB"  ,  remark: " 2660d, K 11.8k/s, V0 +24.0k/s, asini 396.  Unresolved by speckle interferometry 1978.96, 1980.02.  SKYLAB UV spectra" },$
{ hr: "HR3080" , count:  2 ,  cat: "SB"  ,  remark: " spectra indicate cool star with hot subdwarf or white dwarf companion." },$
{ hr: "HR3099" , count:  1 ,  cat: "VAR" ,  remark: " Amp. 0.42V." },$
{ hr: "HR3141" , count:  1 ,  cat: "VAR" ,  remark: " FK Com, amp. 0.020V, 0.025B, 0.030U, 0.207878d." },$
{ hr: "HR3155" , count:  1 ,  cat: "VAR" ,  remark: " Amp. 0.07(U-B)." },$
{ hr: "HR3187" , count:  1 ,  cat: "VAR" ,  remark: " 6.70 - 6.80p." },$
{ hr: "HR3185" , count:  1 ,  cat: "N"   ,  remark: " Called Iota Pup in Argelander's atlas, and in Bayer." },$
{ hr: "HR3185" , count:  1 ,  cat: "S"   ,  remark: " High Fe abundance.  Violet shifted CaII K emission at some phase of light curve." },$
{ hr: "HR3185" , count:  1 ,  cat: "SB"  ,  remark: " 0.14088143d over 60 yr. interval." },$
{ hr: "HR3185" , count:  1 ,  cat: "VAR" ,  remark: " Delta Sct 2.68 - 2.78v, 0.14088143d." },$
{ hr: "HR3225" , count:  1 ,  cat: "VAR" ,  remark: " Lc 4.4 - 4.5V." },$
{ hr: "HR3247" , count:  1 ,  cat: "G"   ,  remark: " Praesepe cluster." },$
{ hr: "HR3243" , count:  1 ,  cat: "SB"  ,  remark: " 930d, K 10.8k/s, V0 +13.5k/s, asini 127." },$
{ hr: "HR3296" , count:  1 ,  cat: "VAR" ,  remark: " 7.9 - 8.03B." },$
{ hr: "HR3319" , count:  1 ,  cat: "G"   ,  remark: " Arcturus group." },$
{ hr: "HR3319" , count:  1 ,  cat: "VAR" ,  remark: " SRb 5.41 - 5.75V, about 40d." },$
{ hr: "HR3357" , count:  1 ,  cat: "D"   ,  remark: " Occultation pair 6.4, 6.4v, blended mag. and colors.  Visual component 10v at 63.  Suspected as double by Innes from" },$
{ hr: "HR3357" , count:  2 ,  cat: "D"   ,  remark: " observation of occultation of April 28, 1898 (references:  Astron. Nachr. 150, 423, 1899; MNRAS, 61, 416, 1901;" },$
{ hr: "HR3357" , count:  3 ,  cat: "D"   ,  remark: " Cape Ann. 2, part 6, 1907)." },$
{ hr: "HR3357" , count:  1 ,  cat: "VAR" ,  remark: " Theta Cnc B is NSV 4117, 11.5v at 58, 59d." },$
{ hr: "HR3431" , count:  1 ,  cat: "VAR" ,  remark: " Amp. 0.05v, 1.43d." },$
{ hr: "HR3445" , count:  1 ,  cat: "C"   ,  remark: " U-B values scatter from +0.22 to +0.54." },$
{ hr: "HR3445" , count:  1 ,  cat: "G"   ,  remark: " Vel OB1." },$
{ hr: "HR3477" , count:  1 ,  cat: "G"   ,  remark: " Possibly member open cluster Trumpler 10." },$
{ hr: "HR3461" , count:  1 ,  cat: "D"   ,  remark: " AP, suspected double, unresolved by speckle interferometry. Visual companion 12.2v at 38 optical." },$
{ hr: "HR3461" , count:  1 ,  cat: "N"   ,  remark: " Asellus Australis." },$
{ hr: "HR3485" , count:  1 ,  cat: "D"   ,  remark: " AB binary with CPM double companion CD at 69.  CD 11.0, 13.5v sep. 6." },$
{ hr: "HR3485" , count:  1 ,  cat: "DYN" ,  remark: " 0.034." },$
{ hr: "HR3485" , count:  1 ,  cat: "G"   ,  remark: " In Ursa cluster? Sirius group?" },$
{ hr: "HR3485" , count:  1 ,  cat: "RV"  ,  remark: " Two determinations of vsini, 0 and 80k/s." },$
{ hr: "HR3475" , count:  1 ,  cat: "D"   ,  remark: " Binary with HR 3474." },$
{ hr: "HR3475" , count:  1 ,  cat: "DYN" ,  remark: " 0.023." },$
{ hr: "HR3475" , count:  1 ,  cat: "S"   ,  remark: " Also classified G8II." },$
{ hr: "HR3475" , count:  1 ,  cat: "VAR" ,  remark: " Probably NSV 4238." },$
{ hr: "HR3474" , count:  1 ,  cat: "D"   ,  remark: " Binary with HR 3475." },$
{ hr: "HR3474" , count:  1 ,  cat: "DYN" ,  remark: " 0.023." },$
{ hr: "HR3474" , count:  1 ,  cat: "VAR" ,  remark: " The magnitude difference between HR 3474 and 3475 appears to vary." },$
{ hr: "HR3482" , count:  1 ,  cat: "D"   ,  remark: " AB 3.8 G5III, 4.7 A8IV or F0V, 15.05y, a = 0.238.  Speckle interferometric sep. 0.263-0.272, 1980-3.  Combined mag.," },$
{ hr: "HR3482" , count:  2 ,  cat: "D"   ,  remark: " colors.  ABxC, 3.4, 7.8, dF7 at 3 from AB, 890y, a = 4.536.  Component D, 12.7v at 19 from A, in hyperbolic orbit" },$
{ hr: "HR3482" , count:  3 ,  cat: "D"   ,  remark: " about ABC, periastron distance, 29." },$
{ hr: "HR3482" , count:  1 ,  cat: "DYN" ,  remark: " 0.018." },$
{ hr: "HR3482" , count:  1 ,  cat: "S"   ,  remark: " Secondary has been classified dF7, later A8IV." },$
{ hr: "HR3482" , count:  1 ,  cat: "SB"  ,  remark: " ADS 6993B, 5492d, K 7.3k/s, V0 +36.4k/s, asini 437.  Secondary period 70d suspected.  ADS 6993C, SB 9.9047d, K" },$
{ hr: "HR3482" , count:  2 ,  cat: "SB"  ,  remark: " 35.0k/s, V0 +31.2, asini 3.74." },$
{ hr: "HR3685" , count:  1 ,  cat: "N"   ,  remark: " Miaplacidus." },$
{ hr: "HR3685" , count:  1 ,  cat: "R"   ,  remark: " Diam. = 0.00151 - 0.00159." },$
{ hr: "HR3685" , count:  1 ,  cat: "VAR" ,  remark: " Balmer lines show quasi periodic var. in cycles of about 35 min." },$
{ hr: "HR3692" , count:  1 ,  cat: "S"   ,  remark: " Also classified K4III." },$
{ hr: "HR3692" , count:  1 ,  cat: "VAR" ,  remark: " 5.08 - 5.14V." },$
{ hr: "HR3699" , count:  1 ,  cat: "N"   ,  remark: " Turais; Tureis; Scutulum; Aspidiske." },$
{ hr: "HR3699" , count:  1 ,  cat: "VAR" ,  remark: " 2.2 - 2.5:v." },$
{ hr: "HR3705" , count:  1 ,  cat: "S"   ,  remark: " Ultraviolet FeII emission." },$
{ hr: "HR3731" , count:  1 ,  cat: "D"   ,  remark: " AB binary." },$
{ hr: "HR3731" , count:  1 ,  cat: "N"   ,  remark: " Al Minliar al Asad." },$
{ hr: "HR3731" , count:  1 ,  cat: "VAR" ,  remark: " NSV 4478 is ADS 7351B, 9.5 - 11.5v." },$
{ hr: "HR3738" , count:  1 ,  cat: "N"   ,  remark: " In many older catalogues called A Hya; in Bayer, 3 stars are near the letter A, of which the brightest is 33 Hya = HR" },$
{ hr: "HR3738" , count:  2 ,  cat: "N"   ,  remark: " 3814, another HR 3750." },$
{ hr: "HR3748" , count:  1 ,  cat: "N"   ,  remark: " ALPHARD; Alfard; Alphart; Kalbelaphard; Cor Hydrae." },$
{ hr: "HR3748" , count:  1 ,  cat: "S"   ,  remark: " Balloon-borne spectrometer revealed pronounced emission of MgII." },$
{ hr: "HR3773" , count:  1 ,  cat: "N"   ,  remark: " Alterf." },$
{ hr: "HR3773" , count:  1 ,  cat: "VAR" ,  remark: " Sp. var., 7 - 12d." },$
{ hr: "HR3779" , count:  1 ,  cat: "D"   ,  remark: " Companion 9.54V, +0.44(B-V), +0.03(U-B), F6V." },$
{ hr: "HR3779" , count:  1 ,  cat: "SB"  ,  remark: " ADS 7416A.  Sp. comp. B, F5." },$
{ hr: "HR3834" , count:  1 ,  cat: "G"   ,  remark: " Zeta Her group." },$
{ hr: "HR3845" , count:  1 ,  cat: "G"   ,  remark: " Wolf 630 group." },$
{ hr: "HR3884" , count:  1 ,  cat: "RV"  ,  remark: " 35.5374d." },$
{ hr: "HR3884" , count:  1 ,  cat: "S"   ,  remark: " Possible circumstellar shell.  Also classified F6Ib-K0Ib." },$
{ hr: "HR3884" , count:  1 ,  cat: "VAR" ,  remark: " CDelta 3.28 - 4.18V, 35.53584d.  Period varies." },$
{ hr: "HR3873" , count:  1 ,  cat: "N"   ,  remark: " Ras Elased Australis; Al Ras al Asad al Janubiyyah; Algenubi; with HR 3905, Al Ashfar." },$
{ hr: "HR3873" , count:  1 ,  cat: "VAR" ,  remark: " Cep amp. 0.1V, period a few days." },$
{ hr: "HR3912" , count:  1 ,  cat: "SB"  ,  remark: " 329.30d, K 14.1k/s, V0 +11.0k/s, asini 63.8." },$
{ hr: "HR3905" , count:  1 ,  cat: "N"   ,  remark: " Ras Elased Borealis; Rasalas; Ras al Asad al Shamaliyy; Alshemali; with HR 3873, Al Ashfar." },$
{ hr: "HR3905" , count:  1 ,  cat: "S"   ,  remark: " Super metal-rich star." },$
{ hr: "HR3980" , count:  1 ,  cat: "D"   ,  remark: " CPM." },$
{ hr: "HR3980" , count:  1 ,  cat: "R"   ,  remark: " Occultation diam = 0.0028 - 0.0031." },$
{ hr: "HR3982" , count:  1 ,  cat: "C"   ,  remark: " Color excess E(B-V) = +0.01." },$
{ hr: "HR3982" , count:  1 ,  cat: "D"   ,  remark: " AB binary, B, 8.13V, +0.86(B-V), +0.51(U-B), K1V. BC, 7.6, 13.1v, 2000y, a = 4.163." },$
{ hr: "HR3982" , count:  1 ,  cat: "N"   ,  remark: " REGULUS; Cor Leonis; Rex; Al Kalb al Asad; Kabeleced." },$
{ hr: "HR3982" , count:  1 ,  cat: "R"   ,  remark: " Diam. = 0.00132 - 0.00137." },$
{ hr: "HR3982" , count:  1 ,  cat: "S"   ,  remark: " C1 neutral carbon continuum shows discontinuities in UV. Excess IR emission." },$
{ hr: "HR3994" , count:  1 ,  cat: "D"   ,  remark: " Visual companions both optical." },$
{ hr: "HR3994" , count:  1 ,  cat: "SB"  ,  remark: " ADS 7671A, 1585.8d, K 3.7k/s, V0 +19.4k/s, asini 79.9.  Unresolved by speckle interferometry." },$
{ hr: "HR4007" , count:  1 ,  cat: "VAR" ,  remark: " Lb? 6.1 - 6.40v." },$
{ hr: "HR4050" , count:  1 ,  cat: "VAR" ,  remark: " Lc? 3.36 - 3.44V." },$
{ hr: "HR4049" , count:  1 ,  cat: "S"   ,  remark: " Lambda Boo star.  Pronounced line weakening makes MK classification unsatisfactory.  Visible spectrum shows weak Ca II" },$
{ hr: "HR4049" , count:  2 ,  cat: "S"   ,  remark: " lines and He I 4021 is absent, as well as expected lines of Fe II and Mg II.  UV spectrum, as obtained with IUE," },$
{ hr: "HR4049" , count:  3 ,  cat: "S"   ,  remark: " anomalous for late B/early A supergiants, showing numerous C I and C II lines.  All spectra indicate very metal-" },$
{ hr: "HR4049" , count:  4 ,  cat: "S"   ,  remark: " deficient star with high C abundance (see Waelkens et al. 1987, The Messenger No. 49, p. 29)." },$
{ hr: "HR4049" , count:  1 ,  cat: "VAR" ,  remark: " Alpha Cyg: 5.30 - 5.65V, amp. 0.65U, about 140d." },$
{ hr: "HR4063" , count:  1 ,  cat: "VAR" ,  remark: " 6.37 - 6.44P, 0.21R." },$
{ hr: "HR4057" , count:  1 ,  cat: "D"   ,  remark: " AB 2.22 K0IIIP, 3.47 G7III, 618.56y, a = 2.505.  B is HR 4058.  Colors for combined light.  Mag. for blend, 1.90V." },$
{ hr: "HR4057" , count:  1 ,  cat: "D"   ,  remark: " Component C is the flare star AD Leo (8.07-11.00B) at 5', optical." },$
{ hr: "HR4057" , count:  1 ,  cat: "DYN" ,  remark: " 0.013." },$
{ hr: "HR4057" , count:  1 ,  cat: "G"   ,  remark: " Gamma Leo group." },$
{ hr: "HR4057" , count:  1 ,  cat: "N"   ,  remark: " ALGIEBA; Algeiba; Al Gieba." },$
{ hr: "HR4057" , count:  1 ,  cat: "VAR" ,  remark: " Originally confused with eclipsing star Y Leo when var. suspect number 6777 was assigned in 1965.  Now HR 4057 is again" },$
{ hr: "HR4057" , count:  2 ,  cat: "VAR" ,  remark: " suspected of variability, 1.84 - 2.03V for combined HR 4057/8.  Uncertain which component is the variable." },$
{ hr: "HR4058" , count:  1 ,  cat: "D"   ,  remark: " See HR 4057." },$
{ hr: "HR4058" , count:  1 ,  cat: "DYN" ,  remark: " 0.013." },$
{ hr: "HR4058" , count:  1 ,  cat: "G"   ,  remark: " Gamma Leo group." },$
{ hr: "HR4058" , count:  1 ,  cat: "VAR" ,  remark: " See HR 4057." },$
{ hr: "HR4104" , count:  1 ,  cat: "G"   ,  remark: " Hyades group." },$
{ hr: "HR4177" , count:  1 ,  cat: "D"   ,  remark: " Fixed.  Combined mag., colors.  Companion A5V." },$
{ hr: "HR4177" , count:  1 ,  cat: "S"   ,  remark: " Also classified K1II, K4Ib-II, K5Ib." },$
{ hr: "HR4179" , count:  1 ,  cat: "D"   ,  remark: " Optical." },$
{ hr: "HR4200" , count:  1 ,  cat: "S"   ,  remark: " Also classified K3Ib." },$
{ hr: "HR4247" , count:  1 ,  cat: "G"   ,  remark: " Wolf 630 group." },$
{ hr: "HR4247" , count:  1 ,  cat: "N"   ,  remark: " Praecipua." },$
{ hr: "HR4257" , count:  1 ,  cat: "VAR" ,  remark: " 3.76 - 3.80V." },$
{ hr: "HR4287" , count:  1 ,  cat: "G"   ,  remark: " 61 Cyg group." },$
{ hr: "HR4287" , count:  1 ,  cat: "N"   ,  remark: " Alkes." },$
{ hr: "HR4337" , count:  1 ,  cat: "G"   ,  remark: " Car OB2; NGC 3532." },$
{ hr: "HR4337" , count:  1 ,  cat: "S"   ,  remark: " Also classified F8Ia-G2Ia." },$
{ hr: "HR4337" , count:  1 ,  cat: "VAR" ,  remark: " Delta Cep? 3.84 - 4.02V." },$
{ hr: "HR4362" , count:  1 ,  cat: "S"   ,  remark: " Ultraviolet FeII emission." },$
{ hr: "HR4362" , count:  1 ,  cat: "VAR" ,  remark: " Lb?, 4.59 - 4.65V." },$
{ hr: "HR4379" , count:  1 ,  cat: "VAR" ,  remark: " 6.0 - 6.6V." },$
{ hr: "HR4377" , count:  1 ,  cat: "D"   ,  remark: " CPM." },$
{ hr: "HR4377" , count:  1 ,  cat: "DYN" ,  remark: " 0.005." },$
{ hr: "HR4377" , count:  1 ,  cat: "N"   ,  remark: " Alula Borealis." },$
{ hr: "HR9089" , count:  1 ,  cat: "S"   ,  remark: " Ultraviolet FeII emission." },$
{ hr: "HR9089" , count:  1 ,  cat: "VAR" ,  remark: " Lb? 4.35 - 4.41V." },$
{ hr: "HR4450" , count:  1 ,  cat: "G"   ,  remark: " Probable Hyades group." },$
{ hr: "HR4471" , count:  1 ,  cat: "D"   ,  remark: " Duplicity doubtful." },$
{ hr: "HR4503" , count:  1 ,  cat: "D"   ,  remark: " AC CPM.  C, 8.44V, +0.50(B-V), +0.035(U-B), F7V." },$
{ hr: "HR4526" , count:  1 ,  cat: "VAR" ,  remark: " 7.0 - 7.12p" },$
{ hr: "HR4564" , count:  1 ,  cat: "D"   ,  remark: " Discovered as double by W. Herschel, sep. 90 but no visual companion subsequently seen at that separation." },$
{ hr: "HR4564" , count:  1 ,  cat: "G"   ,  remark: " Possible Eggen group with HR 63, q.v." },$
{ hr: "HR4564" , count:  1 ,  cat: "SB"  ,  remark: " 6.6254d, K 57.6k/s, V0 -20.4k/s, asini 5.25." },$
{ hr: "HR4700" , count:  1 ,  cat: "G"   ,  remark: " Hyades group." },$
{ hr: "HR4700" , count:  1 ,  cat: "VAR" ,  remark: " I? 3.4 - 4.0v." },$
{ hr: "HR4737" , count:  1 ,  cat: "G"   ,  remark: " Mel 111 #129 (Coma)." },$
{ hr: "HR4786" , count:  1 ,  cat: "N"   ,  remark: " Kraz in Becvar; Allen says unnamed." },$
{ hr: "HR4825" , count:  1 ,  cat: "D"   ,  remark: " AB 3.48 F0V, 3.50 F0V, 171.37y, a = 3.746. Speckle interferometric sep. 3.674, 1982.38.  Combined mag. 2.75V.  Colors" },$
{ hr: "HR4825" , count:  2 ,  cat: "D"   ,  remark: " for combined light.  Component C, 15v at 53, optical." },$
{ hr: "HR4825" , count:  1 ,  cat: "DYN" ,  remark: " 0.084." },$
{ hr: "HR4825" , count:  1 ,  cat: "N"   ,  remark: " Porrima; Arich in Becvar." },$
{ hr: "HR4825" , count:  1 ,  cat: "R"   ,  remark: " Radius 1.5 solar." },$
{ hr: "HR4825" , count:  1 ,  cat: "VAR" ,  remark: " Amp. 0.02V.  Blend with 4826.  Uncertain which component is the variable suspect." },$
{ hr: "HR4826" , count:  1 ,  cat: "D"   ,  remark: " Binary with HR 4825, q.v." },$
{ hr: "HR4826" , count:  1 ,  cat: "DYN" ,  remark: " 0.084." },$
{ hr: "HR4902" , count:  1 ,  cat: "D"   ,  remark: " Close binary, sep. 0.040, unresolved by speckle interferometry.  If companion on main sequence, the inferred spectral" },$
{ hr: "HR4902" , count:  2 ,  cat: "D"   ,  remark: " type is F6V." },$
{ hr: "HR4902" , count:  1 ,  cat: "R"   ,  remark: " Occultation diam. = 0.00492 - 0.0065." },$
{ hr: "HR4902" , count:  1 ,  cat: "S"   ,  remark: " Ultraviolet FeII emission." },$
{ hr: "HR4902" , count:  1 ,  cat: "VAR" ,  remark: " Lb 4.7 - 4.8V." },$
{ hr: "HR4923" , count:  1 ,  cat: "SB"  ,  remark: " 847d, K 7.8k/s, V0 +36.5k/s, asini 83.3." },$
{ hr: "HR4930" , count:  1 ,  cat: "RV"  ,  remark: " Variable emission-line velocity.  vsini 300k/s." },$
{ hr: "HR4930" , count:  1 ,  cat: "S"   ,  remark: " Line width of H alpha emission variable." },$
{ hr: "HR4930" , count:  1 ,  cat: "VAR" ,  remark: " 6.02 - 6.17V.  Miscellaneous magnitude determinations range from 5.93 to 6.132V, probably confirming variability.  Also" },$
{ hr: "HR4930" , count:  2 ,  cat: "VAR" ,  remark: " suspect amp. 0.03V on time scale 2 hrs." },$
{ hr: "HR5002" , count:  1 ,  cat: "VAR" ,  remark: " 6.54 - 6.60p." },$
{ hr: "HR5015" , count:  1 ,  cat: "VAR" ,  remark: " 4.8 - 4.85V." },$
{ hr: "HR5020" , count:  1 ,  cat: "G"   ,  remark: " Sirius group; UMa stream." },$
{ hr: "HR5056" , count:  1 ,  cat: "C"   ,  remark: " Color excess E(B-V) = +0.03." },$
{ hr: "HR5056" , count:  1 ,  cat: "D"   ,  remark: " Interferometer indicates visual component A is multiple system.  Occultations yield three companions: 3.1v at 0.0025," },$
{ hr: "HR5056" , count:  2 ,  cat: "D"   ,  remark: " 4.5 at 0.05 and 7.5 at 0.5.  Combined mag. and colors. Visual component B, 12.0v at 148." },$
{ hr: "HR5056" , count:  1 ,  cat: "N"   ,  remark: " SPICA; Azimech; Spica Virginis; Alaraph, a name also given HR 4540, 4932." },$
{ hr: "HR5056" , count:  1 ,  cat: "R"   ,  remark: " Diam. = 0.00085 - 0.00087." },$
{ hr: "HR5056" , count:  1 ,  cat: "S"   ,  remark: " Also variously classified B2V+B2V, B1.5IV-V+B3V, B1V+B3V.  Rocket observations show hydrogen lines Lyman alpha" },$
{ hr: "HR5056" , count:  2 ,  cat: "S"   ,  remark: " through Zeta." },$
{ hr: "HR5056" , count:  1 ,  cat: "SB"  ,  remark: " 4.0145d, K 120k/s, V0 0k/s, msin3i 7.16, asini 6.52.  Rotation apsides 130 yrs.  Rotational velocity 190k/s." },$
{ hr: "HR5056" , count:  2 ,  cat: "SB"  ,  remark: " vsini secondary 102k/s." },$
{ hr: "HR5056" , count:  1 ,  cat: "VAR" ,  remark: " Ell (Beta C) 0.97 - 1.04V, 4.01454d, and Beta C, 0.1737853d.  Period changes." },$
{ hr: "HR5064" , count:  1 ,  cat: "G"   ,  remark: " 61 Cyg group." },$
{ hr: "HR5089" , count:  1 ,  cat: "D"   ,  remark: " 4.5 G8III, 4.7 G9III, 78.7y, a = 0.165.  Combined mag., colors." },$
{ hr: "HR5089" , count:  1 ,  cat: "DYN" ,  remark: " 0.004." },$
{ hr: "HR5089" , count:  1 ,  cat: "S"   ,  remark: " Luminosity classes discordant:  G8III and G9Ib." },$
{ hr: "HR5192" , count:  1 ,  cat: "VAR" ,  remark: " SRb 4.16 - 4.26V, 5.79 - 5.87P, 12:d." },$
{ hr: "HR5200" , count:  1 ,  cat: "S"   ,  remark: " Ultraviolet FeII emission." },$
{ hr: "HR5219" , count:  1 ,  cat: "VAR" ,  remark: " SR? 4.72 - 4.81V." },$
{ hr: "HR5235" , count:  1 ,  cat: "D"   ,  remark: " A* 2.68 G0IV.  Visual component 8.8v at 113 optical." },$
{ hr: "HR5235" , count:  1 ,  cat: "N"   ,  remark: " Mufrid; Muphrid; Mufride; Muphride." },$
{ hr: "HR5235" , count:  1 ,  cat: "SB"  ,  remark: " 494.173d, K 8.4k/s, V0 +1.0k/s, asini 55.1.  Unresolved by speckle interferometry." },$
{ hr: "HR5267" , count:  1 ,  cat: "C"   ,  remark: " Color excess E(B-V) = +0.02.  Soft X-ray source." },$
{ hr: "HR5267" , count:  1 ,  cat: "G"   ,  remark: " Sco-Cen assoc." },$
{ hr: "HR5267" , count:  1 ,  cat: "N"   ,  remark: " AGENA; HADAR." },$
{ hr: "HR5267" , count:  1 ,  cat: "S"   ,  remark: " Lyman alpha observed from COPERNICUS; spectra revealed MgII emission." },$
{ hr: "HR5267" , count:  1 ,  cat: "SB"  ,  remark: " 0.157d and 352d.  Interferometer measures indicate multiple star." },$
{ hr: "HR5267" , count:  1 ,  cat: "VAR" ,  remark: " Beta C? Amp. 0.07V, 0.157d, modulation 352d. Line profiles also vary per. 0.157d." },$
{ hr: "HR5288" , count:  1 ,  cat: "G"   ,  remark: " Theta Cen group?" },$
{ hr: "HR5288" , count:  1 ,  cat: "N"   ,  remark: " Menkent." },$
{ hr: "HR5315" , count:  1 ,  cat: "S"   ,  remark: " Also classified K3III CN-1." },$
{ hr: "HR5340" , count:  1 ,  cat: "G"   ,  remark: " Arcturus group." },$
{ hr: "HR5340" , count:  1 ,  cat: "M"   ,  remark: " High space velocity?" },$
{ hr: "HR5340" , count:  1 ,  cat: "N"   ,  remark: " ARCTURUS; Haris-el-sema." },$
{ hr: "HR5340" , count:  1 ,  cat: "R"   ,  remark: " Diam. = 0.019 - 0.027." },$
{ hr: "HR5340" , count:  1 ,  cat: "RV"  ,  remark: " Radial velocity varies in period 1.842d." },$
{ hr: "HR5340" , count:  1 ,  cat: "VAR" ,  remark: " H and K emission vary." },$
{ hr: "HR5485" , count:  1 ,  cat: "S"   ,  remark: " Ultraviolet FeII emission.  Also classified as K5III." },$
{ hr: "HR5506" , count:  1 ,  cat: "D"   ,  remark: " Binary with HR 5505.  Colors for combined light. Mag. of blend, 2.37V." },$
{ hr: "HR5506" , count:  1 ,  cat: "DYN" ,  remark: " 0.007." },$
{ hr: "HR5506" , count:  1 ,  cat: "N"   ,  remark: " IZAR; Mirac; Mirak; Mirach; Mizar, a name commonly applied to HR 5054; Pulcherrima." },$
{ hr: "HR5505" , count:  1 ,  cat: "D"   ,  remark: " Binary with HR 5506." },$
{ hr: "HR5505" , count:  1 ,  cat: "DYN" ,  remark: " 0.007." },$
{ hr: "HR5496" , count:  1 ,  cat: "G"   ,  remark: " Zeta Her group." },$
{ hr: "HR5526" , count:  1 ,  cat: "G"   ,  remark: " Sigma Pup group." },$
{ hr: "HR5540" , count:  1 ,  cat: "VAR" ,  remark: " Cst? 7.8p." },$
{ hr: "HR5603" , count:  1 ,  cat: "N"   ,  remark: " Brachium; Cornu; Zuben el Genubi; Zuban al Akrab; Zuben Hakrabi.  Sigma Lib is also Gamma Sco, in Lib." },$
{ hr: "HR5603" , count:  1 ,  cat: "S"   ,  remark: " Ultraviolet FeII emission." },$
{ hr: "HR5603" , count:  1 ,  cat: "VAR" ,  remark: " SRb 3.20 - 3.46V, 20d." },$
{ hr: "HR5649" , count:  1 ,  cat: "D"   ,  remark: " CPM.  B is F8.  Nearly same proper motion as HR 5646, 5647." },$
{ hr: "HR5686" , count:  1 ,  cat: "G"   ,  remark: " Upper Cen group of Sco-Cen assoc." },$
{ hr: "HR5787" , count:  1 ,  cat: "D"   ,  remark: " ADS 9704 AP, sep. 0.097, unresolved by speckle interferometry.  Component B, 11.2v at 42, optical." },$
{ hr: "HR5787" , count:  1 ,  cat: "N"   ,  remark: " Zuben Elakrab; Zuben Hakraki; Zuben el Hakrabi." },$
{ hr: "HR5771" , count:  1 ,  cat: "D"   ,  remark: " Companion A5." },$
{ hr: "HR5797" , count:  1 ,  cat: "D"   ,  remark: " CPM." },$
{ hr: "HR5854" , count:  1 ,  cat: "D"   ,  remark: " SR? Amp. 0.2V. ADS 9765B, optical." },$
{ hr: "HR5854" , count:  1 ,  cat: "N"   ,  remark: " UNUKALHAI; Unuk al Hay; Unuk Elhaia; Unuk; Unukalhay; Cor Serpentis." },$
{ hr: "HR6048" , count:  1 ,  cat: "N"   ,  remark: " See HR 6031." },$
{ hr: "HR6055" , count:  1 ,  cat: "VAR" ,  remark: " Amp. 0.10V." },$
{ hr: "HR6075" , count:  1 ,  cat: "N"   ,  remark: " Yed Posterior." },$
{ hr: "HR6075" , count:  1 ,  cat: "S"   ,  remark: " Oxygen deficient relative to magnesium." },$
{ hr: "HR6072" , count:  1 ,  cat: "G"   ,  remark: " Hyades group." },$
{ hr: "HR6081" , count:  1 ,  cat: "C"   ,  remark: " Probably not IR source.  Heavily reddened.  Analysis of spectral energy distribution (Whittet 1988, MNRAS, 230, 473)" },$
{ hr: "HR6081" , count:  2 ,  cat: "C"   ,  remark: " shows no significant IR excess and possible overluminosity for A5II type." },$
{ hr: "HR6081" , count:  1 ,  cat: "G"   ,  remark: " Sco-Cen assoc.; upper Sco complex." },$
{ hr: "HR6081" , count:  1 ,  cat: "VAR" ,  remark: " Small amp. in V. MgII 4481 appears to vary." },$
{ hr: "HR6136" , count:  1 ,  cat: "G"   ,  remark: " Wolf 630 group." },$
{ hr: "HR6134" , count:  1 ,  cat: "D"   ,  remark: " Var. M1Ib, 5.5 B2.5V, 878y, a = 2.90, masses 15.5 and 7.0 solar.  Companion is radio source. SKYLAB confirms cool star," },$
{ hr: "HR6134" , count:  2 ,  cat: "D"   ,  remark: " hot companion." },$
{ hr: "HR6134" , count:  1 ,  cat: "DYN" ,  remark: " 0.011." },$
{ hr: "HR6134" , count:  1 ,  cat: "G"   ,  remark: " Sco OB2; Sco-Cen stream; in reflection nebula; assoc. Sco R1; dust shell beyond 12 R." },$
{ hr: "HR6134" , count:  1 ,  cat: "N"   ,  remark: " ANTARES; Cor Scorpii; Kalb al Akrab; Vespertilio." },$
{ hr: "HR6134" , count:  1 ,  cat: "R"   ,  remark: " Occultation diam. = 0.041." },$
{ hr: "HR6134" , count:  1 ,  cat: "RV"  ,  remark: " 7.5 yrs." },$
{ hr: "HR6134" , count:  1 ,  cat: "S"   ,  remark: " Ultraviolet FeII emission. 5-micrometer observations indicate carbon monoxide." },$
{ hr: "HR6134" , count:  1 ,  cat: "VAR" ,  remark: " ADS 10074A, SRc 0.88 - 1.8V, 1733d. Possibly considerably fainter before 150 A.D.: see HR 5685." },$
{ hr: "HR6148" , count:  1 ,  cat: "D"   ,  remark: " Visual companion probably optical." },$
{ hr: "HR6148" , count:  1 ,  cat: "N"   ,  remark: " Kornephoros; Korneforos; Rutilicus." },$
{ hr: "HR6148" , count:  1 ,  cat: "SB"  ,  remark: " 410.575d, K 12.8k/s, V0 -25.5k/s, asini 60.4.  Unresolved by speckle interferometry." },$
{ hr: "HR6212" , count:  1 ,  cat: "D"   ,  remark: " ADS 10157AB, 2.90 F9IV, 5.53 G7V, 34.49y, a = 1.355.  ADS 10157A*, 10.5y, a = 0.08." },$
{ hr: "HR6212" , count:  1 ,  cat: "DYN" ,  remark: " 0.096." },$
{ hr: "HR6212" , count:  1 ,  cat: "G"   ,  remark: " Zeta Her group." },$
{ hr: "HR6212" , count:  1 ,  cat: "SB"  ,  remark: " ADS 10157A, 34.417y D, K 3.8k/s, V0 -69.9k/s, asini 590.  Resolved by speckle interferometry." },$
{ hr: "HR6212" , count:  1 ,  cat: "VAR" ,  remark: " ADS 10157A is var. suspect NSV 7915." },$
{ hr: "HR6163" , count:  1 ,  cat: "G"   ,  remark: " 61 Cyg group." },$
{ hr: "HR6257" , count:  1 ,  cat: "VAR" ,  remark: " Amp. 0.14V." },$
{ hr: "HR6271" , count:  1 ,  cat: "G"   ,  remark: " Sco OB1." },$
{ hr: "HR6271" , count:  1 ,  cat: "VAR" ,  remark: " 3.6 - 3.64V." },$
{ hr: "HR6262" , count:  1 ,  cat: "C"   ,  remark: " Strongly reddened." },$
{ hr: "HR6262" , count:  1 ,  cat: "G"   ,  remark: " Possible member of NGC 6231, 30' south of the center of the cluster. See HR 6260." },$
{ hr: "HR6262" , count:  1 ,  cat: "RV"  ,  remark: " Mass loss estimated 0.00005 solar masses/y." },$
{ hr: "HR6262" , count:  1 ,  cat: "S"   ,  remark: " Shell star. Possible H alpha emission." },$
{ hr: "HR6262" , count:  1 ,  cat: "VAR" ,  remark: " Amp. 0.09V.  Variations in HeI, NII, OII suggest turbulent outer layers." },$
{ hr: "HR6266" , count:  1 ,  cat: "G"   ,  remark: " Sco OB1." },$
{ hr: "HR6299" , count:  1 ,  cat: "VAR" ,  remark: " Lb? 3.14 - 3.20V, 4.1 - 5.0p." },$
{ hr: "HR6526" , count:  1 ,  cat: "N"   ,  remark: " Maasym; Masym; Misam, a name also applied to h and Chi Per." },$
{ hr: "HR6556" , count:  1 ,  cat: "D"   ,  remark: " A* 2.08 A5III, 8.5y, a = 0.065.  Resolved by speckle interferometry." },$
{ hr: "HR6556" , count:  1 ,  cat: "G"   ,  remark: " UMa stream; Sirius group." },$
{ hr: "HR6556" , count:  1 ,  cat: "N"   ,  remark: " RASALHAGUE; Ras Alhague." },$
{ hr: "HR6556" , count:  1 ,  cat: "R"   ,  remark: " Diam. = 0.00153 - 0.00163." },$
{ hr: "HR6556" , count:  1 ,  cat: "S"   ,  remark: " Interstellar CaII lines indicate a cloud of about 1 pc depth in front of Alpha Oph." },$
{ hr: "HR6556" , count:  1 ,  cat: "VAR" ,  remark: " Delta Sct?" },$
{ hr: "HR6553" , count:  1 ,  cat: "N"   ,  remark: " Sargas." },$
{ hr: "HR6553" , count:  1 ,  cat: "VAR" ,  remark: " 1.90 - 1.94V?" },$
{ hr: "HR6603" , count:  1 ,  cat: "D"   ,  remark: " Possibly close double." },$
{ hr: "HR6603" , count:  1 ,  cat: "N"   ,  remark: " Cebalrai; Kelb Alrai; Kabalrai; Cheleb; Celb-al-Rai." },$
{ hr: "HR6623" , count:  1 ,  cat: "D"   ,  remark: " BC 10.3 dM4, 10.8, 43.20y, a = 1.360.  This close pair forms a wider physical binary with component A." },$
{ hr: "HR6623" , count:  1 ,  cat: "DYN" ,  remark: " 0.132." },$
{ hr: "HR6623" , count:  1 ,  cat: "G"   ,  remark: " Wolf 630 group." },$
{ hr: "HR6694" , count:  1 ,  cat: "D"   ,  remark: " Fixed with HR 6693." },$
{ hr: "HR6693" , count:  1 ,  cat: "C"   ,  remark: " V magnitudes scatter from 4.98 to 5.14, B-V from +1.62 to +1.76, U-B from +1.52 to +1.93." },$
{ hr: "HR6693" , count:  1 ,  cat: "D"   ,  remark: " Fixed with HR 6694.  Mag. and colors combined light, 4.98V, +1.63(B-V), +1.52(U-B)." },$
{ hr: "HR6693" , count:  1 ,  cat: "VAR" ,  remark: " 4.96 - 5.00V for combined light with 6694. Uncertain which varies, probably 6693." },$
{ hr: "HR6706" , count:  1 ,  cat: "G"   ,  remark: " Arcturus group." },$
{ hr: "HR6713" , count:  1 ,  cat: "G"   ,  remark: " Red star Pleiades group." },$
{ hr: "HR6713" , count:  1 ,  cat: "S"   ,  remark: " Barium star." },$
{ hr: "HR6746" , count:  1 ,  cat: "G"   ,  remark: " Wolf 630 group." },$
{ hr: "HR6746" , count:  1 ,  cat: "N"   ,  remark: " Nash; Alnasl; Alwazl; Zujj al Nushshabah; Nushaba.  Gamma1 or gamma2 Sgr; see HR 6742." },$
{ hr: "HR6816" , count:  1 ,  cat: "S"   ,  remark: " Case infrared spectra indicate M3." },$
{ hr: "HR6832" , count:  1 ,  cat: "S"   ,  remark: " Ultraviolet FeII emission." },$
{ hr: "HR6832" , count:  1 ,  cat: "VAR" ,  remark: " Lb 3.08 - 3.12V." },$
{ hr: "HR6860" , count:  1 ,  cat: "SB"  ,  remark: " 478d, K 16.1k/s, V0 -14.4k/s, asini 97.0." },$
{ hr: "HR6859" , count:  1 ,  cat: "N"   ,  remark: " Kaus Meridionalis; Kaus Media; Media." },$
{ hr: "HR6859" , count:  1 ,  cat: "S"   ,  remark: " K3-IIIa CN0.5 Ba0.2 Fe0.5.  Also classified K3IIIa CN 1 Ba 0.1 Fe 0.5." },$
{ hr: "HR6869" , count:  1 ,  cat: "S"   ,  remark: " Also classified K0III-IV." },$
{ hr: "HR6855" , count:  1 ,  cat: "D"   ,  remark: " Primary of visual double and a suspected astrometric binary." },$
{ hr: "HR6855" , count:  1 ,  cat: "DYN" ,  remark: " 0.008." },$
{ hr: "HR6855" , count:  1 ,  cat: "SB"  ,  remark: " 2214d, K 17.9k/s, V0 +12.4k/s, asini 526.  7 and 6 solar masses.  Secondary of SB may be a collapsed star." },$
{ hr: "HR6879" , count:  1 ,  cat: "N"   ,  remark: " KAUS AUSTRALIS." },$
{ hr: "HR6879" , count:  1 ,  cat: "R"   ,  remark: " Diam. = 0.00137 - 0.00144." },$
{ hr: "HR6879" , count:  1 ,  cat: "RV"  ,  remark: " Two discordant determinations of vsini, 0 and 175k/s." },$
{ hr: "HR6896" , count:  1 ,  cat: "D"   ,  remark: " Companion is A5:." },$
{ hr: "HR6896" , count:  1 ,  cat: "DYN" ,  remark: " 0.006." },$
{ hr: "HR6896" , count:  1 ,  cat: "G"   ,  remark: " Red star Pleiades group." },$
{ hr: "HR6913" , count:  1 ,  cat: "G"   ,  remark: " Hyades group." },$
{ hr: "HR6913" , count:  1 ,  cat: "N"   ,  remark: " Kaus Borealis." },$
{ hr: "HR6913" , count:  1 ,  cat: "R"   ,  remark: " Occult diam. = 0.0044." },$
{ hr: "HR6905" , count:  1 ,  cat: "G"   ,  remark: " Probable Hyades group." },$
{ hr: "HR6973" , count:  1 ,  cat: "VAR" ,  remark: " Amp. 0.10V." },$
{ hr: "HR6982" , count:  1 ,  cat: "G"   ,  remark: " Hyades group." },$
{ hr: "HR7063" , count:  1 ,  cat: "G"   ,  remark: " Sct OB2." },$
{ hr: "HR7063" , count:  1 ,  cat: "S"   ,  remark: " H alpha emission.  Also classified G5II CN0.5 Fe1 Hdel1.  IUE observations indicate a B9.5 companion." },$
{ hr: "HR7063" , count:  1 ,  cat: "SB"  ,  remark: " 834d, K 16.7k/s, V0 -21.9k/s, asini 179.  Unresolved by speckle interferometry." },$
{ hr: "HR7116" , count:  1 ,  cat: "D"   ,  remark: " AB fixed, combined mag., colors.  C, 11.21V, +1.25(B-V), +1.20(U-B), at 28." },$
{ hr: "HR7116" , count:  1 ,  cat: "N"   ,  remark: " Ain al Rami." },$
{ hr: "HR7150" , count:  1 ,  cat: "R"   ,  remark: " Occultation diam. = 0.0030 - 0.0042." },$
{ hr: "HR7176" , count:  1 ,  cat: "C"   ,  remark: " V magnitudes scatter from 5.56 to 5.81, B-V from +0.35 to +0.45, U-B from -0.01 to +0.04." },$
{ hr: "HR7176" , count:  1 ,  cat: "N"   ,  remark: " Deneb el Okab; Deneb. Names combined with HR 7235." },$
{ hr: "HR7234" , count:  1 ,  cat: "G"   ,  remark: " Possibly Wolf 630 group." },$
{ hr: "HR7264" , count:  1 ,  cat: "D"   ,  remark: " AB, combined mag., colors, sep. 0.093.  Third component 6.0v at 0.4." },$
{ hr: "HR7264" , count:  1 ,  cat: "G"   ,  remark: " Red star Pleiades group." },$
{ hr: "HR7264" , count:  1 ,  cat: "N"   ,  remark: " Albaldah; Al Baldah." },$
{ hr: "HR7405" , count:  1 ,  cat: "D"   ,  remark: " Secondary K0." },$
{ hr: "HR7405" , count:  1 ,  cat: "G"   ,  remark: " Arcturus group. Same space motion as Arcturus, HR 5340." },$
{ hr: "HR7405" , count:  1 ,  cat: "N"   ,  remark: " Anser (rarely used)." },$
{ hr: "HR7417" , count:  1 ,  cat: "D"   ,  remark: " 7270.2y, a = 62.90.  Binary with HR 7418.  vsini of B-type component of ADS 12540A 50:k/s.  Component C, 11v at 50." },$
{ hr: "HR7417" , count:  2 ,  cat: "D"   ,  remark: " Two additional components of A resolved by speckle interferometry:  Aa 1981.70, sep. 0.42; Ap 1978.41, sep. 0.12 and" },$
{ hr: "HR7417" , count:  3 ,  cat: "D"   ,  remark: " 1979.46, sep. <0.08." },$
{ hr: "HR7417" , count:  1 ,  cat: "DYN" ,  remark: " 0.009." },$
{ hr: "HR7417" , count:  1 ,  cat: "N"   ,  remark: " ALBIREO." },$
{ hr: "HR7418" , count:  1 ,  cat: "D"   ,  remark: " See HR 7417.  Unresolved by speckle interferometry 1981.47, sep. <0.03." },$
{ hr: "HR7418" , count:  1 ,  cat: "DYN" ,  remark: " 0.009." },$
{ hr: "HR7429" , count:  1 ,  cat: "D"   ,  remark: " B and C optical." },$
{ hr: "HR7475" , count:  1 ,  cat: "D"   ,  remark: " CPM companion B3V." },$
{ hr: "HR7536" , count:  1 ,  cat: "D"   ,  remark: " Suspected visual double probably single image, composite spectrum.  Secondary either B6 or A0V." },$
{ hr: "HR7536" , count:  1 ,  cat: "G"   ,  remark: " In reflection nebula; Gamma Cas-type nebula.  Assoc. of Delta Sge with nebula probable but not certain; nebula" },$
{ hr: "HR7536" , count:  2 ,  cat: "G"   ,  remark: " could be HII region excited by O8f star, 9 Sge, HR 7574." },$
{ hr: "HR7536" , count:  1 ,  cat: "SB"  ,  remark: " 3725d, K 7.5k/s, V0 +1.9k/s, asini 364, vsini of both components =<50k/s." },$
{ hr: "HR7536" , count:  1 ,  cat: "VAR" ,  remark: " Amp. 0.09p." },$
{ hr: "HR7537" , count:  1 ,  cat: "VAR" ,  remark: " Amp. 0.12V." },$
{ hr: "HR7557" , count:  1 ,  cat: "D"   ,  remark: " Component B optical." },$
{ hr: "HR7557" , count:  1 ,  cat: "N"   ,  remark: " ALTAIR; Atair." },$
{ hr: "HR7557" , count:  1 ,  cat: "R"   ,  remark: " Diam. = 0.00278 - 0.00298." },$
{ hr: "HR7570" , count:  1 ,  cat: "S"   ,  remark: " Also classified F6Ib-G4Ib.  UV suggests A0V companion." },$
{ hr: "HR7570" , count:  1 ,  cat: "VAR" ,  remark: " Discovered by Pigott in 1784.  CDelta 3.50 - 4.30V, 7.176641d.  Period changes.  Variable He 10830 in emission and" },$
{ hr: "HR7570" , count:  2 ,  cat: "VAR" ,  remark: " absorption." },$
{ hr: "HR7602" , count:  1 ,  cat: "D"   ,  remark: " AB binary.  B 12v dM3 at 13." },$
{ hr: "HR7602" , count:  1 ,  cat: "DYN" ,  remark: " 0.049." },$
{ hr: "HR7602" , count:  1 ,  cat: "N"   ,  remark: " ALSHAIN; Alschairn." },$
{ hr: "HR7602" , count:  1 ,  cat: "VAR" ,  remark: " ADS 13110A, amp. 0.05V." },$
{ hr: "HR7615" , count:  1 ,  cat: "D"   ,  remark: " AB CPM.  B, 12v at 7.  Other components optical." },$
{ hr: "HR7615" , count:  1 ,  cat: "DYN" ,  remark: " 0.035." },$
{ hr: "HR7604" , count:  1 ,  cat: "N"   ,  remark: " Terebellum, name shared with HR 7597, 7618, 7650." },$
{ hr: "HR7635" , count:  1 ,  cat: "G"   ,  remark: " Hyades group." },$
{ hr: "HR7635" , count:  1 ,  cat: "S"   ,  remark: " Ultraviolet FeII emission." },$
{ hr: "HR7645" , count:  1 ,  cat: "VAR" ,  remark: " Lb? 5.27 - 5.57V, 7.0 - 7.24p." },$
{ hr: "HR7665" , count:  1 ,  cat: "S"   ,  remark: " Metal rich star with normal Doppler broadening." },$
{ hr: "HR7665" , count:  1 ,  cat: "VAR" ,  remark: " 3.52 - 3.65V." },$
{ hr: "HR7747" , count:  1 ,  cat: "D"   ,  remark: " See note for HR 7754.  ADS 13632B, 14v at 44; C, 9.6v K5III, at 45 physical, vsini =<54k/s. D, 14.3v at 29 from C." },$
{ hr: "HR7747" , count:  1 ,  cat: "N"   ,  remark: " Prima Giedi; Algiedi Prima; Algedi with HR 7754." },$
{ hr: "HR7754" , count:  1 ,  cat: "D"   ,  remark: " IDS notes Alpha1 Cap = HR 7747 (ADS 13632, four components) as one of five components of Alpha2 Cap = HR" },$
{ hr: "HR7754" , count:  2 ,  cat: "D"   ,  remark: " 7754 = ADS 13645.  Hence, we have recorded n = 9 for both. ADS 13645AB optical; BC 11.2, 11.5v, sep. 1.2 binary." },$
{ hr: "HR7754" , count:  1 ,  cat: "N"   ,  remark: " Secunda Giedi; Algiedi Secunda; Gredi; Algedi, with HR 7747." },$
{ hr: "HR7754" , count:  1 ,  cat: "D"   ,  remark: " IDS notes Alpha1 Cap = HR 7747 (ADS 13632, four components) as one of five components of Alpha2 Cap = HR" },$
{ hr: "HR7754" , count:  2 ,  cat: "D"   ,  remark: " 7754 = ADS 13645.  Hence, we have recorded n = 9 for both. ADS 13645AB optical; BC 11.2, 11.5v, sep. 1.2 binary." },$
{ hr: "HR7754" , count:  1 ,  cat: "N"   ,  remark: " Secunda Giedi; Algiedi Secunda; Gredi; Algedi, with HR 7747." },$
{ hr: "HR7747" , count:  1 ,  cat: "D"   ,  remark: " See note for HR 7754.  ADS 13632B, 14v at 44; C, 9.6v K5III, at 45 physical, vsini =<54k/s. D, 14.3v at 29 from C." },$
{ hr: "HR7747" , count:  1 ,  cat: "N"   ,  remark: " Prima Giedi; Algiedi Prima; Algedi with HR 7754." },$
{ hr: "HR7776" , count:  1 ,  cat: "D"   ,  remark: " Complex system with HR 7775, q.v.  Component B, vsini 97k/s.  Occultations indicate component A is multiple system: 4.0," },$
{ hr: "HR7776" , count:  2 ,  cat: "D"   ,  remark: " 4.3v sep. 0.0002, 4.8v at 0.022 and 6.7v at 0.0001.  A also suspected astrometric binary, 3.07 F8V.  Possibly also" },$
{ hr: "HR7776" , count:  3 ,  cat: "D"   ,  remark: " two faint 13v components at 112 discovered by John Herschel." },$
{ hr: "HR7776" , count:  1 ,  cat: "N"   ,  remark: " Dabih. Beta1 = Dabih Major; Beta2 = Dabih Minor." },$
{ hr: "HR7776" , count:  1 ,  cat: "R"   ,  remark: " Occultation diam. = 0.00305 - 0.00317.  Diam. primary 0.0033." },$
{ hr: "HR7776" , count:  1 ,  cat: "S"   ,  remark: " Also classified G0III + B8V, K0II-IIIp + A0, B8V + K0II-III, or G8II + A0V:." },$
{ hr: "HR7776" , count:  1 ,  cat: "SB"  ,  remark: " HR 7776-7775 = AxBC.  1374.126d, K 21.9k/s, V0 -18.9k/s, msin3i 3.75, asini 376.  Alternate orbit 1374.23d," },$
{ hr: "HR7776" , count:  2 ,  cat: "SB"  ,  remark: " K 22.44k/s, V0 -18.95k/s, msin3i 3.63, asini 382.5.  Might be eclipsing.  vsini of sceondary 115k/s?" },$
{ hr: "HR7775" , count:  1 ,  cat: "D"   ,  remark: " Complex system with HR 7776, CPM at 205.  ADS 13717A is occultation double, 6.2 - 8.3v, sep. 0.8; also 7.2, 7.2v," },$
{ hr: "HR7775" , count:  2 ,  cat: "D"   ,  remark: " sep. 0.05.  Component B, 10.2v, A1, binary with A at 0.9.  A is astrometric binary.  The close occultation pair is" },$
{ hr: "HR7775" , count:  3 ,  cat: "D"   ,  remark: " questioned; it has not been confirmed by speckle interferometry." },$
{ hr: "HR7775" , count:  1 ,  cat: "SB"  ,  remark: " ADS 13717A = component B of multiple star of which HR 7776 is component A. 8.6780d, K 37.9k/s, asini 4.22.  These are" },$
{ hr: "HR7775" , count:  2 ,  cat: "SB"  ,  remark: " components BC of triple spectroscopic system with HR 7776.  BC sep. 0.0225, mag. diff 1.1.  BC could be eclipsing." },$
{ hr: "HR7775" , count:  3 ,  cat: "SB"  ,  remark: " Component C of the spectroscopic triple system is not the same as any of the visual components of ADS 13717 listed by" },$
{ hr: "HR7775" , count:  4 ,  cat: "SB"  ,  remark: " Worley; nor is it component C of the components Worley lists for HR 7776 = STF 52." },$
{ hr: "HR7806" , count:  1 ,  cat: "S"   ,  remark: " Also classified as K3III." },$
{ hr: "HR7900" , count:  1 ,  cat: "R"   ,  remark: " Occultation diam. = 0.0041 - 0.0086." },$
{ hr: "HR7949" , count:  1 ,  cat: "D"   ,  remark: " AB optical.  C, 13v at 78 CPM." },$
{ hr: "HR7949" , count:  1 ,  cat: "N"   ,  remark: " Gienah Cygni; Gienah, also applied to HR 4662." },$
{ hr: "HR7948" , count:  1 ,  cat: "D"   ,  remark: " See HR 7947." },$
{ hr: "HR7948" , count:  1 ,  cat: "DYN" ,  remark: " 0.033." },$
{ hr: "HR7948" , count:  1 ,  cat: "G"   ,  remark: " Wolf 630 group." },$
{ hr: "HR7947" , count:  1 ,  cat: "D"   ,  remark: " 3249y, a = 13.813.  Binary with HR 7948." },$
{ hr: "HR7947" , count:  1 ,  cat: "DYN" ,  remark: " 0.033." },$
{ hr: "HR7947" , count:  1 ,  cat: "G"   ,  remark: " Wolf 630 group." },$
{ hr: "HR8128" , count:  1 ,  cat: "G"   ,  remark: " Hyades group." },$
{ hr: "HR8173" , count:  1 ,  cat: "D"   ,  remark: " AB CPM.  Companion K0V." },$
{ hr: "HR8173" , count:  1 ,  cat: "SB"  ,  remark: " ADS 14909B." },$
{ hr: "HR8204" , count:  1 ,  cat: "N"   ,  remark: " DM is CoD (star moved from -23d zone to -22d zone between 1855 and 1875).  In Southern Durchmusterung extension" },$
{ hr: "HR8204" , count:  1 ,  cat: "N"   ,  remark: " (Schoenfeld 1886), SD-23d442." },$
{ hr: "HR8204" , count:  1 ,  cat: "S"   ,  remark: " BaII star.  Overabundance of praseodymium.  White dwarf companion." },$
{ hr: "HR8232" , count:  1 ,  cat: "D"   ,  remark: " Both companions optical." },$
{ hr: "HR8232" , count:  1 ,  cat: "G"   ,  remark: " With Alpha Aqr (HR 8414) and Epsilon Peg (HR 8308) forms an OB triple system. Motion of HR 8232 and 8414" },$
{ hr: "HR8232" , count:  2 ,  cat: "G"   ,  remark: " (separated by 12d) is nearly perpendicular to the galactic plane." },$
{ hr: "HR8232" , count:  1 ,  cat: "N"   ,  remark: " Sadalsuud; Sadalsud; Sad es Saud; Sadalsund; Saad el Sund." },$
{ hr: "HR8254" , count:  1 ,  cat: "D"   ,  remark: " A* 3.76 K0III, 2.84y, a = 0.052." },$
{ hr: "HR8254" , count:  1 ,  cat: "G"   ,  remark: " Wolf 630 group." },$
{ hr: "HR8254" , count:  1 ,  cat: "SB"  ,  remark: " 1020d, K 8.0k/s, V0 +34.0k/s, asini 103." },$
{ hr: "HR8308" , count:  1 ,  cat: "C"   ,  remark: " Large infrared excess." },$
{ hr: "HR8308" , count:  1 ,  cat: "D"   ,  remark: " ADS 15268AB optical." },$
{ hr: "HR8308" , count:  1 ,  cat: "G"   ,  remark: " See HR 8232." },$
{ hr: "HR8308" , count:  1 ,  cat: "N"   ,  remark: " ENIF; Enf; Enir; Al Anf; Os Pegasi; Fom." },$
{ hr: "HR8308" , count:  1 ,  cat: "S"   ,  remark: " Ultraviolet FeII emission. MgII emissions indicate a cooler shell surrounding the supergiant. Barium marginally" },$
{ hr: "HR8308" , count:  2 ,  cat: "S"   ,  remark: " overabundant." },$
{ hr: "HR8308" , count:  1 ,  cat: "VAR" ,  remark: " 0.7 - 3.5V.  1.7m flare 1972 Sept. 26-7; fainter than normal following night." },$
{ hr: "HR8350" , count:  1 ,  cat: "VAR" ,  remark: " I, amp. 0.4B." },$
{ hr: "HR8414" , count:  1 ,  cat: "G"   ,  remark: " See HR 8232." },$
{ hr: "HR8414" , count:  1 ,  cat: "N"   ,  remark: " SADALMELIK; Sadalmelek; Sadlamulk; El Melik; Saad el Melik." },$
{ hr: "HR8414" , count:  1 ,  cat: "VAR" ,  remark: " He 10830 possibly variable." },$
{ hr: "HR8436" , count:  1 ,  cat: "VAR" ,  remark: " 6.3 - 7.7:v." },$
{ hr: "HR8502" , count:  1 ,  cat: "D"   ,  remark: " A* 2.85 K3III, 11.5y, a = 0.049." },$
{ hr: "HR8502" , count:  1 ,  cat: "SB"  ,  remark: " 4197.7d, K 7.2k/s, V0 +42.2k/s, asini 383." },$
{ hr: "HR8650" , count:  1 ,  cat: "D"   ,  remark: " A* 2.94 G2II-III, 2.23y, a = 0.022.  Speckle interferometry measures range from unresolved to sep. 0.059. BC, 10.0," },$
{ hr: "HR8650" , count:  2 ,  cat: "D"   ,  remark: " 10.0v sep. 0.2 at 90 from A, physical." },$
{ hr: "HR8650" , count:  1 ,  cat: "N"   ,  remark: " Matar." },$
{ hr: "HR8650" , count:  1 ,  cat: "SB"  ,  remark: " ADS 16211A, 818.0d, K 14.2k/s, V0 +4.3k/s, asini 158, vsini of G8 component 9k/s, F0 component =<50k/s." },$
{ hr: "HR8650" , count:  1 ,  cat: "VAR" ,  remark: " ADS 16211A." },$
{ hr: "HR8667" , count:  1 ,  cat: "S"   ,  remark: " G8IIIa CN1 Ba 0.3 H delta-1" },$
{ hr: "HR8679" , count:  1 ,  cat: "N"   ,  remark: " Sometimes called Tau2 Aqr; usually without superscript." },$
{ hr: "HR8698" , count:  1 ,  cat: "R"   ,  remark: " Occultation diam. = 0.0074." },$
{ hr: "HR8698" , count:  1 ,  cat: "S"   ,  remark: " Ultraviolet FeII emission." },$
{ hr: "HR8698" , count:  1 ,  cat: "VAR" ,  remark: " Lb 3.70 - 3.80V." },$
{ hr: "HR8774" , count:  1 ,  cat: "G"   ,  remark: " Eta Cep group." },$
{ hr: "HR8820" , count:  1 ,  cat: "G"   ,  remark: " Probable Hyades group." },$
{ hr: "HR8820" , count:  1 ,  cat: "SB"  ,  remark: " 409.614d, K 13.6k/s, V0 -4.2k/s, asini 57.5." },$
{ hr: "HR8841" , count:  1 ,  cat: "D"   ,  remark: " BC, 10.0, 10.5v, K3V, 130y, a = 0.6, mean mass BC 0.35 solar. BC combined, 9.19V, +1.03(B-V), +0.93(U-B), CPM with" },$
{ hr: "HR8841" , count:  2 ,  cat: "D"   ,  remark: " A.  Component C is a close double, equal components, showing orbital motion." },$
{ hr: "HR8841" , count:  1 ,  cat: "G"   ,  remark: " Variously described as belonging to the 61 Cyg, Epsilon Ind or Zeta Her groups." },$
{ hr: "HR8852" , count:  1 ,  cat: "M"   ,  remark: " High space velocity?" },$
{ hr: "HR8906" , count:  1 ,  cat: "G"   ,  remark: " Sirius group." },$
{ hr: "HR9004" , count:  1 ,  cat: "G"   ,  remark: " Gamma Leo group." },$
{ hr: "HR9004" , count:  1 ,  cat: "R"   ,  remark: " Occultation diam. = 0.0080 - 0.0102." },$
{ hr: "HR9004" , count:  1 ,  cat: "S"   ,  remark: " Technetium found in spectrum." },$
{ hr: "HR9004" , count:  1 ,  cat: "VAR" ,  remark: " Lb 6.9 - 7.7p." }$
	]


   specphot = [ $
{ name: "HD1522"   },$
{ name: "HD4128"   },$
{ name: "HD6805"   },$
{ name: "HD11353"  },$
{ name: "HD12524"  },$
{ name: "HD27697"  },$
{ name: "HD37160"  },$
{ name: "HD49293"  },$
{ name: "HD81420"  },$
{ name: "HD95272"  },$
{ name: "HD95578"  },$
{ name: "HD101666" },$
{ name: "HD102461" },$
{ name: "HD112213" },$
{ name: "HD116870" },$
{ name: "HD123139" },$
{ name: "HD126927" },$
{ name: "HD133774" },$
{ name: "HD139127" },$
{ name: "HD151249" },$
{ name: "HD156277" },$
{ name: "HD163376" },$
{ name: "HD169916" },$
{ name: "HD175775" },$
{ name: "HD177716" },$
{ name: "HD178345" },$
{ name: "HD196321" },$
{ name: "HD196171" },$
{ name: "HD196917" },$
{ name: "HD198048" },$
{ name: "HD216032" },$
{ name: "HD217902" },$
{ name: "HD218670" },$
{ name: "HD219449" },$
{ name: "HD219784" },$
{ name: "HD113996" },$
{ name: "HD120477" },$
{ name: "HD124897" },$
{ name: "HD187642" },$
{ name: "HD216131" }$
	]

names=strarr(510)
for f=0, N_elements(names)-1 do begin
if strlen(caldb[f].name) eq 5 then names[f]= caldb[f].name +"   "
if strlen(caldb[f].name) eq 6 then names[f]= caldb[f].name +"  "
if strlen(caldb[f].name) eq 7 then names[f]= caldb[f].name +" "
if strlen(caldb[f].name) eq 8 then names[f]= caldb[f].name
endfor


	 wertx = ""
	 werty = ""


	 i=0
	 repeat begin
	 i=i+1
	 openr, lun, ('usercomment.txt'), /get_lun
	 count=Strcompress("(" + String(i)+"(1x,/),A8)", /Remove_all)
	 readf, lun, wertx, format=count
	 free_lun, lun
	 endrep until  wertx eq "file-end"
	 i=i+1

	 hdnumber=strarr(i)
	 usrcmt=strarr(i)


	 i=1
	 repeat begin
	 openr, lun, ('usercomment.txt'), /get_lun
	 count=Strcompress("(" + String(i)+"(1x,/),A8,5x,A80)", /Remove_all)
	 readf, lun, wertx, werty, format=count
	 free_lun, lun
	 hdnumber[i]= wertx
	 usrcmt[i]= werty
	 i=i+1
	 endrep until  wertx eq "file-end"

if not file_test("Output") then spawn,'mkdir "Output"'


;-------------------------------------------------------------------------------------------------------------------------------------



if (not keyword_set(star)) then begin

rect = ''
decl = ''
d = 0
 
read, rect, prompt='Please enter the rectascension: '
read, decl, prompt='Please enter the declination: '
read, d, prompt='Please enter the distance in deg: '


      recta = strsplit(rect, ' ', /extract)
      decli = strsplit(decl, ' ', /extract)

if N_elements(recta) eq 0 then begin
w = '0'
x = '0'
endif

if N_elements(recta) eq 1 then begin
w = recta[0]
x = '0'
endif

if (N_elements(recta) ne 1) and (N_elements(recta) ne 0) then begin
w = recta[0]
x = recta[1]
endif

if N_elements(decli) eq 0 then begin
y = '0'
z = '0'
endif

if N_elements(decli) eq 1 then begin
y = decli[0]
z = '0'
endif

if (N_elements(decli) ne 1) and (N_elements(decli) ne 0) then begin
y = decli[0]
z = decli[1]
endif


      alphahx = float(w)
      alphamx = float(x)
      deltagx = float(y)
      deltamx = float(z)
      filename = Strcompress(String(w) +"_" + String(x) +"_" + String(y) + "_" + String(z) + "_" + String(d) +".txt" , /Remove_all)

      alphax = (alphamx / 60 + alphahx) *15
      if (deltagx ne 0) then deltax = (deltamx * deltagx / abs(deltagx) / 60 + deltagx) else deltax = (deltamx / 60)


if (not keyword_set(path)) then begin
cd,  CURRENT=thisdir
file = filepath(filename, ROOT_DIR=thisdir, SUBDIRECTORY='Output')
endif

if (keyword_set(path)) then begin
fpath = ''
read, fpath, prompt='Please enter filepath: '
file = Strcompress(fpath + filename , /Remove_all)
endif  	  
  
openw, lun, file, /GET_LUN

  for i=0, N_elements(caldb)-1 do begin
      alpha = ((caldb[i].alphas / 60 +caldb[i].alpham) / 60 + caldb[i].alphah) *15
      delta = ((caldb[i].deltas / 60 +caldb[i].deltam) / 60 + caldb[i].deltag) *caldb[i].plusmin
      x = 180/!PI*acos(cos(!PI/180*(90-delta))*cos(!PI/180*(90-deltax))+sin(!PI/180*(90-deltax))*sin(!PI/180*(90-delta))*cos(!PI/180*(alpha-alphax)))
      if (x le d) then begin
         deltag = caldb[i].deltag * caldb[i].plusmin
	 print, ''
	 printf, lun, ''
	 print, caldb[i].name, ':'
	 printf, lun, caldb[i].name, ':'
         if (caldb[i].starname ne "") then print, 'Name: ', caldb[i].starname
	 if (caldb[i].starname ne "") then printf, lun, 'Name: ', caldb[i].starname
	 print, 'Position = ', Strcompress(String(fix(caldb[i].alphah), fix(caldb[i].alpham), caldb[i].alphas, fix(deltag), fix(caldb[i].deltam), caldb[i].deltas))
	 printf, lun, 'Position = ', Strcompress(String(fix(caldb[i].alphah), fix(caldb[i].alpham), caldb[i].alphas, fix(deltag), fix(caldb[i].deltam), caldb[i].deltas))
	 print, 'Distance = ', Strcompress(String(x), /Remove_all), ' deg'
 	 printf, lun, 'Distance = ', Strcompress(String(x), /Remove_all), ' deg'
	 if (caldb[i].diam ne 0.00) then print, 'Diameter = ', Strcompress(String(caldb[i].diam) + " +- " + String(caldb[i].errdiam) +" marcsec") else print, 'Diameter = -'
	 if (caldb[i].diam ne 0.00) then printf, lun, 'Diameter = ', Strcompress(String(caldb[i].diam) + " +- " + String(caldb[i].errdiam) +" marcsec") else printf, lun, 'Diameter = -'
	 print, 'Spectral Type: ', caldb[i].spectype
	 printf, lun, 'Spectral Type: ', caldb[i].spectype
	 print, 'Vmag = ', Strcompress(String(caldb[i].vmag), /Remove_all), ' mag'
	 printf, lun, 'Vmag = ', Strcompress(String(caldb[i].vmag), /Remove_all), ' mag'
	 print, 'Hmag = ', Strcompress(String(caldb[i].hmag), /Remove_all), ' mag'
	 printf, lun, 'Hmag = ', Strcompress(String(caldb[i].hmag), /Remove_all), ' mag'
	 if caldb[i].orig eq "iras" then begin 
	 	if (caldb[i].irastwelvemu eq 0.0) then print, 'N (Iras) = -' else print, Strcompress("N (Iras) = " + String(caldb[i].irastwelvemu) +" Jy")
		if (caldb[i].irastwelvemu eq 0.0) then printf, lun, 'N (Iras) = -' else printf, lun, Strcompress("N (Iras) = " + String(caldb[i].irastwelvemu) +" Jy")
	 endif
	 if caldb[i].orig eq "msx" then begin
	 	if (caldb[i].ftwelve eq 0.0) then print, 'N (Msx) = -' else print, Strcompress("N (Msx) = " + String(caldb[i].ftwelve) +" +- " + String(caldb[i].ones) +" Jy")
		if (caldb[i].ftwelve eq 0.0) then printf, lun, 'N (Msx) = -' else printf, lun, Strcompress("N (Msx) = " + String(caldb[i].ftwelve) +" +- " + String(caldb[i].ones) +" Jy")
	 endif	 
	 print, 'Simbad Remark: ', caldb[i].simrem
	 printf, lun, 'Simbad Remark: ', caldb[i].simrem	 

	 for s=0, N_elements(specphot)-1 do begin
	 if caldb[i].name eq specphot[s].name then begin
	 	print, 'Spectrophotometric Star'
	 	printf, lun, 'Spectrophotometric Star'
	 endif
	 endfor


	 print, ""
	 printf, lun, ""
	 
	 if (caldb[i].hvartype eq "C") then print, 'Hipparcos-defined type of variability: no variability detected ("constant")'
	 if (caldb[i].hvartype eq "D") then print, 'Hipparcos-defined type of variability: duplicity-induced variability'
 	 if (caldb[i].hvartype eq "M") then print, 'Hipparcos-defined type of variability: possibly micro-variable (amplitude < 0.03mag)'
 	 if (caldb[i].hvartype eq "P") then print, 'Hipparcos-defined type of variability: periodic variable'
	 if (caldb[i].hvartype eq "R") then print, 'Hipparcos-defined type of variability: V-I colour index was revised due to variability analysis'			 
	 if (caldb[i].hvartype eq "U") then print, 'Hipparcos-defined type of variability: unsolved variable which does not fall in the other categories'			 	
	 
	 if (caldb[i].multflag eq "C") then print, 'Hipparcos Double/Multiple Systems flag: solutions for the components'			 	
	 if (caldb[i].multflag eq "G") then print, 'Hipparcos Double/Multiple Systems flag: acceleration or higher order terms'			 	
	 if (caldb[i].multflag eq "O") then print, 'Hipparcos Double/Multiple Systems flag: orbital solutions'			 	
	 if (caldb[i].multflag eq "V") then print, 'Hipparcos Double/Multiple Systems flag: variability-induced movers (apparent motion arises from variability)'			 	
	 if (caldb[i].multflag eq "X") then print, 'Hipparcos Double/Multiple Systems flag: stochastic solution (probably astrometric binaries with short period)'			 	
	 
	 if (caldb[i].compid ne "") then print, 'Component identifiers (HIP): ', caldb[i].compid
	 if (caldb[i].rho ne 0.0) then print, 'Angular separation between components (HIP): ',Strcompress(String(caldb[i].rho) +" arcsec")         
	 if (caldb[i].theta ne 0.0) then print, 'Position angle between components (HIP): ',Strcompress(String(caldb[i].theta) +" deg")         
	 if (caldb[i].hdnotes ne "") then print, 'Hipparcos Notes: ', caldb[i].hdnotes
	 
	 if (caldb[i].hvartype eq "C") then printf, lun, 'Hipparcos-defined type of variability: no variability detected ("constant")'
	 if (caldb[i].hvartype eq "D") then printf, lun, 'Hipparcos-defined type of variability: duplicity-induced variability'
 	 if (caldb[i].hvartype eq "M") then printf, lun, 'Hipparcos-defined type of variability: possibly micro-variable (amplitude < 0.03mag)'
 	 if (caldb[i].hvartype eq "P") then printf, lun, 'Hipparcos-defined type of variability: periodic variable'
	 if (caldb[i].hvartype eq "R") then printf, lun, 'Hipparcos-defined type of variability: V-I colour index was revised due to variability analysis'			 
	 if (caldb[i].hvartype eq "U") then printf, lun, 'Hipparcos-defined type of variability: unsolved variable which does not fall in the other categories'			 	
	 
	 if (caldb[i].multflag eq "C") then printf, lun, 'Hipparcos Double/Multiple Systems flag: solutions for the components'			 	
	 if (caldb[i].multflag eq "G") then printf, lun, 'Hipparcos Double/Multiple Systems flag: acceleration or higher order terms'			 	
	 if (caldb[i].multflag eq "O") then printf, lun, 'Hipparcos Double/Multiple Systems flag: orbital solutions'			 	
	 if (caldb[i].multflag eq "V") then printf, lun, 'Hipparcos Double/Multiple Systems flag: variability-induced movers (apparent motion arises from variability)'			 	
	 if (caldb[i].multflag eq "X") then printf, lun, 'Hipparcos Double/Multiple Systems flag: stochastic solution (probably astrometric binaries with short period)'

	 if (caldb[i].compid ne "") then printf, lun, 'Component identifiers (HIP): ', caldb[i].compid
	 if (caldb[i].rho ne 0.0) then printf, lun, 'Angular separation between components (HIP): ',Strcompress(String(caldb[i].rho) +" arcsec")         
	 if (caldb[i].theta ne 0.0) then printf, lun, 'Position angle between components (HIP): ',Strcompress(String(caldb[i].theta) +" deg")         
	 
	 if (not keyword_set(unformat)) then begin
	 if (caldb[i].hdnotes ne "") then begin
	 
	 printf, lun, 'Hipparcos Notes:'
	 
	 if (strlen(caldb[i].hdnotes) le 120) then printf, lun, caldb[i].hdnotes else begin
	 
	 strone = ""
	 strtwo = caldb[i].hdnotes
	 
	 repeat begin
	 strone = strmid(strtwo,0,120)
	 strtwo = strmid(strtwo,120)
	 printf, lun, strone
	 endrep until strlen(strtwo) eq 0
	 
	 endelse
	 endif
	 endif
	 
	 if (keyword_set(unformat)) then begin
	 if (caldb[i].hdnotes ne "") then printf, lun, 'Hipparcos Notes: ', caldb[i].hdnotes
	 endif
	 
	 
	 
	 for j=0, N_elements(hdmcom)-1 do begin
	 	if (caldb[i].name eq hdmcom[j].name) AND (hdmcom[j].seq eq 1) then print, 'Magnitude of component ', hdmcom[j].compid, ' (HIP): ', Strcompress(String(hdmcom[j].hpmag) + " mag")
		if (caldb[i].name eq hdmcom[j].name) AND (hdmcom[j].seq eq 2) then begin
			print, 'Magnitude of component ', hdmcom[j].compid, ' (HIP): ', Strcompress(String(hdmcom[j].hpmag) + " mag")
	 		if (hdmcom[j].type) eq "F" then print, 'Double/multiple solution (HIP): fixed double or multiple system (identical proper motions and parallaxes)'
			if (hdmcom[j].type) eq "I" then print, 'Double/multiple solution (HIP): individual parallaxes and linear (relative) motion (possible optical double star)'
			if (hdmcom[j].type) eq "L" then print, 'Double/multiple solution (HIP): linear double or multiple system (may have different proper motions but assumed to have same parallax)'
			if (hdmcom[j].qual) eq "A" then print, 'Reliability of double/multiple solution (HIP) : good'
			if (hdmcom[j].qual) eq "B" then print, 'Reliability of double/multiple solution (HIP) : fair'
			if (hdmcom[j].qual) eq "C" then print, 'Reliability of double/multiple solution (HIP) : poor'
			if (hdmcom[j].qual) eq "D" then print, 'Reliability of double/multiple solution (HIP) : uncertain'
			print, 'Number of free parameters in solution: ',Strcompress(String(hdmcom[j].nparm))
			if (hdmcom[j].theta ne 0.0) then print, 'Position angle relative to reference component (HIP): ',Strcompress(String(hdmcom[j].theta) +" deg")         
			if (hdmcom[j].rho ne 0.0) then print, 'Separation from reference component (HIP): ',Strcompress(String(hdmcom[j].rho) +" arcsec")         
			if (hdmcom[j].dtheta ne 99.9) then print, 'Rate of change of Position angle (HIP): ',Strcompress(String(hdmcom[j].dtheta) +" deg/yr")         
			if (hdmcom[j].drho ne 99.9) then print, 'Rate of change of Separation (HIP): ',Strcompress(String(hdmcom[j].drho) +" arcsec/yr")         
		endif

	 	if (caldb[i].name eq hdmcom[j].name) AND (hdmcom[j].seq eq 1) then printf, lun, 'Magnitude of component ', hdmcom[j].compid, ' (HIP): ', Strcompress(String(hdmcom[j].hpmag) + " mag")
		if (caldb[i].name eq hdmcom[j].name) AND (hdmcom[j].seq eq 2) then begin
			printf, lun, 'Magnitude of component ', hdmcom[j].compid, ' (HIP): ', Strcompress(String(hdmcom[j].hpmag) + " mag")
	 		if (hdmcom[j].type) eq "F" then printf, lun, 'Double/multiple solution (HIP): fixed double or multiple system (identical proper motions and parallaxes)'
			if (hdmcom[j].type) eq "I" then printf, lun, 'Double/multiple solution (HIP): individual parallaxes and linear (relative) motion (possible optical double star)'
			if (hdmcom[j].type) eq "L" then printf, lun, 'Double/multiple solution (HIP): linear double or multiple system (may have different proper motions but assumed to have same parallax)'
			if (hdmcom[j].qual) eq "A" then printf, lun, 'Reliability of double/multiple solution (HIP) : good'
			if (hdmcom[j].qual) eq "B" then printf, lun, 'Reliability of double/multiple solution (HIP) : fair'
			if (hdmcom[j].qual) eq "C" then printf, lun, 'Reliability of double/multiple solution (HIP) : poor'
			if (hdmcom[j].qual) eq "D" then printf, lun, 'Reliability of double/multiple solution (HIP) : uncertain'
			printf, lun, 'Number of free parameters in solution: ',Strcompress(String(hdmcom[j].nparm))
			if (hdmcom[j].theta ne 0.0) then printf, lun, 'Position angle relative to reference component (HIP): ',Strcompress(String(hdmcom[j].theta) +" deg")         
			if (hdmcom[j].rho ne 0.0) then printf, lun, 'Separation from reference component (HIP): ',Strcompress(String(hdmcom[j].rho) +" arcsec")         
			if (hdmcom[j].dtheta ne 99.9) then printf, lun, 'Rate of change of Position angle (HIP): ',Strcompress(String(hdmcom[j].dtheta) +" deg/yr")         
			if (hdmcom[j].drho ne 99.9) then printf, lun, 'Rate of change of Separation (HIP): ',Strcompress(String(hdmcom[j].drho) +" arcsec/yr")         
		endif

	 endfor
	 
	 for k=0, N_elements(hdmo)-1 do begin
	 if (caldb[i].name eq hdmo[k].name) then begin
	 	print, 'Orbital period (HIP): ',Strcompress(String(hdmo[k].period) +" d")
	 	print, 'Time of periastron passage (HIP): ',Strcompress(String(hdmo[k].time) +" d")
	 	print, 'Semi-major axis of photocentric orbit (HIP): ',Strcompress(String(hdmo[k].axis) +" marcsec")
 	 	print, 'Orbital Eccentricity (HIP): ',Strcompress(String(hdmo[k].ecc))	 
		print, 'Argument of periastron (HIP): ',Strcompress(String(hdmo[k].w) +" deg")
		print, 'Inclination (HIP): ',Strcompress(String(hdmo[k].i) +" deg")
		print, 'Position angle of the node (HIP): ',Strcompress(String(hdmo[k].omega) +" deg")
	 	printf, lun, 'Orbital period (HIP): ',Strcompress(String(hdmo[k].period) +" d")
	 	printf, lun, 'Time of periastron passage (HIP): ',Strcompress(String(hdmo[k].time) +" d")
	 	printf, lun, 'Semi-major axis of photocentric orbit (HIP): ',Strcompress(String(hdmo[k].axis) +" marcsec")
 	 	printf, lun, 'Orbital Eccentricity (HIP): ',Strcompress(String(hdmo[k].ecc))	 
		printf, lun, 'Argument of periastron (HIP): ',Strcompress(String(hdmo[k].w) +" deg")
		printf, lun, 'Inclination (HIP): ',Strcompress(String(hdmo[k].i) +" deg")
		printf, lun, 'Position angle of the node (HIP): ',Strcompress(String(hdmo[k].omega) +" deg")
	 endif
	 endfor
	 
	 print, ""
	 printf, lun, ""
	 
	 for l=0, N_elements(bright)-1 do begin
	 if (caldb[i].name eq bright[l].name) then begin
	 	if (bright[l].multiple) eq "A" then print, 'Double/multiple-star code (HR): Astrometric binary'
	 	if (bright[l].multiple) eq "D" then print, 'Double/multiple-star code (HR): Duplicity discovered by occultation'
	 	if (bright[l].multiple) eq "I" then print, 'Double/multiple-star code (HR): Innes, Southern Double Star Catalogue (1927)'
	 	if (bright[l].multiple) eq "R" then print, 'Double/multiple-star code (HR): Rossiter, Michigan Publ. 9, 1955'
	 	if (bright[l].multiple) eq "S" then print, 'Double/multiple-star code (HR): Duplicity discovered by speckle interferometry'
	 	if (bright[l].multiple) eq "W" then print, 'Double/multiple-star code (HR): Worley (1978) update of the IDS'
		if (bright[l].adscomp ne "") then print, 'ADS number components (HR): ', bright[l].adscomp
	 	if (bright[l].dmag ne 99.9) then print, 'Magnitude difference of double, or brightest multiple (HR): ', Strcompress(String(bright[l].dmag) + " mag")
	 	if (bright[l].sep ne 9999.9) then print, 'Separation of components in Dmag if occultation binary (HR): ', Strcompress(String(bright[l].sep) + " arcsec")
		if (bright[l].multid ne "") then print, 'Identifications of components in Dmag (HR): ', bright[l].multid
		if (bright[l].multcnt ne 0) then print, 'Number of components assigned to a multiple (HR): ', bright[l].multcnt
		
		if (bright[l].multiple) eq "A" then printf, lun, 'Double/multiple-star code (HR): Astrometric binary'
	 	if (bright[l].multiple) eq "D" then printf, lun, 'Double/multiple-star code (HR): Duplicity discovered by occultation'
	 	if (bright[l].multiple) eq "I" then printf, lun, 'Double/multiple-star code (HR): Innes, Southern Double Star Catalogue (1927)'
	 	if (bright[l].multiple) eq "R" then printf, lun, 'Double/multiple-star code (HR): Rossiter, Michigan Publ. 9, 1955'
	 	if (bright[l].multiple) eq "S" then printf, lun, 'Double/multiple-star code (HR): Duplicity discovered by speckle interferometry'
	 	if (bright[l].multiple) eq "W" then printf, lun, 'Double/multiple-star code (HR): Worley (1978) update of the IDS'
		if (bright[l].adscomp ne "") then printf, lun, 'ADS number components (HR): ', bright[l].adscomp
	 	if (bright[l].dmag ne 99.9) then printf, lun, 'Magnitude difference of double, or brightest multiple (HR): ', Strcompress(String(bright[l].dmag) + " mag")
	 	if (bright[l].sep ne 9999.9) then printf, lun, 'Separation of components in Dmag if occultation binary (HR): ', Strcompress(String(bright[l].sep) + " arcsec")
		if (bright[l].multid ne "") then printf, lun, 'Identifications of components in Dmag (HR): ', bright[l].multid
		if (bright[l].multcnt ne 0) then printf, lun, 'Number of components assigned to a multiple (HR): ', bright[l].multcnt
		
		if (bright[l].flag eq "*") then begin
		for m=0, N_elements(brightrem)-1 do begin
			if (bright[l].hr eq brightrem[m].hr) and (brightrem[m].cat eq "D") and (brightrem[m].count eq 1) then print, 'Double/multiple HR remark:', brightrem[m].remark
			if (bright[l].hr eq brightrem[m].hr) and (brightrem[m].cat eq "R") and (brightrem[m].count eq 1) then print, 'Stellar radii/diameters HR remark:', brightrem[m].remark
			if (bright[l].hr eq brightrem[m].hr) and (brightrem[m].cat eq "RV") and (brightrem[m].count eq 1) then print, 'Radial and/or rotational velocities HR remark:', brightrem[m].remark
			if (bright[l].hr eq brightrem[m].hr) and (brightrem[m].cat eq "SB") and (brightrem[m].count eq 1) then print, 'Spectroscopic binaries HR remark:', brightrem[m].remark
			if (bright[l].hr eq brightrem[m].hr) and (brightrem[m].cat eq "M") and (brightrem[m].count eq 1) then print, 'Miscellaneous HR remark:', brightrem[m].remark
			if (bright[l].hr eq brightrem[m].hr) and (brightrem[m].cat eq "VAR") and (brightrem[m].count eq 1) then print, 'Variability HR remark:', brightrem[m].remark
			if (bright[l].hr eq brightrem[m].hr) and (brightrem[m].cat eq "D") and (brightrem[m].count ne 1) then print, brightrem[m].remark
			if (bright[l].hr eq brightrem[m].hr) and (brightrem[m].cat eq "R") and (brightrem[m].count ne 1) then print, brightrem[m].remark
			if (bright[l].hr eq brightrem[m].hr) and (brightrem[m].cat eq "RV") and (brightrem[m].count ne 1) then print, brightrem[m].remark
			if (bright[l].hr eq brightrem[m].hr) and (brightrem[m].cat eq "SB") and (brightrem[m].count ne 1) then print, brightrem[m].remark
			if (bright[l].hr eq brightrem[m].hr) and (brightrem[m].cat eq "M") and (brightrem[m].count ne 1) then print, brightrem[m].remark
			if (bright[l].hr eq brightrem[m].hr) and (brightrem[m].cat eq "VAR") and (brightrem[m].count ne 1) then print, brightrem[m].remark			
			
			if (bright[l].hr eq brightrem[m].hr) and (brightrem[m].cat eq "D") and (brightrem[m].count eq 1) then printf, lun, 'Double/multiple HR remark:', brightrem[m].remark
			if (bright[l].hr eq brightrem[m].hr) and (brightrem[m].cat eq "R") and (brightrem[m].count eq 1) then printf, lun, 'Stellar radii/diameters HR remark:', brightrem[m].remark
			if (bright[l].hr eq brightrem[m].hr) and (brightrem[m].cat eq "RV") and (brightrem[m].count eq 1) then printf, lun, 'Radial and/or rotational velocities HR remark:', brightrem[m].remark
			if (bright[l].hr eq brightrem[m].hr) and (brightrem[m].cat eq "SB") and (brightrem[m].count eq 1) then printf, lun, 'Spectroscopic binaries HR remark:', brightrem[m].remark
			if (bright[l].hr eq brightrem[m].hr) and (brightrem[m].cat eq "M") and (brightrem[m].count eq 1) then printf, lun, 'Miscellaneous HR remark:', brightrem[m].remark
			if (bright[l].hr eq brightrem[m].hr) and (brightrem[m].cat eq "VAR") and (brightrem[m].count eq 1) then printf, lun, 'Variability HR remark:', brightrem[m].remark
			if (bright[l].hr eq brightrem[m].hr) and (brightrem[m].cat eq "D") and (brightrem[m].count ne 1) then printf, lun, brightrem[m].remark
			if (bright[l].hr eq brightrem[m].hr) and (brightrem[m].cat eq "R") and (brightrem[m].count ne 1) then printf, lun, brightrem[m].remark
			if (bright[l].hr eq brightrem[m].hr) and (brightrem[m].cat eq "RV") and (brightrem[m].count ne 1) then printf, lun, brightrem[m].remark
			if (bright[l].hr eq brightrem[m].hr) and (brightrem[m].cat eq "SB") and (brightrem[m].count ne 1) then printf, lun, brightrem[m].remark
			if (bright[l].hr eq brightrem[m].hr) and (brightrem[m].cat eq "M") and (brightrem[m].count ne 1) then printf, lun, brightrem[m].remark
			if (bright[l].hr eq brightrem[m].hr) and (brightrem[m].cat eq "VAR") and (brightrem[m].count ne 1) then printf, lun, brightrem[m].remark



		endfor
		endif



	 endif
	 endfor
	 
	 print, ''
	 printf, lun, ''
	 
	 firsttime=0
	 for q=0, N_elements(usrcmt)-1 do begin
	 if (names[i] eq hdnumber[q]) and (firsttime eq 0) then begin
	 	print, 'User Comment: '
		printf, lun, 'User Comment: '
		firsttime=1
	 endif
	 endfor	
	 	 
	 for p=0, N_elements(usrcmt)-1 do begin
	 	if names[i] eq hdnumber[p] then print, usrcmt[p]
	 	if names[i] eq hdnumber[p] then printf, lun, usrcmt[p]
	 endfor

	 
	 
	 
	 print, ''
	 print, '---------------------------------------------------'
	 printf, lun, ''
	 printf, lun, '---------------------------------------------------'
      endif
  endfor

endif



;----------------------------------------------------------------------------------------------------------------------------------------------------------------------

if (keyword_set(star)) then begin

hdname = ''

read, hdname, prompt='Please enter the HD-Number, e.g. HD402: '
hdname = Strcompress(STRUPCASE(hdname), /Remove_all)
hd = stregex(hdname, '[123456789]')
hdnumb = Strcompress("HD"+strmid(hdname, hd), /Remove_all)


filename = Strcompress(hdnumb +".txt" , /Remove_all)

if (not keyword_set(path)) then begin
cd,  CURRENT=thisdir
file = filepath(filename, ROOT_DIR=thisdir, SUBDIRECTORY='Output')
endif

if (keyword_set(path)) then begin
fpath = ''
read, fpath, prompt='Please enter filepath: '
file = Strcompress(fpath + filename , /Remove_all)
endif  	  
  
openw, lun, file, /GET_LUN

  for i=0, N_elements(caldb)-1 do begin
      if (caldb[i].name eq hdnumb) then begin
         deltag = caldb[i].deltag * caldb[i].plusmin
	 print, ''
	 printf, lun, ''
	 print, caldb[i].name, ':'
	 printf, lun, caldb[i].name, ':'
         if (caldb[i].starname ne "") then print, 'Name: ', caldb[i].starname
	 if (caldb[i].starname ne "") then printf, lun, 'Name: ', caldb[i].starname
	 print, 'Position = ', Strcompress(String(fix(caldb[i].alphah), fix(caldb[i].alpham), caldb[i].alphas, fix(deltag), fix(caldb[i].deltam), caldb[i].deltas))
	 printf, lun, 'Position = ', Strcompress(String(fix(caldb[i].alphah), fix(caldb[i].alpham), caldb[i].alphas, fix(deltag), fix(caldb[i].deltam), caldb[i].deltas))
	 if (caldb[i].diam ne 0.00) then print, 'Diameter = ', Strcompress(String(caldb[i].diam) + " +- " + String(caldb[i].errdiam) +" marcsec") else print, 'Diameter = -'
	 if (caldb[i].diam ne 0.00) then printf, lun, 'Diameter = ', Strcompress(String(caldb[i].diam) + " +- " + String(caldb[i].errdiam) +" marcsec") else printf, lun, 'Diameter = -'
	 print, 'Spectral Type: ', caldb[i].spectype
	 printf, lun, 'Spectral Type: ', caldb[i].spectype
	 print, 'Vmag = ', Strcompress(String(caldb[i].vmag), /Remove_all), ' mag'
	 printf, lun, 'Vmag = ', Strcompress(String(caldb[i].vmag), /Remove_all), ' mag'
	 print, 'Hmag = ', Strcompress(String(caldb[i].hmag), /Remove_all), ' mag'
	 printf, lun, 'Hmag = ', Strcompress(String(caldb[i].hmag), /Remove_all), ' mag'
	 if caldb[i].orig eq "iras" then begin 
	 	if (caldb[i].irastwelvemu eq 0.0) then print, 'N (Iras) = -' else print, Strcompress("N (Iras) = " + String(caldb[i].irastwelvemu) +" Jy")
		if (caldb[i].irastwelvemu eq 0.0) then printf, lun, 'N (Iras) = -' else printf, lun, Strcompress("N (Iras) = " + String(caldb[i].irastwelvemu) +" Jy")
	 endif
	 if caldb[i].orig eq "msx" then begin
	 	if (caldb[i].ftwelve eq 0.0) then print, 'N (Msx) = -' else print, Strcompress("N (Msx) = " + String(caldb[i].ftwelve) +" +- " + String(caldb[i].ones) +" Jy")
		if (caldb[i].ftwelve eq 0.0) then printf, lun, 'N (Msx) = -' else printf, lun, Strcompress("N (Msx) = " + String(caldb[i].ftwelve) +" +- " + String(caldb[i].ones) +" Jy")
	 endif	 
	 print, 'Simbad Remark: ', caldb[i].simrem
	 printf, lun, 'Simbad Remark: ', caldb[i].simrem	 

	 for s=0, N_elements(specphot)-1 do begin
	 if caldb[i].name eq specphot[s].name then begin
	 	print, 'Spectrophotometric Star'
	 	printf, lun, 'Spectrophotometric Star'
	 endif
	 endfor


	 print, ""
	 printf, lun, ""
	 
	 if (caldb[i].hvartype eq "C") then print, 'Hipparcos-defined type of variability: no variability detected ("constant")'
	 if (caldb[i].hvartype eq "D") then print, 'Hipparcos-defined type of variability: duplicity-induced variability'
 	 if (caldb[i].hvartype eq "M") then print, 'Hipparcos-defined type of variability: possibly micro-variable (amplitude < 0.03mag)'
 	 if (caldb[i].hvartype eq "P") then print, 'Hipparcos-defined type of variability: periodic variable'
	 if (caldb[i].hvartype eq "R") then print, 'Hipparcos-defined type of variability: V-I colour index was revised due to variability analysis'			 
	 if (caldb[i].hvartype eq "U") then print, 'Hipparcos-defined type of variability: unsolved variable which does not fall in the other categories'			 	
	 
	 if (caldb[i].multflag eq "C") then print, 'Hipparcos Double/Multiple Systems flag: solutions for the components'			 	
	 if (caldb[i].multflag eq "G") then print, 'Hipparcos Double/Multiple Systems flag: acceleration or higher order terms'			 	
	 if (caldb[i].multflag eq "O") then print, 'Hipparcos Double/Multiple Systems flag: orbital solutions'			 	
	 if (caldb[i].multflag eq "V") then print, 'Hipparcos Double/Multiple Systems flag: variability-induced movers (apparent motion arises from variability)'			 	
	 if (caldb[i].multflag eq "X") then print, 'Hipparcos Double/Multiple Systems flag: stochastic solution (probably astrometric binaries with short period)'			 	
	 
	 if (caldb[i].compid ne "") then print, 'Component identifiers (HIP): ', caldb[i].compid
	 if (caldb[i].rho ne 0.0) then print, 'Angular separation between components (HIP): ',Strcompress(String(caldb[i].rho) +" arcsec")         
	 if (caldb[i].theta ne 0.0) then print, 'Position angle between components (HIP): ',Strcompress(String(caldb[i].theta) +" deg")         
	 if (caldb[i].hdnotes ne "") then print, 'Hipparcos Notes: ', caldb[i].hdnotes
	 
	 if (caldb[i].hvartype eq "C") then printf, lun, 'Hipparcos-defined type of variability: no variability detected ("constant")'
	 if (caldb[i].hvartype eq "D") then printf, lun, 'Hipparcos-defined type of variability: duplicity-induced variability'
 	 if (caldb[i].hvartype eq "M") then printf, lun, 'Hipparcos-defined type of variability: possibly micro-variable (amplitude < 0.03mag)'
 	 if (caldb[i].hvartype eq "P") then printf, lun, 'Hipparcos-defined type of variability: periodic variable'
	 if (caldb[i].hvartype eq "R") then printf, lun, 'Hipparcos-defined type of variability: V-I colour index was revised due to variability analysis'			 
	 if (caldb[i].hvartype eq "U") then printf, lun, 'Hipparcos-defined type of variability: unsolved variable which does not fall in the other categories'			 	
	 
	 if (caldb[i].multflag eq "C") then printf, lun, 'Hipparcos Double/Multiple Systems flag: solutions for the components'			 	
	 if (caldb[i].multflag eq "G") then printf, lun, 'Hipparcos Double/Multiple Systems flag: acceleration or higher order terms'			 	
	 if (caldb[i].multflag eq "O") then printf, lun, 'Hipparcos Double/Multiple Systems flag: orbital solutions'			 	
	 if (caldb[i].multflag eq "V") then printf, lun, 'Hipparcos Double/Multiple Systems flag: variability-induced movers (apparent motion arises from variability)'			 	
	 if (caldb[i].multflag eq "X") then printf, lun, 'Hipparcos Double/Multiple Systems flag: stochastic solution (probably astrometric binaries with short period)'			 	
	 
	 if (caldb[i].compid ne "") then printf, lun, 'Component identifiers (HIP): ', caldb[i].compid
	 if (caldb[i].rho ne 0.0) then printf, lun, 'Angular separation between components (HIP): ',Strcompress(String(caldb[i].rho) +" arcsec")         
	 if (caldb[i].theta ne 0.0) then printf, lun, 'Position angle between components (HIP): ',Strcompress(String(caldb[i].theta) +" deg")         
	 
	 if (not keyword_set(unformat)) then begin
	 if (caldb[i].hdnotes ne "") then begin
	 
	 printf, lun, 'Hipparcos Notes:'
	 
	 if (strlen(caldb[i].hdnotes) le 120) then printf, lun, caldb[i].hdnotes else begin
	 
	 strone = ""
	 strtwo = caldb[i].hdnotes
	 
	 repeat begin
	 strone = strmid(strtwo,0,120)
	 strtwo = strmid(strtwo,120)
	 printf, lun, strone
	 endrep until strlen(strtwo) eq 0
	 
	 endelse
	 endif
	 endif
	 
	 if (keyword_set(unformat)) then begin
	 if (caldb[i].hdnotes ne "") then printf, lun, 'Hipparcos Notes: ', caldb[i].hdnotes
	 endif
	 
	 
	 
	 for j=0, N_elements(hdmcom)-1 do begin
	 	if (caldb[i].name eq hdmcom[j].name) AND (hdmcom[j].seq eq 1) then print, 'Magnitude of component ', hdmcom[j].compid, ' (HIP): ', Strcompress(String(hdmcom[j].hpmag) + " mag")
		if (caldb[i].name eq hdmcom[j].name) AND (hdmcom[j].seq eq 2) then begin
			print, 'Magnitude of component ', hdmcom[j].compid, ' (HIP): ', Strcompress(String(hdmcom[j].hpmag) + " mag")
	 		if (hdmcom[j].type) eq "F" then print, 'Double/multiple solution (HIP): fixed double or multiple system (identical proper motions and parallaxes)'
			if (hdmcom[j].type) eq "I" then print, 'Double/multiple solution (HIP): individual parallaxes and linear (relative) motion (possible optical double star)'
			if (hdmcom[j].type) eq "L" then print, 'Double/multiple solution (HIP): linear double or multiple system (may have different proper motions but assumed to have same parallax)'
			if (hdmcom[j].qual) eq "A" then print, 'Reliability of double/multiple solution (HIP) : good'
			if (hdmcom[j].qual) eq "B" then print, 'Reliability of double/multiple solution (HIP) : fair'
			if (hdmcom[j].qual) eq "C" then print, 'Reliability of double/multiple solution (HIP) : poor'
			if (hdmcom[j].qual) eq "D" then print, 'Reliability of double/multiple solution (HIP) : uncertain'
			print, 'Number of free parameters in solution: ',Strcompress(String(hdmcom[j].nparm))
			if (hdmcom[j].theta ne 0.0) then print, 'Position angle relative to reference component (HIP): ',Strcompress(String(hdmcom[j].theta) +" deg")         
			if (hdmcom[j].rho ne 0.0) then print, 'Separation from reference component (HIP): ',Strcompress(String(hdmcom[j].rho) +" arcsec")         
			if (hdmcom[j].dtheta ne 99.9) then print, 'Rate of change of Position angle (HIP): ',Strcompress(String(hdmcom[j].dtheta) +" deg/yr")         
			if (hdmcom[j].drho ne 99.9) then print, 'Rate of change of Separation (HIP): ',Strcompress(String(hdmcom[j].drho) +" arcsec/yr")         
		endif

	 	if (caldb[i].name eq hdmcom[j].name) AND (hdmcom[j].seq eq 1) then printf, lun, 'Magnitude of component ', hdmcom[j].compid, ' (HIP): ', Strcompress(String(hdmcom[j].hpmag) + " mag")
		if (caldb[i].name eq hdmcom[j].name) AND (hdmcom[j].seq eq 2) then begin
			printf, lun, 'Magnitude of component ', hdmcom[j].compid, ' (HIP): ', Strcompress(String(hdmcom[j].hpmag) + " mag")
	 		if (hdmcom[j].type) eq "F" then printf, lun, 'Double/multiple solution (HIP): fixed double or multiple system (identical proper motions and parallaxes)'
			if (hdmcom[j].type) eq "I" then printf, lun, 'Double/multiple solution (HIP): individual parallaxes and linear (relative) motion (possible optical double star)'
			if (hdmcom[j].type) eq "L" then printf, lun, 'Double/multiple solution (HIP): linear double or multiple system (may have different proper motions but assumed to have same parallax)'
			if (hdmcom[j].qual) eq "A" then printf, lun, 'Reliability of double/multiple solution (HIP) : good'
			if (hdmcom[j].qual) eq "B" then printf, lun, 'Reliability of double/multiple solution (HIP) : fair'
			if (hdmcom[j].qual) eq "C" then printf, lun, 'Reliability of double/multiple solution (HIP) : poor'
			if (hdmcom[j].qual) eq "D" then printf, lun, 'Reliability of double/multiple solution (HIP) : uncertain'
			printf, lun, 'Number of free parameters in solution: ',Strcompress(String(hdmcom[j].nparm))
			if (hdmcom[j].theta ne 0.0) then printf, lun, 'Position angle relative to reference component (HIP): ',Strcompress(String(hdmcom[j].theta) +" deg")         
			if (hdmcom[j].rho ne 0.0) then printf, lun, 'Separation from reference component (HIP): ',Strcompress(String(hdmcom[j].rho) +" arcsec")         
			if (hdmcom[j].dtheta ne 99.9) then printf, lun, 'Rate of change of Position angle (HIP): ',Strcompress(String(hdmcom[j].dtheta) +" deg/yr")         
			if (hdmcom[j].drho ne 99.9) then printf, lun, 'Rate of change of Separation (HIP): ',Strcompress(String(hdmcom[j].drho) +" arcsec/yr")         
		endif

	 endfor
	 
	 for k=0, N_elements(hdmo)-1 do begin
	 if (caldb[i].name eq hdmo[k].name) then begin
	 	print, 'Orbital period (HIP): ',Strcompress(String(hdmo[k].period) +" d")
	 	print, 'Time of periastron passage (HIP): ',Strcompress(String(hdmo[k].time) +" d")
	 	print, 'Semi-major axis of photocentric orbit (HIP): ',Strcompress(String(hdmo[k].axis) +" marcsec")
 	 	print, 'Orbital Eccentricity (HIP): ',Strcompress(String(hdmo[k].ecc))	 
		print, 'Argument of periastron (HIP): ',Strcompress(String(hdmo[k].w) +" deg")
		print, 'Inclination (HIP): ',Strcompress(String(hdmo[k].i) +" deg")
		print, 'Position angle of the node (HIP): ',Strcompress(String(hdmo[k].omega) +" deg")
	 	printf, lun, 'Orbital period (HIP): ',Strcompress(String(hdmo[k].period) +" d")
	 	printf, lun, 'Time of periastron passage (HIP): ',Strcompress(String(hdmo[k].time) +" d")
	 	printf, lun, 'Semi-major axis of photocentric orbit (HIP): ',Strcompress(String(hdmo[k].axis) +" marcsec")
 	 	printf, lun, 'Orbital Eccentricity (HIP): ',Strcompress(String(hdmo[k].ecc))	 
		printf, lun, 'Argument of periastron (HIP): ',Strcompress(String(hdmo[k].w) +" deg")
		printf, lun, 'Inclination (HIP): ',Strcompress(String(hdmo[k].i) +" deg")
		printf, lun, 'Position angle of the node (HIP): ',Strcompress(String(hdmo[k].omega) +" deg")
	 endif
	 endfor
	 
	 print, ""
	 printf, lun, ""
	 
	 for l=0, N_elements(bright)-1 do begin
	 if (caldb[i].name eq bright[l].name) then begin
	 	if (bright[l].multiple) eq "A" then print, 'Double/multiple-star code (HR): Astrometric binary'
	 	if (bright[l].multiple) eq "D" then print, 'Double/multiple-star code (HR): Duplicity discovered by occultation'
	 	if (bright[l].multiple) eq "I" then print, 'Double/multiple-star code (HR): Innes, Southern Double Star Catalogue (1927)'
	 	if (bright[l].multiple) eq "R" then print, 'Double/multiple-star code (HR): Rossiter, Michigan Publ. 9, 1955'
	 	if (bright[l].multiple) eq "S" then print, 'Double/multiple-star code (HR): Duplicity discovered by speckle interferometry'
	 	if (bright[l].multiple) eq "W" then print, 'Double/multiple-star code (HR): Worley (1978) update of the IDS'
		if (bright[l].adscomp ne "") then print, 'ADS number components (HR): ', bright[l].adscomp
	 	if (bright[l].dmag ne 99.9) then print, 'Magnitude difference of double, or brightest multiple (HR): ', Strcompress(String(bright[l].dmag) + " mag")
	 	if (bright[l].sep ne 9999.9) then print, 'Separation of components in Dmag if occultation binary (HR): ', Strcompress(String(bright[l].sep) + " arcsec")
		if (bright[l].multid ne "") then print, 'Identifications of components in Dmag (HR): ', bright[l].multid
		if (bright[l].multcnt ne 0) then print, 'Number of components assigned to a multiple (HR): ', bright[l].multcnt
		
		if (bright[l].multiple) eq "A" then printf, lun, 'Double/multiple-star code (HR): Astrometric binary'
	 	if (bright[l].multiple) eq "D" then printf, lun, 'Double/multiple-star code (HR): Duplicity discovered by occultation'
	 	if (bright[l].multiple) eq "I" then printf, lun, 'Double/multiple-star code (HR): Innes, Southern Double Star Catalogue (1927)'
	 	if (bright[l].multiple) eq "R" then printf, lun, 'Double/multiple-star code (HR): Rossiter, Michigan Publ. 9, 1955'
	 	if (bright[l].multiple) eq "S" then printf, lun, 'Double/multiple-star code (HR): Duplicity discovered by speckle interferometry'
	 	if (bright[l].multiple) eq "W" then printf, lun, 'Double/multiple-star code (HR): Worley (1978) update of the IDS'
		if (bright[l].adscomp ne "") then printf, lun, 'ADS number components (HR): ', bright[l].adscomp
	 	if (bright[l].dmag ne 99.9) then printf, lun, 'Magnitude difference of double, or brightest multiple (HR): ', Strcompress(String(bright[l].dmag) + " mag")
	 	if (bright[l].sep ne 9999.9) then printf, lun, 'Separation of components in Dmag if occultation binary (HR): ', Strcompress(String(bright[l].sep) + " arcsec")
		if (bright[l].multid ne "") then printf, lun, 'Identifications of components in Dmag (HR): ', bright[l].multid
		if (bright[l].multcnt ne 0) then printf, lun, 'Number of components assigned to a multiple (HR): ', bright[l].multcnt
		
		if (bright[l].flag eq "*") then begin
		for m=0, N_elements(brightrem)-1 do begin
			if (bright[l].hr eq brightrem[m].hr) and (brightrem[m].cat eq "D") and (brightrem[m].count eq 1) then print, 'Double/multiple HR remark:', brightrem[m].remark
			if (bright[l].hr eq brightrem[m].hr) and (brightrem[m].cat eq "R") and (brightrem[m].count eq 1) then print, 'Stellar radii/diameters HR remark:', brightrem[m].remark
			if (bright[l].hr eq brightrem[m].hr) and (brightrem[m].cat eq "RV") and (brightrem[m].count eq 1) then print, 'Radial and/or rotational velocities HR remark:', brightrem[m].remark
			if (bright[l].hr eq brightrem[m].hr) and (brightrem[m].cat eq "SB") and (brightrem[m].count eq 1) then print, 'Spectroscopic binaries HR remark:', brightrem[m].remark
			if (bright[l].hr eq brightrem[m].hr) and (brightrem[m].cat eq "M") and (brightrem[m].count eq 1) then print, 'Miscellaneous HR remark:', brightrem[m].remark
			if (bright[l].hr eq brightrem[m].hr) and (brightrem[m].cat eq "VAR") and (brightrem[m].count eq 1) then print, 'Variability HR remark:', brightrem[m].remark
			if (bright[l].hr eq brightrem[m].hr) and (brightrem[m].cat eq "D") and (brightrem[m].count ne 1) then print, brightrem[m].remark
			if (bright[l].hr eq brightrem[m].hr) and (brightrem[m].cat eq "R") and (brightrem[m].count ne 1) then print, brightrem[m].remark
			if (bright[l].hr eq brightrem[m].hr) and (brightrem[m].cat eq "RV") and (brightrem[m].count ne 1) then print, brightrem[m].remark
			if (bright[l].hr eq brightrem[m].hr) and (brightrem[m].cat eq "SB") and (brightrem[m].count ne 1) then print, brightrem[m].remark
			if (bright[l].hr eq brightrem[m].hr) and (brightrem[m].cat eq "M") and (brightrem[m].count ne 1) then print, brightrem[m].remark
			if (bright[l].hr eq brightrem[m].hr) and (brightrem[m].cat eq "VAR") and (brightrem[m].count ne 1) then print, brightrem[m].remark			
			
			if (bright[l].hr eq brightrem[m].hr) and (brightrem[m].cat eq "D") and (brightrem[m].count eq 1) then printf, lun, 'Double/multiple HR remark:', brightrem[m].remark
			if (bright[l].hr eq brightrem[m].hr) and (brightrem[m].cat eq "R") and (brightrem[m].count eq 1) then printf, lun, 'Stellar radii/diameters HR remark:', brightrem[m].remark
			if (bright[l].hr eq brightrem[m].hr) and (brightrem[m].cat eq "RV") and (brightrem[m].count eq 1) then printf, lun, 'Radial and/or rotational velocities HR remark:', brightrem[m].remark
			if (bright[l].hr eq brightrem[m].hr) and (brightrem[m].cat eq "SB") and (brightrem[m].count eq 1) then printf, lun, 'Spectroscopic binaries HR remark:', brightrem[m].remark
			if (bright[l].hr eq brightrem[m].hr) and (brightrem[m].cat eq "M") and (brightrem[m].count eq 1) then printf, lun, 'Miscellaneous HR remark:', brightrem[m].remark
			if (bright[l].hr eq brightrem[m].hr) and (brightrem[m].cat eq "VAR") and (brightrem[m].count eq 1) then printf, lun, 'Variability HR remark:', brightrem[m].remark
			if (bright[l].hr eq brightrem[m].hr) and (brightrem[m].cat eq "D") and (brightrem[m].count ne 1) then printf, lun, brightrem[m].remark
			if (bright[l].hr eq brightrem[m].hr) and (brightrem[m].cat eq "R") and (brightrem[m].count ne 1) then printf, lun, brightrem[m].remark
			if (bright[l].hr eq brightrem[m].hr) and (brightrem[m].cat eq "RV") and (brightrem[m].count ne 1) then printf, lun, brightrem[m].remark
			if (bright[l].hr eq brightrem[m].hr) and (brightrem[m].cat eq "SB") and (brightrem[m].count ne 1) then printf, lun, brightrem[m].remark
			if (bright[l].hr eq brightrem[m].hr) and (brightrem[m].cat eq "M") and (brightrem[m].count ne 1) then printf, lun, brightrem[m].remark
			if (bright[l].hr eq brightrem[m].hr) and (brightrem[m].cat eq "VAR") and (brightrem[m].count ne 1) then printf, lun, brightrem[m].remark



		endfor
		endif



	 endif
	 endfor
	 
	 print, ''
	 printf, lun, ''
	 
	 firsttime=0
	 for q=0, N_elements(usrcmt)-1 do begin
	 if (names[i] eq hdnumber[q]) and (firsttime eq 0) then begin
	 	print, 'User Comment: '
		printf, lun, 'User Comment: '
		firsttime=1
	 endif
	 endfor	
	 	 
	 for p=0, N_elements(usrcmt)-1 do begin
	 	if names[i] eq hdnumber[p] then print, usrcmt[p]
	 	if names[i] eq hdnumber[p] then printf, lun, usrcmt[p]
	 endfor

	 
	 
	 
	 print, ''
	 print, '---------------------------------------------------'
	 printf, lun, ''
	 printf, lun, '---------------------------------------------------'
      endif
  endfor

endif



free_lun, lun

end


